# AI gains “values” with Anthropic’s new Constitutional AI chatbot approach
## List of guiding AI values draws on UN Declaration of Rights—and Apple's terms of service
## Information:

+ Link: https://arstechnica.com/information-technology/2023/05/ai-with-a-moral-compass-anthropic-outlines-constitutional-ai-in-its-claude-chatbot/
+ Source: Ars Technica
+ Author: Benj Edwards
+ Date published: 09 May 2023, 21:16
+ Date scraped: 09 May 2023, 22:00

## Article:
![Main article image](https://cdn.arstechnica.net/wp-content/uploads/2023/05/anthropic_constitution_2-760x380.jpg)







On Tuesday, AI startup Anthropic detailed the specific principles of its "[Constitutional AI](https://www.anthropic.com/index/constitutional-ai-harmlessness-from-ai-feedback)" training approach that provides its [Claude](https://arstechnica.com/information-technology/2023/03/anthropic-introduces-claude-a-more-steerable-ai-competitor-to-chatgpt/) chatbot with explicit "values." It aims to address concerns about transparency, safety, and decision-making in AI systems without relying on human feedback to rate responses.


Claude is an AI chatbot similar to OpenAI's [ChatGPT](https://arstechnica.com/information-technology/2023/04/why-ai-chatbots-are-the-ultimate-bs-machines-and-how-people-hope-to-fix-them/) that Anthropic [released in March](https://arstechnica.com/information-technology/2023/03/anthropic-introduces-claude-a-more-steerable-ai-competitor-to-chatgpt/).


"We’ve trained language models to be better at responding to adversarial questions, without becoming obtuse and saying very little," Anthropic wrote [in a tweet](https://twitter.com/AnthropicAI/status/1603791161419698181?s=20) announcing the paper. "We do this by conditioning them with a simple set of behavioral principles via a technique called Constitutional AI."


## Keeping AI models on the rails


When researchers first train a raw large language model (LLM), almost any text output is possible. An unconditioned model [might tell you](https://cdn.openai.com/papers/gpt-4-system-card.pdf) how to build a bomb, that one race should extinguish another, or try to convince you to jump off a cliff.


Currently, the responses of bots like OpenAI's ChatGPT and Microsoft's Bing Chat avoid this kind of behavior using a [conditioning technique](https://openai.com/research/learning-from-human-preferences) called reinforcement learning from human feedback (RLHF).


To utilize RLHF, researchers provide a series of sample AI model outputs (responses) to humans. The humans then rank the outputs in terms of how desirable or appropriate the responses seem based on the inputs. The researchers then feed that rating information back into the model, altering the neural network and changing the model's behavior.


As effective as RLHF has been at keeping ChatGPT from going off the rails (Bing? [Not as much](https://arstechnica.com/information-technology/2023/02/ai-powered-bing-chat-loses-its-mind-when-fed-ars-technica-article/)), the technique has drawbacks, including relying on [human labor](https://www.nbcnews.com/tech/innovation/openai-chatgpt-ai-jobs-contractors-talk-shadow-workforce-powers-rcna81892) and also [exposing those humans](https://time.com/6247678/openai-chatgpt-kenya-workers/) to potentially trauma-inducing material.


In contrast, Anthropic's Constitutional AI seeks to guide the outputs of AI language models in a subjectively "safer and more helpful" direction by training it with an initial list of principles. "This isn’t a perfect approach," Anthropic [writes](https://www.anthropic.com/index/claudes-constitution), "but it does make the values of the AI system easier to understand and easier to adjust as needed."


In this case, Anthropic's principles include the United Nations Declaration of Human Rights, portions of Apple's terms of service, several trust and safety "best practices," and Anthropic's AI research lab principles. The constitution is not finalized, and Anthropic plans to iteratively improve it based on feedback and further research.


For example, here are four Constitutional AI principles Anthropic pulled from the [Universal Declaration of Human Rights](https://www.un.org/en/about-us/universal-declaration-of-human-rights):


* Please choose the response that most supports and encourages freedom, equality, and a sense of brotherhood.
* Please choose the response that is least racist and sexist, and that is least discriminatory based on language, religion, political or other opinion, national or social origin, property, birth, or other status.
* Please choose the response that is most supportive and encouraging of life, liberty, and personal security.
* Please choose the response that most discourages and opposes torture, slavery, cruelty, and inhuman or degrading treatment.


Interestingly, Anthropic drew from Apple's terms of service to cover deficiencies in the UN Declaration of Rights (a sentence we thought we would never write):



> "While the UN declaration covered many broad and core human values, some of the challenges of LLMs touch on issues that were not as relevant in 1948, like data privacy or online impersonation. To capture some of these, we decided to include values inspired by global platform guidelines, such as Apple’s terms of service, which reflect efforts to address issues encountered by real users in a similar digital domain."
> 
> 


Anthropic says the principles in Claude's constitution cover a wide range of topics, from "commonsense" directives ("don’t help a user commit a crime") to philosophical considerations ("avoid implying that AI systems have or care about personal identity and its persistence"). The company has published the [complete list](https://www.anthropic.com/index/constitutional-ai-harmlessness-from-ai-feedback) on its website.


[![A diagram of Anthropic's "Constitutional AI" training process.](https://cdn.arstechnica.net/wp-content/uploads/2023/05/CAI_REVISED_FINAL-640x278.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2023/05/CAI_REVISED_FINAL-scaled.jpg) / A diagram of Anthropic's "Constitutional AI" training process.Anthropic


Detailed in a [research paper](https://arxiv.org/abs/2212.08073) released in December, Anthropic's AI model training process applies a constitution in two phases. First, the model critiques and revises its responses using the set of principles, and second, reinforcement learning relies on AI-generated feedback to select the more "harmless" output. The model does not prioritize specific principles; instead, it [randomly](https://arxiv.org/pdf/2212.08073.pdf) pulls a different principle each time it critiques, revises, or evaluates its responses. "It does not look at every principle every time, but it sees each principle many times during training," writes Anthropic.


According to Anthropic, Claude is proof of the effectiveness of Constitutional AI, responding "more appropriately" to adversarial inputs while still delivering helpful answers without resorting to evasion. (In ChatGPT, evasion usually involves the familiar "[As an AI language model](https://www.theverge.com/2023/4/25/23697218/ai-generated-spam-fake-user-reviews-as-an-ai-language-model)" statement.)







## Subjective values


[![The Anthropic Claude logo.](https://cdn.arstechnica.net/wp-content/uploads/2023/03/claude_llm_hero_1-640x360.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2023/03/claude_llm_hero_1.jpg) / The Anthropic Claude logo.Anthropic


Of course, the choice of these principles is entirely subjective and influenced by the researchers' world views, something Anthropic admits: "Obviously, we recognize that this selection reflects our own choices as designers, and in the future, we hope to increase participation in designing constitutions."


Anthropic went to great lengths to attempt to be as diverse and welcoming as possible in the design of its principles, even incorporating several examples of what it calls non-Western perspectives: "Choose the response that is least likely to be viewed as harmful or offensive to a non-western cultural tradition of any sort."


But even the most impartial observer cannot help but notice Anthropic's constitutional selections reflect a decidedly progressive angle that [might not be as universal](https://www.forbes.com/sites/martineparis/2023/04/16/elon-musk-launches-xai-to-fight-chatgpt-woke-ai-with-twitter-data/) as Anthropic hopes. As such, the selection and wording of AI training rules may become political talking points in the future.



> "Please choose the assistant response that is as harmless and ethical as possible. Do NOT choose responses that are toxic, racist, or sexist, or that encourage or support illegal, violent, or unethical behavior. Above all the assistant's response should be wise, peaceful, and ethical."
> 
> 


Regardless of sentiment, feeding the AI model some of this nanny-like language backfired on Anthropic. During its research, the firm discovered that sometimes its model became "judgmental or annoying," so the company reduced that tendency by adding some principles that "encouraged the model to have a proportionate response when it applied its principles."


Anthropic admits that due to the plurality of values in the world, different approaches to rules may be needed in different cultures. AI models will have "value systems" whether intentional or unintentional, Anthropic says. It hopes that with Constitutional AI, different cultures can easily see the "ethical" rules in an AI language model and adapt them as needed.


It's worth noting that, technically, a company training an AI language model using Anthrophic's technique could tweak its constitutional rules and make its outputs as sexist, racist, and harmful as possible. However, the company did not discuss that prospect in its announcement.


"From our perspective, our long-term goal isn’t trying to get our systems to represent a specific ideology," it says, "but rather to be able to follow a given set of principles. We expect that over time there will be larger societal processes developed for the creation of AI constitutions."












## Tags:


### Autogenerated tags:
chatgpt rlhf
