# AI is changing scientists’ understanding of language learning
## And it is also raising questions about innate grammar.
## Information:

+ Link: https://arstechnica.com/information-technology/2022/10/ai-is-changing-scientists-understanding-of-language-learning/
+ Source: Ars Technica
+ Author: The Conversation
+ Date published: 19 October 2022, 13:54
+ Date scraped: 19 October 2022, 14:01

## Article:
![Main article image](https://cdn.arstechnica.net/wp-content/uploads/2022/10/parent-child-760x380.jpg)







Unlike the carefully scripted dialogue found in most books and movies, the language of everyday interaction tends to be messy and incomplete, full of false starts, interruptions and people talking over each other. From casual conversations between friends, to bickering between siblings, to formal discussions in a boardroom, [authentic conversation](https://vod.video.cornell.edu/media/TLG_C2_conversation-excerpt/1_419ixr2o) is chaotic. It seems miraculous that anyone can learn language at all given the haphazard nature of the linguistic experience.


For this reason, many language scientists—including [Noam Chomsky](https://chomsky.info/), a founder of modern linguistics—believe that language learners require a kind of glue to rein in the unruly nature of everyday language. And that glue is grammar: a system of rules for generating grammatical sentences.


Children must have a [grammar template wired into their brains](https://www.nytimes.com/2002/01/15/science/expert-says-he-discerns-hard-wired-grammar-rules.html) to help them overcome the limitations of their language experience—or so the thinking goes.


This template, for example, might contain a “super-rule” that dictates how new pieces are added to existing phrases. Children then only need to learn whether their native language is one, like English, where the verb goes before the object (as in “I eat sushi”), or one like Japanese, where the verb goes after the object (in Japanese, the same sentence is structured as “I sushi eat”).


But new insights into language learning are coming from an unlikely source: artificial intelligence. A new breed of large AI language models [can write newspaper articles](https://www.theguardian.com/commentisfree/2020/sep/08/robot-wrote-this-article-gpt-3), [poetry](https://doi.org/10.1016/j.chb.2020.106553) and [computer code](https://www.nytimes.com/2021/09/09/technology/codex-artificial-intelligence-coding.html) and [answer questions truthfully](https://www.lesswrong.com/posts/yYkrbS5iAwdEQyynW/how-do-new-models-from-openai-deepmind-and-anthropic-perform) after being exposed to vast amounts of language input. And even more astonishingly, they all do it without the help of grammar.


## Grammatical language without a grammar


Even if their [choice of words is sometimes strange](https://www.nytimes.com/2020/11/24/science/artificial-intelligence-gpt3-writing-love.html), [nonsensical](https://twitter.com/quasimondo/status/1284509525500989445) or contains [racist, sexist and other harmful biases](https://twitter.com/an_open_mind/status/1284487376312709120), one thing is very clear: the overwhelming majority of the output of these AI language models is grammatically correct. And yet, there are no grammar templates or rules hardwired into them—they rely on linguistic experience alone, messy as it may be.


GPT-3, arguably the [most well-known of these models](https://www.nytimes.com/2022/04/15/magazine/ai-language.html), is a gigantic [deep-learning neural network](https://interestingengineering.com/science/neural-networks) with 175 billion parameters. It was trained to predict the next word in a sentence given what came before across hundreds of billions of words from the internet, books and Wikipedia. When it made a wrong prediction, its parameters were adjusted using an automatic learning algorithm.


Remarkably, GPT-3 can generate believable text reacting to prompts such as “A summary of the last ‘Fast and Furious’ movie is…” or “Write a poem in the style of Emily Dickinson.” Moreover, [GPT-3 can respond](https://doi.org/10.48550/arXiv.2005.14165) to SAT level analogies, reading comprehension questions and even solve simple arithmetic problems—all from learning how to predict the next word.


[![An AI model and a human brain may generate the same language, but are they doing it the same way?](https://cdn.arstechnica.net/wp-content/uploads/2022/10/ai-brain-640x427.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2022/10/ai-brain.jpg) / An AI model and a human brain may generate the same language, but are they doing it the same way?Just\_Super/E+ via Getty


## Comparing AI models and human brains


The similarity with human language doesn’t stop here, however. Research published in Nature Neuroscience demonstrated that these artificial deep-learning networks seem to use the [same computational principles as the human brain](https://doi.org/10.1038/s41593-022-01026-4). The research group, led by [neuroscientist Uri Hasson](https://scholar.google.com/citations?user=VRw8v4kAAAAJ&hl=en&oi=ao), first compared how well [GPT-2](https://openai.com/blog/better-language-models/)—a “little brother” of GPT-3—and humans could predict the next word in a story taken from the podcast “This American Life”: people and the AI predicted the exact same word nearly 50% of the time.


The researchers recorded volunteers’ brain activity while listening to the story. The best explanation for the patterns of activation they observed was that people’s brains—like GPT-2—were not just using the preceding one or two words when making predictions but relied on the accumulated context of up to 100 previous words. Altogether, the authors conclude: “Our finding of spontaneous predictive neural signals as participants listen to natural speech suggests that [active prediction may underlie humans’ lifelong language learning](https://doi.org/10.1038/s41593-022-01026-4).”


A possible concern is that these new AI language models are fed a lot of input: GPT-3 was trained on [linguistic experience equivalent to 20,000 human years](https://arxiv.org/abs/2208.07998). But [a preliminary study](https://doi.org/10.1101/2022.10.04.510681) that has not yet been peer-reviewed found that GPT-2 can still model human next-word predictions and brain activations even when trained on just 100 million words. That’s well within the amount of linguistic input that an average child might [hear during the first 10 years of life](https://doi.org/10.1044/2016_AJSLP-15-0169).


We are not suggesting that GPT-3 or GPT-2 learn language exactly like children do. Indeed, [these AI models do not appear to comprehend much](https://www.lengoo.com/blog/gpt3hype/), if anything, of what they are saying, whereas [understanding is fundamental to human language use](https://www.basicbooks.com/titles/morten-h-christiansen/the-language-game/9781541674981/). Still, what these models prove is that a learner—albeit a silicon one—can learn language well enough from mere exposure to produce perfectly good grammatical sentences and do so in a way that resembles human brain processing.


[![More back and forth yields more language learning.](https://cdn.arstechnica.net/wp-content/uploads/2022/10/learning-640x427.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2022/10/learning.jpg) / More back and forth yields more language learning.[Westend61 via Getty](https://www.gettyimages.com/detail/photo/father-and-daughter-reading-a-book-in-bed-royalty-free-image/1227566554)


## Rethinking language learning


[For years, many linguists have believed](https://doi.org/10.1093/oxfordhb/9780199573776.001.0001) that learning language is impossible without a built-in grammar template. The new AI models prove otherwise. They demonstrate that the ability to produce grammatical language can be learned from linguistic experience alone. Likewise, we suggest that [children do not need an innate grammar](https://www.scientificamerican.com/article/evidence-rebuts-chomsky-s-theory-of-language-learning/) to learn language.


“Children should be seen, not heard” goes the old saying, but the latest AI language models suggest that nothing could be further from the truth. Instead, children need to be [engaged in the back-and-forth of conversation](https://doi.org/10.1177/0956797617742725) as much as possible to help them develop their language skills. Linguistic experience—not grammar—is key to becoming a competent language user.


[Morten H. Christiansen](https://theconversation.com/profiles/morten-h-christiansen-1227288) is Professor of Psychology at *[Cornell University](https://theconversation.com/institutions/cornell-university-1270)* and [Pablo Contreras Kallens](https://theconversation.com/profiles/pablo-contreras-kallens-1378949) is a Ph.D. Student in Psychology at *[Cornell University](https://theconversation.com/institutions/cornell-university-1270)*


This article is republished from [The Conversation](https://theconversation.com) under a Creative Commons license. Read the [original article](https://theconversation.com/ai-is-changing-scientists-understanding-of-language-learning-and-raising-questions-about-an-innate-grammar-190594).

















## Tags:


### Autogenerated tags:
gpt-3
