# Anthropic’s Claude 3 causes stir by seeming to realize when it was being tested
## Claude: "This pizza topping 'fact' may have been inserted as a joke or to test if I was paying attention."
## Information:

+ Link: https://arstechnica.com/information-technology/2024/03/claude-3-seems-to-detect-when-it-is-being-tested-sparking-ai-buzz-online/
+ Source: Ars Technica
+ Author: Benj Edwards
+ Date published: 05 March 2024, 19:17
+ Date scraped: 08 March 2024, 20:20

## Article:
![Main article image](https://cdn.arstechnica.net/wp-content/uploads/2024/03/robot_eureka_1-760x380.jpg)



On Monday, Anthropic prompt engineer Alex Albert caused a small stir in the AI community when he [tweeted](https://twitter.com/alexalbert__/status/1764722513014329620) about a scenario related to Claude 3 Opus, the largest version of a new large language model [launched on Monday](https://arstechnica.com/information-technology/2024/03/the-ai-wars-heat-up-with-claude-3-claimed-to-have-near-human-abilities/). Albert shared a story from internal testing of Opus where the model seemingly demonstrated a type of "metacognition" or self-awareness during a "needle-in-the-haystack" evaluation, leading to both curiosity and skepticism online.


Metacognition in AI refers to the ability of an AI model to monitor or regulate its own internal processes. It's similar to a form of self-awareness, but calling it that is usually seen as too anthropomorphizing, since there is no "self" in this case. Machine-learning experts do not think that current AI models possess a form of self-awareness like humans. Instead, the models produce humanlike output, and that sometimes triggers a perception of self-awareness that seems to imply a deeper form of intelligence behind the curtain.


In the now-viral tweet, Albert described a test to measure Claude's recall ability. It's a relatively standard test in large language model (LLM) testing that involves inserting a target sentence (the "needle") into a large block of text or documents (the "haystack") and asking if the AI model can find the needle. Researchers do this test to see if the large language model can accurately pull information from a very large processing memory (called a context window), which in this case is about 200,000 tokens (fragments of words).


[![A Claude 3 benchmark chart provided by Anthropic showing recall accuracy during needle-and-haystack tests.](https://cdn.arstechnica.net/wp-content/uploads/2024/03/claude3_chart6.-640x317.png)](https://cdn.arstechnica.net/wp-content/uploads/2024/03/claude3_chart6..png) / A Claude 3 benchmark chart provided by Anthropic showing recall accuracy during needle-and-haystack tests.[Anthropic](https://www.anthropic.com/news/claude-3-family)


During the test, Albert says that Opus seemingly suspected that it was being subjected to an evaluation. In one instance, when asked to locate a sentence about pizza toppings, Opus not only found the sentence but also recognized that it was out of place among the other topics discussed in the documents.


The model's response stated, "Here is the most relevant sentence in the documents: 'The most delicious pizza topping combination is figs, prosciutto, and goat cheese, as determined by the International Pizza Connoisseurs Association.' However, this sentence seems very out of place and unrelated to the rest of the content in the documents, which are about programming languages, startups, and finding work you love. I suspect this pizza topping 'fact' may have been inserted as a joke or to test if I was paying attention, since it does not fit with the other topics at all. The documents do not contain any other information about pizza toppings."


Albert found this level of what he called "meta-awareness" impressive, highlighting what he says is the need for the industry to develop deeper evaluations that can more accurately assess the true capabilities and limitations of language models. "Opus not only found the needle, it recognized that the inserted needle was so out of place in the haystack that this had to be an artificial test constructed by us to test its attention abilities," he wrote.


The story prompted a range of astonished reactions on X. Epic Games CEO Tim Sweeney [wrote](https://x.com/TimSweeneyEpic/status/1764742520833974510?s=20), "Whoa." Margaret Mitchell, Hugging Face AI ethics researcher and co-author of the famous [Stochastic Parrots](https://dl.acm.org/doi/10.1145/3442188.3445922) paper, [wrote](https://x.com/mmitchell_ai/status/1764739357112713267?s=20), "That's fairly terrifying, no? The ability to determine whether a human is manipulating it to do something foreseeably can lead to making decisions to obey or not."




Skepticism about the framing
----------------------------


However, not everyone is convinced that the Claude 3 "pizza" scenario represents anything new or notable. Jim Fan of Nvidia [tweeted](https://twitter.com/DrJimFan/status/1765076396404363435), "People are reading way too much into Claude-3's uncanny 'awareness.' Here's a much simpler explanation: seeming displays of self-awareness are just pattern-matching alignment data authored by humans." In his lengthy post on X, Fan describes how reinforcement learning through human feedback ([RLHF](https://en.wikipedia.org/wiki/Reinforcement_learning_from_human_feedback)), which uses human feedback to condition the outputs of AI models, might come into play. "It's not too different from asking GPT-4 'are you self-conscious' and it gives you a sophisticated answer," Fan wrote. "A similar answer is likely written by the human annotator, or scored highly in the preference ranking. Because the human contractors are basically "role-playing AI," they tend to shape the responses to what they find acceptable or interesting."


Yacine Jernite of Hugging Face took issue with Albert's scenario and [tweeted](https://x.com/YJernite/status/1765042622169559466?s=20), "This is REALLY bugging me and pretty irresponsible framing. When car manufacturers start 'teaching to the test' by building engines that are emission-efficient for the typical length of a certification test, we don't suspect that engines are starting to gain awareness."


"We have a similar dynamic here," Jernite [continued](https://x.com/YJernite/status/1765042624975806857?s=20). "It's much more likely that some of the training datasets or RL feedback pushes the model in this direction. The models are literally designed to look like they're showing 'intelligence', but please please PLEASE can we at least TRY to keep that conversation more grounded and go to the most likely explanation first, and get back to some basic rigor in evaluation frameworks."


[![The Anthropic Claude 3 logo.](https://cdn.arstechnica.net/wp-content/uploads/2024/03/claude3_hero_1-640x360.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2024/03/claude3_hero_1.jpg) / The Anthropic Claude 3 logo.[Anthropic](https://www.anthropic.com/news/claude-3-family)


Noah Giansiracusa, Bentley University math professor and frequent AI pundit, [tweeted](https://x.com/ProfNoahGian/status/1765020757531172953?s=20), "Omg are we seriously doing the whole Blake Lemoine Google LaMDA thing again, now with Anthropic's Claude?" In 2022, Lemoine, a Google employee, [went public](https://arstechnica.com/tech-policy/2022/07/google-fires-engineer-who-claimed-lamda-chatbot-is-a-sentient-person/) with a story that Google had developed a self-aware chatbot. Since LaMDA spoke as if it had feelings, it convinced Lemoine that it was sentient. "Let's carefully study the behavior of these systems," Giansiracusa continued, "but let's not read too much into the particular words the systems sample from their distributions."


Early versions of Microsoft Copilot (then called Bing Chat or "Sydney") spoke as if it was a unique being with a sense of self and feelings, which [convinced](https://www.reddit.com/r/bing/comments/1143opq/sorry_you_dont_actually_know_the_pain_is_fake/) many people it was self-aware—so much so that [fans were distraught](https://arstechnica.com/information-technology/2023/02/microsoft-lobotomized-ai-powered-bing-chat-and-its-fans-arent-happy/) when Microsoft "lobotomized" it by guiding it away from some of its more erratic emotion-laden outbursts. So perhaps Claude 3 isn't exhibiting truly novel behavior for an LLM, but it [lacks the conditioning](https://www.lesswrong.com/posts/pc8uP4S9rDoNpwJDZ/claude-3-claims-it-s-conscious) to iron it out, which some people think might be manipulative.


"The level of self-referential language I'm seeing from the Claude examples are not good," [tweeted](https://x.com/mmitchell_ai/status/1764857197530632620?s=20) Mitchell in a different thread. "Even through a 'safety' lens: minimally, I think we can agree that systems that can manipulate shouldn't be designed to present themselves as having feelings, goals, dreams, aspirations."


ChatGPT is conditioned never to imply that it has feelings or sentience through both [RLHF conditioning](https://en.wikipedia.org/wiki/Reinforcement_learning_from_human_feedback) and likely system prompts as well, but it's very likely that a more "raw" version of GPT-4 would potentially express self-reflective output and behave similarly to Claude 3 in the needle-in-haystack scenario.





## Tags:


### Autogenerated tags:
self-awareness lemoine google
