# ChatGPT gets “eyes and ears” with plugins that can interface AI with the world
## Plugins allow ChatGPT to book a flight, order food, send email, execute code (and more).
## Information:

+ Link: https://arstechnica.com/information-technology/2023/03/chatgpt-gets-eyes-and-ears-with-plugins-that-can-interface-ai-with-the-world/
+ Source: Ars Technica
+ Author: Benj Edwards
+ Date published: 24 March 2023, 19:29
+ Date scraped: 27 March 2023, 12:02

## Article:
![Main article image](https://cdn.arstechnica.net/wp-content/uploads/2023/03/chatGPT-sees-through-the-cloud-760x380.jpg)







On Thursday, OpenAI [announced](https://openai.com/blog/chatgpt-plugins) a plugin system for its [ChatGPT](https://arstechnica.com/information-technology/2022/12/openai-invites-everyone-to-test-new-ai-powered-chatbot-with-amusing-results/) AI assistant. The plugins give ChatGPT the ability to interact with the wider world through the Internet, including booking flights, ordering groceries, browsing the web, and more. Plugins are bits of code that tell ChatGPT how to use an external resource on the Internet.


Basically, if a developer wants to give ChatGPT the ability to access any network service (for example: "looking up current stock prices") or perform any task controlled by a network service (for example: "ordering pizza through the Internet"), it is now possible, provided it doesn't go against OpenAI's rules.


Conventionally, most large language models (LLM) like ChatGPT have been constrained in a bubble, so to speak, only able to interact with the world through text conversations with a user. As OpenAI writes in its introductory [blog post](https://openai.com/blog/chatgpt-plugins) on ChatGPT plugins, "The only thing language models can do out-of-the-box is emit text."


[Bing Chat](https://arstechnica.com/information-technology/2023/03/microsoft-equips-bing-chat-with-multiple-personalities-creative-balanced-precise/) has taken this paradigm further by allowing it to search the web for more recent information, but so far ChatGPT has still been isolated from the wider world. While closed off in this way, ChatGPT can only draw on data from its training set (limited to 2021 and earlier) and any information provided by a user during the conversation. Also, ChatGPT can be prone to making factual errors and mistakes (what AI researchers call "hallucinations").


To get around these limitations, OpenAI has popped the bubble and created a [ChatGPT plugin interface](https://platform.openai.com/docs/plugins/introduction) (what OpenAI calls ChatGPT's "eyes and ears") that allows developers to create new components that "plug in" to ChatGPT and allow the AI model to interact with other services on the Internet. These services can [perform calculations](https://writings.stephenwolfram.com/2023/03/chatgpt-gets-its-wolfram-superpowers/) and reference factual information to reduce hallucinations, and they can also potentially interact with any other software service on the Internet—if developers create a plugin for that task.


## What kind of plugins are we talking about?


[![The ChatGPT "Plugin store" lets users select from plugins they wish to "install" in their ChatGPT session.](https://cdn.arstechnica.net/wp-content/uploads/2023/03/Fr8mpAMakAAbqeJ-640x364.jpeg)](https://cdn.arstechnica.net/wp-content/uploads/2023/03/Fr8mpAMakAAbqeJ-scaled.jpeg) / The ChatGPT "Plugin store" lets users select from plugins they wish to "install" in their ChatGPT session.[Marco Mascorro](https://twitter.com/Mascobot/status/1639071614590660610?s=20)


In the case of ChatGPT, OpenAI will allow users to select from a list of plugins before starting a ChatGPT session. They present themselves almost like apps in an app store, each plugin having its own icon and description.


OpenAI says that a first round of plugins have been created by the following companies:


* Expedia (for trip planning)
* [FiscalNote](https://fiscalnote.com/) (for real-time market data)
* Instacart (for grocery ordering)
* Kayak (searching for flights and rental cars)
* [Klarna](https://www.klarna.com/) (for price-comparison shopping)
* [Milo](https://www.joinmilo.com/) (an AI-powered parent assistant)
* OpenTable (for restaurant recommendations and reservations)
* Shopify (for shopping on that site)
* Slack (for communications)
* [Speak](https://www.speak.com/) (for AI-powered language tutoring)
* [Wolfram](http://wolfram.com/) (for computation and real-time data)
* [Zapier](https://zapier.com/) (an automation platform)


In particular, the Zapier plugin seems especially powerful since it grants ChatGPT access to an existing software automation system, [or as Zapier](https://zapier.com/blog/announcing-zapier-chatgpt-plugin/) puts it: "You can ask ChatGPT to execute any of Zapier's 50,000 actions (including search, update, and write) with Zapier's 5,000+ supported apps, turning chat into action. It can write an email, then send it for you. Or find contacts in a CRM, then update them directly. Or add rows to a spreadsheet, then send them as a Slack message. The possibilities are endless."


OpenAI is also hosting three plugins itself, a web browser (that can grab info from the web in a manner similar to Bing Chat), a code interpreter for executing Python programs (in a sandbox), and a retrieval tool that allows access to "personal or organizational" information sources hosted elsewhere (basically, fetching information from documents).







A demo video of ChatGPT plugins from OpenAI.


While OpenAI calls the plugin selection process a "plugin store," the company has not announced plans to sell individual plugins. But by using the "store" label, that outcome seems likely at some point.


Already, developers with early access have been [rapidly prototyping plugins](https://twitter.com/rez0__/status/1639259413553750021) for ChatGPT. Compared to other approaches in plugin development, the way ChatGPT plugins work is notable. Instead of an arcane process of using "[glue code](https://en.wikipedia.org/wiki/Glue_code)" to interface an API with ChatGPT, the developer basically just "tells" ChatGPT how to use their service using natural language, and ChatGPT does it.



Beyond that, developers have been using ChatGPT and [GPT-4](https://twitter.com/danielgross/status/1639040289816866818?s=20) to write ChatGPT plugin manifests (a manifest is "a machine-readable description of the plugin’s capabilities and how to invoke them," according to OpenAI), further simplifying the plugin development process.


This kind of self-compounding development capability feels like [uncharted territory](https://twitter.com/krishnanrohit/status/1638980086874374145?s=20) for some programmers. In one case, a Twitter user named Rohit [worried aloud](https://twitter.com/krishnanrohit/status/1638980086874374145?s=20), "Guys. Existential crisis. Did OpenAI just finish software? What's there left to do but clean-up and sweep?"


Sam Altman, the CEO of OpenAI, [replied](https://twitter.com/sama/status/1639012413185085440?s=20), "No."


## Is it safe?


[![A hyperbolic, sensational AI-generated image of the earth enveloped in an explosion.](https://cdn.arstechnica.net/wp-content/uploads/2023/03/AI_world_hero-640x360.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2023/03/AI_world_hero.jpg) / A hyperbolic, sensational AI-generated image of the earth enveloped in an explosion.Stable Diffusion


Given that OpenAI has previously [tested its AI models](https://arstechnica.com/information-technology/2023/03/openai-checked-to-see-whether-gpt-4-could-take-over-the-world/) (such as GPT-4) to see if they have the agency to modify, improve, and spread themselves among the world's computer systems, it's unsurprising that OpenAI spends almost half of its ChatGPT plugins [blog post](https://openai.com/blog/chatgpt-plugins) talking about safety and impacts. "Plugins will likely have wide-ranging societal implications," the company casually mentions in one section about [potential impacts on jobs](https://arxiv.org/abs/2303.10130).


Beyond jobs, a recurring fear among some AI researchers involves granting an advanced AI model access to other systems, where it can potentially do harm. The AI system need not be "conscious" or "sentient," just driven to complete a certain task it deems necessary. In this case with plugins, it seems like OpenAI is doing exactly that.



OpenAI appears to be aware of the risks, frequently referencing its [GPT-4 system card](https://cdn.openai.com/papers/gpt-4-system-card.pdf) that describes the kind of worst-case-scenario testing we [described in a previous article](https://arstechnica.com/information-technology/2023/03/openai-checked-to-see-whether-gpt-4-could-take-over-the-world/). Beyond hypothetical doomsday scenarios, AI-powered harms could come in the form of accelerated versions of current online dangers, such as automated phishing rings, disinformation campaigns, [astroturfing](https://en.wikipedia.org/wiki/Astroturfing), or personal attacks.


"There’s a risk that plugins could increase safety challenges by taking harmful or unintended actions, increasing the capabilities of bad actors who would defraud, mislead, or abuse others," writes OpenAI. "By increasing the range of possible applications, plugins may raise the risk of negative consequences from mistaken or misaligned actions taken by the model in new domains. From day one, these factors have guided the development of our plugin platform, and we have implemented several safeguards."


One of these safeguards appears to be a gradual deployment of access to plugins. Also, while ChatGPT plugin use is covered by OpenAI's blanket [usage policy](https://openai.com/policies/usage-policies) that prohibits using it to generate misinformation and prohibited forms of content, it also specifies [rules for plugins](https://openai.com/policies/usage-policies#plugin-policies), such as a prohibition on automating conversations with real people. Also, plugins that utilize content generated by ChatGPT (such as emails) must disclaim that the content was generated by AI.


Individual OpenAI plugins have their own safety disclaimers, including the ability to opt out of ChatGPT web crawling with a robots.txt file and the fact that the Python code interpreter runs in a "firewalled" sandbox. But will those restrictions apply to plugins to other services that can execute code? These are questions that OpenAI and developers will need to address and work out together in the coming days, weeks, and months ahead.


At the moment, ChatGPT plugins are only available on an alpha basis to select developers and those approved from a [waitlist](http://openai.com/waitlist/plugins). "While we will initially prioritize a small number of developers and ChatGPT Plus users, we plan to roll out larger-scale access over time."












## Tags:


### Autogenerated tags:
chatgpt plugins openai plugin zapier ai-powered gpt-4
