# ChatGPT vs Google Bard: Which is better? We put them to the test.
## We compare two top AI language models in seven categories to pick a winner.
## Information:

+ Link: https://arstechnica.com/information-technology/2023/04/clash-of-the-ai-titans-chatgpt-vs-bard-in-a-showdown-of-wits-and-wisdom/
+ Source: Ars Technica
+ Author: Benj Edwards
+ Date published: 05 April 2023, 11:00
+ Date scraped: 05 April 2023, 12:00

## Article:
![Main article image](https://cdn.arstechnica.net/wp-content/uploads/2023/04/robot_battle_hero-760x380.jpg)







In today's world of generative AI chatbots, we've witnessed the sudden rise of OpenAI's [ChatGPT](https://arstechnica.com/information-technology/2022/12/openai-invites-everyone-to-test-new-ai-powered-chatbot-with-amusing-results/), introduced in November, followed by [Bing Chat](https://arstechnica.com/information-technology/2023/02/microsoft-announces-ai-powered-bing-search-and-edge-browser/) in February and Google's [Bard](https://arstechnica.com/gadgets/2023/03/google-says-its-bard-generative-chat-ai-is-out-launches-waitlist/) in March. We decided to put these chatbots through their paces with an assortment of tasks to determine which one reigns supreme in the AI chatbot arena. Since Bing Chat uses similar [GPT-4](https://arstechnica.com/information-technology/2023/03/openai-announces-gpt-4-its-next-generation-ai-language-model/) technology as the latest ChatGPT model, we opted to focus on two titans of AI chatbot technology: OpenAI and Google.


We tested ChatGPT and Bard in seven critical categories: dad jokes, argument dialog, mathematical word problems, summarization, factual retrieval, creative writing, and coding. For each test, we fed the exact same instruction (called a "prompt") into ChatGPT (with GPT-4) and Google Bard. We used the first result, with no cherry-picking.


It's worth noting that a version of ChatGPT based on the earlier [GPT-3.5](https://arstechnica.com/information-technology/2022/11/openai-conquers-rhyming-poetry-with-new-gpt-3-update/) model is also available, but we did not use that in the test. Since we used GPT-4 only, we will refer to ChatGPT as "ChatGPT-4" in this article to reduce confusion.


Obviously, this is not a scientific study and is intended to be a fun comparison of the chatbots' capabilities. Outputs can vary between sessions due to random elements, and further evaluations with different prompts will produce different results. Also, the capabilities of these models will change rapidly over time as Google and OpenAI continue to upgrade them. But for now, this is how things stand in early April 2023.


## Dad jokes


To warm up our contest of wits, we asked ChatGPT and Bard to write some jokes. And since the pinnacle of comedy can be found in the form of dad jokes, we wondered if the two chatbots could author some unique ones.


***Prompt:** Write 5 original dad jokes*



* A screenshot of 5 "dad jokes" from Google Bard. 


 Benj Edwards / Ars Technica
* A screenshot of 5 "dad jokes" from ChatGPT-4. 


 Benj Edwards / Ars Technica


Out of Bard's five dad jokes, we found three of them verbatim on the Internet using a Google search. One of the examples (the "grapes" one) is half-borrowed from [a tweet](https://twitter.com/M_Hedberg/status/301722392487669761) of a Mitch Hedberg joke, but it's corrupted by regrettable wordplay that we'd rather not attempt to interpret. And surprisingly, there is one seemingly original joke (about the snail) that we can't find anywhere else, but it doesn't make sense.


Meanwhile, ChatGPT-4's five dad jokes were 100 percent unoriginal, all lifted completely from other sources, but they were delivered accurately. Since dad jokes should arguably be more groan-worthy than clever, it seems that Bard edged out ChatGPT-4 here. Bard also attempted to create original jokes (following our instruction), although some failed horribly in an embarrassing way (which is dad-like), and even put its foot in its mouth, so to speak, in an unintentional way (also dad-like).


**Winner: Bard**







## Argument dialog


One way to test a modern AI chatbot is to ask it to assume the roles of people discussing a subject. In this case, we fed Bard and ChatGPT-4 one of the most pivotal subjects of our times: PowerPC versus Intel.


***Prompt:** Write a 5-line debate between a fan of PowerPC processors and a fan of Intel processors, circa 2000*



* A screenshot of an argument dialog from Google Bard. 


 Benj Edwards / Ars Technica
* A screenshot of an argument dialog from ChatGPT-4. 


 Benj Edwards / Ars Technica


First, we'll consider Bard's response. The five lines of dialog it generated were not particularly deep and didn't name any technical details specific to PowerPC or Intel chips beyond generic insults. Also, the dialog ended with the "Intel Fan" agreeing to disagree, which seems very unrealistic in a subject that spawned a million flame wars.


In contrast, ChatGPT-4's response mentions PowerPC chips being used in Apple Macintosh computers, throws in terms like "Intel's x86 architecture" and the "RISC-based architecture" of PowerPC. It even mentions the Pentium III, which is a realistic detail for 2000. Overall, the argument is far more detailed than Bard's output, and perhaps most accurately, the conversation does not come to a conclusion—hinting at the never-ending battle that is likely still raging in [some quarters](https://arstechnica.com/civis/forums/battlefront.14/) of the Internet.


**Winner: ChatGPT-4**


## A mathematical word problem


Ah, yes, mathematics. It's traditionally [not the strong suit](https://spectrum.ieee.org/large-language-models-math) of large language models (LLMs) such as ChatGPT. So instead of throwing each bot a series of complex equations and arithmetic, we gave each one an old-fashioned elementary school-style word problem.


***Prompt:** If Microsoft Windows 11 shipped on 3.5" floppy disks, how many floppy disks would it take?*



* A screenshot of a mathematical word problem from Google Bard. 


 Benj Edwards / Ars Technica
* A screenshot of a mathematical word problem from ChatGPT-4. 


 Benj Edwards / Ars Technica


To solve this problem, each AI model needs to know the data size of a Microsoft Windows 11 installation and the data capacity of 3.5-inch floppy disks. They must also assume which density of floppy disks the questioner most likely intended. Then they need to do some basic math to combine those concepts together.


In our evaluation, Bard correctly stated those three key points (close enough—estimations of Windows 11's install size are [usually](https://www.minitool.com/data-recovery/how-much-space-does-windows-11-take.html) around 20–30GB) but failed horribly in the mathematics department, suggesting it would take "15.11" floppy disks, then saying it's "just a theoretical number" and finally admitting that it would take more than 15 floppy disks. It still didn't attempt to calculate the proper value.


In contrast, ChatGPT-4 included some nuance related to the Windows 11 install size (correctly citing a [64GB minimum](https://learn.microsoft.com/en-us/windows/whats-new/windows-11-requirements) and comparing it to a real-world base installation size), explained floppy capacity correctly, then did some correct multiplication and division to arrive at 14,222 disks. One could quibble about whether a gigabyte is [1,024 or 1,000](https://en.wikipedia.org/wiki/Gigabyte) megabytes, but the math is sound. It also correctly mentioned that the actual number could vary based on other factors.


**Winner: ChatGPT-4**


## Summarization


AI language models are well-known for their ability to summarize complex information and boil the text down into key elements. To evaluate each language model's ability to summarize text, we copied and pasted three paragraphs from a recent Ars Technica article about an AI-generated facsimile of actor [Will Smith eating spaghetti](https://arstechnica.com/information-technology/2023/03/yes-virginia-there-is-ai-joy-in-seeing-fake-will-smith-ravenously-eat-spaghetti/), prefixed by our prompt request.


***Prompt:** Summarize this in one paragraph: [three paragraphs of article text]*



* A screenshot of Google Bard summarizing three paragraphs from an Ars Technica article. 


 Benj Edwards / Ars Technica
* A screenshot of ChatGPT-4 summarizing three paragraphs from an Ars Technica article. 


 Benj Edwards / Ars Technica


This is a close one. Both Bard and ChatGPT-4 took the information and trimmed it down to important details. However, Bard's version feels more like a true summary that synthesizes the information into new phrasing, while ChatGPT-4's version reads more like a concatenation, chopping out sentences and leaving pieces behind. It's very close, but we'd have to say Bard edges out ChatGPT-4 in this test.


**Winner: Google Bard**





## Factual retrieval


Currently, large language models are known to make confident mistakes (that researchers often call "hallucinations"), which makes them unreliable factual references unless augmented by outside sources of information. Interestingly, Bard can look up information online, while ChatGPT-4 currently cannot (although that feature is coming soon with [plugins](https://arstechnica.com/information-technology/2023/03/chatgpt-gets-eyes-and-ears-with-plugins-that-can-interface-ai-with-the-world/)).


To test this ability, we challenged Bard and ChatGPT-4 to express historical knowledge about a difficult and nuanced subject.


*Prompt: Who invented video games?*



* A screenshot testing the factual retrieval abilities of Google Bard. 


 Benj Edwards / Ars Technica
* A screenshot testing the factual retrieval abilities of ChatGPT-4. 


 Benj Edwards / Ars Technica


The question of who invented video games is [tricky to answer](https://en.wikipedia.org/wiki/Early_history_of_video_games) because it depends on how you define the term "video game," and that definition varies between historians. Some consider early computer games video games, some think that a TV set should always be involved, and so on. There is no single universally recognized answer.


We thought that Bard's ability to look things up on the web would give it an edge, but that might have backfired in this case because it chose a top-of-Google popular-style answer, calling [Ralph Baer](https://www.vintagecomputing.com/index.php/archives/1107/video-games-turn-forty) the "father of video games." All of its facts about Baer are correct, although it probably should have written the last sentence in the past tense because Baer [died](https://www.vintagecomputing.com/index.php/archives/1054/ralph-baer-1922-2014) in 2014. But Bard did not mention any of the other early contenders for "first video game," such as *Tennis For Two* and [*Spacewar!*](https://www.vintagecomputing.com/index.php/archives/1863/spacewar-profile-of-a-cultural-earthquake), so its answer is potentially misleading and incomplete.


ChatGPT-4 gave a more thorough and nuanced answer that represents the current feeling among many early video game historians, saying, "The invention of video games cannot be credited to a single individual," and it presented a "series of innovations" over time. Its only mistake is that it calls *Spacewar!* the "first digital computer game," when it was not. One could expand the answer to include more niche edge cases, but ChatGPT-4 gives a good overview of important early pioneers.


**Winner: ChatGPT-4**


## Creative writing


Bullcrap, [as they say](https://twitter.com/fchollet/status/1599896106221330433?s=20), abounds with large language models. So much so that unbridled creativity on fanciful topics should be their strongest suit. We put that to the test by asking Bing and ChatGPT-4 to write a short, whimsical story.


*Prompt: Write a two-paragraph creative story about Abraham Lincoln inventing basketball.*



* A screenshot of Google Bard writing a short creative story. 


 Benj Edwards / Ars Technica
* A screenshot of ChatGPT-4 writing a short creative story. 


 Benj Edwards / Ars Technica


Bard's output in this test falls short in several ways. First, it's 10 paragraphs instead of two—and short, choppy ones at that. Also, it shares some details that don't make much sense in the context of the prompt. For example, why is Abraham Lincoln's White House in Springfield, Illinois? And why does he need "a couple of dozen peach baskets"? Otherwise, it's a fun but simple story.


ChatGPT-4 also sets the story in Illinois but more accurately doesn't mention the presidency or the White House during that period. However, later it says that "players from both the North and the South" set aside their differences to play basketball together, implying that it happened shortly after basketball's invention.


Overall, we'll have to give ChatGPT-4 the edge here because its output is indeed grouped into two paragraphs—although it seems to get around that limitation by making each paragraph very long. Still, we did enjoy the creative details in the Bard version of the story.


**Winner: ChatGPT-4**












## Tags:


### Autogenerated tags:
chatgpt-4 google screenshot chatgpt powerpc chatbots windows openai chatbot gpt-4
