# DALL-E 2 and Midjourney can be a boon for industrial designers
## AI lets designers input abstract concepts and turn them into a flood of images.
## Information:

+ Link: https://arstechnica.com/information-technology/2023/03/dall-e-2-and-midjourney-can-be-a-boon-for-industrial-designers/
+ Source: Ars Technica
+ Author: Juan Nougera, The Conversation
+ Date published: 01 March 2023, 14:56
+ Date scraped: 01 March 2023, 16:01

## Article:
![Main article image](https://cdn.arstechnica.net/wp-content/uploads/2023/03/ai-list-760x380.jpg)







Since the introduction of DALL-E 2 and ChatGPT, there has been a fair amount of [hand-wringing](https://theconversation.com/chatgpt-and-cheating-5-ways-to-change-how-students-are-graded-200248) about AI technology—some of it justified.


It’s true that the technology’s future is unclear. There is great debate about [the ethics](https://www.mediaethicsmagazine.com/index.php/browse-back-issues/219-fall-2022-vol-34-no-1/3999403-an-extension-of-the-artist-dall-e-2-and-the-ethical-challenges-of-ai-art) of using existing artwork, images, and content to train these AI products, [and concern](https://theconversation.com/chatgpt-dall-e-2-and-the-collapse-of-the-creative-process-196461) about what industries [it will displace or change](https://theconversation.com/ai-and-the-future-of-work-5-experts-on-what-chatgpt-dall-e-and-other-ai-tools-mean-for-artists-and-knowledge-workers-196783). And it seems as if an AI arms race between companies like [Microsoft](https://blogs.microsoft.com/blog/2023/02/07/reinventing-search-with-a-new-ai-powered-microsoft-bing-and-edge-your-copilot-for-the-web/) and [Google](https://blog.google/technology/ai/bard-google-ai-search-updates/) is already underway.


And yet as an [industrial designer and professor](http://www.no.gt), I’ve found AI image-generation programs to be a fantastic way to improve the design process.


They don’t replace the valuable insights and critical thinking skills I’ve accumulated from years of experience. But they do spark creativity and expand the range of what’s possible with the products my students and I design.


## A peek behind the design curtain


[Industrial design](https://www.idsa.org/what-industrial-design) involves creating everyday objects, with a particular focus on their form and function. Industrial designers have a hand in anything from furniture and consumer electronics to accessories and apparel.


A typical design process involves lots of research and talking to consumers about their needs. From there, designers brainstorm ideas and sketch them out, followed by the prototyping and fabrication stage. Finally, the objects get refined and manufactured.


During the early stages of brainstorming, designers spend a lot of time with their sketchbooks, getting inspired by their immediate environment, by history books, and by their own experiences. The Internet also plays a big role—it’s where designers collect many of the images they use to create [inspiration boards](https://www.dictionary.com/browse/inspiration-board). Famously, [Jonathan Ive](https://www.hodinkee.com/magazine/jony-ive-apple), who designed many iconic Apple products, looked at luxury watches as inspiration for the Apple Watch, using the “[crown](https://www.uniformwares.com/wp-content/uploads/2021/07/watch-crown.png)”—normally used to wind a mechanical watch and set the time—as an input device to allow users to scroll through content.


AI has given designers like myself the ability to generate images just based on a simple text prompt. Tools like [DALL-E](https://towardsdatascience.com/dall-e-2-explained-the-promise-and-limitations-of-a-revolutionary-ai-3faf691be220) or [Midjourney](https://www.midjourney.com/home/) let us input abstract concepts and turn them into a flood of images.


Enter any sentence—no matter how crazy—and you’ll receive a set of unique images generated just for you. Want to design a teapot? Here, have 1,000 of them. Some may have a dinosaur shape; others may be made of mashed potatoes.


While only a small subset of them may be usable as a teapot, they provide a seed of inspiration that the designer can nurture and refine into a finished product.


## From nostalgia to a tissue box


Perhaps a handful of those 1,000 teapot images allow a designer to conceive of a new, unexpected shape that is easier to hold, more economical to manufacture, or more beautiful to look at. Generative AI can facilitate the brainstorming process, but it’s still the designer’s responsibility to make the choices that ultimately lead to products that enrich people’s lives.


Recently, I have found myself using AI image generators like DALL-E and Midjourney to explore complex ideas that might be difficult or time-consuming to articulate and channel into a physical product. For example, for one project, I wanted to create objects that really connected people, in a deep way, to a place they had visited or lived in—as opposed to the refrigerator magnet souvenirs that tourists often end up buying.


So I decided to design a set of small household objects to be sold to tourists visiting the small colonial town of [Antigua, Guatemala](https://www.nytimes.com/2019/01/21/t-magazine/antigua-guatemala-travel-guide.html), just a few miles from where I grew up. I wanted the objects to elicit nostalgia about the town—and perhaps inspire those who purchased them to want to return.


I began by prompting DALL-E for tabletop objects that were nostalgic. The results were hilarious and unexpected. I received images of objects that looked sad, like erasers and a tissue box with a frown. It had taken my prompt very literally.







Then I got more specific, inserting “Antigua” into my prompts. The results started including iconic symbols of the town—the volcanoes that surround it, the cobblestone streets, the colonial architecture.


[![In the left column are images generated by OpenAI’s DALL-E when the author prompted it to come up with nostalgic desktop objects. The middle columns represent refined inputs for tabletop objects that represent the city of Antigua. The column on the right holds composites created by the author before proceeding with the traditional design process. ](https://cdn.arstechnica.net/wp-content/uploads/2023/03/ai-1-640x320.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2023/03/ai-1.jpg) / In the left column are images generated by OpenAI’s DALL-E when the author prompted it to come up with nostalgic desktop objects. The middle columns represent refined inputs for tabletop objects that represent the city of Antigua. The column on the right holds composites created by the author before proceeding with the traditional design process. [Juan Nougera (CC-BY-SA)](https://creativecommons.org/licenses/by-sa/4.0/legalcode)


After a little sketching, I narrowed down the results further by inputting “tissue boxes” and “eruption of tissue.”


From there, I continued playing around in my sketchbook and eventually created a Photoshop mock-up of a tissue box shaped like the Volcán de Agua, or “Water Volcano,” which lies south of the city.


I then used my traditional design skills to create a 3D computer drawing of it—also known as a “[CAD model](https://www.designlaunchers.com/what-is-3d-cad-modeling)”—using actual terrain data from the volcano, and fabricated a fully functional and manufacturable object.


[![A 3D model of a volcano-topped tissue box based on AI-generated images and the author’s ensuing sketches. ](https://cdn.arstechnica.net/wp-content/uploads/2023/03/ai-2-640x323.gif)](https://cdn.arstechnica.net/wp-content/uploads/2023/03/ai-2.gif) / A 3D model of a volcano-topped tissue box based on AI-generated images and the author’s ensuing sketches. [Juan Noguera (CC-BY-SA)](https://creativecommons.org/licenses/by-sa/4.0/legalcode)


Continuing with the volcano theme, I decided to create a companion object of the neighboring Volcán de Fuego, or “Fire Volcano,” which is constantly active and erupting. Fire made me think of matches, and I prompted the AI to generate images of volcano-shaped matchstick holders.


The results weren’t great. But they were good enough to help me imagine a small cast-iron object that could hold some stormproof matches, which I chose because when placed on the holder, they evoked a lava-filled eruption.


To me, the tissue box and matchbox holder are perfect homages to Antigua and all the memories this place holds for me, good and bad. The fire volcano matchstick holder conveys excitement and adventure, while the tissue box evokes tears, longing, and nostalgia.


Even though I made all of the design choices, the AI generator helped me navigate my abstract design goals.


It’s hard to say if I would have landed on these prototypes on my own.


[![The tissue box, Agua, was modeled using the terrain data of the real volcano of the same name.](https://cdn.arstechnica.net/wp-content/uploads/2023/03/ai-3-640x480.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2023/03/ai-3.jpg) / The tissue box, Agua, was modeled using the terrain data of the real volcano of the same name.Juan Noguera (CC-BY-SA)


## Opening new creative doors


AI technology is not going away any time soon. As an educator, I believe it would be irresponsible to not explore, with my students, the ways in which it can improve the design process.


In the fall semester of the 2022-2023 academic year, I had my graduate students at the Rochester Institute of Technology use AI image generation to develop their own products. [The results were impressive](https://www.core77.com/posts/117169/Unexpected-outcomes-when-design-students-use-AI-as-part-of-their-process), with students creating an electric violin, a chair inspired by fruit, and shoes made out of fungus. They all used AI in a different way, but they all noted how it led them down an unexpected path.


[![An electric violin designed by Rochester Institute of Technology graduate student Jayden Zhou.](https://cdn.arstechnica.net/wp-content/uploads/2023/03/ai-4-640x427.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2023/03/ai-4.jpg) / An electric violin designed by Rochester Institute of Technology graduate student Jayden Zhou.[Jayden Zhou (CC-BY-SA)](https://creativecommons.org/licenses/by-sa/4.0/legalcode)


When I read alarmist articles about this new technology, I’ll sometimes think back to the early days of 3D modeling systems and how some people thought they would replace designers and artists. Those fears were ultimately dispelled, and designers never went back to the large blueprints and drafting boards of old.


Just as Google can make it easier for a journalist to conduct research for an article or find someone to interview, I believe AI can serve as a valuable wellspring of inspiration in the designer’s toolbox.


*[Juan Noguera](https://theconversation.com/profiles/juan-noguera-1413118) is assistant professor of design at the [Rochester Institute of Technology](https://theconversation.com/institutions/rochester-institute-of-technology-1379)*


*This article is republished from [The Conversation](https://theconversation.com) under a Creative Commons license. Read the [original article](https://theconversation.com/dall-e-2-and-midjourney-can-be-a-boon-for-industrial-designers-199267).*















## Tags:


### Autogenerated tags:
dall-e cc-by-sa antigua 3d noguera
