# Everybody’s talking about Mistral, an upstart French challenger to OpenAI
## "Mixture of experts" Mixtral 8x7B helps open-weights AI punch above its weight class.
## Information:

+ Link: https://arstechnica.com/information-technology/2023/12/new-french-ai-model-makes-waves-by-matching-gpt-3-5-on-benchmarks/
+ Source: Ars Technica
+ Author: Benj Edwards
+ Date published: 12 December 2023, 20:15
+ Date scraped: 12 December 2023, 21:02

## Article:
![Main article image](https://cdn.arstechnica.net/wp-content/uploads/2023/12/french_robot_1-760x380.jpg)







On Monday, Mistral AI [announced](https://mistral.ai/news/mixtral-of-experts/) a new AI language model called Mixtral 8x7B, a "mixture of experts" (MoE) model with open weights that reportedly truly matches OpenAI's [GPT-3.5](https://arstechnica.com/information-technology/2022/12/openai-invites-everyone-to-test-new-ai-powered-chatbot-with-amusing-results/) in performance—an achievement that has been claimed by others in the past but is being taken seriously by AI heavyweights such as OpenAI's [Andrej Karpathy](https://x.com/karpathy/status/1734251375163511203?s=20) and [Jim Fan](https://x.com/DrJimFan/status/1734269362100437315?s=20). That means we're closer to having a ChatGPT-3.5-level AI assistant that can run freely and locally on our devices, given the right implementation.


Mistral, [based in Paris](https://mistral.ai/) and founded by Arthur Mensch, Guillaume Lample, and Timothée Lacroix, has seen a rapid rise in the AI space recently. It has been quickly [raising venture capital](https://www.bloomberg.com/news/articles/2023-12-04/openai-rival-mistral-nears-2-billion-valuation-with-nvidia-funding?sref=gni836kR) to become a sort of French anti-OpenAI, championing smaller models with eye-catching performance. Most notably, Mistral's models run locally with open weights that can be downloaded and used with fewer restrictions than closed AI models from OpenAI, Anthropic, or Google. (In this context "weights" are the computer files that represent a trained neural network.)


Mixtral 8x7B can process a 32K token context window and works in French, German, Spanish, Italian, and English. It works much like ChatGPT, in that it can assist with compositional tasks, analyze data, troubleshoot software, and write programs. Mistral claims that it outperforms Meta's much larger [LLaMA 2 70B](https://arstechnica.com/information-technology/2023/07/meta-launches-llama-2-an-open-source-ai-model-that-allows-commercial-applications/) (70 billion parameter) [large language model](https://arstechnica.com/science/2023/07/a-jargon-free-explanation-of-how-ai-large-language-models-work/) and that it matches or exceeds OpenAI's GPT-3.5 on certain benchmarks, as seen in the chart below.


[![A chart of Mixtral 8x7B performance vs. LLaMA 2 70B and GPT-3.5, provided by Mistral.](https://cdn.arstechnica.net/wp-content/uploads/2023/12/overview-640x412.png)](https://cdn.arstechnica.net/wp-content/uploads/2023/12/overview.png) / A chart of Mixtral 8x7B performance vs. LLaMA 2 70B and GPT-3.5, provided by Mistral.Mistral


The speed at which open-weights AI models have caught up with OpenAI's top offering a year ago has taken many by surprise. Pietro Schirano, the founder of EverArt, [wrote on X](https://x.com/skirano/status/1734351099451023534?s=20), "Just incredible. I am running Mistral 8x7B instruct at 27 tokens per second, completely locally thanks to @LMStudioAI. A model that scores better than GPT-3.5, locally. Imagine where we will be 1 year from now."


LexicaArt founder Sharif Shameem [tweeted](https://x.com/sharifshameem/status/1734470299314459108?s=20), "The Mixtral MoE model genuinely feels like an inflection point — a true GPT-3.5 level model that can run at 30 tokens/sec on an M1. Imagine all the products now possible when inference is 100% free and your data stays on your device." To which Andrej Karpathy [replied](https://x.com/karpathy/status/1734618776430150122?s=20), "Agree. It feels like the capability / reasoning power has made major strides, lagging behind is more the UI/UX of the whole thing, maybe some tool use finetuning, maybe some RAG databases, etc."


Mixture of experts
------------------


So what does mixture of experts (MoE) mean? As this excellent [Hugging Face guide](https://huggingface.co/blog/moe) explains, it refers to a machine-learning model architecture where a gate network routes input data to different specialized neural network components, known as "experts," for processing. The advantage of this is that it enables more efficient and scalable model training and inference, as only a subset of experts are activated for each input, reducing the computational load compared to monolithic models with equivalent parameter counts.


In layperson's terms, a MoE is like having a team of specialized workers (the "experts") in a factory, where a smart system (the "gate network") decides which worker is best suited to handle each specific task. This setup makes the whole process more efficient and faster, as each task is done by an expert in that area, and not every worker needs to be involved in every task, unlike in a traditional factory where every worker might have to do a bit of everything.


OpenAI has been [rumored to use](https://the-decoder.com/gpt-4-architecture-datasets-costs-and-more-leaked/) a MoE system with [GPT-4](https://arstechnica.com/information-technology/2023/03/openai-announces-gpt-4-its-next-generation-ai-language-model/), accounting for some of its performance. In the case of Mixtral 8x7B, the name implies that the model is a mixture of eight 7 billion-parameter neural networks, but as Karpathy [pointed](https://twitter.com/karpathy/status/1734251375163511203?s=20) out in a tweet, the name is slightly misleading because, "it is not all 7B params that are being 8x'd, only the FeedForward blocks in the Transformer are 8x'd, everything else stays the same. Hence also why total number of params is not 56B but only 46.7B."


Mixtral is [not the first](https://x.com/DrJimFan/status/1733515729691906304?s=20) "open" mixture of experts model, but it is notable for its relatively small size in parameter count and performance. It's out now, available on [Hugging Face](https://huggingface.co/models?search=mistralai/Mixtral) and [Bittorrent](https://x.com/MistralAI/status/1733150512395038967?s=20). People have been running it locally using an app called [LM Studio](https://lmstudio.ai/beta-releases.html). Also, Mistral began [offering beta access](https://mistral.ai/news/la-plateforme/) to an API for three levels of Mistral models on Monday.














## Tags:


### Autogenerated tags:
mixtral openai 8x7b gpt-3.5 karpathy
