# Fearing “loss of control,” AI critics call for 6-month pause in AI development
## "This pause should be public and verifiable, and include all key actors."
## Information:

+ Link: https://arstechnica.com/information-technology/2023/03/fearing-loss-of-control-ai-critics-call-for-6-month-pause-in-ai-development/
+ Source: Ars Technica
+ Author: Benj Edwards
+ Date published: 29 March 2023, 20:05
+ Date scraped: 29 March 2023, 21:00

## Article:
![Main article image](https://cdn.arstechnica.net/wp-content/uploads/2023/03/AI_pause_hero_1-760x380.jpg)







On Wednesday, the Future of Life Institute published an [open letter](https://futureoflife.org/open-letter/pause-giant-ai-experiments/) on its website calling on AI labs to "immediately pause for at least 6 months the training of AI systems more powerful than [GPT-4](https://arstechnica.com/information-technology/2023/03/openai-announces-gpt-4-its-next-generation-ai-language-model/)." Signed by Elon Musk and several prominent AI researchers, the letter quickly began to [draw attention](https://www.reuters.com/technology/musk-experts-urge-pause-training-ai-systems-that-can-outperform-gpt-4-2023-03-29/) in the press—and some [criticism](https://twitter.com/timnitGebru/status/1640924853493714944?s=20) on social media.


Earlier this month, OpenAI released [GPT-4](https://arstechnica.com/information-technology/2023/03/openai-announces-gpt-4-its-next-generation-ai-language-model/), an AI model that can perform compositional tasks and allegedly pass standardized tests at a human level, although those claims are still being evaluated by research. Regardless, GPT-4 and [Bing Chat's](https://arstechnica.com/information-technology/2023/02/ai-powered-bing-chat-loses-its-mind-when-fed-ars-technica-article/) advancement in capabilities over previous AI models [spooked some experts](https://arstechnica.com/information-technology/2023/03/openai-checked-to-see-whether-gpt-4-could-take-over-the-world/) who believe we are heading toward super-intelligent AI systems faster than previously expected.


Along these lines, the Future of Life Institute argues that recent advancements in AI have led to an "out-of-control race" to develop and deploy AI models that are difficult to predict or control. They believe that the lack of planning and management of these AI systems is concerning and that powerful AI systems should only be developed once their effects are well-understood and manageable. As they write in the letter:



> AI systems with human-competitive intelligence can pose profound risks to society and humanity, as shown by extensive research and acknowledged by top AI labs. As stated in the widely-endorsed [Asilomar AI Principles](https://futureoflife.org/open-letter/ai-principles/), Advanced AI could represent a profound change in the history of life on Earth, and should be planned for and managed with commensurate care and resources.
> 
> 


In particular, the letter poses four loaded questions, some of which presume hypothetical scenarios that are highly controversial in some quarters of the AI community, including the loss of "all the jobs" to AI and "loss of control" of civilization:


* *"Should* we let machines flood our information channels with propaganda and untruth?"
* *"Should* we automate away all the jobs, including the fulfilling ones?*"*
* *"Should* we develop nonhuman minds that might eventually outnumber, outsmart, obsolete, and replace us?"
* *"Should* we risk loss of control of our civilization?"


To address these potential threats, the letter calls on AI labs to "immediately pause for at least 6 months the training of AI systems more powerful than GPT-4." During the pause, the authors propose that AI labs and independent experts collaborate to establish shared safety protocols for AI design and development. These protocols would be overseen by independent outside experts and should ensure that AI systems are "safe beyond a reasonable doubt."


However, it's unclear what "more powerful than GPT-4" actually means in a practical or regulatory sense. The letter does not specify a way to ensure compliance by measuring the relative power of a [multimodal](https://arstechnica.com/information-technology/2023/03/microsoft-unveils-kosmos-1-an-ai-language-model-with-visual-perception-abilities/) or large language model. In addition, OpenAI has [specifically avoided](https://www.theverge.com/2023/3/15/23640180/openai-gpt-4-launch-closed-research-ilya-sutskever-interview) publishing technical details about how GPT-4 works.


The Future of Life Institute is a nonprofit founded in 2014 by a group of scientists concerned about existential risks facing humanity, including biotechnology, nuclear weapons, and climate change. In addition, the hypothetical existential risk from AI has been a key focus for the group. According [to Reuters](https://www.reuters.com/technology/musk-experts-urge-pause-training-ai-systems-that-can-outperform-gpt-4-2023-03-29/), the organization is primarily funded by the Musk Foundation, London-based effective altruism group [Founders Pledge](https://founderspledge.com/), and [Silicon Valley Community Foundation](https://www.siliconvalleycf.org/).


Notable signatories to the letter [confirmed by a Reuters reporter](https://twitter.com/readkrystalhu/status/1640919637821911040?s=20) include the aforementioned Tesla CEO Elon Musk, AI pioneers Yoshua Bengio and Stuart Russell, Apple co-founder Steve Wozniak, Stability AI CEO Emad Mostaque, and author Yuval Noah Harari. The open letter is available for anyone on the Internet to sign without verification, which initially led to the inclusion of some falsely added names, such as former Microsoft CEO Bill Gates, OpenAI CEO Sam Altman, and fictional character [John Wick](https://twitter.com/GustavoCollar/status/1640955659763023873?s=20). Those names were later removed.







## “AI hype” and potential regulation


Despite the urgent tone of the letter, not everyone buys into the potential existential risk from AI, preferring to focus on other less-hypothetical AI harms first. As we [previously mentioned](https://arstechnica.com/information-technology/2023/03/openai-checked-to-see-whether-gpt-4-could-take-over-the-world/), there's a strong disconnect among [factions](https://twitter.com/xuanalogue/status/1641034516994179072?s=20) of the AI community about which potential AI dangers to focus on.


Some critics already take issue with GPT-4. Prominent AI ethicist [Timnit Gibru](https://en.wikipedia.org/wiki/Timnit_Gebru) [quipped](https://twitter.com/timnitGebru/status/1640924853493714944?s=20) on Twitter, "They want to stop people from using stuff 'with more power' than GPT-4, but GPT-4 is fine right?"


Dr. Emily Bender, a frequent critic of commercialized large language models, called portions of the open letter "unhinged #AIhype" [on Twitter](https://twitter.com/emilymbender/status/1640922750746501121?s=20), noting that the fear of AI becoming superhuman is helping to drive publicity for these models, which have rolled out widely despite issues of social bias and tendencies to completely make up information in a convincing way.


"The risks and harms have never been about 'too powerful AI,'" Bender wrote [in a tweet](https://twitter.com/emilymbender/status/1640922978165882880?s=20) that mentions her paper, [On the Dangers of Stochastic Parrots](https://dl.acm.org/doi/10.1145/3442188.3445922) (2021). "Instead," she [continued](https://twitter.com/emilymbender/status/1640923122831626247?s=20), "They're about concentration of power in the hands of people, about reproducing systems of oppression, about damage to the information ecosystem, and about damage to the natural ecosystem (through profligate use of energy resources)."


Still, many on both sides of the AI safety/ethics debate agree that the pace of change in the AI space has been overwhelmingly rapid over this past year, giving legal systems, academic researchers, ethical scholars, and culture little time to adapt to the new tools, which are poised to potentially [kick-start radical changes](https://arstechnica.com/information-technology/2023/03/generative-ai-set-to-affect-300-million-jobs-across-major-economies/) in the economy.


[![A screenshot of GPT-4's introduction to ChatGPT Plus customers from March 14, 2023.](https://cdn.arstechnica.net/wp-content/uploads/2023/03/introducing_gpt4-640x428.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2023/03/introducing_gpt4.jpg) / A screenshot of GPT-4's introduction to ChatGPT Plus customers from March 14, 2023.Benj Edwards / Ars Technica


As the open letter points out, even OpenAI urges slower progress on AI. In a [statement on artificial general intelligence](https://openai.com/blog/planning-for-agi-and-beyond) (a term that roughly means human equivalent AI or greater) published earlier this year, OpenAI wrote, "At some point, it may be important to get independent review before starting to train future systems, and for the most advanced efforts to agree to limit the rate of growth of compute used for creating new models."


The Future of Life Institute believes that the time to limit that growth is now, and that if "all key actors" don't agree to slow AI research soon, "governments should step in and institute a moratorium."


However, there might be some difficulty on the government-regulation front. As The Guardian [points out](https://www.theguardian.com/technology/2023/mar/29/elon-musk-joins-call-for-pause-in-creation-of-giant-ai-digital-minds?CMP=share_btn_tw), "The call for strict regulation stands in stark contrast to the UK government’s flagship [AI regulation white paper](https://www.gov.uk/government/publications/ai-regulation-a-pro-innovation-approach), published on Wednesday, which contains no new powers at all."


Meanwhile, in the US, there appears to be little government consensus about potential AI regulation, especially in regard to large language models such as GPT-4. In October, the Biden administration proposed an "[AI Bill of Rights](https://arstechnica.com/information-technology/2022/10/biden-proposes-new-bill-of-rights-to-protect-americans-from-ai-snooping/)" to protect Americans from AI harms, but it serves as suggested guidelines rather than a document backed by force of law. Also, it does not specifically address potential harms from AI chatbots that [emerged](https://arstechnica.com/information-technology/2022/12/openai-invites-everyone-to-test-new-ai-powered-chatbot-with-amusing-results/) after the guidelines were written.


Whether the points laid out in the open letter present the best way forward or not, it seems likely that the disruptive power of AI models—whether through super-intelligence (as some argue) or through a reckless rollout full of excessive hype (as others argue)—will land on regulators' doorsteps eventually.












## Tags:


### Autogenerated tags:
gpt-4 openai ceo
