# From toy to tool: DALL-E 3 is a wake-up call for visual artists—and the rest of us
## AI image synthesis is getting more capable at executing ideas, and it's not slowing down.
## Information:

+ Link: https://arstechnica.com/information-technology/2023/11/from-toy-to-tool-dall-e-3-is-a-wake-up-call-for-visual-artists-and-the-rest-of-us/
+ Source: Ars Technica
+ Author: Benj Edwards
+ Date published: 16 November 2023, 12:20
+ Date scraped: 16 November 2023, 13:01

## Article:
![Main article image](https://cdn.arstechnica.net/wp-content/uploads/2023/10/dalle3_composite_hero_5-760x380.jpg)







In October, OpenAI launched its newest AI image generator—DALL-E 3—[into wide release](https://openai.com/blog/dall-e-3-is-now-available-in-chatgpt-plus-and-enterprise) for ChatGPT subscribers. DALL-E can pull off media generation tasks that would have seemed absurd just two years ago—and although it can inspire delight with its unexpectedly detailed creations, it also brings trepidation for some. Science fiction forecast tech like this long ago, but seeing machines upend the creative order feels different when it's actually happening before our eyes.


"It’s impossible to dismiss the power of AI when it comes to image generation," says [Aurich Lawson](https://arstechnica.com/author/aurich-lawson/), Ars Technica's creative director. "With the rapid increase in visual acuity and ability to get a usable result, there’s no question it’s beyond being a gimmick or toy and is a legit tool."


With the advent of AI image synthesis, it's looking increasingly like the future of media creation for many will come through the aid of creative machines that can replicate any artistic style, format, or medium. Media reality is becoming completely fluid and malleable. But how is AI image synthesis getting more capable so rapidly—and what might that mean for artists ahead?


Using AI to improve itself
--------------------------


We [first covered](https://arstechnica.com/information-technology/2023/09/openai-announces-dall-e-3-a-next-gen-ai-image-generator-based-on-chatgpt/) DALL-E 3 upon its announcement from OpenAI in late September, and since then, we've used it quite a bit. For those just tuning in, DALL-E 3 is an AI model (a neural network) that uses a technique called [latent diffusion](https://en.wikipedia.org/wiki/Diffusion_model) to pull images it "recognizes" out of noise, progressively, based on written prompts provided by a user—or in this case, by [ChatGPT](https://arstechnica.com/ai/2023/08/how-chatgpt-turned-generative-ai-into-an-anything-tool/). It works using the same underlying technique as other prominent image synthesis models like [Stable Diffusion](https://arstechnica.com/information-technology/2023/07/stable-diffusion-xl-puts-ai-generated-visual-worlds-at-your-gpus-command/) and [Midjourney](https://arstechnica.com/information-technology/2023/03/ai-imager-midjourney-v5-stuns-with-photorealistic-images-and-5-fingered-hands/).


You type in a description of what you want to see, and DALL-E 3 creates it.


ChatGPT and DALL-E 3 currently work hand-in-hand, making AI art generation into an interactive and conversational experience. You tell ChatGPT (through the [GPT-4](https://arstechnica.com/information-technology/2023/11/openai-introduces-gpt-4-turbo-larger-memory-lower-cost-new-knowledge/) large language model) what you'd like it to generate, and it writes ideal prompts for you and submits them to the DALL-E backend. DALL-E returns the images (usually two at a time), and you see them appear through the ChatGPT interface, whether through the web or via the [ChatGPT app](https://arstechnica.com/information-technology/2023/05/ai-in-your-pocket-chatgpt-officially-comes-to-iphone-with-new-app/).



* An AI-generated image of a fictional "Beet Bros." arcade game, created by DALL-E 3. 


 DALL-E 3 / Benj Edwards
* An AI-generated image of Abraham Lincoln holding a sign that is intended to say "Ars Technica," created by DALL-E 3. 


 DALL-E 3 / Benj Edwards
* An AI-generated image of autumn leaves, created by DALL-E 3. 


 DALL-E 3 / Benj Edwards
* An AI-generated image of a pixelated Christmas scene created by DALL-E 3. 


 DALL-E 3 / Benj Edwards
* An AI-generated image of a neon shop sign created by DALL-E 3. 


 DALL-E 3 / Benj Edwards
* An AI-generated image of a plate of pickles, created by DALL-E 3. 


 DALL-E 3 / Benj Edwards
* An AI-generated illustration of a promotional image for "The Cave BBS," created by DALL-E 3. 


 DALL-E 3 / Benj Edwards


Many times, ChatGPT will vary the artistic medium of the outputs, so you might see the same subject depicted in a range of styles—such as photo, illustration, render, oil painting, or vector art. You can also change the aspect ratio of the generated image from the square default to "wide" (16:9) or "tall" (9:16).


OpenAI has not revealed the dataset used to train DALL-E 3, but if previous models are any indication, it's likely that OpenAI used hundreds of millions of images found online and licensed from Shutterstock libraries. To learn visual concepts, the AI training process typically associates words from descriptions of images found online (through captions, alt tags, and metadata) with the images themselves. Then it encodes that association in a multidimensional vector form. However, those scraped captions—written by humans—aren't always detailed or accurate, which leads to some faulty associations that reduce an AI model's ability to follow a written prompt.


To get around that problem, OpenAI decided to use AI to improve itself. As detailed in the DALL-E 3 [research paper](https://cdn.openai.com/papers/dall-e-3.pdf), the team at OpenAI trained this new model to surpass its predecessor by using synthetic (AI-written) image captions generated by [GPT-4V](https://arstechnica.com/information-technology/2023/09/chatgpt-goes-multimodal-with-image-recognition-and-speech-synthesis/), the visual version of GPT-4. With GPT-4V writing the captions, the team generated far more accurate and detailed descriptions for the DALL-E model to learn from during the training process. That made a world of difference in terms of DALL-E's prompt fidelity—accurately rendering what is in the written prompt. (It does hands pretty well, too.)



* What the older DALL-E 2 generated when we prompted our old standby, "a muscular barbarian with weapons beside a CRT television set, cinematic, 8K, studio lighting." This was considered groundbreaking, state-of-the art AI image synthesis in April 2022. 


 DALL-E 2 / Benj Edwards
* What the newer DALL-E 3 generated in October 2023 when we prompted our old standby, "a muscular barbarian with weapons beside a CRT television set, cinematic, 8K, studio lighting." 


 DALL-E 3 / Benj Edwards








In addition, DALL-E 3 is very good at rendering accurate text compared to DALL-E 2 and some other image synthesis models. This is another effect of the highly detailed captioning created by GPT-4V:  "When building our captioner, we paid special attention to ensuring that it was able to include prominent words found in images in the captions it generated," writes the DALL-E 3 team in its paper. "As a result, DALL-E 3 can generate text when prompted."


[![An example of DALL-E 3 rendering text: "A muscular barbarian with weapons stands confidently beside a CRT television set displaying the text 'Ars Technica'. The scene is cinematic with 8K resolution and dramatic studio lighting."](https://cdn.arstechnica.net/wp-content/uploads/2023/11/barbarian_tv_arstechnica_full-640x366.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2023/11/barbarian_tv_arstechnica_full.jpg) / An example of DALL-E 3 rendering text: "A muscular barbarian with weapons stands confidently beside a CRT television set displaying the text 'Ars Technica'. The scene is cinematic with 8K resolution and dramatic studio lighting."DALL-E 3 / Benj Edwards


DALL-E's text rendering ability isn't perfect—some words have extra or missing characters, and others seem garbled at times. The team speculates that this is due to the [token encoder](https://platform.openai.com/tokenizer) they used. Tokens are [fragments of words](https://help.openai.com/en/articles/4936856-what-are-tokens-and-how-to-count-them) (and sometimes whole words) used to represent words in machine learning models such as GPT-4 and the prompt interpreter for DALL-E 3. The reliance on tokens sometimes creates a type of blindness for certain words or spellings when chunks of words get lumped into a single token together.


For example, the word "dog" is represented to DALL-E 3 as a single token and not three characters (D-O-G), as you might expect. "When the model encounters text in a prompt, it actually sees tokens that represent whole words and must map those to letters in an image," the team writes. "In future work, we would like to explore conditioning on character-level language models to help improve this behavior."


What does it mean for artists?
------------------------------


By now, you've seen some of what DALL-E 3 can do. It vastly exceeds the state of the art from a year ago, and it dwarfs [DALL-E 1](https://openai.com/research/dall-e) from 2021. It's a technical triumph. But it's still very difficult to write about AI image generators without an asterisk. The technology is highly divisive. For some people, the tech represents an [exciting development](https://arstechnica.com/gadgets/2023/04/artists-astound-with-ai-generated-film-stills-from-a-parallel-universe/) in creative expression, but for others, it symbolizes insensitivity and corporate greed.


"I don't want to use the technology. It's literally a giant stew of plagiarism," says [Gwendolyn Wood](https://www.gwendolynwood.com/), an illustrator and graphic designer based in Seattle who replied to questions from Ars Technica. She frequently works in non-digital media, such as watercolors. "I'm sympathetic to people who designed it, but I think it will further rob our world of joyful experiences. It just makes me so sad. I hope that handmade art will remain something that matters to people."


By referring to plagiarism, Wood is referencing the fact that many AI image generators have been trained on scrapes of copyright-protected works downloaded from the Internet without artist permission. The issue of whether training an AI model on scraped work falls under fair use has [not yet been resolved](https://arstechnica.com/tech-policy/2023/11/artists-may-poison-ai-models-before-copyright-office-can-issue-guidance/) in US law, but the practice has made image synthesis feel like an antagonistic technology to many artists who feel like they might be replaced by it. We have covered this [angst](https://arstechnica.com/information-technology/2022/12/artstation-artists-stage-mass-protest-against-ai-generated-artwork/) in detail at Ars Technica over the past year through dozens of articles.



* An AI-generated image of a fictional book, "The Hardy Boys and the Ancient Thirst Trap," created by DALL-E 3. 


 DALL-E 3 / Benj Edwards
* An AI-generated image of a hamster riding a dragon underwater, created by DALL-E 3. 


 DALL-E 3 / Benj Edwards
* An AI-generated watercolor image of a ghost sitting on a planet, created by DALL-E 3. 


 DALL-E 3 / Benj Edwards
* An AI-generated image of a fictional Atari 2600 game, "Cabbage Patch Squatch," created by DALL-E 3. 


 DALL-E 3 / Benj Edwards
* An AI-generated illustration of a running man with a floppy disk for a head, created by DALL-E 3. 


 DALL-E 3 / Benj Edwards
* An AI-generated render-style image of a fictional 1990s "Gerbil Essences" shampoo ad, created by DALL-E 3. 


 DALL-E 3 / Benj Edwards
* An AI-generated fictional 1980s home magazine decoration spread of "way too many pumpkins," created by DALL-E 3. 


 DALL-E 3 / Benj Edwards
* An AI-generated promotional photo of a fictional "Slurge" soft drink, created by DALL-E 3. 


 DALL-E 3 / Benj Edwards
* An AI-generated image of a fictional 1990s "Just Shoulders" shampoo ad created by DALL-E 3. 


 DALL-E 3 / Benj Edwards
* An AI-generated image of fictional "Frosted Prick" cereal, created by DALL-E 3. 


 DALL-E 3 / Benj Edwards


To address this issue, some companies like Adobe (with [Firefly](https://arstechnica.com/information-technology/2023/03/ethical-ai-art-generation-adobe-firefly-may-be-the-answer/)) and [Getty Images](https://arstechnica.com/ai/2023/09/getty-images-subscribers-to-get-access-to-ai-image-generator/) have trained AI image models solely on public domain art and images they have the rights to use, licensed through their stock photo archives. But it's not a perfect solution because some artists and photographers don't feel that the company's use of their work to [train their replacements](https://petapixel.com/2023/06/26/photographers-upset-that-adobe-firefly-ai-is-competing-against-them/) is fair or equitable.


In some ways, AI art is a continuation of an ancient trend. For thousands of years, innovations in art have made it easier for humans to make complex art faster—metal chisels, paper, paintbrushes, mass-produced paints, pencils, cameras, airbrushes, digital photo editors, and vector illustration software were all revolutionary in their day. Many advances have gone hand-in-hand with improvements in the mass production of artistic works—a development that some critics [once thought](https://en.wikipedia.org/wiki/The_Work_of_Art_in_the_Age_of_Mechanical_Reproduction) would diminish the value of art. Each advance allowed for expressing ideas faster and communicating them more broadly. Image synthesis builds upon that tradition by reducing friction between idea and execution.





But faster isn't always better, according to Wood, who prefers the satisfying and often therapeutic process of creating art by hand.


"I have heard the argument in favor of [AI art] is that it will save time and that it allows people without artistic training to make art they're proud of and bring their creativity to life," says Wood. "My response to that is that time spent creating is not wasted time. It's incredibly important time that is nourishing to the soul." And she emphasized the handmade element of her art: "Everyone should create art with their hands! [AI art] is not giving people a skill, it's taking away a more joyful experience they could have physically creating art, if they could be humble enough to enjoy the process of learning."


While AI art can feel like a continuation of previous advances in art technology, this time feels different because we’re outsourcing a portion of the creative process to a machine. Prior to that, ideas only came from people—whether your own brain, in conversation, in books, or through audiovisual communications. Now, machines also have ideas. It’s the first step in an uncharted type of partnership.


“Taste is the new skill”—AI art as an accessibility tool
--------------------------------------------------------


As wholesome as handmade art sounds, not everyone can physically create art due to mental or physical limitations. Over the past year, we've heard from several people with disabilities who enjoy using image synthesis to express themselves in ways they could not otherwise. You can find their stories through searches on [Reddit](https://www.reddit.com/r/StableDiffusion/comments/zsm6bz/you_know_i_never_actually_thought_about_it_this/) or [social media](https://x.com/ClaireSilver12/status/1621963416435937281?s=20).


"I have stage 4 cancer and aiart [sic] actually gave me reason to keep fighting it," [wrote](https://www.reddit.com/r/StableDiffusion/comments/zsm6bz/comment/j1alf8l/?utm_source=share&utm_medium=web3x&utm_name=web3xcss&utm_term=1&utm_content=share_button) a user named bodden3113 on Reddit in December 2022. "I no longer have to wait till I'm not doing chemo to figure out how to draw hair or decide if i should even learn if i won't live long enough to see on paper what i had in mind... Why do we have to do things the same way it was always done?"


One artist, [Claire Silver](https://www.clairesilver.com/), has been using AI art collaboratively since 2018 and gained renown from it, becoming the first AI-augmented artist to sign with the [WME talent agency](https://www.wmeagency.com/). "I have a chronic, disabling illness, an experience that has galvanized my love for augmenting skill in favor of expression," she told Ars Technica in an interview. "I grew up in poverty and have changed my family’s life with my AI art."


[!["Skins," a collaborative AI-human artwork created by Claire Silver.](https://cdn.arstechnica.net/wp-content/uploads/2023/11/skins_by_claire_silver-640x427.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2023/11/skins_by_claire_silver.jpg) / "Skins," a collaborative AI-human artwork created by Claire Silver.[Claire Silver](https://www.clairesilver.com/selected-work?pgid=ljqf2xmk-fd032fff-d391-4091-8005-d03420215808)


Silver sees most criticism of AI art as being shortsighted. The technology exists, and it will have an undeniable impact, both positive and negative, based on how it is used. "AI is transformative in the same way that cavemen discovering fire was transformative. Fire isn’t good or bad. It just is. It’s a homo-sapiens-sapiens moment for our species, and for better and worse, we can’t go back to the darkness."


Given technology's evolving role in augmenting human art throughout history, perhaps we've confused the meaning of the process with the meaning of the content. "In my opinion, adapting in the age of AI means finding what makes us human and leaning into it," says Silver. "Artists have learned that skill is what matters, and while admirable, skill has been king for millennia. There’s room for new perspectives."


Perhaps our focus on the value of time-consuming labor and a high degree of artistic skill unduly keeps people from expressing themselves, she wonders. "Art isn’t about skill for me. It’s about emotion, imagination, meaning—the things that make us human," she says. "Is a future where we value those things over technical ability really so terrible? Given an infinite answer machine, those with the imagination and discernment to ask the right questions will succeed. With AI, taste is the new skill."


Aurich Lawson sees the issue of skill in AI art differently, with some being better at using generative tools than others. "There may be a new field of people who are AI wranglers, using a lot of tools and experience to navigate those waters, but they’re ultimately going to be developing skill sets and processes much like anyone who is a pro in tools like Photoshop."












## Tags:


### Autogenerated tags:
dall-e ai-generated chatgpt openai gpt-4 gpt-4v crt 8k
