# Google’s RT-2 AI model brings us one step closer to WALL-E
## "First-of-its-kind" robot AI model can recognize trash and perform complex actions.
## Information:

+ Link: https://arstechnica.com/information-technology/2023/07/googles-rt-2-ai-model-brings-us-one-step-closer-to-wall-e/
+ Source: Ars Technica
+ Author: Benj Edwards
+ Date published: 28 July 2023, 21:32
+ Date scraped: 28 July 2023, 22:00

## Article:
![Main article image](https://cdn.arstechnica.net/wp-content/uploads/2023/07/rt2_hero_1-760x380.jpg)







On Friday, Google DeepMind announced [Robotic Transformer 2](https://www.deepmind.com/blog/rt-2-new-model-translates-vision-and-language-into-action) (RT-2), a ["first-of-its-kind"](https://blog.google/technology/ai/google-deepmind-rt2-robotics-vla-model/) vision-language-action (VLA) model that uses data scraped [from the Internet](https://paperswithcode.com/dataset/webli) to enable better robotic control through plain language commands. The ultimate goal is to create general-purpose robots that can navigate human environments, similar to fictional robots like [WALL-E](https://en.wikipedia.org/wiki/WALL-E) or C-3PO.


When a human wants to learn a task, we often read and observe. In a similar way, RT-2 utilizes a large language model (the tech behind [ChatGPT](https://arstechnica.com/information-technology/2022/12/openai-invites-everyone-to-test-new-ai-powered-chatbot-with-amusing-results/)) that has been trained on text and images found online. RT-2 uses this information to recognize patterns and perform actions even if the robot hasn't been specifically trained to do those tasks—a concept called generalization.


For example, Google says that RT-2 can allow a robot to recognize and throw away trash without having been specifically trained to do so. It uses its understanding of what trash is and how it is usually disposed to guide its actions. RT-2 even sees discarded food packaging or banana peels as trash, despite the potential ambiguity.


[![Examples of generalized robotic skills RT-2 can perform that were not in the robotics data. Instead, it learned about them from scrapes of the web.](https://cdn.arstechnica.net/wp-content/uploads/2023/07/Fig_203-640x502.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2023/07/Fig_203-scaled.jpg) / Examples of generalized robotic skills RT-2 can perform that were not in the robotics data. Instead, it learned about them from scrapes of the web.Google


In another example, [The New York Times](https://www.nytimes.com/2023/07/28/technology/google-robots-ai.html) recounts a Google engineer giving the command, "Pick up the extinct animal," and the RT-2 robot locates and picks out a dinosaur from a selection of three figurines on a table.


This capability is notable because robots have typically been trained from a vast number of manually acquired data points, making that process difficult due to the high time and cost of covering every possible scenario. Put simply, the real world is a dynamic mess, with changing situations and configurations of objects. A practical robot helper needs to be able to adapt on the fly in ways that are impossible to explicitly program, and that's where RT-2 comes in.


## More than meets the eye


With RT-2, Google DeepMind has adopted a strategy that plays on the strengths of [transformer AI models](https://blogs.nvidia.com/blog/2022/03/25/what-is-a-transformer-model/), known for their capacity to generalize information. RT-2 draws on earlier AI work at Google, including the Pathways Language and Image model ([PaLI-X](https://ai.googleblog.com/2022/09/pali-scaling-language-image-learning-in.html)) and the Pathways Language model Embodied ([PaLM-E](https://arstechnica.com/information-technology/2023/03/embodied-ai-googles-palm-e-allows-robot-control-with-natural-commands/)). Additionally, RT-2 was also co-trained on data from its predecessor model ([RT-1](https://ai.googleblog.com/2022/12/rt-1-robotics-transformer-for-real.html)), which was collected over a period of 17 months in an "office kitchen environment" by 13 robots.


The RT-2 architecture involves fine-tuning a pre-trained VLM model on robotics and web data. The resulting model processes robot camera images and predicts actions that the robot should execute.


[![Google fine-tuned a VLM model on robotics and web data. The resulting model takes in robot camera images and predicts actions for a robot to perform.](https://cdn.arstechnica.net/wp-content/uploads/2023/07/Fig_201-640x614.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2023/07/Fig_201-scaled.jpg) / Google fine-tuned a VLM model on robotics and web data. The resulting model takes in robot camera images and predicts actions for a robot to perform.Google


Since RT-2 uses a language model to process information, Google chose to represent actions as tokens, which are traditionally fragments of a word. "To control a robot, it must be trained to output actions," Google [writes](https://www.deepmind.com/blog/rt-2-new-model-translates-vision-and-language-into-action?utm_source=keywordblog&utm_medium=referral&utm_campaign=rt2). "We address this challenge by representing actions as tokens in the model’s output—similar to language tokens—and describe actions as strings that can be processed by standard natural language tokenizers."


In developing RT-2, researchers used the same method of breaking down robot actions into smaller parts as they did with the first version of the robot, RT-1. They found out that by turning these actions into a series of symbols or codes (a "string" representation), they could teach the robot new skills using the same learning models they use for processing web data.


The model also utilizes chain-of-thought reasoning, enabling it to perform multi-stage reasoning like choosing an alternative tool (a rock as an improvised hammer) or picking the best drink for a tired person (an energy drink).


[![According to Google, chain-of-thought reasoning enables a robot control model that perform complex actions when instructed.](https://cdn.arstechnica.net/wp-content/uploads/2023/07/Fig_208-640x573.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2023/07/Fig_208.jpg) / According to Google, chain-of-thought reasoning enables a robot control model that perform complex actions when instructed.Google


Google says that in over 6,000 trials, RT-2 was found to perform as well as its predecessor, RT-1, on tasks that it was trained for, referred to as "seen" tasks. However, when tested with new, "unseen" scenarios, RT-2 almost doubled its performance to 62 percent compared to RT-1's 32 percent.


Although RT-2 shows a great ability to adapt what it has learned to new situations, Google recognizes that it's not perfect. In the "Limitations" section of the [RT-2 technical paper](https://robotics-transformer2.github.io/assets/rt2.pdf), the researchers admit that while including [web data](https://paperswithcode.com/dataset/webli) in the training material "boosts generalization over semantic and visual concepts," it does not magically give the robot new abilities to perform physical motions that it hasn't already learned from its predecessor's robot training data. In other words, it can't perform actions it hasn't physically practiced before, but it gets better at using the actions it already knows in new ways.


While Google DeepMind's ultimate goal is to create general-purpose robots, the company knows that there is still plenty of research work ahead before it gets there. But technology like RT-2 seems like a strong step in that direction.














## Tags:


### Autogenerated tags:
rt-2 google rt-1 deepmind
