# Hear Elvis sing “Baby Got Back” using AI—and learn how it was made
## Despite help from neural networks, it requires more human work than you might think.
## Information:

+ Link: https://arstechnica.com/information-technology/2023/08/hear-elvis-sing-baby-got-back-using-ai-and-learn-how-it-was-made/
+ Source: Ars Technica
+ Author: Benj Edwards
+ Date published: 04 August 2023, 15:32
+ Date scraped: 04 August 2023, 16:01

## Article:
![Main article image](https://cdn.arstechnica.net/wp-content/uploads/2023/08/rockstar_hero_6-760x380.jpg)







Recently, a number of viral music videos from a YouTube channel called [There I Ruined It](https://www.youtube.com/c/ThereIRuinedIt) have included AI-generated voices of famous musical artists singing lyrics from surprising songs. One recent example imagines Elvis singing lyrics to Sir Mix-a-Lot's "[Baby Got Back](https://en.wikipedia.org/wiki/Baby_Got_Back)." Another [features](https://www.youtube.com/watch?v=HyfQVZHmArA) a faux Johnny Cash singing the lyrics to Aqua's "Barbie Girl."


(The original Elvis video has since been [taken down](https://www.youtube.com/watch?v=MINwa4_BVsY) from YouTube due to a copyright claim from Universal Music Group, but thanks to the magic of the Internet, you can [hear it anyway](https://www.youtube.com/watch?v=IXcITn507Jk).)


An excerpt copy of the "Elvis Sings Baby Got Back" video.


Obviously, since Elvis has been dead for 46 years (and Cash for 20), neither man could have actually sung the songs themselves. That's where AI comes in. But as we'll see, although [generative AI](https://arstechnica.com/gadgets/2023/01/the-generative-ai-revolution-has-begun-how-did-we-get-here/) can be amazing, there's still a lot of human talent and effort involved in crafting these musical mash-ups.


To figure out how "There I Ruined It" does its magic, we first reached out to the channel's creator, musician Dustin Ballard. Ballard's response was low in detail, but he laid out the basic workflow. He uses an AI model called [so-vits-svc](https://github.com/svc-develop-team/so-vits-svc) to transform his own vocals he records into those of other artists. "It's currently not a very user-friendly process (and the training itself is even more difficult)," he told Ars Technica in an email, "but basically once you have the trained model (based on a large sample of clean audio references), then you can upload your own vocal track, and it replaces it with the voice that you've modeled. You then put that into your mix and build the song around it."


But let's back up a second: What does "so-vits-svc" mean? The name originates from a series of open source technologies being chained together. The "so" part comes from "[SoftVC](https://github.com/bshall/soft-vc)" (VC for "voice conversion"), which breaks source audio (a singer's voice) into key parts that can be encoded and learned by a neural network. The "VITS" part is an acronym for "Variational Inference with adversarial learning for end-to-end Text-to-Speech," coined in this [2021 paper](https://arxiv.org/abs/2106.06103). VITS takes knowledge of the trained vocal model and generates the converted voice output. And "SVC" means "singing voice conversion"—converting one singing voice to another—as opposed to converting someone's speaking voice.


The recent "There I Ruined It" songs primarily use AI in one regard: The AI model relies on Ballard's vocal performance, but it changes the timbre of his voice to that of someone else, similar to how Respeecher's voice-to-voice technology can [transform](https://arstechnica.com/information-technology/2022/09/james-earl-jones-signed-darth-vader-voice-rights-to-disney-for-ai-use/) one actor's performance of Darth Vader into James Earl Jones' voice. The rest of the song comes from Ballard's arrangement in a conventional music app.


## A complicated process—at the moment


[![The GUI interface for a fork of so-vits-svc.](https://cdn.arstechnica.net/wp-content/uploads/2023/08/sovitssvc-gui-640x408.png)](https://cdn.arstechnica.net/wp-content/uploads/2023/08/sovitssvc-gui.png) / The GUI interface for a fork of so-vits-svc.Michael van Voorst


To get more insight into the musical voice-cloning process with [so-vits-svc-fork](https://github.com/voicepaw/so-vits-svc-fork) (an altered version of the original so-vits-svc), we tracked down Michael van Voorst, the creator of the Elvis voice AI model that Ballard used in his "Baby Got Back" video. He walked us through the steps necessary to create an AI mash-up.


"In order to create an accurate replica of a voice, you start off with creating a data set of clean vocal audio samples from the person you are building a voice model of," said van Voorst. "The audio samples need to be of studio quality for the best results. If they are of lower quality, it will reflect back into the vocal model."


In the case of Elvis, van Voorst used vocal tracks from the singer's famous [*Aloha From Hawaii*](https://en.wikipedia.org/wiki/Aloha_from_Hawaii_via_Satellite) concert in 1973 as the foundational material to train the voice model. After careful manual screening, van Voorst extracted 36 minutes of high-quality audio, which he then divided into 10-second chunks for correct processing. "I listened carefully for any interference, like band or audience noise, and removed it from my data set," he said. Also, he tried to capture a wide variety of vocal expressions: "The quality of the model improves with more and varied samples."







Next, van Voorst shared the series of somewhat convoluted and technical steps necessary to perform the so-vits-svc-fork training process, repeated here in case it's useful for anyone who might want to attempt it:



> Once you've prepared your audio, you'll put it inside the program's directory structure. In my case, it was /dataset\_raw/elvis/ Then you'll have to run a few commands in this order to start training the model. "svc pre-resample" converts your audio to mono 44.1khz files. Following that, "svc pre-config" downloads a few configuration files and puts it in the correct directory. "svc pre-hubert" downloads and runs a speech model pre-training. It contains guidelines so that you get a predictable output when creating your own model in the last step.
> 
> 
> This last step is "svc train -t". It starts the training and opens up a browser window with the [TensorBoard](https://www.tensorflow.org/tensorboard). With the TensorBoard, you can keep track of the progress of your model. Once you are satisfied with the results, you can stop the training. The progress is measured in steps. In the configuration files, you can change how often you want to write the model to disk. For Elvis, i wanted to have a copy after every 100 steps and was ultimately satisfied at 211k steps.
> 
> 


After van Voorst ran 211,000 steps of training, the Elvis AI voice model was ready for action. Next, van Voorst shared the model with others online. "There I Ruined It" creator Dustin Ballard downloaded the Elvis vocal model—people frequently share them through Discord communities of like-minded voice-cloning hobbyists—and his part of the work began.


To craft the song, Ballard opened a conventional music workstation app, such as [Pro Tools](https://en.wikipedia.org/wiki/Pro_Tools), and imported an instrumental backing track for the Elvis hit "Don't Be Cruel," played by human musicians. Next, Ballard sang the lyrics of "Baby Got Back" to the tune of "Don't Be Cruel," recording his performance. He repeated the same with any backing vocals in the song. Next, he ran his recorded vocals through van Voorst's Elvis AI model using so-vits-svc, making them sound like Elvis singing them instead.


To make the song sound authentic and as close to the original record as possible, van Voorst said, it's best to not make any use of modern techniques like pitch correction or time stretching. "Phrasing and timing the vocal during recording is the best way to make sure it sounds natural," he said, pointing out some telltale signs in the "Baby Got Back" AI song. "I hear some remnants of a time stretching feature being used on the word 'sprung' and a little bit of pitch correction, but otherwise it sounds very natural."


Ballard then imported the Elvis-style vocals into Pro Tools, replacing his original guide vocals and lining them up with the instrumental backing track. After mixing, the new AI-augmented song was complete, and he documented it in YouTube and TikTok videos.
"At this moment, tools like these still require a lot of preparation and often come with a not so user-friendly installation process," said van Voorst, acknowledging the hoops necessary to jump through to make this kind of mash-up possible. But as technology progresses, we'll likely see easier-to-use solutions in the months and years ahead. For now, technically inclined musicians like Ballard who are willing to tinker with open source software have an edge when it comes to generating novel material using AI.


*There I Ruined It* makes Johnny Cash sing *Barbie Girl* lyrics.


In another recent showcase of this technology, a YouTube artist known as Dae Lims used a similar technique to [recreate a young Paul McCartney's voice](https://www.youtube.com/watch?v=JltBGm3oIO4), although the result arguably still sounds very artificial. He replaced the vocals of a 2018 song by McCartney, "I Don't Know," with his own, then converted them using a voice model of the young Beatle. The relatively high-quality results Ballard has achieved by comparison may partially come from his ability to imitate the vocal phrasing and mannerisms of Elvis, making so-vits-svc's job of transforming the vocals easier.


It seems that we're on the precipice of a new era in music, where AI can effectively mimic the voices of legendary artists. The implications of this tech are broad and [uncertain](https://arstechnica.com/information-technology/2023/04/grimes-says-anyone-can-ai-generate-her-voice-without-penalty/) and touch copyright, trademark, and deep ethical issues. But for now, we can marvel at the horribly weird reality that, through the power of AI, we can hear Elvis sing about his anaconda—and it has nothing to do with the Jungle Room.












## Tags:


### Autogenerated tags:
voorst so-vits-svc youtube
