# IBM’s generative AI tool aims to refactor ancient COBOL code for its mainframes
## Humans are still "in the driver's seat," but it could make code more modular.
## Information:

+ Link: https://arstechnica.com/information-technology/2023/08/ibms-generative-ai-tool-aims-to-refactor-ancient-cobol-code-for-its-mainframes/
+ Source: Ars Technica
+ Author: Kevin Purdy
+ Date published: 23 August 2023, 16:34
+ Date scraped: 23 August 2023, 17:01

## Article:
![Main article image](https://cdn.arstechnica.net/wp-content/uploads/2023/08/cobol_73-760x380.jpg)







There are [hundreds of billions of lines of COBOL code](https://www.microfocus.com/en-us/press-room/press-releases/2022/cobol-market-shown-to-be-three-times-larger-than-previously-estimated-in-new-independent-survey) running on production systems worldwide. That's not ideal for a language over 60 years old and whose primary architects are mostly retired or dead.


IBM, eager to keep those legacy functions on [its Z mainframe systems](https://arstechnica.com/information-technology/2023/07/the-ibm-mainframe-how-it-runs-and-why-it-survives/), wants that code rewritten in Java. It tried [getting humans to do it](https://arstechnica.com/tech-policy/2020/04/ibm-scrambles-to-find-or-train-more-cobol-programmers-to-help-states/) a few years back, but now it has another idea. Yes, you guessed it: It's putting AI on the job.

AdChoicesADVERTISING
The [IBM watsonx Code Assistant](https://www.ibm.com/products/watsonx-code-assistant), slated to be available in Q4 this year, intends to keep humans in the mix, but with a push from generative AI in analyzing, refactoring, and testing the new object-oriented code. It's not an all-or-nothing process, either, as IBM claims that watsonx-generated code should be interoperable with COBOL and certain Z mainframe functions.


In a technical blog post [specific to COBOL conversion](https://community.ibm.com/community/user/ibmz-and-linuxone/blogs/kyle-charlet/2023/08/22/harnessing-generative-ai-for-modernization), IBM's Kyle Charlet, CTO for zSystems software, steps up to the plate and says what a lot of people have said about COBOL: It's not just the code; it's the business logic, the edge-cases, and the institutional memory, or the lack thereof.



> 
> Some clients... have spent years and millions trying to modernize their COBOL code, and despite all that, only a fraction has been modernized. It takes lots of developers and painstaking manual work to rewrite COBOL. People have tried many different ways to modernize these applications, and in my experience, with varied results. None are exemplary.
> 
> 
> 


IBM's watsonx, Charlet writes, could help large organizations decouple individual services from monolithic COBOL apps. In IBM's view, it will come in three steps:


* Refactor, in which individual services are "surgically" separated or extracted from larger code
* Transform, either to mainframe-friendly Java code or COBOL that can speak directly to Java
* Validate, with AI helping to create test cases but with coders still "in the driver's seat"


IBM's walk-through of how its AI-based watsonx Code Assistant can "Refactor, Transform, and Validate."


In some ways, AI assistance seems like it can only help with the generational challenge of moving COBOL forward while keeping it functional. While COBOL codebases can be relatively stable and secure—once found to be [among the least problematic](https://arstechnica.com/information-technology/2011/12/bad-code-plagues-it-applications-especially-java-ones/) in a broad survey—the costs of updating and extending them are [gigantic](https://arstechnica.com/information-technology/2016/05/government-agencies-keep-sacrificing-cash-to-zombie-it-systems-gao-finds/). Legacy COBOL was [one of the reasons](https://arstechnica.com/information-technology/2015/06/encryption-would-not-have-helped-at-opm-says-dhs-official/) the Office of Personnel Management suffered a [deeply intrusive break-in in 2015](https://arstechnica.com/information-technology/2015/06/why-the-biggest-government-hack-ever-got-past-opm-dhs-and-nsa/), as the antiquated code could not be encrypted or made to work with other secure systems.


But there's a recurring argument that COBOL is good at managing business-specific systems and exchanges in ways that ([some might argue](https://www.washingtonpost.com/opinions/2023/01/21/defense-cobol/)) present fewer attack vectors. Or you [might argue](https://developers.slashdot.org/story/23/08/22/2037200/ibm-says-its-generative-ai-tool-can-convert-old-cobol-code-to-java?utm_source=rss1.0mainlinkanon&utm_medium=feed) that AI-generated and restructured code might look proper and seem test-ready, but without the people around who know exactly why the code does the things it does, AI-upscaled code could have just as much noise as AI-upscaled video.


IBM's watsonx Code Assistant for Z will next be deployed for Red Hat Ansible Light speed. Given that [watsonx.ai](https://www.ibm.com/products/watsonx-ai) was purportedly trained on more than 100 coding languages, more AI co-pilots for old mainframe code will likely follow.














## Tags:


### Autogenerated tags:
watsonx
