# LLMs keep leaping with Llama 3, Meta’s newest open-weights AI model
## Zuckerberg says new AI model "was still learning" when Meta stopped training.
## Information:

+ Link: https://arstechnica.com/information-technology/2024/04/meta-releases-chatgpt-like-ai-site-and-open-weights-llama-3-model/
+ Source: Ars Technica
+ Author: Benj Edwards
+ Date published: 18 April 2024, 21:04
+ Date scraped: 18 April 2024, 22:02

## Article:
![Main article image](https://cdn.arstechnica.net/wp-content/uploads/2023/08/code_llamas_hero-760x380.jpg)



On Thursday, Meta unveiled early versions of its [Llama 3](https://llama.meta.com/llama3/) open-weights AI model that can be used to power text composition, code generation, or chatbots. It also announced that its [Meta AI Assistant](https://about.fb.com/news/2024/04/meta-ai-assistant-built-with-llama-3/) is now [available on a website](https://www.meta.ai/?utm_source=ai_meta_site&utm_medium=web&utm_content=MetaAI_page&utm_campaign=April_moment) and is going to be integrated into its major social media apps, intensifying the company's efforts to position its products against other AI assistants like OpenAI's ChatGPT, Microsoft's Copilot, and Google's Gemini.


Like its predecessor, [Llama 2](https://arstechnica.com/information-technology/2023/07/meta-launches-llama-2-an-open-source-ai-model-that-allows-commercial-applications/), Llama 3 is notable for being a freely available, open-weights large language model (LLM) provided by a major AI company. Llama 3 technically does not quality as "open source" because that term has a [specific meaning](https://opensource.org/osd) in software (as we have mentioned in [other coverage](https://arstechnica.com/information-technology/2024/03/elon-musks-xai-releases-grok-source-and-weights-taunting-openai/)), and the industry has not yet settled on terminology for AI model releases that ship either code or weights with restrictions (you can read Llama 3's license [here](https://llama.meta.com/llama3/license/)) or that ship without providing training data. We typically call these releases "open weights" instead.


At the moment, Llama 3 is available in two parameter sizes: 8 billion (8B) and 70 billion (70B), both of which are available as free downloads through Meta's website with a [sign-up.](https://llama.meta.com/llama-downloads) Llama 3 comes in two versions: pre-trained (basically the raw, next-token-prediction model) and instruction-tuned (fine-tuned to follow user instructions). Each has a 8,192 token context limit.


[![A screenshot of the Meta AI Assistant website on April 18, 2024.](https://cdn.arstechnica.net/wp-content/uploads/2024/04/meta_ai_website_screenshot_april_18_2024-640x514.png)](https://cdn.arstechnica.net/wp-content/uploads/2024/04/meta_ai_website_screenshot_april_18_2024.png) / A screenshot of the Meta AI Assistant website on April 18, 2024.Benj Edwards


Meta trained both models on two [custom-built, 24,000-GPU clusters](https://engineering.fb.com/2024/03/12/data-center-engineering/building-metas-genai-infrastructure/). In a podcast interview with [Dwarkesh Patel](https://x.com/AndrewCurran_/status/1781034892840833471), Meta CEO Mark Zuckerberg said that the company trained the 70B model with around 15 trillion tokens of data. Throughout the process, the model never reached "saturation" (that is, it never hit a wall in terms of capability increases). Eventually, Meta pulled the plug and moved on to training other models.


"I guess our prediction going in was that it was going to asymptote more, but even by the end it was still leaning. We probably could have fed it more tokens, and it would have gotten somewhat better," Zuckerberg said on the podcast.


Meta also announced that it is currently training a 400B parameter version of Llama 3, which some experts like Nvidia's Jim Fan think may [perform in the same league](https://x.com/DrJimFan/status/1781006672452038756) as GPT-4 Turbo, Claude 3 Opus, and Gemini Ultra on benchmarks like [MMLU](https://paperswithcode.com/dataset/mmlu), [GPQA](https://paperswithcode.com/dataset/gpqa), [HumanEval](https://paperswithcode.com/sota/code-generation-on-humaneval), and [MATH](https://paperswithcode.com/sota/math-word-problem-solving-on-math).


Speaking of benchmarks, we have [devoted many words](https://arstechnica.com/information-technology/2024/03/the-king-is-dead-claude-3-surpasses-gpt-4-on-chatbot-arena-for-the-first-time/) in the past to [explaining](https://arstechnica.com/information-technology/2024/03/the-ai-wars-heat-up-with-claude-3-claimed-to-have-near-human-abilities/3/) how frustratingly imprecise benchmarks can be when applied to large language models due to issues like training contamination (that is, including benchmark test questions in the training dataset), cherry-picking on the part of vendors, and an inability to capture AI's general usefulness in an interactive session with chat-tuned models.


But, as expected, Meta provided some benchmarks for Llama 3 that list results from [MMLU](https://paperswithcode.com/sota/multi-task-language-understanding-on-mmlu) (undergraduate level knowledge), [GSM-8K](https://paperswithcode.com/dataset/gsm8k) (grade-school math), [HumanEval](https://paperswithcode.com/dataset/humaneval) (coding), [GPQA](https://paperswithcode.com/dataset/gpqa) (graduate-level questions), and [MATH](https://paperswithcode.com/sota/math-word-problem-solving-on-math) (math word problems). These show the 8B model performing well compared to open-weights models like Google's [Gemma 7B](https://arstechnica.com/information-technology/2024/02/google-goes-open-ai-with-gemma-a-free-open-weights-chatbot-family/) and [Mistral 7B](https://mistral.ai/news/announcing-mistral-7b/) Instruct, and the 70B model also held its own against [Gemini Pro 1.5](https://arstechnica.com/information-technology/2024/02/google-upstages-itself-with-gemini-1-5-ai-launch-one-week-after-ultra-1-0/) and [Claude 3 Sonnet](https://arstechnica.com/information-technology/2024/03/the-ai-wars-heat-up-with-claude-3-claimed-to-have-near-human-abilities/2/).


[![A chart of instruction-tuned Llama 3 8B and 70B benchmarks provided by Meta.](https://cdn.arstechnica.net/wp-content/uploads/2024/04/llama3_benchmarks-640x360.png)](https://cdn.arstechnica.net/wp-content/uploads/2024/04/llama3_benchmarks.png) / A chart of instruction-tuned Llama 3 8B and 70B benchmarks provided by Meta.[Meta](https://llama.meta.com/llama3/)


Meta says that the Llama 3 model has been enhanced with capabilities to understand coding (like Llama 2) and, for the first time, has been trained with both images and text—though it currently outputs only text. According to [Reuters](https://www.reuters.com/technology/meta-releases-early-versions-its-llama-3-ai-model-2024-04-18/), Meta Chief Product Officer Chris Cox noted in an interview that more complex processing abilities (like executing multi-step plans) are expected in future updates to Llama 3, which will also support multimodal outputs—that is, both text and images.


Meta plans to host the Llama 3 models on a range of cloud platforms, making them accessible through AWS, Databricks, Google Cloud, and other major providers.


Also on Thursday, Meta announced that Llama 3 will become the new basis of the Meta AI virtual assistant, which the company [first announced](https://arstechnica.com/information-technology/2023/09/meta-launches-consumer-ai-chatbots-with-celebrity-avatars-in-its-social-apps/) in September. The assistant will appear prominently in search features for Facebook, Instagram, WhatsApp, Messenger, and the aforementioned [dedicated website](https://www.meta.ai/?utm_source=ai_meta_site&utm_medium=web&utm_content=MetaAI_page&utm_campaign=April_moment) that features a design similar to [ChatGPT](https://arstechnica.com/information-technology/2023/11/chatgpt-was-the-spark-that-lit-the-fire-under-generative-ai-one-year-ago-today/), including the ability to generate images in the same interface. The company also announced a partnership with Google to integrate real-time search results into the Meta AI assistant, adding to an existing partnership with Microsoft's Bing.





## Tags:


### Autogenerated tags:
website google 70b open-weights 8b
