# Machine learning, concluded: Did the “no-code” tools beat manual analysis?
## In the finale of our experiment, we look at how the low/no-code tools performed.
## Information:

+ Link: https://arstechnica.com/information-technology/2022/08/no-code-wrapped-our-ml-experiment-concludes-but-did-the-machine-win/
+ Source: Ars Technica
+ Author: Sean Gallagher
+ Date published: 15 August 2022, 13:00
+ Date scraped: 15 August 2022, 14:01

## Article:
![Main article image](https://cdn.arstechnica.net/wp-content/uploads/2022/08/robot-holding-monitored-heart-760x380.jpg)







I am not a data scientist. And while I know my way around a Jupyter notebook and have written a good amount of Python code, I do not profess to be anything close to a machine learning expert. So when I performed [the first part of our no-code/low-code machine learning experiment](https://arstechnica.com/information-technology/2022/08/new-year-new-ai-challenge-can-we-create-an-algorithm-to-predict-heart-attacks/) and got better than a 90 percent accuracy rate on a model, I suspected I had done something wrong.


If you haven't been following along thus far, here's a quick review before I direct you back to the first two articles in this series. To see how much machine learning tools for the rest of us had advanced—and to redeem myself for [the unwinnable task](https://arstechnica.com/information-technology/2021/07/is-our-machine-learning-ars-takes-a-dip-into-artificial-intelligence/) I had been assigned with machine learning last year—I took a well-worn heart attack data set from an archive at the University of California-Irvine and tried to outperform data science students' results using the "easy button" of Amazon Web Services' low-code and no-code tools.


The whole point of this experiment was to see:


* Whether a relative novice could use these tools effectively and accurately
* Whether the tools were more cost-effective than finding someone who knew what the heck they were doing and handing it off to them


That's not exactly a true picture of how machine learning projects usually happen. And as I found, the "no-code" option that Amazon Web Services provides—[SageMaker Canvas](https://aws.amazon.com/sagemaker/canvas/)—is intended to work hand-in-hand with the more data science-y approach of [SageMaker Studio](https://aws.amazon.com/sagemaker/studio/). But Canvas outperformed what I was able to do with the low-code approach of Studio—though probably because of my less-than-skilled data-handling hands.
(For those who have not read the previous two articles, now is the time to catch up: [Here's part one](https://arstechnica.com/information-technology/2022/08/new-year-new-ai-challenge-can-we-create-an-algorithm-to-predict-heart-attacks/), and [here's part two](https://arstechnica.com/information-technology/2022/08/no-code-no-problem-part-two-setting-the-ai-loose-with-the-easy-button/).) 



## Assessing the robot’s work


Canvas allowed me to export a sharable link that opened the model I created with my full build from the 590-plus rows of patient data from the Cleveland Clinic and the Hungarian Institute of Cardiology. That link gave me a little more insight into what went on inside Canvas' very black box with Studio, a [Jupyter-based](https://jupyter.org/) platform for doing data science and machine learning experiments.


As its name slyly suggests, Jupyter is based on Python. It is a web-based interface to a container environment that allows you to spin up kernels based on different Python implementations, depending on the task.


![Examples of the different kernel containers available in Studio.](https://cdn.arstechnica.net/wp-content/uploads/2022/08/sean-aiml3-01.png)Examples of the different kernel containers available in Studio.


Kernels can be populated with whatever modules the project requires when you're doing code-focused explorations, such as the Python Data Analysis Library ([pandas](https://pandas.pydata.org/)) and SciKit-Learn ([sklearn](https://scikit-learn.org/stable/index.html)). I used a local version of Jupyter Lab to do most of my initial data analysis to save on AWS compute time.


The Studio environment created with the Canvas link included some pre-built content providing insight into the model Canvas produced—some of which I discussed briefly in [the last article](https://arstechnica.com/information-technology/2022/08/no-code-no-problem-part-two-setting-the-ai-loose-with-the-easy-button/):


[![Model details from the Canvas best-of-show in Studio.](https://cdn.arstechnica.net/wp-content/uploads/2022/08/sean-aiml3-02-980x445.png)](https://cdn.arstechnica.net/wp-content/uploads/2022/08/sean-aiml3-02.png) / Model details from the Canvas best-of-show in Studio.


Some of the details included the hyperparameters used by the best-tuned version of the model created by Canvas:


[![Model hyperparameters.](https://cdn.arstechnica.net/wp-content/uploads/2022/08/sean-aiml3-03-980x355.png)](https://cdn.arstechnica.net/wp-content/uploads/2022/08/sean-aiml3-03.png) / Model hyperparameters.


Hyperparameters are tweaks that AutoML made to calculations by the algorithm to improve the accuracy, as well as some basic housekeeping—the SageMaker instance parameters, the tuning metric ("F1," which we'll discuss in a moment), and other inputs. These are all pretty standard for a binary classification like ours.


The model overview in Studio provided some basic information about the model produced by Canvas, including the algorithm used (XGBoost) and the relative importance of each of the columns rated with something called [SHAP values](https://shap.readthedocs.io/en/latest/index.html). SHAP is a really horrible acronym that stands for "SHapley Additive exPlanations," which is a [game theory](https://en.wikipedia.org/wiki/Game_theory)-based method of extracting each data feature's contribution to a change in the model output. It turns out that "maximum heart rate achieved" had negligible impact on the model, while [thalassemia](https://en.wikipedia.org/wiki/Delta-beta_thalassemia) ("thall") and angiogram results ("caa")—data points we had significant missing data for—had more impact than I wanted them to. I couldn't just drop them, apparently. So I downloaded a performance report for the model to get more detailed information on how the model held up:


![](https://cdn.arstechnica.net/wp-content/uploads/2022/08/sean-aiml3-04.png)







In the statistics from the Canvas model for our data set, we see that it had a much better rate of picking true negatives (not a heart attack) than true positives (definitely a heart attack)—94 percent versus 86 percent. There are a few other figures that are of importance here statistically: the precision of the model, the recall of the model, and the model's [F1 score](https://towardsdatascience.com/the-f1-score-bec2bbc38aa6).


* Precision: The total number of true positives (the number of times it guessed "heart attack" correctly) divided by the total number of positives (all the "heart attack" guesses, both correct and incorrect).
* Recall: The total number of true positives (correct heart attack guesses) divided by the total number that should have been positives.
* The F1 score is a measurement used for *balanced* accuracy. It is the [harmonic mean](https://en.wikipedia.org/wiki/Harmonic_mean) of precision and recall, rating the model on how well it performs in finding the desired category overall. It is calculated by multiplying together Precision and Recall, dividing them by the sum of Precision and Recall, and multiplying by two. (As in `*F1 = 2 \* ((Precision \* Recall) / (Precision + Recall))*`).


The Canvas model's precision was 0.86—meaning that when it categorized a patient as one who would have a heart attack, it was right 86 percent of the time. And its recall—the rate at which it correctly categorized patients as having a heart attack—was 0.84. The F1 value (0.85) represents the balanced accuracy of the model.


Another way of looking at the performance of the model is what's called the "confusion matrix"—a box showing the distribution of correct and incorrect categorizations:


![](https://cdn.arstechnica.net/wp-content/uploads/2022/08/sean-aiml3-06.png)


You can see that 59 times—9.88 percent of the time—the model saw actual heart attack cases and classified them as "not heart attack."


When you're trying to forecast something as serious as a heart attack, you want the false negative value to be as low as possible (and the F1 value to be as high as possible). So I wanted to see if I could squeeze any better performance out of the data I had using my limited data science skills.


I could not.



## Here comes Data Wrangler


In an attempt to make things better, I started by using SageMaker's Data Wrangler to do something about my questionable data quality. I opened a new Launcher tab in Studio and got started:


[![SageMaker Data Wrangler.](https://cdn.arstechnica.net/wp-content/uploads/2022/08/sean-aiml3-07-980x580.png)](https://cdn.arstechnica.net/wp-content/uploads/2022/08/sean-aiml3-07.png) / SageMaker Data Wrangler.


Following along with the procedures I had just learned five minutes earlier by reading a tutorial, I created a new data flow:


![](https://cdn.arstechnica.net/wp-content/uploads/2022/08/sean-aiml3-08.png)


This launched a new Data Wrangler app in the EC2 cloud, and I could almost feel my compute budget draining. I then pointed Data Wrangler at my comma-separated value table, sucked it in, and began digesting. Hopefully, some magical data transform would make everything better.


[![](https://cdn.arstechnica.net/wp-content/uploads/2022/08/sean-aiml3-09-980x711.png)](https://cdn.arstechnica.net/wp-content/uploads/2022/08/sean-aiml3-09.png)





The first thing I did was look at how the data had been typed:


[![](https://cdn.arstechnica.net/wp-content/uploads/2022/08/sean-aiml3-10-980x545.png)](https://cdn.arstechnica.net/wp-content/uploads/2022/08/sean-aiml3-10.png)


Everything was seen as long integer except for "slp," "caa," and "thall," which were read as strings. Why strings? Well, some of the cells were empty, so maybe they were being read as labels. There were also question marks in some of the cells (which I thought I had purged), which clearly meant I needed to do some more cleanup.


To see the extent of what I needed to do, I did a data quality analysis, which generated a pile of statistics about the table I had imported. This is downloadable, but only as a .PNG graphic file, which is not super helpful unless you're creating analysis reports out of screen grabs. But hey, better than nothing. (As a rule, SageMaker notebooks are generally not great at outputting data in a format you can do anything with other than show how pretty SageMaker is.)


[![](https://cdn.arstechnica.net/wp-content/uploads/2022/08/sean-aiml3-11-980x547.png)](https://cdn.arstechnica.net/wp-content/uploads/2022/08/sean-aiml3-11.png)


Here I learned some lessons. A little over 10 percent of my data was missing—the gap left by the Hungarian data for those two unfortunately important columns of data. I could either try to fill in those fields with something—like marking them as null—or I could look at the forecast and leave them be.



[![](https://cdn.arstechnica.net/wp-content/uploads/2022/08/sean-aiml3-12-980x657.png)](https://cdn.arstechnica.net/wp-content/uploads/2022/08/sean-aiml3-12.png)


I decided to locate where exactly all the missing data was before I moved on. The SHAP values predicted here were different from those I got from the Canvas model. My analysis also showed that "thall" and "caa" were both very important and missing data in over 40 percent of their rows.


Also, a quick model analysis, which is a forecast of how well the model built from the data will do, was not super-optimistic. While extremely accurate for the training scores, the validation scores projected were worse than what the Canvas model delivered:


![](https://cdn.arstechnica.net/wp-content/uploads/2022/08/sean-aiml3-13.png)


To get an exact count of the missing rows, I ran a single Python PANDAS command in a custom data transformation step:


[![](https://cdn.arstechnica.net/wp-content/uploads/2022/08/sean-aiml3-14-980x564.png)](https://cdn.arstechnica.net/wp-content/uploads/2022/08/sean-aiml3-14.png)












## Tags:


### Autogenerated tags:
sagemaker f1 jupyter hyperparameters thall caa
