# Meta launches Llama 2, an open source AI model that allows commercial applications
## A family of pretrained and fine-tuned language models in sizes from 7 to 70 billion parameters.
## Information:

+ Link: https://arstechnica.com/information-technology/2023/07/meta-launches-llama-2-an-open-source-ai-model-that-allows-commercial-applications/
+ Source: Ars Technica
+ Author: Benj Edwards
+ Date published: 18 July 2023, 20:07
+ Date scraped: 18 July 2023, 21:01

## Article:
![Main article image](https://cdn.arstechnica.net/wp-content/uploads/2023/07/cyberllama-760x380.jpg)







On Tuesday, Meta announced [Llama 2](https://ai.meta.com/llama/), a new open source family of AI language models notable for its commercial license, which means the models can be integrated into commercial products, unlike its [predecessor](https://arstechnica.com/information-technology/2023/02/chatgpt-on-your-pc-meta-unveils-new-ai-model-that-can-run-on-a-single-gpu/). They range in size from 7 to 70 billion parameters and reportedly "outperform open source chat models on most benchmarks we tested," according to Meta.


"This is going to change the landscape of the LLM market," [tweeted](https://twitter.com/ylecun) Chief AI Scientist Yann LeCun. "Llama-v2 is available on Microsoft Azure and will be available on AWS, Hugging Face, and other providers."


According to Meta, its Llama 2 "pretrained" models (the bare-bones models) are trained on 2 trillion tokens and have a context window of 4,096 tokens (fragments of words). The context window determines the length of the content the model can process at once. Meta also says that the Llama 2 fine-tuned models, developed for chat applications similar to ChatGPT, have been trained on "over 1 million human annotations."


While it can't match OpenAI's [GPT-4](https://arstechnica.com/information-technology/2023/03/openai-announces-gpt-4-its-next-generation-ai-language-model/) in performance, Llama 2 apparently fares well for an open source model. According to [Jim Fan](https://twitter.com/DrJimFan/status/1681337179057029121?s=20), senior AI scientist at Nvidia, "70B is close to GPT-3.5 on reasoning tasks, but there is a significant gap on coding benchmarks. It's on par or better than PaLM-540B on most benchmarks, but still far behind GPT-4 and PaLM-2-L." More details on Llama 2's performance, benchmarks, and construction can be found in a [research](https://ai.meta.com/research/publications/llama-2-open-foundation-and-fine-tuned-chat-models/) paper released by Meta on Tuesday.


[![Llama 2 information from Meta.](https://cdn.arstechnica.net/wp-content/uploads/2023/07/361590483_235309902165028_8558564526447568738_n-640x383.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2023/07/361590483_235309902165028_8558564526447568738_n-scaled.jpg) / Llama 2 information from Meta.Meta


In February, Meta [released](https://arstechnica.com/information-technology/2023/02/chatgpt-on-your-pc-meta-unveils-new-ai-model-that-can-run-on-a-single-gpu/) the precursor of Llama 2, LLaMA, as open source with a non-commercial license. Officially only available to academics with certain credentials, someone soon leaked LLaMA's weights (files containing the parameter values of the trained neural networks) to torrent sites, and they spread widely in the AI community. Soon, fine-tuned variations of LLaMA, such as [Alpaca](https://arstechnica.com/information-technology/2023/03/you-can-now-run-a-gpt-3-level-ai-model-on-your-laptop-phone-and-raspberry-pi/), sprang up, providing the seed of a fast-growing underground LLM development scene.


Llama 2 brings this activity more fully out into the open with its allowance for commercial use, although [potential licensees](https://ai.meta.com/resources/models-and-libraries/llama-downloads/) with "greater than 700 million monthly active users in the preceding calendar month" must request special permission from Meta to use it, potentially [precluding](https://twitter.com/minimaxir/status/1681337241740910594?s=20) its free use by giants the size of Amazon or Google.


## The power and peril of open source AI


While open source AI models have proven popular with hobbyists and people seeking [uncensored chatbots](https://www.nytimes.com/2023/07/02/technology/ai-chatbots-misinformation-free-speech.html), they have also proven controversial. Meta is notable for standing alone among the tech giants in supporting major open source [foundation](https://en.wikipedia.org/wiki/Foundation_models) models, while those in the closed-source corner include OpenAI, Microsoft, and Google.


Critics [say](https://www.ft.com/content/0cad55cd-7f07-4fd6-86b7-a2bbfacd214c) that open source AI models carry potential risks, such as misuse in [synthetic biology](https://www.gao.gov/products/gao-23-106648) or in generating spam or disinformation. It's easy to imagine Llama 2 filling some of these roles, although such uses violate Meta's terms of service. Currently, if someone performs restricted acts with OpenAI's ChatGPT API, access can be revoked. But with open source software, once the weights are released, there is no taking them back.


However, proponents of open source AI [often argue](https://www.axios.com/2023/06/26/ais-next-battle-open-closed-chatgpt) that open source AI models encourage transparency (in terms of the training data used to make them), foster economic competition (not limiting the technology to giant companies), encourage free speech (no censorship), and democratize access to AI (without paywall restrictions).


Perhaps getting ahead of potential criticism for its open source release, Meta also [published](https://about.fb.com/news/2023/07/llama-2-statement-of-support/) a short "Statement of Support for Meta's Open Approach to Today's AI" that reads, "We support an open innovation approach to AI. Responsible and open innovation gives us all a stake in the AI development process, bringing visibility, scrutiny and trust to these technologies. Opening today’s Llama models will let everyone benefit from this technology."


As of Tuesday afternoon, the statement has been signed by a list of executives and educators such as Drew Houston (CEO of Dropbox), Matt Bornstein (Partner at Andreessen Horowitz), Julien Chaumond (CTO of Hugging Face), Lex Fridman (research scientist at MIT), and Paul Graham (Founding Partner of Y Combinator).


Although Llama 2 is open source, Meta did not disclose the source of the training data used in creating the Llama 2 models, which Mozilla Senior Fellow of Trustworthy AI Abeba Birhane [pointed out](https://twitter.com/Abebab/status/1681358469402705928?s=20) on Twitter. Lack of training data transparency is still a [sticking point](https://arstechnica.com/information-technology/2023/02/chatgpt-is-a-data-privacy-nightmare-and-you-ought-to-be-concerned/) for some LLM critics because the training data that teaches these LLMs what they "know" often comes from an unauthorized scrape of the Internet with little regard for privacy or commercial impact. Meta says it "made an effort to remove data from certain sites known to contain a high volume of personal information about private individuals" in the Llama 2 research paper, but it did not list what those sites are.


Currently, anyone can request access to download Llama 2 by [filling out a form](https://ai.meta.com/resources/models-and-libraries/llama-downloads/) on Meta's website. Ars Technica submitted a request for the download and received a download link about an hour later, suggesting that the list may be manually screened.














## Tags:


### Autogenerated tags:
llm openai
