# Meta’s AI-powered audio codec promises 10x compression over MP3
## Technique could allow high-quality calls and music on low-quality connections.
## Information:

+ Link: https://arstechnica.com/information-technology/2022/11/metas-ai-powered-audio-codec-promises-10x-compression-over-mp3/
+ Source: Ars Technica
+ Author: Benj Edwards
+ Date published: 01 November 2022, 21:18
+ Date scraped: 06 November 2022, 14:18

## Article:
![Main article image](https://cdn.arstechnica.net/wp-content/uploads/2022/11/encodec_hero_2-760x380.jpg)







Last week, Meta [announced](https://ai.facebook.com/blog/ai-powered-audio-compression-technique/) an AI-powered audio compression method called "EnCodec" that can reportedly compress audio 10 times smaller than the [MP3 format](https://arstechnica.com/features/2007/10/the-audiofile-understanding-mp3-compression/) at 64kbps with no loss in quality. Meta says this technique could dramatically improve the sound quality of speech on low-bandwidth connections, such as phone calls in areas with spotty service. The technique also works for music.


Meta debuted the technology on October 25 in a paper titled "[High Fidelity Neural Audio Compression](https://arxiv.org/abs/2210.13438)," authored by Meta AI researchers Alexandre Défossez, Jade Copet, Gabriel Synnaeve, and Yossi Adi. Meta also summarized the research on [its blog](https://ai.facebook.com/blog/ai-powered-audio-compression-technique/) devoted to EnCodec.


[![Meta claims its new audio encoder/decoder can compress audio 10x smaller than MP3.](https://cdn.arstechnica.net/wp-content/uploads/2022/11/hypercompression_graph_2-640x242.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2022/11/hypercompression_graph_2.jpg) / Meta claims its new audio encoder/decoder can compress audio 10x smaller than MP3.Meta AI


Meta describes its method as a three-part system trained to compress audio to a desired target size. First, the encoder transforms uncompressed data into a lower frame rate "latent space" representation. The "quantizer" then compresses the representation to the target size while keeping track of the most important information that will later be used to rebuild the original signal. (This compressed signal is what gets sent through a network or saved to disk.) Finally, the decoder turns the compressed data back into audio in real time using a neural network on a single CPU.


[![A block diagram illustrating how Meta's EnCodec compression works.](https://cdn.arstechnica.net/wp-content/uploads/2022/11/meta_audio_process-640x360.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2022/11/meta_audio_process.jpg) / A block diagram illustrating how Meta's EnCodec compression works.Meta AI


Meta's use of [discriminators](https://developers.google.com/machine-learning/gan/discriminator) proves key to creating a method for compressing the audio as much as possible without losing key elements of a signal that make it distinctive and recognizable:



> "The key to lossy compression is to identify changes that will not be perceivable by humans, as perfect reconstruction is impossible at low bit rates. To do so, we use discriminators to improve the perceptual quality of the generated samples. This creates a cat-and-mouse game where the discriminator’s job is to differentiate between real samples and reconstructed samples. The compression model attempts to generate samples to fool the discriminators by pushing the reconstructed samples to be more perceptually similar to the original samples."
> 
> 


It's worth noting that using a neural network for audio compression and decompression is [far from new](https://ai.googleblog.com/2021/08/soundstream-end-to-end-neural-audio.html)—especially for speech compression—but Meta's researchers claim they are the first group to apply the technology to 48 kHz stereo audio (slightly better than CD's 44.1 kHz sampling rate), which is typical for music files distributed on the Internet.


As for applications, Meta says this AI-powered "hypercompression of audio" could support "faster, better-quality calls" in bad network conditions. And, of course, being Meta, the researchers also mention EnCodec's metaverse implications, saying the technology could eventually deliver "rich metaverse experiences without requiring major bandwidth improvements."


Beyond that, maybe we'll also get really small music audio files out of it someday. For now, Meta's new tech remains in the research phase, but it points toward a future where high-quality audio can use less bandwidth, which would be great news for mobile broadband providers with [overburdened networks](https://www.pcmag.com/news/is-my-cell-phone-carrier-throttling-my-speed) from streaming media.




## Promoted Comments


* [redleader](/civis/memberlist.php?mode=viewprofile&u=7528)
Ars Legatus Legionis




[Astralock](https://arstechnica.com/information-technology/2022/11/metas-ai-powered-audio-codec-promises-10x-compression-over-mp3/?comments=1&post=41354657) wrote:So what is the difference between this and Opus, other than one is a standard and the other by Meta?  
  
Opus is two different codecs which are selected from based on input. There is a voice codec (silk) used for voice data that models the range of sounds that human speech contains and then essentially transmits which voice sounds are used. Then there is a music codec (CELT) which is based on a modified discrete cosine transform, similar to Vorbis, AAC or WMA. The fourier transformed data is then compared to a model of human auditory perception and any inaudible detail is discarded (or rather quantized coarsely).   
  
This codec is organized somewhat differently. Looking quickly at their paper, it looks like a convolution neural network that uses vector quantization on the network output. Training uses a fourier transform, but unless I'm misunderstanding something, it doesn't look like the codec itself does any frequency analysis at all aside from what the network has learned.   
  
[brendanlong](https://arstechnica.com/information-technology/2022/11/metas-ai-powered-audio-codec-promises-10x-compression-over-mp3/?comments=1&post=41354747) wrote:Why are they comparing this to an ancient audio compression format (MP3) instead of something modern like Opus? I can't even tell if this is good or not.  
  
They do compare to Opus:  
  
**Quote:**Results for EnCodec working at 6 kbps, EnCodec with Residual Vector Quantization (RVQ) at 6 kbps, and Opus at 6 kbps, and MP3 at 64 kbps are reported in Table 4. EnCodec is significantly outperforms Opus at 6kbps and is comparable to MP3 at 64kbps, while EnCodec at 12kpbs achieve comparable performance to EnCodec at 24kbps.  
  
<https://arxiv.org/pdf/2210.13438.pdf>  
  
That said, it is also a lot slower. Opus is designed to be very low complexity so that it can be used on low power mobile devices running at ~ 25-30 MHz, whereas this is only a little faster than realtime on a 4600 MHz CoffeeLake CPU, so the comparison is a little unfair to Opus, which is intentionally doing orders of magnitude less processing for sake of efficiency.
 
 


34330 posts | registered 3/18/2000














## Tags:
***urls***: https://arxiv.org/pdf/2210.13438.pdfThat

### Autogenerated tags:
encodec mp3
