# Meta’s “massively multilingual” AI model translates up to 100 languages, speech or text
## Meta aims for a universal translator like "Babel Fish" from Hitchhiker’s Guide.
## Information:

+ Link: https://arstechnica.com/information-technology/2023/08/metas-massively-multilingual-ai-model-translates-up-to-100-languages-speech-or-text/
+ Source: Ars Technica
+ Author: Benj Edwards
+ Date published: 22 August 2023, 19:57
+ Date scraped: 22 August 2023, 20:00

## Article:
![Main article image](https://cdn.arstechnica.net/wp-content/uploads/2023/08/ai_translation_hero-760x380.jpg)







On Tuesday, Meta announced [SeamlessM4T](https://about.fb.com/news/2023/08/seamlessm4t-ai-translation-model/), a multimodal AI model for speech and text translations. As a neural network that can process both text and audio, it can perform text-to-speech, speech-to-text, speech-to-speech, and text-to-text translations for "up to 100 languages," according to Meta. Its goal is to help people who speak different languages communicate with each other more effectively.


Continuing Meta's relatively open approach to AI, Meta is releasing SeamlessM4T under a [research license](https://creativecommons.org/licenses/by-nc/4.0/) (CC BY-NC 4.0) that allows developers to build on the work. They're also releasing SeamlessAlign, which Meta calls "the biggest open multimodal translation dataset to date, totaling 270,000 hours of mined speech and text alignments." That will likely kickstart the training of future translation AI models from other researchers.


Among the features of SeamlessM4T touted on Meta's promotional blog, the company says that the model can perform speech recognition (you give it audio of speech and it converts it to text), speech-to-text translation (it translates spoken audio to a different language in text), speech-to-speech translation (you feed it speech audio, and it outputs translated speech audio), text-to-text translation (similar to how Google Translate functions), and text-to-speech translation (feed it text and it will translate and then speak it out in another language). Each of the text translation functions support nearly 100 languages, and the speech output functions support about 36 output languages.


In the SeamlessM4T announcement, Meta references the Babel Fish, a fictional fish from Douglas Adams' [classic sci-fi series](https://en.wikipedia.org/wiki/The_Hitchhiker%27s_Guide_to_the_Galaxy) that, when placed in one's ear, can instantly translate any spoken language:



> Building a universal language translator, like the fictional Babel Fish in *The Hitchhiker’s Guide to the Galaxy*, is challenging because existing speech-to-speech and speech-to-text systems only cover a small fraction of the world’s languages. But we believe the work we’re announcing today is a significant step forward in this journey.
> 
> 


How did they train it? According to the Seamless4MT [research paper](https://scontent-atl3-1.xx.fbcdn.net/v/t39.2365-6/369747868_602316515432698_2401716319310287708_n.pdf?_nc_cat=106&ccb=1-7&_nc_sid=3c67a6&_nc_ohc=M4meHi05rNYAX_sSn44&_nc_ht=scontent-atl3-1.xx&oh=00_AfCE2RzIs5jTtZFjI2FhoSrPqOfwbgT1K2j2XQ8Gn6cwqQ&oe=64EA93F9), Meta's researchers "created a multimodal corpus of automatically aligned speech translations of more than 470,000 hours, dubbed SeamlessAlign" (previously mentioned above). They then "filtered a subset of this corpus with human-labeled and pseudo-labeled data, totaling 406,000 hours."


As usual, Meta is being a little vague about where it got its training data. The text data came from "the same dataset deployed in [NLLB](https://arxiv.org/ftp/arxiv/papers/2207/2207.04672.pdf)," (sets of sentences pulled from Wikipedia, news sources, scripted speeches, and other sources and translated by professional human translators). And SeamlessM4T's speech data came from "4 million hours of raw audio originating from a publicly available repository of crawled web data," of which 1 million hours were in English, according to the research paper. Meta did not specify which repository or the provenance of the audio clips used.


Meta is far from the first AI vendor to offer machine-learning translation tools. [Google Translate](https://en.wikipedia.org/wiki/Google_Translate) has used machine-learning techniques since 2006, and large language models (such as [GPT-4](https://arstechnica.com/information-technology/2023/03/openai-announces-gpt-4-its-next-generation-ai-language-model/)) are well known for their ability to translate between languages. But more recently, the tech has heated up on the audio processing front. In September, OpenAI released its own open source speech-to-text translation model, called [Whisper](https://arstechnica.com/information-technology/2022/09/new-ai-model-from-openai-automatically-recognizes-speech-and-translates-to-english/), that can recognize speech in audio and translate it to text with a high level of accuracy.


SeamlessM4T builds off of that trend by expanding multimodal translation to many more languages. In addition, Meta says that SeamlessM4T’s "single system approach"—a monolithic AI model instead of multiple models combined in a chain (like some of Meta's [previous](https://arstechnica.com/information-technology/2022/11/metas-ai-powered-audio-codec-promises-10x-compression-over-mp3/) audio-processing techniques)—reduces errors and increases the efficiency of the translation process.


More technical details on how SeamlessM4T works are available [on Meta's website](https://ai.meta.com/blog/seamless-m4t/), and its code and weights (the actual trained neural network files) can be found [on Hugging Face](https://huggingface.co/facebook/seamless-m4t-large).














## Tags:


### Autogenerated tags:
seamlessm4t speech-to-text speech-to-speech
