# Microsoft’s Phi-3 shows the surprising power of small, locally run AI language models
## Microsoft’s 3.8B parameter Phi-3 may rival GPT-3.5, signaling a new era of “small language models."
## Information:

+ Link: https://arstechnica.com/information-technology/2024/04/microsofts-phi-3-shows-the-surprising-power-of-small-locally-run-ai-language-models/
+ Source: Ars Technica
+ Author: Benj Edwards
+ Date published: 23 April 2024, 20:47
+ Date scraped: 23 April 2024, 21:05

## Article:
![Main article image](https://cdn.arstechnica.net/wp-content/uploads/2024/04/llm_compression-760x380.jpg)



On Tuesday, Microsoft [announced](https://arxiv.org/abs/2404.14219) a new, freely available lightweight AI language model named Phi-3-mini, which is simpler and less expensive to operate than traditional large language models (LLMs) like OpenAI's [GPT-4 Turbo](https://arstechnica.com/information-technology/2023/11/openai-introduces-gpt-4-turbo-larger-memory-lower-cost-new-knowledge/). Its small size is ideal for running locally, which could bring an AI model of similar capability to the free version of [ChatGPT](https://arstechnica.com/information-technology/2023/11/chatgpt-was-the-spark-that-lit-the-fire-under-generative-ai-one-year-ago-today/) to a smartphone without needing an Internet connection to run it.


The AI field typically measures AI language model size by parameter count. Parameters are numerical values in a neural network that determine how the language model processes and generates text. They are learned during training on large datasets and essentially encode the model's knowledge into quantified form. More parameters generally allow the model to capture more nuanced and complex language-generation capabilities but also require more computational resources to train and run.


Some of the largest language models today, like [Google's PaLM 2](https://arstechnica.com/information-technology/2023/05/googles-top-ai-model-palm-2-hopes-to-upstage-gpt-4-in-generative-mastery/), have hundreds of billions of parameters. OpenAI's GPT-4 is [rumored to have](https://the-decoder.com/gpt-4-architecture-datasets-costs-and-more-leaked/) over a trillion parameters but spread over eight 220-billion parameter models in a mixture-of-experts configuration. Both models require heavy-duty data center GPUs (and supporting systems) to run properly.


In contrast, Microsoft aimed small with Phi-3-mini, which contains only 3.8 billion parameters and was trained on 3.3 trillion tokens. That makes it ideal to run on consumer GPU or AI-acceleration hardware that can be found in smartphones and laptops. It's a follow-up of two previous small language models from Microsoft: [Phi-2](https://www.microsoft.com/en-us/research/blog/phi-2-the-surprising-power-of-small-language-models/), released in December, and [Phi-1](https://arxiv.org/abs/2306.11644), released in June 2023.


[![A chart provided by Microsoft showing Phi-3 performance on various benchmarks.](https://cdn.arstechnica.net/wp-content/uploads/2024/04/phi-benhmarks-chart-640x642.png)](https://cdn.arstechnica.net/wp-content/uploads/2024/04/phi-benhmarks-chart.png) / A chart provided by Microsoft showing Phi-3 performance on various benchmarks.[Microsoft](https://arxiv.org/pdf/2404.14219.pdf)


Phi-3-mini features a 4,000-token context window, but Microsoft also introduced a 128K-token version called "phi-3-mini-128K." Microsoft has also created 7-billion and 14-billion parameter versions of Phi-3 that it plans to release later that it claims are "significantly more capable" than phi-3-mini.


Microsoft says that Phi-3 features overall performance that "rivals that of models such as [Mixtral 8x7B](https://arstechnica.com/information-technology/2023/12/new-french-ai-model-makes-waves-by-matching-gpt-3-5-on-benchmarks/) and GPT-3.5," as detailed in a paper titled "[Phi-3 Technical Report: A Highly Capable Language Model Locally on Your Phone](https://arxiv.org/abs/2404.14219)." Mixtral 8x7B, from French AI company Mistral, utilizes a mixture-of-experts model, and GPT-3.5 powers the free version of ChatGPT.


"[Phi-3] looks like it's going to be a shockingly good small model if their benchmarks are reflective of what it can actually do," said AI researcher Simon Willison in an interview with Ars. Shortly after providing that quote, Willison downloaded Phi-3 to his Macbook laptop locally and said, "I got it working, and it's GOOD" in a text message sent to Ars.


[![A screenshot of Phi-3-mini running locally on Simon Willison's Macbook.](https://cdn.arstechnica.net/wp-content/uploads/2024/04/gg_t6GCN-640x736.jpeg)](https://cdn.arstechnica.net/wp-content/uploads/2024/04/gg_t6GCN.jpeg) / A screenshot of Phi-3-mini running locally on Simon Willison's Macbook.Simon Willison


"Most models that run on a local device still need hefty hardware," says Willison. "Phi-3-mini runs comfortably with less than 8GB of RAM, and can churn out tokens at a reasonable speed even on just a regular CPU. It's licensed MIT and should work well on a $55 Raspberry Pi—and the quality of results I've seen from it so far are comparable to models 4x larger."


How did Microsoft cram a capability similar to GPT-3.5, which has at least 175 billion parameters, into such a small model? Its researchers found the answer by using carefully curated, high-quality training data they initially [pulled from textbooks](https://arxiv.org/abs/2306.11644). "The innovation lies entirely in our dataset for training, a scaled-up version of the one used for phi-2, composed of heavily filtered web data and synthetic data," writes Microsoft. "The model is also further aligned for robustness, safety, and chat format."


Much has been written about the potential [environmental impact](https://www.vox.com/climate/2024/3/28/24111721/ai-uses-a-lot-of-energy-experts-expect-it-to-double-in-just-a-few-years) of AI models and datacenters themselves, [including on Ars](https://arstechnica.com/gadgets/2023/04/generative-ai-is-cool-but-lets-not-forget-its-human-and-environmental-costs/). With new techniques and research, it's possible that machine learning experts may continue to increase the capability of smaller AI models, replacing the need for larger ones—at least for everyday tasks. That would theoretically not only save money in the long run but also require far less energy in aggregate, dramatically decreasing AI's environmental footprint. AI models like Phi-3 may be a step toward that future if the benchmark results hold up to scrutiny.


Phi-3 is [immediately available](https://huggingface.co/microsoft/Phi-3-mini-4k-instruct-gguf) on Microsoft's cloud service platform Azure, as well as through partnerships with machine learning model platform Hugging Face and [Ollama](https://ollama.com/), a framework that allows models to run locally on Macs and PCs.





## Tags:


### Autogenerated tags:
microsoft phi-3 phi-3-mini willison gpt-3.5
