# Microsoft’s new AI can simulate anyone’s voice with 3 seconds of audio
## Text-to-speech model can preserve speaker's emotional tone and acoustic environment.
## Information:

+ Link: https://arstechnica.com/information-technology/2023/01/microsofts-new-ai-can-simulate-anyones-voice-with-3-seconds-of-audio/
+ Source: Ars Technica
+ Author: Benj Edwards
+ Date published: 09 January 2023, 22:15
+ Date scraped: 09 January 2023, 23:01

## Article:
![Main article image](https://cdn.arstechnica.net/wp-content/uploads/2023/01/abstract_silhouette-760x380.jpg)







On Thursday, Microsoft researchers announced a new text-to-speech AI model called [VALL-E](https://valle-demo.github.io/) that can closely simulate a person's voice when given a three-second audio sample. Once it learns a specific voice, VALL-E can synthesize audio of that person saying anything—and do it in a way that attempts to preserve the speaker's emotional tone.


Its creators speculate that VALL-E could be used for high-quality text-to-speech applications, speech editing where a recording of a person could be edited and changed from a text transcript (making them say something they originally didn't), and audio content creation when combined with other generative AI models like [GPT-3](https://arstechnica.com/information-technology/2022/11/openai-conquers-rhyming-poetry-with-new-gpt-3-update/).


Microsoft calls VALL-E a "neural codec language model," and it builds off of a technology called EnCodec, [which Meta announced](https://arstechnica.com/information-technology/2022/11/metas-ai-powered-audio-codec-promises-10x-compression-over-mp3/) in October 2022. Unlike other text-to-speech methods that typically synthesize speech by manipulating waveforms, VALL-E generates discrete audio codec codes from text and acoustic prompts. It basically analyzes how a person sounds, breaks that information into discrete components (called "tokens") thanks to EnCodec, and uses training data to match what it "knows" about how that voice would sound if it spoke other phrases outside of the three-second sample. Or, as Microsoft puts it in the [VALL-E paper](https://arxiv.org/pdf/2301.02111.pdf):



> To synthesize personalized speech (e.g., zero-shot TTS), VALL-E generates the corresponding acoustic tokens conditioned on the acoustic tokens of the 3-second enrolled recording and the phoneme prompt, which constrain the speaker and content information respectively. Finally, the generated acoustic tokens are used to synthesize the final waveform with the corresponding neural codec decoder.
> 
> 


Microsoft trained VALL-E's speech synthesis capabilities on an audio library, assembled by Meta, called [LibriLight](https://ai.facebook.com/tools/libri-light/). It contains 60,000 hours of English language speech from more than 7,000 speakers, mostly pulled from [LibriVox](https://librivox.org/) public domain audiobooks. For VALL-E to generate a good result, the voice in the three-second sample must closely match a voice in the training data.


On the VALL-E [example website](https://valle-demo.github.io/), Microsoft provides dozens of audio examples of the AI model in action. Among the samples, the "Speaker Prompt" is the three-second audio provided to VALL-E that it must imitate. The "Ground Truth" is a pre-existing recording of that same speaker saying a particular phrase for comparison purposes (sort of like the "control" in the experiment). The "Baseline" is an example of synthesis provided by a conventional text-to-speech synthesis method, and the "VALL-E" sample is the output from the VALL-E model.


[![A block diagram of VALL-E provided by Microsoft researchers.](https://cdn.arstechnica.net/wp-content/uploads/2023/01/Overview-640x345.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2023/01/Overview.jpg) / A block diagram of VALL-E provided by Microsoft researchers.Microsoft


While using VALL-E to generate those results, the researchers only fed the three-second "Speaker Prompt" sample and a text string (what they wanted the voice to say) into VALL-E. So compare the "Ground Truth" sample to the "VALL-E" sample. In some cases, the two samples are very close. Some VALL-E results seem computer-generated, but others could potentially be mistaken for a human's speech, which is the goal of the model.


In addition to preserving a speaker's vocal timbre and emotional tone, VALL-E can also imitate the "acoustic environment" of the sample audio. For example, if the sample came from a telephone call, the audio output will simulate the acoustic and frequency properties of a telephone call in its synthesized output (that's a fancy way of saying it will sound like a telephone call, too). And Microsoft's [samples](https://valle-demo.github.io/) (in the "Synthesis of Diversity" section) demonstrate that VALL-E can generate variations in voice tone by changing the random seed used in the generation process.


Perhaps owing to VALL-E's ability to potentially fuel mischief and deception, Microsoft has not provided VALL-E code for others to experiment with, so we could not test VALL-E's capabilities. The researchers seem aware of the potential social harm that this technology could bring. For the paper's conclusion, they write:


"Since VALL-E could synthesize speech that maintains speaker identity, it may carry potential risks in misuse of the model, such as spoofing voice identification or impersonating a specific speaker. To mitigate such risks, it is possible to build a detection model to discriminate whether an audio clip was synthesized by VALL-E. We will also put [Microsoft AI Principles](https://www.microsoft.com/en-us/ai/responsible-ai) into practice when further developing the models."














## Tags:


### Autogenerated tags:
vall-e microsoft three-second text-to-speech
