# Nvidia announces “moonshot” to create embodied human-level AI in robot form
## As companies race to pair AI with general-purpose humanoid robots, Nvidia's GR00T emerges.
## Information:

+ Link: https://arstechnica.com/information-technology/2024/03/nvidia-announces-moonshot-to-create-embodied-human-level-ai-in-robot-form/
+ Source: Ars Technica
+ Author: Benj Edwards
+ Date published: 20 March 2024, 20:21
+ Date scraped: 20 March 2024, 21:03

## Article:
![Main article image](https://cdn.arstechnica.net/wp-content/uploads/2024/03/project-gr00t-humanoid_header-760x380.jpg)



In sci-fi films, the rise of humanlike artificial intelligence often comes hand in hand with a physical platform, such as an android or robot. While the most advanced [AI language models](https://arstechnica.com/science/2023/07/a-jargon-free-explanation-of-how-ai-large-language-models-work/7/) so far seem mostly like disembodied voices echoing from an anonymous data center, they might not remain that way for long. Some companies like [Google](https://arstechnica.com/information-technology/2023/07/googles-rt-2-ai-model-brings-us-one-step-closer-to-wall-e/), [Figure](https://arstechnica.com/gadgets/2024/03/huge-funding-round-makes-figure-big-techs-favorite-humanoid-robot-company/), [Microsoft](https://arstechnica.com/information-technology/2023/02/robots-let-chatgpt-touch-the-real-world-thanks-to-microsoft/), [Tesla](https://arstechnica.com/information-technology/2023/12/teslas-latest-humanoid-robot-optimus-gen-2-can-handle-eggs-without-cracking-them/), [Boston Dynamics](https://bostondynamics.com/blog/robots-that-can-chat/), and others are working toward giving AI models a body. This is called "embodiment," and AI chipmaker Nvidia wants to accelerate the process.


"Building foundation models for general humanoid robots is one of the most exciting problems to solve in AI today," said Nvidia CEO Jensen Huang in a statement. Huang spent a portion of Nvidia's annual [GTC conference keynote](https://www.nvidia.com/gtc/keynote/) on Monday going over Nvidia's robotics efforts. "The next generation of robotics will likely be humanoid robotics," Huang said. "We now have the necessary technology to imagine generalized human robotics."


To that end, Nvidia [announced](https://nvidianews.nvidia.com/news/foundation-model-isaac-robotics-platform) Project GR00T, a general-purpose foundation model for humanoid robots. As a type of AI model itself, Nvidia hopes GR00T (which stands for "Generalist Robot 00 Technology" but sounds a lot like a famous Marvel character) will serve as an AI mind for robots, enabling them to learn skills and solve various tasks on the fly. In a [tweet](https://x.com/DrJimFan/status/1769860044324319658?s=20), Nvidia researcher Linxi "Jim" Fan called the project "our moonshot to solve embodied AGI in the physical world."


AGI, or artificial general intelligence, is a poorly defined term that usually refers to hypothetical human-level AI (or beyond) that can learn any task a human could without specialized training. Given a capable enough humanoid body driven by AGI, one could imagine fully autonomous robotic assistants or workers. Of course, [some experts](https://x.com/Grady_Booch/status/1770282624973705422?s=20) think that true AGI is long way off, so it's possible that Nvidia's goal is more aspirational than realistic. But that's also what makes Nvidia's plan a moonshot.


NVIDIA Robotics: A Journey From AVs to Humanoids.


"The GR00T model will enable a robot to understand multimodal instructions, such as language, video, and demonstration, and perform a variety of useful tasks," [wrote](https://x.com/DrJimFan/status/1769860044324319658?s=20) Fan on X. "We are collaborating with many leading humanoid companies around the world, so that GR00T may transfer across embodiments and help the ecosystem thrive." We reached out to Nvidia researchers, including Fan, for comment but did not hear back by press time.


Nvidia is designing GR00T to understand natural language and emulate human movements, potentially allowing robots to learn coordination, dexterity, and other skills necessary for navigating and interacting with the real world like a person. And as it turns out, Nvidia says that making robots shaped like humans might be the key to creating functional robot assistants.


The humanoid key
----------------


[![Robotics startup figure, an Nvidia partner, recently showed off its humanoid "Figure 01" robot.](https://cdn.arstechnica.net/wp-content/uploads/2024/03/NEW-_DSCF1820_Desktop_10923A__3_-640x320.webp)](https://cdn.arstechnica.net/wp-content/uploads/2024/03/NEW-_DSCF1820_Desktop_10923A__3_.webp) / Robotics startup figure, an Nvidia partner, recently showed off its humanoid "Figure 01" robot.Figure


So far, we've seen plenty of robotics platforms that aren't human-shaped, including [robot vacuum cleaners](https://arstechnica.com/gadgets/2023/11/matic-is-a-1795-robot-vacuum-for-people-concerned-about-privacy/), [autonomous weed pullers](https://arstechnica.com/information-technology/2023/11/mother-plucker-steel-fingers-guided-by-ai-pluck-weeds-rapidly-and-autonomously/), industrial units used in [automobile manufacturing](https://arstechnica.com/cars/2023/11/small-batch-evs-and-plenty-of-robots-hyundais-new-innovation-center/), and even research arms that can [fold laundry](https://arstechnica.com/information-technology/2022/10/tired-of-laundry-folding-ai-breaks-the-robot-folding-speed-record/). So why focus on imitating the human form? "In a way, human robotics is likely easier," said Huang in his GTC keynote. "And the reason for that is because we have a lot more imitation training data that we can provide robots, because we are constructed in a very similar way."


That means that researchers can feed samples of training data captured from human movement into AI models that control robot movement, teaching them how to better move and balance themselves. Also, humanoid robots are particularly convenient because they can fit anywhere a person can, and we've designed a world of physical objects and interfaces (such as tools, furniture, stairs, and appliances) to be used or manipulated by the human form.


Along with GR00T, Nvidia also debuted a new computer platform called Jetson Thor, based on NVIDIA's Thor system-on-a-chip (SoC), as part of the new [Blackwell](https://arstechnica.com/information-technology/2024/03/nvidia-unveils-blackwell-b200-the-worlds-most-powerful-chip-designed-for-ai/) GPU architecture, which it hopes will power this new generation of humanoid robots. The SoC reportedly includes a transformer engine capable of 800 teraflops of 8-bit floating point AI computation for running models like GR00T.




On Monday, Nvidia also unveiled updates to its [Isaac Sim](https://developer.nvidia.com/isaac-sim) robotics platform, which allows robots to learn physical interactions [at an accelerated rate](https://arstechnica.com/information-technology/2023/10/eureka-uses-gpt-4-and-massively-parallel-simulations-to-accelerate-robot-training/) in thousands of parallel simulated physical environments. The updates include "[Isaac Lab](https://developer.nvidia.com/isaac-sim#isaac-lab)" for reinforcement learning, [OSMO](https://developer.nvidia.com/blog/scale-ai-enabled-robotics-development-workloads-with-nvidia-osmo/) for compute orchestration, and collections of robotics pretrained models and libraries called [Isaac Manipulator and Isaac Perceptor](https://blogs.nvidia.com/blog/isaac-generative-ai-manufacturing-logistics/). Isaac Manipulator offers AI capabilities for robotic arms, while Isaac Perceptor provides multi-camera 3D vision capabilities for manufacturing robots. Nvidia is aiming these tools at giving robotics researchers a head start while using its development platform.


Speaking of robotics researchers, NVIDIA says it is collaborating with several leading humanoid robot companies on GR00T and its other robotics initiatives. That includes names like Apptronik, [Agility Robotics](https://agilityrobotics.com/), Boston Dynamics, Figure AI, Fourier Intelligence, and Sanctuary AI. Nvidia could potentially do for robotics what it has done so far in AI: provide components and tools that other companies can build their own products on top of.


Figure AI in particular recently turned heads on social media with a video demonstration of its Figure 01 humanoid robot—which responds to verbal commands courtesy of an OpenAI back-end—after [raising $675 million](https://arstechnica.com/gadgets/2024/03/huge-funding-round-makes-figure-big-techs-favorite-humanoid-robot-company/) in a funding round from Big Tech investors, including Nvidia. That's exactly the kind of customer Nvidia hopes to cater to with its robotics platforms in the future.


Figure Status Update - Real World Task.


All this being said, if Nvidia's tools actually help achieve embodied humanoid AGI at some point in the future, it's likely to bring along deep ethical issues, including the potential for massive human job displacement. In marketing materials, the company portrays its robotics initiatives as if they are an unqualified public good. But like other Big Tech firms, ethical considerations often take a back seat to making money—or simply to pushing tech forward because it may fulfill the science fiction-inspired dreams of the engineers involved.


According to Fan, Project GR00T is a cornerstone of his newly founded [GEAR Lab](https://twitter.com/DrJimFan/status/1761052023821369639) (short for "Generalist Embodied Agent Research"). During his time at Nvidia, Fan has [specialized](https://arstechnica.com/information-technology/2022/11/nvidia-wins-award-for-ai-that-can-play-minecraft-on-command/) in using simulations of physical worlds to train AI models, and now that approach is [extending to robotics](https://arstechnica.com/information-technology/2023/10/eureka-uses-gpt-4-and-massively-parallel-simulations-to-accelerate-robot-training/). "At GEAR, we are building generally capable agents that learn to act skillfully in many worlds, virtual and real," [wrote](https://x.com/DrJimFan/status/1769860044324319658?s=20) Fan in a tweet. "Join us on the journey to land on the moon."





## Tags:


### Autogenerated tags:
nvidia gr00t agi huang
