# Nvidia unveils Blackwell B200, the “world’s most powerful chip” designed for AI
## 208B transistor chip can reportedly reduce AI cost and energy consumption by up to 25x.
## Information:

+ Link: https://arstechnica.com/information-technology/2024/03/nvidia-unveils-blackwell-b200-the-worlds-most-powerful-chip-designed-for-ai/
+ Source: Ars Technica
+ Author: Benj Edwards
+ Date published: 19 March 2024, 15:27
+ Date scraped: 19 March 2024, 16:03

## Article:
![Main article image](https://cdn.arstechnica.net/wp-content/uploads/2024/03/GB200_hero_3-760x380.jpg)



On Monday, Nvidia [unveiled](https://nvidianews.nvidia.com/news/nvidia-blackwell-platform-arrives-to-power-a-new-era-of-computing) the Blackwell B200 tensor core chip—the company's most powerful single-chip GPU, with 208 billion transistors—which Nvidia claims can reduce AI inference operating costs (such as running [ChatGPT](https://arstechnica.com/information-technology/2023/11/chatgpt-was-the-spark-that-lit-the-fire-under-generative-ai-one-year-ago-today/)) and energy consumption by up to 25 times compared to the [H100](https://arstechnica.com/information-technology/2022/09/hopper-time-nvidias-most-powerful-ai-chip-yet-ships-in-october/). The company also unveiled the GB200, a "superchip" that combines two B200 chips and a Grace CPU for even more performance.


The news came as part of Nvidia's annual GTC conference, which is taking place this week at the San Jose Convention Center. Nvidia CEO Jensen Huang delivered the [keynote](https://blogs.nvidia.com/blog/2024-gtc-keynote/) Monday afternoon. "We need bigger GPUs," Huang said during his keynote. The Blackwell platform will allow the training of trillion-parameter AI models that will make today's generative AI models look rudimentary in comparison, he said. For reference, OpenAI's GPT-3, launched in 2020, included 175 billion parameters. Parameter count is a rough indicator of AI model complexity.


Nvidia named the Blackwell architecture after [David Harold Blackwell](https://en.wikipedia.org/wiki/David_Blackwell), a mathematician who specialized in game theory and statistics and was the first Black scholar inducted into the National Academy of Sciences. The platform introduces six technologies for accelerated computing, including a second-generation Transformer Engine, fifth-generation NVLink, RAS Engine, secure AI capabilities, and a decompression engine for accelerated database queries.


[![Press photo of the Grace Blackwell GB200 chip, which combines two B200 GPUs with a Grace CPU into one chip.](https://cdn.arstechnica.net/wp-content/uploads/2024/03/NVIDIA-GB200-Grace-Blackwell-Superchip-full-640x360.jpeg)](https://cdn.arstechnica.net/wp-content/uploads/2024/03/NVIDIA-GB200-Grace-Blackwell-Superchip-full.jpeg) / Press photo of the Grace Blackwell GB200 chip, which combines two B200 GPUs with a Grace CPU into one chip.[Nvidia](https://nvidianews.nvidia.com/news/nvidia-blackwell-platform-arrives-to-power-a-new-era-of-computing)


Several major organizations, such as Amazon Web Services, Dell Technologies, Google, Meta, Microsoft, OpenAI, Oracle, Tesla, and xAI, are expected to adopt the Blackwell platform, and Nvidia's [press release](https://nvidianews.nvidia.com/news/nvidia-blackwell-platform-arrives-to-power-a-new-era-of-computing) is replete with canned quotes from tech CEOs (key Nvidia customers) like Mark Zuckerberg and Sam Altman praising the platform.


GPUs, once only designed for gaming acceleration, are especially well suited for AI tasks because their massively parallel architecture accelerates the immense number of matrix multiplication tasks necessary to run today's neural networks. With the dawn of new deep learning architectures in the 2010s, Nvidia found itself in an ideal position to [capitalize on the AI revolution](https://blogs.nvidia.com/blog/accelerating-ai-artificial-intelligence-gpus/) and began designing specialized GPUs just for the task of accelerating AI models.


Nvidia's data center focus has made the company [wildly rich](https://arstechnica.com/information-technology/2023/08/nvidia-thinks-ai-boom-is-far-from-over-as-gpu-sales-drive-big-earnings-win/) and [valuable](https://arstechnica.com/gadgets/2024/02/nvidia-passes-googles-market-cap-now-worlds-fourth-most-valuable-company/), and these new chips continue the trend. Nvidia's gaming GPU revenue ($2.9 billion in the last quarter) is [dwarfed in comparison](https://arstechnica.com/gadgets/2023/11/nvidias-earnings-are-up-206-from-last-year-as-it-continues-riding-the-ai-wave/) to data center revenue (at $18.4 billion), and that shows no signs of stopping.


A beast within a beast
----------------------


[![Press photo of the Nvidia GB200 NVL72 data center computer system.](https://cdn.arstechnica.net/wp-content/uploads/2024/03/NVIDIA-GB200-NVL72-640x360.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2024/03/NVIDIA-GB200-NVL72.jpg) / Press photo of the Nvidia GB200 NVL72 data center computer system.[Nvidia](https://nvidianews.nvidia.com/news/nvidia-blackwell-platform-arrives-to-power-a-new-era-of-computing)


The aforementioned Grace Blackwell GB200 chip arrives as a key part of the new NVIDIA GB200 NVL72, a multi-node, liquid-cooled data center computer system designed specifically for AI training and inference tasks. It combines 36 GB200s (that's 72 B200 GPUs and 36 Grace CPUs total), interconnected by fifth-generation NVLink, which links chips together to multiply performance.


[![A specification chart for the Nvidia GB200 NVL72 system.](https://cdn.arstechnica.net/wp-content/uploads/2024/03/GB200_NVL72_specs-640x487.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2024/03/GB200_NVL72_specs.jpg) / A specification chart for the Nvidia GB200 NVL72 system.[Nvidia](https://developer.nvidia.com/blog/nvidia-gb200-nvl72-delivers-trillion-parameter-llm-training-and-real-time-inference/)


"The GB200 NVL72 provides up to a 30x performance increase compared to the same number of NVIDIA H100 Tensor Core GPUs for LLM inference workloads and reduces cost and energy consumption by up to 25x," Nvidia said.


That kind of speed-up could potentially save money and time while running today's AI models, but it will also allow for more complex AI models to be built. Generative AI models—like the kind that power [Google Gemini](https://arstechnica.com/information-technology/2024/02/google-upstages-itself-with-gemini-1-5-ai-launch-one-week-after-ultra-1-0/) and [AI image generators](https://arstechnica.com/information-technology/2023/11/from-toy-to-tool-dall-e-3-is-a-wake-up-call-for-visual-artists-and-the-rest-of-us/)—are famously computationally hungry. Shortages of compute power have widely been cited as holding back progress and [research](https://www.washingtonpost.com/technology/2024/03/10/big-tech-companies-ai-research/) in the AI field, and the search for more compute has led to figures like OpenAI CEO Sam Altman [trying to broker deals](https://arstechnica.com/information-technology/2024/02/report-sam-altman-seeking-trillions-for-ai-chip-fabrication-from-uae-others/) to create new chip foundries.


While Nvidia's claims about the Blackwell platform's capabilities are significant, it's worth noting that its real-world performance and adoption of the technology remain to be seen as organizations begin to implement and utilize the platform themselves. Competitors like Intel and AMD are also looking to grab a piece of Nvidia's AI pie.


Nvidia says that Blackwell-based products will be available from various partners starting later this year.





## Tags:


### Autogenerated tags:
nvidia blackwell gb200 gpus b200 nvl72 openai
