# Nvidia’s “Chat With RTX” is a ChatGPT-style app that runs on your own GPU
## Nvidia's local private AI chatbot is a high-profile step toward cloud independence.
## Information:

+ Link: https://arstechnica.com/information-technology/2024/02/nvidias-chat-with-rtx-is-a-chatgpt-style-app-that-runs-on-your-own-gpu/
+ Source: Ars Technica
+ Author: Benj Edwards
+ Date published: 15 February 2024, 16:54
+ Date scraped: 15 February 2024, 17:02

## Article:
![Main article image](https://cdn.arstechnica.net/wp-content/uploads/2024/02/studio-chat-with-rtx-blog-1280x680-1-760x380.jpg)



On Tuesday, Nvidia [released](https://blogs.nvidia.com/blog/chat-with-rtx-available-now/) Chat With RTX, a free personalized AI chatbot similar to [ChatGPT](https://arstechnica.com/information-technology/2023/11/chatgpt-was-the-spark-that-lit-the-fire-under-generative-ai-one-year-ago-today/) that can run locally on a PC with an Nvidia RTX graphics card. It uses [Mistral](https://arstechnica.com/information-technology/2023/12/new-french-ai-model-makes-waves-by-matching-gpt-3-5-on-benchmarks/) or [Llama](https://arstechnica.com/information-technology/2023/07/meta-launches-llama-2-an-open-source-ai-model-that-allows-commercial-applications/) open-weights [LLMs](https://arstechnica.com/science/2023/07/a-jargon-free-explanation-of-how-ai-large-language-models-work/) and can search through local files and answer questions about them.




Chat With RTX works on Windows PCs equipped with NVIDIA GeForce RTX 30 or 40 Series GPUs with at least 8GB of VRAM. It uses a combination of [retrieval-augmented generation](https://blogs.nvidia.com/blog/what-is-retrieval-augmented-generation/) (RAG), NVIDIA [TensorRT-LLM](https://github.com/NVIDIA/TensorRT-LLM) software, and RTX acceleration to enable generative AI capabilities directly on users' devices. This setup allows for conversations with the AI model using local files as a dataset.


"Users can quickly, easily connect local files on a PC as a dataset to an open-source large language model like Mistral or Llama 2, enabling queries for quick, contextually relevant answers," writes Nvidia in a promotional blog post.


[![A screenshot of Chat With RTX, which runs in a web browser window.](https://cdn.arstechnica.net/wp-content/uploads/2024/02/chat_with_rtx_screenshot-640x470.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2024/02/chat_with_rtx_screenshot.jpg) / A screenshot of Chat With RTX, which runs in a web browser window.Benj Edwards


Using Chat With RTX, users can talk about various subjects or ask the AI model to summarize or analyze data, similar to how one might interact with ChatGPT. In particular, the Mistal-7B model has built-in conditioning to avoid certain sensitive topics (like sex and violence, of course), but users could presumably somehow plug in an [uncensored AI model](https://huggingface.co/TheBloke/WizardLM-Uncensored-Falcon-7B-GPTQ) and discuss forbidden topics without the paternalism inherent in the censored models.



Also, the application supports a variety of file formats, including .TXT, .PDF, .DOCX, and .XML. Users can direct the tool to browse specific folders, which Chat With RTX then scans to answer queries quickly. It even allows for the incorporation of information from YouTube videos and playlists, offering a way to include external content in its database of knowledge (in the form of embeddings) without requiring an Internet connection to process queries.


Rough around the edges
----------------------


We downloaded and ran Chat With RTX to test it out. The download file is huge, at around 35 gigabytes, owing to the Mistral and Llama LLM weights files being included in the distribution. ("Weights" are the actual neural network files containing the values that represent data learned during the AI training process.) When installing, Chat With RTX downloads even more files, and it executes in a console window using Python with an interface that pops up in a web browser window.


Several times during our tests on an RTX 3060 with 12GB of VRAM, Chat With RTX crashed. Like open source LLM interfaces, Chat With RTX is a mess of layered dependencies, relying on Python, CUDA, TensorRT, and others. Nvidia hasn't cracked the code for making the installation sleek and non-brittle. It's a rough-around-the-edges solution that feels very much like an Nvidia skin over other local LLM interfaces (such as [GPT4ALL](https://gpt4all.io/index.html)). Even so, it's notable that this capability is officially coming directly from Nvidia.


On the bright side (a massive bright side), local processing capability emphasizes user privacy, as sensitive data does not need to be transmitted to cloud-based services (such as with ChatGPT). Using Mistral 7B feels slightly less capable than ChatGPT-3.5 (the free version of ChatGPT), which is still remarkable for a local LLM running on a consumer GPU. It's not a true ChatGPT replacement yet, and it can't touch GPT-4 Turbo or Google Gemini Pro/Ultra in processing capability.


Nvidia GPU owners can [download Chat With RTX](https://www.nvidia.com/en-us/ai-on-rtx/chat-with-rtx-generative-ai/) for free on the Nvidia website.






## Tags:


### Autogenerated tags:
rtx nvidia chatgpt llm
