# OpenAI experiments with giving ChatGPT a long-term conversation memory
## AI chatbot "memory" will recall facts from previous conversations when enabled.
## Information:

+ Link: https://arstechnica.com/information-technology/2024/02/amnesia-begone-soon-chatgpt-will-remember-what-you-tell-it-between-sessions/
+ Source: Ars Technica
+ Author: Benj Edwards
+ Date published: 13 February 2024, 22:01
+ Date scraped: 13 February 2024, 23:02

## Article:
![Main article image](https://cdn.arstechnica.net/wp-content/uploads/2024/02/chatgpt_memory_1-760x380.jpg)



On Tuesday, OpenAI [announced](https://openai.com/blog/memory-and-new-controls-for-chatgpt) that it is experimenting with adding a form of long-term memory to ChatGPT that will allow it to remember details between conversations. You can ask ChatGPT to remember something, see what it remembers, and ask it to forget. Currently, it's only available to a small number of ChatGPT users for testing.


So far, large language models have typically used two types of memory: one baked into the AI model during the training process (before deployment) and an in-context memory (the conversation history) that persists for the duration of your session. Usually, ChatGPT forgets what you have told it during a conversation once you start a new session.


Various projects have experimented with giving LLMs a memory that persists beyond a context window. (The context window is the hard limit on the number of tokens the LLM can process at once.) The techniques include [dynamically managing context history](https://arxiv.org/abs/2310.08560), compressing previous history through summarization, links to vector databases that store information externally, or simply periodically injecting information into a system prompt (the instructions ChatGPT receives at the beginning of every chat).


[![A screenshot of ChatGPT memory controls provided by OpenAI.](https://cdn.arstechnica.net/wp-content/uploads/2024/02/memory-and-new-controls-for-chatgpt-640x640.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2024/02/memory-and-new-controls-for-chatgpt.jpg) / A screenshot of ChatGPT memory controls provided by OpenAI.OpenAI


OpenAI hasn't explained which technique it uses here, but the implementation reminds us of [Custom Instructions](https://arstechnica.com/information-technology/2023/07/new-chatgpt-feature-remembers-custom-instructions-between-sessions/), a feature OpenAI introduced in July 2023 that lets users add custom additions to the ChatGPT system prompt to change its behavior.


Possible applications for the memory feature provided by OpenAI include explaining how you prefer your meeting notes to be formatted, telling it you run a coffee shop and having ChatGPT assume that's what you're talking about, keeping information about your toddler that loves jellyfish so it can generate relevant graphics, and remembering preferences for kindergarten lesson plan designs.


Also, OpenAI says that memories may help ChatGPT Enterprise and Team subscribers work together better since shared team memories could remember specific document formatting preferences or which programming frameworks your team uses. And OpenAI plans to bring memories to [GPTs](https://arstechnica.com/information-technology/2023/11/openai-introduces-custom-ai-assistants-called-gpts-that-play-different-roles/) soon, with each GPT having its own siloed memory capabilities.


Memory control
--------------


Obviously, any tendency to remember information brings privacy implications. You should already know that sending information to OpenAI for processing on remote servers introduces the possibility of privacy leaks and that OpenAI trains AI models on user-provided information by default unless [conversation history is disabled](https://arstechnica.com/information-technology/2023/04/chatgpt-users-can-now-opt-out-of-chat-history-and-model-training/) or you're using an Enterprise or Team account.


Along those lines, OpenAI says that your saved memories are also subject to OpenAI training use unless you meet the criteria listed above. Still, the memory feature can be turned off completely. Additionally, the company says, "We’re taking steps to assess and mitigate biases, and steer ChatGPT away from proactively remembering sensitive information, like your health details—unless you explicitly ask it to."




 



Users will also be able to control what ChatGPT remembers using a "Manage Memory" interface that lists memory items. "ChatGPT's memories evolve with your interactions and aren't linked to specific conversations," OpenAI says. "Deleting a chat doesn't erase its memories; you must delete the memory itself."


ChatGPT's memory features are not currently available to every ChatGPT account, so we have not experimented with it yet. Access during this testing period appears to be random among ChatGPT (free and paid) accounts for now. "We are rolling out to a small portion of ChatGPT free and Plus users this week to learn how useful it is," OpenAI writes. "We will share plans for broader roll out soon."





## Tags:
***email-adresses***: canprocess@once.the

### Autogenerated tags:
chatgpt openai
