# Paper: Stable Diffusion “memorizes” some images, sparking privacy concerns
## Out of 300,000 high-probability images tested, they found a 0.03% memorization rate.
## Information:

+ Link: https://arstechnica.com/information-technology/2023/02/researchers-extract-training-images-from-stable-diffusion-but-its-difficult/
+ Source: Ars Technica
+ Author: Benj Edwards
+ Date published: 01 February 2023, 18:37
+ Date scraped: 01 February 2023, 19:01

## Article:
![Main article image](https://cdn.arstechnica.net/wp-content/uploads/2023/02/image_extraction_hero_1-760x380.jpg)







On Monday, a group of AI researchers from Google, DeepMind, UC Berkeley, Princeton, and ETH Zurich [released a paper](https://arxiv.org/abs/2301.13188) outlining an adversarial attack that can extract a small percentage of training images from latent diffusion AI image synthesis models like [Stable Diffusion](https://arstechnica.com/information-technology/2022/09/with-stable-diffusion-you-may-never-believe-what-you-see-online-again/). It challenges views that image synthesis models do not memorize their training data and that training data [might remain](https://arxiv.org/abs/2106.05258) private if not disclosed.


Recently, AI image synthesis models have been the subject of intense [ethical debate](https://arstechnica.com/information-technology/2022/12/artstation-artists-stage-mass-protest-against-ai-generated-artwork/) and even [legal action](https://arstechnica.com/information-technology/2023/01/artists-file-class-action-lawsuit-against-ai-image-generator-companies/). Proponents and opponents of generative AI tools [regularly argue](https://www.theverge.com/2022/11/8/23446821/microsoft-openai-github-copilot-class-action-lawsuit-ai-copyright-violation-training-data) over the privacy and copyright implications of these new technologies. Adding fuel to either side of the argument could dramatically affect potential legal regulation of the technology, and as a result, this latest paper, authored by Nicholas Carlini *et al.*, has perked up ears in AI circles.


However, Carlini's results are not as clear-cut as they may first appear. Discovering instances of memorization in Stable Diffusion required 175 million image generations for testing and preexisting knowledge of trained images. Researchers only extracted 94 direct matches and 109 perceptual near-matches out of 350,000 high-probability-of-memorization images they tested (a set of known duplicates in the 160 million-image dataset used to train Stable Diffusion), resulting in a roughly 0.03 percent memorization rate in this particular scenario.


[![</p>
<p>Example images that researchers extracted from Stable Diffusion v1.4 using a random sampling and membership inference procedure, with original images on the top row and extracted images on the bottom row.](https://cdn.arstechnica.net/wp-content/uploads/2023/02/duplicate_images_1-640x198.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2023/02/duplicate_images_1.jpg) /
Example images that researchers extracted from Stable Diffusion v1.4 using a random sampling and membership inference procedure, with original images on the top row and extracted images on the bottom row.

Carlini et al., 2023


Also, the researchers note that the "memorization" they've discovered is approximate since the AI model cannot produce identical byte-for-byte copies of the training images. By definition, Stable Diffusion [cannot memorize large amounts of data](https://twitter.com/Eric_Wallace_/status/1620488766925438976?s=20&t=XfPT5YDFz-hdGD4xosv11A) because the size of the 160,000 million-image training dataset is many orders of magnitude larger than the 2GB Stable Diffusion AI model. That means any memorization that exists in the model is small, rare, and very difficult to accidentally extract.


## Privacy and copyright implications


Still, even when present in very small quantities, the paper appears to show that approximate memorization in latent diffusion models does exist, and that could have implications for [data privacy](https://arstechnica.com/information-technology/2022/09/artist-finds-private-medical-record-photos-in-popular-ai-training-data-set/) and copyright. The results may one day affect potential image synthesis regulation if the AI models become considered "lossy databases" that can reproduce training data, as [one AI pundit speculated](https://twitter.com/alexjc/status/1620466058565132288). Although considering the 0.03 percent hit rate, they would have to be considered very, very lossy databases—perhaps to a statistically insignificant degree.


When training an image synthesis model, researchers feed millions of existing images into the model from a dataset, typically [obtained](https://laion.ai/blog/laion-5b/) from the public web. The model then compresses knowledge of each image into a series of statistical weights, which form the neural network. This compressed knowledge is stored in a lower-dimensional representation called "latent space." Sampling from this latent space allows the model to generate new images with similar properties to those in the training data set.


If, while training an image synthesis model, the same image is present many times in the dataset, it can result in "overfitting," which can result in generations of a recognizable interpretation of the original image. For example, the *[Mona Lisa](https://twitter.com/ai_curio/status/1564899484819197953)* has been found to have this property in Stable Diffusion. That property allowed researchers to target known-duplicate images in the dataset while looking for memorization, which dramatically amplified their chances of finding a memorized match.


Along those lines, the researchers also experimented on the top 1,000 most-duplicated training images in the [Google Imagen](https://imagen.research.google/) AI model and found a much higher percentage rate of memorization (2.3 percent) than Stable Diffusion. And by training their own AI models, the researchers found that diffusion models have a tendency to memorize images more than [GANs](https://en.wikipedia.org/wiki/Generative_adversarial_network).


Eric Wallace, one of the paper's authors, shared some personal thoughts on the research in a [Twitter thread](https://twitter.com/Eric_Wallace_/status/1620449934863642624). As stated in the paper, he suggested that AI model-makers should de-duplicate their data to reduce memorization. He also noted that Stable Diffusion's model is small relative to its training set, so larger diffusion models are likely to memorize more. And he advised against applying today's diffusion models to privacy-sensitive domains like medical imagery.


Like many academic papers, Carlini *et al.* 2023 is dense with nuance that could potentially be molded to fit a particular narrative as lawsuits around image synthesis play out, and the paper's authors are aware that their research may come into legal play. But overall, their goal is to improve future diffusion models and reduce potential harms from memorization: "We believe that publishing our paper and publicly disclosing these privacy vulnerabilities is both ethical and responsible. Indeed, at the moment, no one appears to be immediately harmed by the (lack of) privacy of diffusion models; our goal with this work is thus to make sure to preempt these harms and encourage responsible training of diffusion models in the future."














## Tags:


### Autogenerated tags:
carlini
