# Stability announces Stable Diffusion 3, a next-gen AI image generator
## SD3 may bring DALL-E-like prompt fidelity to an open-weights image-synthesis model.
## Information:

+ Link: https://arstechnica.com/information-technology/2024/02/stability-announces-stable-diffusion-3-a-next-gen-ai-image-generator/
+ Source: Ars Technica
+ Author: Benj Edwards
+ Date published: 22 February 2024, 21:28
+ Date scraped: 22 February 2024, 22:01

## Article:
![Main article image](https://cdn.arstechnica.net/wp-content/uploads/2024/02/sd3_cham_hero_1-760x380.jpg)



On Thursday, Stability AI announced Stable Diffusion 3, an open-weights next-generation image-synthesis model. It follows its predecessors by reportedly generating detailed, multi-subject images with improved quality and accuracy in text generation. The brief announcement was not accompanied by a public demo, but Stability is [opening up a waitlist](http://stability.ai/stablediffusion3) today for those who would like to try it.


Stability says that its Stable Diffusion 3 family of models (which takes text descriptions called "prompts" and turns them into matching images) range in size from 800 million to 8 billion parameters. The size range accommodates allowing different versions of the model to run locally on a variety of devices—from smartphones to servers. Parameter size roughly corresponds to model capability in terms of how much detail it can generate. Larger models also require more VRAM on GPU accelerators to run.


Since 2022, we've seen Stability launch a progression of AI image-generation models: Stable Diffusion [1.4](https://arstechnica.com/information-technology/2022/09/with-stable-diffusion-you-may-never-believe-what-you-see-online-again/), 1.5, [2.0](https://stability.ai/news/stable-diffusion-v2-release), [2.1](https://arstechnica.com/information-technology/2022/12/artstation-artists-stage-mass-protest-against-ai-generated-artwork/), [XL](https://arstechnica.com/information-technology/2023/07/stable-diffusion-xl-puts-ai-generated-visual-worlds-at-your-gpus-command/), [XL Turbo](https://arstechnica.com/information-technology/2023/11/stable-diffusion-turbo-xl-accelerates-image-synthesis-with-one-step-generation/), and now 3. Stability has made a name for itself as providing a more open alternative to proprietary image-synthesis models like OpenAI's DALL-E 3, though [not without controversy](https://arstechnica.com/information-technology/2022/09/have-ai-image-generators-assimilated-your-art-new-tool-lets-you-check/) due to the use of copyrighted training data, bias, and the [potential for abuse](https://arstechnica.com/information-technology/2022/12/thanks-to-ai-its-probably-time-to-take-your-photos-off-the-internet/). (This has led to [lawsuits](https://arstechnica.com/tech-policy/2023/04/stable-diffusion-copyright-lawsuits-could-be-a-legal-earthquake-for-ai/) that are unresolved.) Stable Diffusion models have been open-weights and source-available, which means the models can be run locally and fine-tuned to change their outputs.



* Stable Diffusion 3 generation with the prompt: Epic anime artwork of a wizard atop a mountain at night casting a cosmic spell into the dark sky that says "Stable Diffusion 3" made out of colorful energy. 


[Stability AI](https://stability.ai/news/stable-diffusion-3)
* An AI-generated image of a grandma wearing a "Go big or go home sweatshirt" generated by Stable Diffusion 3. 


[Emad Mostaque (Stability AI)](https://x.com/EMostaque/status/1760667977123344385?s=20)
* Stable Diffusion 3 generation with the prompt: Three transparent glass bottles on a wooden table. The one on the left has red liquid and the number 1. The one in the middle has blue liquid and the number 2. The one on the right has green liquid and the number 3. 


[André Kerygma (Stability AI)](https://x.com/andrekerygma/status/1760676074491687310?s=20)
* An AI-generated image created by Stable Diffusion 3. 


[André Kerygma (Stability AI)](https://x.com/andrekerygma/status/1760665416991477855?s=20)
* Stable Diffusion 3 generation with the prompt: A horse balancing on top of a colorful ball in a field with green grass and a mountain in the background. 


[André Kerygma (Stability AI)](https://x.com/andrekerygma/status/1760677095062262116?s=20)
* Stable Diffusion 3 generation with the prompt: Moody still life of assorted pumpkins. 


[André Kerygma (Stability AI)](https://x.com/andrekerygma/status/1760677516359209009?s=20)
* Stable Diffusion 3 generation with the prompt: a painting of an astronaut riding a pig wearing a tutu holding a pink umbrella, on the ground next to the pig is a robin bird wearing a top hat, in the corner are the words "stable diffusion." 


[Stability AI](https://x.com/StabilityAI/status/1760658177371115563?s=20)
* Stable Diffusion 3 generation with the prompt: Resting on the kitchen table is an embroidered cloth with the text 'good night' and an embroidered baby tiger. Next to the cloth there is a lit candle. The lighting is dim and dramatic. 


[André Kerygma (Stability AI)](https://x.com/andrekerygma/status/1760676723836993554?s=20)
* Stable Diffusion 3 generation with the prompt: Photo of an 90's desktop computer on a work desk, on the computer screen it says "welcome". On the wall in the background we see
beautiful graffiti with the text "SD3" very large on the wall. 


[André Kerygma (Stability AI)](https://x.com/andrekerygma/status/1760676926421954736?s=20)


As far as tech improvements are concerned, Stability CEO Emad Mostaque [wrote](https://x.com/EMostaque/status/1760660709308846135?s=20) on X, "This uses a new type of diffusion transformer (similar to [Sora](https://arstechnica.com/information-technology/2024/02/openai-collapses-media-reality-with-sora-a-photorealistic-ai-video-generator/)) combined with flow matching and other improvements. This takes advantage of transformer improvements & can not only scale further but accept multimodal inputs."


Like Mostaque said, the Stable Diffusion 3 family uses [diffusion transformer architecture](https://arxiv.org/abs/2212.09748), which is a new way of creating images with AI that swaps out the usual image-building blocks (such as [U-Net architecture](https://en.wikipedia.org/wiki/U-Net)) for a system that works on small pieces of the picture. The method was inspired by transformers, which are good at handling patterns and sequences. This approach not only scales up efficiently but also reportedly produces higher-quality images.


Stable Diffusion 3 also utilizes "[flow matching](https://arxiv.org/abs/2210.02747)," which is a technique for creating AI models that can generate images by learning how to transition from random noise to a structured image smoothly. It does this without needing to simulate every step of the process, instead focusing on the overall direction or flow that the image creation should follow.


[![A comparison of outputs between OpenAI's DALL-E 3 and Stable Diffusion 3 with the prompt, "Night photo of a sports car with the text "SD3" on the side, the car is on a race track at high speed, a huge road sign with the text 'faster.'"](https://cdn.arstechnica.net/wp-content/uploads/2024/02/dalle3_SD3_comparison-640x215.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2024/02/dalle3_SD3_comparison.jpg) / A comparison of outputs between OpenAI's DALL-E 3 and Stable Diffusion 3 with the prompt, "Night photo of a sports car with the text "SD3" on the side, the car is on a race track at high speed, a huge road sign with the text 'faster.'"[André Kerygma (Stability AI) / Benj Edwards](https://x.com/andrekerygma/status/1760677251715330066?s=20)


We do not have access to Stable Diffusion 3 (SD3), but from samples we found posted on Stability's website and associated social media accounts, the generations appear roughly comparable to other state-of-the-art image-synthesis models at the moment, including the aforementioned [DALL-E 3](https://arstechnica.com/information-technology/2023/11/from-toy-to-tool-dall-e-3-is-a-wake-up-call-for-visual-artists-and-the-rest-of-us/), [Adobe Firefly](https://arstechnica.com/information-technology/2023/10/adobes-ai-image-generators-get-beefy-updates-including-vector-graphics/), [Imagine with Meta AI](https://arstechnica.com/information-technology/2023/12/metas-new-ai-image-generator-was-trained-on-1-1-billion-instagram-and-facebook-photos/), [Midjourney](https://arstechnica.com/information-technology/2024/01/a-crazy-update-midjourney-v6-upgrade-heaps-on-ai-generated-detail/), and [Google Imagen](https://arstechnica.com/information-technology/2024/02/google-debuts-more-powerful-ultra-1-0-ai-model-in-rebranded-gemini-chatbot/).


SD3 appears to handle text generation very well in the examples provided by others, which are potentially cherry-picked. Text generation was a particular weakness of earlier image-synthesis models, so an improvement to that capability in a free model is a big deal. Also, prompt fidelity (how closely it follows descriptions in prompts) seems to be similar to DALL-E 3, but we haven't tested that ourselves yet.


While Stable Diffusion 3 isn't widely available, Stability says that once testing is complete, its weights will be free to download and run locally. "This preview phase, as with previous models," Stability writes, "is crucial for gathering insights to improve its performance and safety ahead of an open release."


Stability has been experimenting with a variety of image-synthesis architectures recently. Aside from SDXL and SDXL Turbo, just last week, the company announced [Stable Cascade](https://stability.ai/news/introducing-stable-cascade), which uses a three-stage process for text-to-image synthesis.


*Listing image by [Emad Mostaque (Stability AI)](https://x.com/EMostaque/status/1760667977123344385?s=20)*





## Tags:


### Autogenerated tags:
andré image-synthesis dall-e mostaque sd3 emad
