# Surprising things happen when you put 25 AI agents together in an RPG town
## Researchers study emergent AI behaviors in a sandbox world inspired by The Sims.
## Information:

+ Link: https://arstechnica.com/information-technology/2023/04/surprising-things-happen-when-you-put-25-ai-agents-together-in-an-rpg-town/
+ Source: Ars Technica
+ Author: Benj Edwards
+ Date published: 11 April 2023, 19:49
+ Date scraped: 11 April 2023, 20:01

## Article:
![Main article image](https://cdn.arstechnica.net/wp-content/uploads/2023/04/generative_agents_hero-760x380.jpg)







A group of researchers at Stanford University and Google have created a miniature RPG-style virtual world similar to *The Sims*, where 25 characters, controlled by [ChatGPT](https://arstechnica.com/information-technology/2022/12/openai-invites-everyone-to-test-new-ai-powered-chatbot-with-amusing-results/) and custom code, live out their lives independently with a high degree of realistic behavior. They wrote about their experiment in a [preprint academic paper](https://arxiv.org/abs/2304.03442) released on Friday.


"Generative agents wake up, cook breakfast, and head to work; artists paint, while authors write; they form opinions, notice each other, and initiate conversations; they remember and reflect on days past as they plan the next day," write the researchers in their [paper](https://arxiv.org/pdf/2304.03442.pdf) titled *Generative Agents: Interactive Simulacra of Human Behavior*.


To pull this off, the researchers relied heavily on a large language model (LLM) for social interaction, specifically the [ChatGPT API](https://arstechnica.com/information-technology/2023/03/chatgpt-and-whisper-apis-debut-allowing-devs-to-integrate-them-into-apps/). In addition, they created an architecture that simulates minds with memories and experiences, then let the agents loose in the world to interact. And humans can interact with them, too.


[![Examples of interactions in Smallville from the <em>Generative Agents</em> paper.](https://cdn.arstechnica.net/wp-content/uploads/2023/04/gen_agents_diagram_1-640x393.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2023/04/gen_agents_diagram_1.jpg) / Examples of interactions in Smallville from the *Generative Agents* paper.[J.S. Park, J.C. O’Brien, C.J. Cai, M. Morris, P. Liang, M.S. Bernstein](https://reverie.herokuapp.com/arXiv_Demo/)


"Users can observe and intervene as agents plan their days, share news, form relationships, and coordinate group activities," they write. It's the work of Joon Sung Park, Joseph C. O'Brien, Carrie J. Cai, Meredith Ringel Morris, Percy Liang, and Michael S. Bernstein.


Computer and video games have included computer-controlled characters since the 1970s, but never before have they been able to simulate a social environment with the complexity of natural language that might now be possible thanks to generative AI models like ChatGPT. While the group's research is not necessarily a "game," it could serve as a prototype of a future where dynamic RPG characters interact in complex and unexpected ways.


"Imagine killing an NPC and coming back to the city and seeing a funeral for them," joked a Twitter user named [Dennis Hansen](https://twitter.com/dennizor/status/1645511465544155147?s=20) when replying to a thread about the paper's emergent implications. Judging by this research, that might not be a far-fetched scenario.


## Life in Smallville


To study the group of AI agents, the researchers set up a virtual town called "Smallville," which includes houses, a cafe, a park, and a grocery store. For human interaction purposes, the world is represented on screen from an overhead view using retro-style pixel graphics reminiscent of a classic 16-bit Japanese RPG.


[![A diagram of "Smallville" from the <em>Generative Agents</em> paper.](https://cdn.arstechnica.net/wp-content/uploads/2023/04/gen_agents_diagram_2-640x357.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2023/04/gen_agents_diagram_2.jpg) / A diagram of "Smallville" from the *Generative Agents* paper.[J.S. Park, J.C. O’Brien, C.J. Cai, M. Morris, P. Liang, M.S. Bernstein](https://reverie.herokuapp.com/arXiv_Demo/)


Smallville is home to a community of 25 distinct individuals, each represented by a basic sprite avatar. To capture each agent's identity and their connections with other members of the community, the researchers created a paragraph of natural language description as a seed memory. These descriptions include details about each agent's occupation and relationships with other agents. For example, here's an excerpt of one such seed memory provided in the paper:



> John Lin is a pharmacy shopkeeper at the Willow Market and Pharmacy who loves to help people. He is always looking for ways to make the process of getting medication easier for his customers. John Lin is living with his wife, Mei Lin, who is a college professor, and son, Eddy Lin, who is a student studying music theory. John Lin loves his family very much.
> 
> 


As a virtual environment, Smallville is broken into both areas and objects. Human users can enter the world as an existing or new agent, and both users and agents can influence the state of objects through actions. Human users can also interact with AI agents either through conversation or by issuing directives as an "inner voice." Users communicate in natural language, specifying a persona that the agent perceives them as, or can use the inner voice to influence the agent's actions.







[![A diagram of the "Memory Steam" architecture designed by the authors of the <em>Generative Agents</em> paper.](https://cdn.arstechnica.net/wp-content/uploads/2023/04/gen_agents_diagram_3-640x301.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2023/04/gen_agents_diagram_3.jpg) / A diagram of the "Memory Steam" architecture designed by the authors of the *Generative Agents* paper.[J.S. Park, J.C. O’Brien, C.J. Cai, M. Morris, P. Liang, M.S. Bernstein](https://reverie.herokuapp.com/arXiv_Demo/)


In developing the virtual world, one particular challenge came from the limited "memory" of LLMs. This memory comes in the form of a "[context window](https://arstechnica.com/information-technology/2023/04/why-ai-chatbots-are-the-ultimate-bs-machines-and-how-people-hope-to-fix-them/)," which is the number of tokens (word chunks) that ChatGPT can process at a time. To get around those limitations, they designed a system where "the most relevant pieces of the agent’s memory" are retrieved and synthesized when needed.



> "Agents perceive their environment, and all perceptions are saved in a comprehensive record of the agent’s experiences called the memory stream. Based on their perceptions, the architecture retrieves relevant memories, then uses those retrieved actions to determine an action. These retrieved memories are also used to form longer-term plans, and to create higher-level reflections, which are both entered into the memory stream for future use."
> 
> 


Interestingly, when the characters in the sandbox world encounter each other, they often speak to each other using natural language provided by ChatGPT. In this way, they exchange information and form memories about their daily lives. When the researchers combined these basic ingredients together and ran the simulation, interesting things began to happen.


## Emergent behavior


In the paper, the researchers list three unexpected emergent behaviors that resulted from running the simulation. None of these were pre-programmed, but rather, resulted from the interactions between the agents.


These included "information diffusion" (agents telling each other information and having it spread socially among the town), "relationship memory" (memory of past interactions between agents and mentioning those earlier events later), and "coordination" (planning and attending a Valentine's Day party together with other agents).


During the Valentine's Day experiment, an AI agent named Isabella Rodriguez planned a Valentine's Day party at "Hobbs Cafe" and invited friends and customers. She decorated the cafe with the help of her friend Maria, who invited her crush Klaus to the party.


[![A diagram of "Smallville" agents interacting with regard to a Valentine's Day party from the <em>Generative Agents</em> paper.](https://cdn.arstechnica.net/wp-content/uploads/2023/04/valentines_party-640x423.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2023/04/valentines_party.jpg) / A diagram of "Smallville" agents interacting with regard to a Valentine's Day party from the *Generative Agents* paper.[J.S. Park, J.C. O’Brien, C.J. Cai, M. Morris, P. Liang, M.S. Bernstein](https://reverie.herokuapp.com/arXiv_Demo/)


"Starting with only a single user-specified notion that one agent wants to throw a Valentine's Day party," the researchers write, "the agents autonomously spread invitations to the party over the next two days, make new acquaintances, ask each other out on dates to the party, and coordinate to show up for the party together at the right time."


While 12 agents heard about the party through others, only five agents (including Klaus and Maria) attended. Three said they were too busy, and four agents just didn't go. The experience served as a fun example of unexpected situations that can emerge from complex social interactions in the virtual world.


## More human than human?


As part of their research, the group hired human evaluators to watch replays of the simulation to gauge how well the AI agents produced believable behavior based on their environment and experiences, including "believable plans, reactions, and thoughts" and "information diffusion, relationship formation, and agent coordination across different pockets of the community."


[![On the <em>Generative Agents</em> demo website, you can click on characters to see what each is thinking and feeling.](https://cdn.arstechnica.net/wp-content/uploads/2023/04/gen_agents_characters-640x568.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2023/04/gen_agents_characters.jpg) / On the *Generative Agents* demo website, you can click on characters to see what each is thinking and feeling.[J.S. Park, J.C. O’Brien, C.J. Cai, M. Morris, P. Liang, M.S. Bernstein](https://reverie.herokuapp.com/arXiv_Demo/)


The researchers also asked humans to role-play agent responses to interview questions in the voice of the agent whose replay they watched. Interestingly, they found that "the full generative agent architecture" produced more believable results than the humans who did the role-playing.


This leads to other issues, such as ethical impacts and risks of this kind of technology. The researchers caution of risks such as forming inappropriate "parasocial relationships," the impact of incorrect inferences, exacerbation of existing risks associated with generative AI, and the risk of over-reliance on generative agents in the design process.


To ensure ethical and socially responsible deployment, the researchers argue that developers should adhere to principles such as explicitly disclosing the computational nature of agents, ensuring value alignment, following best practices in human-AI design, maintaining audit logs for inputs and outputs, and not substituting real human input in studies and design processes.


To get a look at Smallville yourself, the researchers have posted an [interactive demo](https://reverie.herokuapp.com/arXiv_Demo/) online through a special website, but it's a "pre-computed replay of a simulation" described in the paper and not a realtime simulation. Still, it gives a good illustration of the richness of social interactions that can emerge from an apparently simple virtual world running in a computer sandbox.












## Tags:


### Autogenerated tags:
smallville bernstein chatgpt j.c c.j m.s paper.j.s
