# The IBM mainframe: How it runs and why it survives
## In this deep-dive explainer, we look at a big-business mainstay.
## Information:

+ Link: https://arstechnica.com/information-technology/2023/07/the-ibm-mainframe-how-it-runs-and-why-it-survives/
+ Source: Ars Technica
+ Author: Andrew Hudson
+ Date published: 24 July 2023, 11:00
+ Date scraped: 24 July 2023, 12:01

## Article:
![Main article image](https://cdn.arstechnica.net/wp-content/uploads/2023/06/new_IBM_z16-760x380.webp)







Mainframe computers are often seen as ancient machines—practically dinosaurs. But mainframes, which are purpose-built to process enormous amounts of data, are still extremely relevant today. If they’re dinosaurs, they’re T-Rexes, and desktops and server computers are puny mammals to be trodden underfoot.


It’s estimated that there are 10,000 mainframes in use today. They’re used almost exclusively by the largest companies in the world, including two-thirds of Fortune 500 companies, 45 of the world’s top 50 banks, eight of the top 10 insurers, seven of the top 10 global retailers, and eight of the top 10 telecommunications companies. And most of those mainframes come from IBM.


In this explainer, we’ll look at the IBM mainframe computer—what it is, how it works, and why it’s still going strong after over 50 years.


## Setting the stage


Mainframes descended directly from the technology of the first computers in the 1950s. Instead of being streamlined into low-cost desktop or server use, though, they evolved to handle massive data workloads, like bulk data processing and high-volume financial transactions.


Vacuum tubes, magnetic core memory, magnetic drum storage, tape drives, and punched cards were the foundation of the IBM 701 in 1952, the IBM 704 in 1954, and the IBM 1401 in 1959. Primitive by today’s standards, these machines provided the functions of scientific calculations and data processing that would otherwise have to be done by hand or mechanical calculators. There was a ready market for these machines, and IBM sold them as fast as it could make them.


In the early years of computing, IBM had many competitors, including Univac, Rand, Sperry, Amdahl, GE, RCA, NEC, Fujitsu, Hitachi, Unisys, Honeywell, Burroughs, and CDC. At the time, all of these other companies combined accounted for about 20 percent of the mainframe market, and IBM claimed the rest. Today, IBM is the only mainframe manufacturer. Its de facto competitors are now the cloud and clusters, but as we'll see, it's not always cost-effective to switch to those platforms, and they're not able to provide the reliability of the mainframe.


## Built-in redundancy


By any standard, mainframes are enormous. Today’s mainframe can have up to 240 server-grade CPUs, 40TB of error-correcting RAM, and many petabytes of redundant flash-based secondary storage. They’re designed to process large amounts of critical data while maintaining a 99.999 percent uptime—that’s three seconds of outage per year. A medium-sized bank may use a mainframe to run 50 or more separate financial applications and supporting processes and employ thousands of support personnel to keep things running smoothly.


Most mainframes process high-volume financial transactions, which include things like credit card purchases at a cash register, withdrawals from an ATM, or stock purchases on the Internet.


A bank’s lifeblood isn't money—it’s data. Every transaction a bank makes involves data that must be processed. A debit card transaction, for instance, involves the following data that must be processed:


* Retrieving a user’s debit account info
* Validating the user ID and PIN
* Checking the availability of funds
* Debiting the user’s account for the transaction amount
* Crediting the seller’s account


All this must happen in seconds, and banks have to ensure they can maintain a rapid response even during high-volume events such as shopping holidays. Mainframes are designed from the ground up to provide both redundancy and high throughput for these purposes. High-speed processing is no good if processing stops during business hours, and reliable processing is no good if people have to wait minutes for a transaction to process.


When you process a financial transaction, it means you’re making money. If you’re processing a lot of transactions, you need to spend a lot of money on redundancy to keep things running smoothly. When parts inevitably fail, the show must go on. That’s where mainframes’ built-in redundant processing comes in.







RAM, CPUs, and disks are all hot-swappable, so if a component fails, it can be pulled and replaced without requiring the mainframe to be powered down. In fact, mainframes are divided into independent partitions, each with separate RAM, storage, CPUs, and even different operating systems, allowing applications to run continuously while certain partitions receive maintenance in the form of OS patches, hardware fixes, and upgrades.


Whereas Intel-based servers can support error correcting code (ECC) memory that can correct for bad memory bits in RAM, Telum CPUs can correct for bad RAM bits and more. The memory can detect and recover from failed hardware memory channels, failed DIMM memory chips, and failed CPU operations.


IBM fellow Christian Jacobi explained the process to me:



> When we detect an error in processing in a CPU core, the core can go through a transparent recovery action. This is a complete core reset—almost like a mini-reboot of the core, but the program state, program location, and all the register contents are recovered. So after recovery, we continue running wherever we were [running] in the program. It's completely transparent to the software layers. This is a “core recovery.” If a core goes through too many restarts, the contents of the core can be moved to a spare core. This is a “brain transplant.”
> 
> 
> A mainframe CPU can recover from bad memory bits, memory channels, memory chips, and CPUs, all transparent to the OS and software.
> 
> 


## Dynamically reconfigurable system partitioning


Equivalent separate mainframe units, or logical partitions (LPARs), can be created through the use of I/O controllers, mainframe permissions, and user-configurable CPUs. Each LPAR can run a separate, isolated instance of Z/OS, the mainframe operating system.


These instances can be used for development, testing, or running separate applications. LPARs can also run different operating systems such as Linux, and they have completely separate hardware resources. If one crashes or has to go down for maintenance, the other partitions are unaffected. LPARs are also separated by permissions; one group of users can have access to the test region LPAR but not a production LPAR, for instance.


IBM uses an efficient and low-latency protocol called “parallel sysplex” to keep different mainframes (or different LPARs on the same mainframe) “coupled” with each other for workload distribution, communication, or recovery/failover. Up to 32 CPUs can be clustered in parallel to achieve near-linear speedup under load, and CPUs can be assigned for either performance or redundancy. Data locking and queueing methods are used to maintain data integrity while processing, and implementing parallel sysplex in the OS requires a holistic approach through the entire OS stack.


The ability to dynamically add and remove capacity means mainframes can be responsive when dealing with workload spikes. Jacobi said that IBM mainframe support teams have seen fluctuations in the processing needed to address supply chain scarcity during the pandemic.


And disaster recovery is not an afterthought for companies that run large loads on mainframes. The same kind of OS support that allows CPUs to be dynamically added to a workload allows a mainframe workload to migrate between geographically separated data centers. Companies can thus hedge their processing against storms, terrorist attacks, or basic infrastructure outages, which is especially valuable to companies in regulated industries such as banking and insurance, where federal law may dictate disaster recovery.





## The CPU: Telum


The latest generation of the Z-series CPU that mainframes are built on is called Telum. A modern chip clocked at 5.2 GHz, it’s built on Samsung’s 7 nm fabrication process, and it’s optimized for single-thread performance.


What differentiates Telum from other performance CPUs from Intel and AMD? In short, it has more of everything: a higher clock speed, more cache, more specialized on-CPU hardware, and more PCI channels for moving data.


Today’s IBM mainframe CPUs are based on a highly evolved version of the POWER architecture that IBM has been developing for over 30 years. The current Telum CPU is powerful. Each core is two-way multithreaded, sports 256KB of L1 cache and 32MB of L2 cache, and supports superscalar instruction execution. Telum has eight cores per chip, two cores per socket, and four sockets per drawer; four drawers make up a system. A fully loaded mainframe can support 250 cores, 190 of which are user-controlled. I/O is handled by two PCI Express 4.0 controllers.


![Mainframe CPU organization.](https://cdn.arstechnica.net/wp-content/uploads/2023/07/image1.jpg)Mainframe CPU organization.IBM


The new Telum cache design is optimized for heterogeneous single-processor performance with a new and unique cache management strategy. Each core has its own 32MB of L2 cache. When a cache line is evicted from an L2 cache, it’s moved to another L2 cache and tagged as an L3 cache line.


This means eight L2 caches can be combined into a 256MB virtual shared L3 cache that’s accessible by any of the eight cores. Compare this to AMD’s Zen 3 chiplet, where each of the eight cores has 512KB of L2 cache and a total of 32MB of L3 cache.


When a cache line is evicted from the virtual L3 cache, the line can find another core’s cache in the system, thus creating a virtual L4 cache. Combining the L2 caches on a system gives a spectacular 8192MB of virtual L4 cache. IBM claims an overall per-socket performance improvement of greater than 40 percent from the previous z15 CPU design.


“Cache management is an example of new design and investment,” Jacobi told me. “Which is overall extremely successful and went smoother than expected. We always knew that when every core does the same thing, it uses the same cache. But the real work doesn’t behave this way. Every CPU uses cache slightly differently. As we ran the real workloads, we were happy to see this fully confirmed in our measurements for L3 and L4. The Z16’s performance has become a new plateau from which to learn and develop from.”


Telum also has an on-chip hardware AI accelerator. Naturally, this part is targeted at large enterprise data tasks such as rapid processing of credit card fraud cases. One hundred and twenty-eight processor tiles are combined together as an array and are supported by floating point matrix math functions. The AI functions support both inference processing and machine learning (or training).


These on-chip AI functions are tightly coupled to the L2 cache for low-latency data pre-fetches and write-backs. The virtual L3 and L4 cache management system helps the AI processing to scale almost linearly across the multiple CPUs in a mainframe drawer, allowing an enterprise to process tens of thousands of inference transactions per second.


Additional mainframe hardware-accelerated functions include:


* zEDC hardware support for lossless compression with minimal CPU usage. The Java Deflater class provides 15X throughput over the previous Z implementation.
* Integrated Accelerator for Z Sort, which provides hardware-accelerated sorting. DB2 database benchmarks show a 12 percent decrease in elapsed time, with up to a 40 percent reduction in CPU usage.
* Pervasive Encryption, the hardware-accelerated implementation of the widely used AES (Advanced Encryption Standard). It's capable of encrypting enterprise data with only 3 percent additional CPU overhead. It’s called Pervasive Encryption because it can encrypt anything and everything on your mainframe as part of any workflow. Hardware acceleration is also available for SHA, DES, GHASH, and CRC32 algorithms.


Secondary storage on mainframes is next-level huge, which is essential for companies processing mountains of time-critical data. You don’t plug disks into a mainframe; you plug in storage arrays. One such array is the Hitachi G1500 Virtual Storage Platform. It can be fitted with spinning disks, SSDs, or NVMes, and it’s rated at 6.7 petabytes of capacity and 48GBps of throughput. For comparison, a single fast NVMe drive maxes out at around 7GBps. These arrays can be configured in various RAID configurations for redundancy, and a typical mainframe will have multiple storage arrays per LPAR, with separate storage arrays for backups.


Multiple dedicated I/O controllers and CPU support for the PCIe 5.0 bus ensure that throughput on a mainframe is fast. Primary storage is on arrays of SSDs or NVMes.





## The OS: Z/OS


To make the most of a purpose-built CPU, you need a purpose-built operating system. Z/OS—pronounced “zee/zed oh ess,” depending on your location—is the mainframe operating system. The 64-bit OS was developed by IBM for the Z/Architecture family of mainframe computers, and it has compatibility with the older MVS mainframe OS. It was released in 2000 and is backward-compatible with older 24-bit and 31-bit applications. Licensed and leased from IBM, Z/OS is proprietary and closed source (the company also offers a personal version of Z/OS for use on PC desktops).


The OS natively supports applications compiled in COBOL, C, C++, Fortran, and PL/1, as well as Java applications in Java application servers. As discussed earlier, Z/OS can be partitioned into separate logical partitions, each with separate hardware, permissions, workloads, and even different operating systems. Red Hat Linux is a supported guest OS.


Z/OS provides a security system implemented through Security Server, Resource Access Control Facility (RACF), and Pervasive Encryption. Security Server controls the access of users and restricts the functions that an authorized user can perform. RACF controls access to all protected Z/OS resources.


This includes access to applications, data files, APIs, and hardware devices. Pervasive Encryption provides the ability to encrypt any data file with strong AES encryption, and encrypted files are transparently decrypted and re-encrypted when accessed. Encryption is done in hardware with minimal load to the CPU. A user who has access to the file but no access to the decryption would see only the random bytes of the encrypted file.


On a system that may have 1,000 supporting personnel, no one person or role is expected to know or run the entire OS. Mainframe support is often divided between many departments, including enterprise storage, permissions and access, cryptography, daily system operations, applications software support, application testing, application deployments, hardware support, and reporting.


## Files


Files on a mainframe are called data sets. Each file is referenced through its complete path, which consists of up to eight “qualifiers,” each made of up to eight characters. Qualifiers can contain numbers, letters, and the symbols @, #, and $.


Here’s an example of a full data set path:



> `TEST1.AREA1.GHCC.AMUST#.T345.INPUT.ACC$.FILEAA`
> 
> 


At the byte level, all characters are in Extended Binary Coded Decimal Interchange Code, or EBCDIC, an 8-bit character encoding alternative to ASCII. Sorting EBCDIC puts lowercase letters before uppercase letters and letters before numbers, exactly the opposite of ASCII.


Z/OS also supports the UNIX-based ZFS filesystem and provides a file system for UNIX or Linux programs to run under Z/OS.


Although Z/OS includes the X Windows system, applications have no concept of bitmapped windows. All display is through character-based screens using 3270 emulated terminals. This is the ancient and proverbial “green screen.” Z/OS applications with screen I/O are generally coded to 24 rows by 80 columns.


Z/OS evolved and matured on a separate evolutionary course from UNIX and Linux. You can see a handy list of similarities and differences between the two systems [here](https://www.ibm.com/docs/en/zos-basic-skills?topic=1960s-brief-comparison-zos-unix).






 




## Tags:
***email-adresses***: chipclocked@5.2 srated@6.7

### Autogenerated tags:
z/os telum l2 l3 lpars i/o lpar linux l4 purpose-built
