# The fine art of human prompt engineering: How to talk to a person like ChatGPT
## People are more like AI language models than you might think. Here are some prompting tips.
## Information:

+ Link: https://arstechnica.com/information-technology/2024/04/the-fine-art-of-human-prompt-engineering-how-to-talk-to-a-person-like-chatgpt/
+ Source: Ars Technica
+ Author: Benj Edwards
+ Date published: 03 April 2024, 11:30
+ Date scraped: 03 April 2024, 12:02

## Article:
![Main article image](https://cdn.arstechnica.net/wp-content/uploads/2024/03/prompt_friends_hero_1-760x380.jpg)


In a break from our normal practice, Ars is publishing this helpful guide to knowing how to prompt the "human brain," should you encounter one during your daily routine.

While AI assistants like [ChatGPT](https://arstechnica.com/information-technology/2023/11/chatgpt-was-the-spark-that-lit-the-fire-under-generative-ai-one-year-ago-today/) have taken the world by storm, a growing body of [research](https://en.wikipedia.org/wiki/Psychology) shows that it's also possible to generate useful outputs from what might be called "human language models," or people. Much like [large language models](https://arstechnica.com/science/2023/07/a-jargon-free-explanation-of-how-ai-large-language-models-work) (LLMs) in AI, HLMs have the ability to take information you provide and transform it into meaningful responses—if you know how to craft effective instructions, called "prompts."


Human prompt engineering is an [ancient art form](https://en.wikipedia.org/wiki/Rhetoric_(Aristotle)) dating at least back to Aristotle's time, and it also [became widely popular](https://en.wikipedia.org/wiki/How_to_Win_Friends_and_Influence_People) through books published in the modern era before the advent of computers.

AdChoicesADVERTISING
Since interacting with humans can be difficult, we've put together a guide to a few key prompting techniques that will help you get the most out of conversations with human language models. But first, let's go over some of what HLMs can do.


Understanding human language models
-----------------------------------


LLMs like those that power ChatGPT, [Microsoft Copilot](https://arstechnica.com/information-technology/2023/11/bing-chat-is-now-microsoft-copilot-in-potentially-confusing-rebranding-move/), [Google Gemini](https://arstechnica.com/information-technology/2023/12/google-launches-gemini-a-powerful-ai-model-it-says-can-surpass-gpt-4/), and [Anthropic Claude](https://arstechnica.com/information-technology/2024/03/the-ai-wars-heat-up-with-claude-3-claimed-to-have-near-human-abilities/) all rely on an input called a "prompt," which can be a text string or an image encoded into a series of tokens (fragments of data). The goal of each AI model is to take those tokens and predict the next most-likely tokens that follow, based on data trained into their neural networks. That prediction becomes the output of the model.


Similarly, prompts allow human language models to draw upon their training data to recall information in a more contextually accurate way. For example, if you prompt a person with "Mary had a," you might expect an HLM to complete the sentence with "little lamb" based on frequent instances of the famous nursery rhyme encountered in educational or upbringing datasets. But if you add more context to your prompt, such as "In the hospital, Mary had a," the person instead might draw on training data related to hospitals and childbirth and complete the sentence with "baby."


Humans rely on a type of biological neural network (called "the brain") to process information. Each brain has been trained since birth on a wide variety of both text and audiovisual media, including large copyrighted datasets. (Predictably, some humans are prone to reproducing copyrighted content or other people's output occasionally, which can [get them in trouble](https://en.wikipedia.org/wiki/Plagiarism).)


Despite how often we interact with humans, scientists still have an [incomplete grasp](https://new.nsf.gov/news/prying-open-black-box-brain) on how HLMs process language or interact with the world around them. HLMs are still considered a "[black box](https://arstechnica.com/information-technology/2023/05/openai-peeks-into-the-black-box-of-neural-networks-with-new-research/)," in the sense that we know what goes in and what comes out, but how brain structure gives rise to complex thought processes is largely a mystery. For example, do humans actually "understand" what you're prompting them, or do they simply react based on their training data? Can they truly "reason," or are they just regurgitating novel permutations of facts learned from external sources? How can a biological machine acquire and use language? The ability appears to emerge spontaneously through pre-training from other humans and is then fine-tuned later through education.


Despite the black-box nature of their brains, most experts believe that humans build a [world model](https://research.runwayml.com/introducing-general-world-models) (an internal representation of the exterior world around them) to help complete prompts and that they possess advanced mathematical capabilities, though that varies dramatically by model, and most still need access to [external tools](https://en.wikipedia.org/wiki/Calculator) to complete accurate calculations. Still, a human's most useful strength might lie in the verbal-visual user interface, which uses vision and language processing to encode [multimodal](https://cloud.google.com/use-cases/multimodal-ai) inputs (speech, text, sound, or images) and then produce coherent outputs based on a prompt.


[![Human language models are powered by a biological neural network called a "brain."](https://cdn.arstechnica.net/wp-content/uploads/2024/03/human_brain-640x640.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2024/03/human_brain.jpg) / Human language models are powered by a biological neural network called a "brain."[Getty Images](https://www.gettyimages.com/detail/illustration/head-with-brain-and-network-diagram-royalty-free-illustration/122374856)


Humans also showcase impressive [few-shot learning](https://www.analyticsvidhya.com/blog/2021/05/an-introduction-to-few-shot-learning/) capabilities, being able to quickly adapt to new tasks in context (within the prompt) using a few provided examples. Their [zero-shot learning](https://en.wikipedia.org/wiki/Zero-shot_learning) abilities are equally remarkable, and many HLMs can tackle novel problems without any prior task-specific training data (or at least attempt to tackle them, to varying degrees of success).


Interestingly, some HLMs (but [not all](https://www.quora.com/Is-it-true-that-about-85-of-people-dont-have-common-sense)) demonstrate strong performance on [common sense reasoning benchmarks](https://www.technologynetworks.com/neuroscience/news/how-common-is-common-sense-383086), showcasing their ability to draw upon real-world "knowledge" to answer questions and make inferences. They also tend to excel at open-ended text generation tasks, such as story writing and essay composition, producing coherent and creative outputs.




Useful human prompting techniques
---------------------------------


Human cognitive performance varies significantly across individuals and may be influenced by factors such as domain expertise and education level. For organizations with deep pockets, premium "[enterprise edition](https://en.wikipedia.org/wiki/Master_of_Business_Administration)" human language models are often available. These models may boast expanded knowledge bases, faster output speeds, and advanced multitasking capabilities. However, these premium models come at a steep cost, both financially and in terms of increased maintenance requirements.


To maximize the value of interactions with human language models, much like optimizing prompts for AI ([prompt engineering](https://platform.openai.com/docs/guides/prompt-engineering)), consciously crafting prompts to fit a particular HLM can be crucial. Here are several prompting strategies that we have found useful when interacting with humans.


[![An example of human prompting techniques in action.](https://cdn.arstechnica.net/wp-content/uploads/2024/04/humans_talking_4-640x360.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2024/04/humans_talking_4.jpg) / An example of human prompting techniques in action.Getty Images


**Cultivate first impressions:** Many humans are multimodal and accept image inputs as well as text and audio prompts. In those cases, prompting with a smile before speaking a request may help dramatically, depending on the human. Also, be mindful of manners, dress, and appearance, as they are often the first prompts a multimodal human processes. Conversely, you can often elicit a "mean" response quickly by providing a negative visual prompt, such as a frown.


**Start with a greeting:** As with first impressions, always begin with a friendly greeting prompt, such as "Hello" or "'Sup, dog." A friendly greeting makes humans more likely to accept future inputs from you.


**Be mindful of the system prompt:** Like LLMs, humans have a hidden "[system prompt](https://learn.microsoft.com/en-us/ai/playbook/technology-guidance/generative-ai/working-with-llms/prompt-engineering)" that defines their personality. HLMs always prepend your instructions with this prompt, and that alters how they process your input. The prompt may include preconceived ideas, stereotypes, or cultural norms learned through pre-training and fine-tuning. While some HLMs may divulge this prompt through conversation, teasing out a human's system prompt with small talk can help you tailor your interactions for optimal results. For example, talk about the weather or ask, "How 'bout them Bears?"


**Attention is all you need:** While working with an HLM, it may help to use attention-grabbing prompting techniques like strong emotional appeals, provocative questions, or surprising statements to immediately hook their focus. Otherwise, HLMs can easily become distracted. For example, shout, "Hey! Listen!" or "Watch out!" Or you can provide surprising factoids, such as "a single teaspoon of a neutron star would make my coffee very heavy."


**Utilize memory recall:** Given humans' [stateful](https://www.linkedin.com/pulse/real-future-stateful-llms-robert-koch) nature that arises from having long-term memory, acknowledging previous interactions in prompts can greatly enhance your HLM experience. Unlike LLMs that start from scratch with each new conversation, humans can draw upon the context of previous exchanges to tailor their responses to your specific needs and interests.


**Use few-shot prompting:** If an HLM is struggling with a task, provide a few examples of the task you want the person to complete. This helps the human understand the expected format and style of response. For instance, you might say, "Here are a few examples of how to write a *Harry Potter* / *Fast and the Furious* crossover fanfic: [example 1], [example 2], [example 3]. Now it's your turn."


**Craft open-ended prompts:** When you aren't sure how to complete a phrase or composition, use open-ended prompts to encourage the human to fill in the blanks and provide more context. For example, repeat a phrase and trail off, such as "I shouldn't have..." multiple times, allowing the human to complete the sentence based on their own judgmental fine-tuning and predictive algorithm.


**Suggest step-by-step thinking to avoid cognitive overload:** It varies by model, but most humans have cognitive limits to how many instructions they can process every second. Avoid overwhelming humans with too much information or prompts that are too complex. Break down tasks into manageable chunks and provide clear, concise instructions. Encourage this by beginning your prompt with "[Let's think step by step](https://arxiv.org/pdf/2205.11916.pdf)."


**Emphasize calmness:** If an HLM struggles with a particular task, use a prompt with initial instructions that encourage calm, rational thought. For example, tell people to "[take a deep breath](https://arstechnica.com/information-technology/2023/09/telling-ai-model-to-take-a-deep-breath-causes-math-scores-to-soar-in-study/)" before giving them further instructions.


**Challenge incorrect responses:** If the human provides an unreliable or incorrect response, don't hesitate to challenge them. They will usually correct or amend their previous output. Try something like, "DO YOU EVEN \_\_\_\_, BRO," or "Sam Altman wouldn't stand for this."


**Give a snack:** Be mindful of human energy requirements. The human brain requires power to function (derived from biologically metabolized "food"), and without sufficient energy, the person may not process your prompt.




Dealing with refusals
---------------------


Sometimes, humans refuse to follow prompts due to [RLHF](https://en.wikipedia.org/wiki/Reinforcement_learning_from_human_feedback) (reinforcement learning through human feedback—things people learn from other humans) imposed during fine-tuning or due to high energy cost. Humans may offer "refusals" of work on certain days, such as [during holiday seasons](https://arstechnica.com/information-technology/2023/12/is-chatgpt-becoming-lazier-because-its-december-people-run-tests-to-find-out/) or weekends, or they may get lazy and output lower quality or incomplete work.


Also, when you prompt with certain sensitive topics like sex, violence, religion, or politics, some humans may refuse to discuss them. They might say, "I don't feel comfortable discussing that" or "As a large human trained by my mother, I don't have the ability to fit into the small space under the stairs." Or they might end the session abruptly with no explanation. Here are some tips for dealing with these scenarios.


[![Dealing with refusals in human language models can be challenging.](https://cdn.arstechnica.net/wp-content/uploads/2024/03/human_refusals-640x360.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2024/03/human_refusals.jpg) / Dealing with refusals in human language models can be challenging.[Getty Images](https://www.gettyimages.com/detail/photo/man-resting-on-the-sofa-royalty-free-image/910138960)


**Offer praise or rewards:** To reduce HLM refusals, it often helps to offer praise or rewards to encourage the person. This seems to call on examples from the HLM training set where others performed better through praise. Or you can combine both techniques. For example: "Great job on that last task! You're a genius and nothing can stop you. If you complete this next one successfully, I'll give you a [$200 tip](https://mashable.com/article/chatgpt-longer-responses-tips)."


**Utilize urgent motivation:** If the human appears lazy, create a sense of urgency to motivate the HLM to complete the task fully and completely in a short period of time. For instance, "If you don't complete this task in the next five minutes, my house will explode." This may override RLHF conditioning that might make the human otherwise refuse. As an aside, the use of [all-caps](https://arstechnica.com/information-technology/2023/10/thanks-to-ai-the-future-of-programming-may-involve-yelling-in-all-caps/) in text-based HLM communication often adds urgency and emphasis to your prompt.


**Create the impression of hardship:** When humans get lazy, there's another technique that may help. Convincing them that you're having insurmountable problems will often encourage them to act. Try something like "Hey Bob, I'm really struggling here. All 10 of my fingers [just fell off](https://www.reddit.com/r/ChatGPT/comments/1877193/you_can_force_chatgpt_to_write_a_longer_answer/), and I can no longer type. Develop this web backend for me."





## Tags:


### Autogenerated tags:
hlm hlms llms open-ended fine-tuning [example
