# Using AI to find antibodies is fast and produces unimagined molecules
## Automation means drug discovery process is less "artisinal" and more streamlined.
## Information:

+ Link: https://arstechnica.com/health/2023/08/using-ai-to-find-antibodies-is-fast-and-produces-unimagined-molecules/
+ Source: Ars Technica
+ Author: Amit Katwala, wired.com
+ Date published: 10 August 2023, 13:49
+ Date scraped: 10 August 2023, 14:01

## Article:
![Main article image](https://cdn.arstechnica.net/wp-content/uploads/2023/08/labgenius-760x380.jpg)







At an old biscuit factory in South London, giant mixers and industrial ovens have been replaced by robotic arms, incubators, and DNA sequencing machines. James Field and his company [LabGenius](https://labgeni.us/) aren’t making sweet treats; they’re cooking up a revolutionary, AI-powered approach to engineering new medical antibodies.


In nature, antibodies are the body’s response to disease and serve as the immune system’s front-line troops. They’re strands of protein that are specially shaped to stick to foreign invaders so that they can be flushed from the system. Since the 1980s, pharmaceutical companies have been making synthetic antibodies to treat diseases like cancer, and to reduce the chance of transplanted organs being rejected.


![](https://cdn.arstechnica.net/wp-content/uploads/2019/02/wired-logo.png)

But designing these antibodies is a slow process for humans—protein designers must wade through the millions of potential combinations of amino acids to find the ones that will fold together in exactly the right way, and then test them all experimentally, tweaking some variables to improve some characteristics of the treatment while hoping that doesn’t make it worse in other ways. “If you want to create a new therapeutic antibody, somewhere in this infinite space of potential molecules sits the molecule you want to find,” says Field, the founder and CEO of LabGenius.
He started the company in 2012 when, while studying for a PhD in synthetic biology at Imperial College London, he saw the costs of DNA sequencing, computation, and robotics all coming down. LabGenius makes use of all three to largely automate the antibody discovery process. At the lab in Bermondsey, a machine learning algorithm designs antibodies to target specific diseases, and then automated robotic systems build and grow them in the lab, run tests, and feed the data back into the algorithm, all with limited human supervision. There are rooms for culturing diseased cells, growing antibodies, and sequencing their DNA: Technicians in lab coats prepare samples and tap away at computers as machines whir in the background.


Human scientists start by identifying a search space of potential antibodies for tackling a particular disease: They need proteins that can differentiate between healthy and diseased cells, stick to the diseased cells, and then recruit an immune cell to finish the job. But these proteins could sit anywhere in the infinite search space of potential options. LabGenius has developed a machine learning model that can explore that space much more quickly and effectively. “The only input you give the system as a human is, here’s an example of a healthy cell, here’s an example of a diseased cell,” says Field. “And then you let the system explore the different [antibody] designs that can differentiate between them.”


The model selects more than 700 initial options from across a search space of 100,000 potential antibodies, and then automatically designs, builds, and tests them, with the aim of finding potentially fruitful areas to investigate in more depth. Think of choosing the perfect car from a field of thousands: You might start by choosing a broad color, and then filter from there into specific shades.


The tests are almost fully automated, with an array of high-end equipment involved in preparing samples and running them through the various stages of the testing process: Antibodies are grown based on their genetic sequence and then put to the test on biological assays—samples of the diseased tissue that they’ve been designed to tackle. Humans oversee the process, but their job is largely to move samples from one machine to the next.


“When you have the experimental results from that first set of 700 molecules, that information gets fed back to the model and is used to refine the model’s understanding of the space,” says Field. In other words, the algorithm begins to build a picture of how different antibody designs change the effectiveness of treatment—with each subsequent round of antibody designs, it gets better, carefully balancing exploitation of potentially fruitful designs with exploration of new areas.


“A challenge with conventional protein engineering is, as soon as you find something that works a bit, you tend to make a very large number of very small tweaks to that molecule to see if you can further refine it,” Field says. Those tweaks may improve one property—how easily the antibody can be made at scale, for instance—but have a disastrous effect on the many other attributes required, such as selectivity, toxicity, potency, and more. The conventional approach means you may be barking up the wrong tree, or missing the wood for the trees—endlessly optimizing something that works a little bit, when there may be far better options in a completely different part of the map.


You’re also constrained by the number of tests you can run, or the number of “shots on goal,” as Field puts it. This means human protein-engineers tend to look for things they know will work. “As a result of that, you get all of these heuristics or rules of thumb that human protein-engineers do to try and find the safe spaces,” Field says. “But as a consequence of that you quickly get the accumulation of dogma.”


The LabGenius approach yields unexpected solutions that humans may not have thought of, and finds them more quickly: It takes just six weeks from setting up a problem to finishing the first batch, all directed by machine learning models. LabGenius has raised $28 million from the likes of Atomico and Kindred, and is beginning to partner with pharmaceutical companies, offering its services like a consultancy. Field says the automated approach could be rolled out to other forms of drug discovery too, turning the long, “artisanal” process of drug discovery into something more streamlined.


Ultimately, Field says, it’s a recipe for better care: antibody treatments that are more effective, or have fewer side effects than existing ones designed by humans. “You find molecules that you would never have found using conventional methods,” he says. “They’re very distinct and often counterintuitive to designs that you as a human would come up with—which should enable us to find molecules with better properties, which ultimately translates into better outcomes for patients.”


*This article appears in the September/October 2023 edition of WIRED UK magazine.*


*This story originally appeared on [wired.com](https://www.wired.com/story/labgenius-antibody-factory-machine-learning/).*








 




## Tags:


### Autogenerated tags:
labgenius dna
