# Why ChatGPT and Bing Chat are so good at making things up
## A look inside the hallucinating artificial minds of the famous text prediction bots.
## Information:

+ Link: https://arstechnica.com/information-technology/2023/04/why-ai-chatbots-are-the-ultimate-bs-machines-and-how-people-hope-to-fix-them/
+ Source: Ars Technica
+ Author: Benj Edwards
+ Date published: 06 April 2023, 15:58
+ Date scraped: 06 April 2023, 17:01

## Article:
![Main article image](https://cdn.arstechnica.net/wp-content/uploads/2023/03/AI-the-ultimate-BSer-760x380.jpg)







Over the past few months, AI chatbots like [ChatGPT](https://arstechnica.com/information-technology/2022/12/openai-invites-everyone-to-test-new-ai-powered-chatbot-with-amusing-results/) have captured the world's attention due to their ability to converse in a human-like way on just about any subject. But they come with a serious drawback: They can present convincing false information easily, making them unreliable sources of factual information and potential sources of [defamation](https://arstechnica.com/tech-policy/2023/04/openai-may-be-sued-after-chatgpt-falsely-says-aussie-mayor-is-an-ex-con/).


Why do AI chatbots make things up, and will we ever be able to fully trust their output? We asked several experts and dug into how these AI models work to find the answers.


## “Hallucinations”—a loaded term in AI


AI chatbots such as OpenAI's ChatGPT rely on a type of AI called a "large language model" (LLM) to generate their responses. An LLM is a computer program trained on millions of text sources that can read and generate "natural language" text—language as humans would naturally write or talk. Unfortunately, they can also make mistakes.


In academic literature, AI researchers often call these mistakes "hallucinations." But that label has grown controversial as the topic becomes mainstream because some people feel it anthropomorphizes AI models (suggesting they have human-like features) or gives them agency (suggesting they can make their own choices) in situations where that should not be implied. The creators of commercial LLMs may also use hallucinations [as an excuse](https://www.bloomberg.com/news/newsletters/2023-04-03/chatgpt-bing-and-bard-don-t-hallucinate-they-fabricate) to blame the AI model for faulty outputs instead of taking responsibility for the outputs themselves.


Still, generative AI is so new that we need metaphors borrowed from existing ideas to explain these highly technical concepts to the broader public. In this vein, we feel the term "confabulation," although similarly imperfect, is a better metaphor than "hallucination." In human psychology, a "[confabulation](https://clinmedjournals.org/articles/ijnn/international-journal-of-neurology-and-neurotherapy-ijnn-4-070.php)" occurs when someone's memory has a gap and the brain convincingly fills in the rest without intending to deceive others. ChatGPT *does not* work like the human brain, but the term "confabulation" arguably serves as a better metaphor because there's a creative gap-filling principle at work, as we'll explore below.


## The confabulation problem


It's a big problem when an AI bot generates false information that can potentially mislead, misinform, or defame. Recently, The Washington Post [reported](https://www.washingtonpost.com/technology/2023/04/05/chatgpt-lies/) on a law professor who discovered that ChatGPT had placed him on a list of legal scholars who had sexually harassed someone. But it never happened—ChatGPT made it up. The same day, Ars [reported](https://arstechnica.com/tech-policy/2023/04/openai-may-be-sued-after-chatgpt-falsely-says-aussie-mayor-is-an-ex-con/) on an Australian mayor who allegedly found that ChatGPT claimed he had been convicted of bribery and sentenced to prison, a complete fabrication.


Shortly after ChatGPT's launch, people began [proclaiming](https://www.nytimes.com/2022/12/21/technology/ai-chatgpt-google-search.html) the end of the search engine. At the same time, though, many examples of ChatGPT's confabulations began to circulate on social media. The AI bot has invented [books](https://twitter.com/hermansaksono/status/1615053056328228864) and [studies](https://twitter.com/sabhlok/status/1621060688658706432) that don't exist, [publications](https://twitter.com/KevinZollman/status/1620438109778509824) that professors didn't write, fake [academic papers](https://twitter.com/dsmerdon/status/1618816703923912704), false [legal citations](https://twitter.com/samuelharden/status/1620439260125077504), non-existent [Linux system features](https://twitter.com/ProgrammerDude/status/1619990879040835584), unreal [retail mascots](https://twitter.com/harrymccracken/status/1618344082576912384), and [technical details](https://twitter.com/jonmasters/status/1598749857237303302) that don't make sense.



And yet despite ChatGPT's predilection for casually fibbing, counter-intuitively, its resistance to confabulation is why we're even talking about it today. Some experts note that ChatGPT was technically an improvement over vanilla GPT-3 (its predecessor model) because it could refuse to answer some questions or let you know when its answers might not be accurate.


"A major factor in Chat's success is that it manages to suppress confabulation enough to make it unnoticeable for many common questions," said Riley Goodside, an expert in large language models who serves as staff prompt engineer at Scale AI. "Compared to its predecessors, ChatGPT is notably less prone to making things up."


If used as a brainstorming tool, ChatGPT's logical leaps and confabulations might lead to creative breakthroughs. But when used as a factual reference, ChatGPT could cause real harm, and OpenAI knows it.


Not long after the model's launch, OpenAI CEO Sam Altman [tweeted](https://twitter.com/sama/status/1601731295792414720?s=20&t=23p6N-FTFaB4rB1HURSJkg), "ChatGPT is incredibly limited, but good enough at some things to create a misleading impression of greatness. It's a mistake to be relying on it for anything important right now. It’s a preview of progress; we have lots of work to do on robustness and truthfulness." In a later [tweet](https://twitter.com/sama/status/1601733962530902017), he wrote, "It does know a lot, but the danger is that it is confident and wrong a significant fraction of the time."


What's going on here?







## How ChatGPT works


[![An AI-generated image of a chatbot hovering in the library, as one does.](https://cdn.arstechnica.net/wp-content/uploads/2023/02/chatgpt_library_hero_1-640x360.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2023/02/chatgpt_library_hero_1.jpg) / An AI-generated image of a chatbot hovering in the library, as one does.Benj Edwards / Stable Diffusion


To understand how a GPT model like ChatGPT or Bing Chat confabulates, we have to know how GPT models work. While OpenAI hasn't released the technical details of ChatGPT, [Bing Chat](https://arstechnica.com/information-technology/2023/02/ai-powered-bing-chat-spills-its-secrets-via-prompt-injection-attack/), or even [GPT-4](https://arstechnica.com/information-technology/2023/03/openai-announces-gpt-4-its-next-generation-ai-language-model/), we do have access to the [research paper](https://arxiv.org/abs/2005.14165) that introduced their precursor, GPT-3, in 2020.


Researchers build (train) large language models like GPT-3 and GPT-4 by using a process called "unsupervised learning," which means the data they use to train the model isn't specially annotated or labeled. During this process, the model is fed a large body of text (millions of books, websites, articles, poems, transcripts, and other sources) and repeatedly tries to predict the next word in every sequence of words. If the model's prediction is close to the actual next word, the neural network updates its parameters to reinforce the patterns that led to that prediction.


Conversely, if the prediction is incorrect, the model adjusts its parameters to improve its performance and tries again. This process of trial and error, though a technique called "backpropagation," allows the model to learn from its mistakes and gradually improve its predictions during the training process.


As a result, GPT learns statistical associations between words and related concepts in the data set. Some people, like OpenAI Chief Scientist Ilya Sutskever, think that GPT models [go even further than that](https://twitter.com/bio_bootloader/status/1640512444958396416?s=20), building a sort of internal reality model so they can predict the next best token more accurately, but the idea is controversial. The exact details of how GPT models come up with the next token within their neural nets are still uncertain.



> "what does it mean to predict the next token well enough? ... it means that you understand the underlying reality that led to the creation of that token"  
>   
> excellent explanation by [@ilyasut](https://twitter.com/ilyasut?ref_src=twsrc%5Etfw), and thoughts on the crucial question: how far can these systems extrapolate beyond human? [pic.twitter.com/v8zFQWvxWY](https://t.co/v8zFQWvxWY)
> 
> — BioBootloader (@bio\_bootloader) [March 28, 2023](https://twitter.com/bio_bootloader/status/1640512444958396416?ref_src=twsrc%5Etfw)


In the current wave of GPT models, this core training (now often called "pre-training") happens only once. After that, people can use the trained neural network in "inference mode," which lets users feed an input into the trained network and get a result. During inference, the input sequence for the GPT model is always provided by a human, and it's called a "prompt." The prompt determines the model's output, and altering the prompt even slightly can dramatically change what the model produces.


For example, if you prompt GPT-3 with "Mary had a," it usually completes the sentence with "little lamb." That's because there are probably thousands of examples of "Mary had a little lamb" in GPT-3's training data set, making it a sensible completion. But if you add more context in the prompt, such as "In the hospital, Mary had a," the result will change and return words like "baby" or "series of tests."


Here's where things get a little funny with ChatGPT, since it's framed as a conversation with an agent rather than just a straight text-completion job. In the case of ChatGPT, the input prompt is the entire conversation you've been having with ChatGPT, starting with your first question or statement and including any [specific instructions](https://arstechnica.com/information-technology/2023/02/ai-powered-bing-chat-spills-its-secrets-via-prompt-injection-attack/) provided to ChatGPT before the simulated conversation even began. Along the way, ChatGPT keeps a running short-term memory (called the "context window") of everything it and you have written, and when it "talks" to you, it is attempting to complete the transcript of a conversation as a text-completion task.


[![A diagram showing how GPT conversational language model prompting works.](https://cdn.arstechnica.net/wp-content/uploads/2023/03/how_gpt_models_work-640x522.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2023/03/how_gpt_models_work.jpg) / A diagram showing how GPT conversational language model prompting works.Benj Edwards / Ars Technica


Additionally, ChatGPT is different from vanilla GPT-3 because it has also been trained on transcripts of conversations written by humans. "We trained an initial model using supervised fine-tuning: human AI trainers provided conversations in which they played both sides—the user and an AI assistant," [wrote OpenAI](https://openai.com/blog/chatgpt) in its initial ChatGPT release page. "We gave the trainers access to model-written suggestions to help them compose their responses."


ChatGPT has also been tuned more heavily than GPT-3 using a technique called "reinforcement learning from human feedback," or RLHF, where human raters ranked ChatGPT's responses in order of preference, then fed that information back into the model. Through RLHF, OpenAI was able to instill in the model the goal of refraining from answering many questions it cannot answer reliably. This has allowed the ChatGPT to produce coherent responses with fewer confabulations than the base model. But inaccuracies still slip through.





## Why ChatGPT confabulates


Natively, there is nothing in a GPT model's raw data set that separates fact from fiction. That guidance comes from a) the prevalence of accurate content in the data set, b) recognition of factual information in the results by humans, or c) reinforcement learning guidance from humans that emphasizes certain factual responses.


The behavior of LLMs is still an active area of research. Even the researchers who created these GPT models are [still discovering](https://arxiv.org/abs/2212.10559) surprising [properties](https://arxiv.org/abs/2206.07682) of the technology that no one predicted when they were first developed. GPT's abilities to do many of the interesting things we are now seeing, such as language translation, programming, and playing chess, were a surprise to researchers at one point (for an early taste of that, check out 2019's GPT-2 [research paper](https://cdn.openai.com/better-language-models/language_models_are_unsupervised_multitask_learners.pdf) and search for the term "surprising").


So when we ask why ChatGPT confabulates, it's [difficult](https://aclanthology.org/2022.naacl-main.387.pdf) to pinpoint an exact technical answer. And because there is a "black box" element of the neural network weights, it's very difficult (if not impossible) to predict their exact output given a complex prompt. Still, we know some basic things about how why confabulation happens.


Key to understanding ChatGPT's confabulation ability is understanding its role as a prediction machine. When ChatGPT confabulates, it is reaching for information or analysis that is not present in its data set and filling in the blanks with plausible-sounding words. ChatGPT is especially good at making things up because of the superhuman amount of data it has to work with, and its ability to glean word context so well helps it place erroneous information seamlessly into the surrounding text.


"I think the best way to think about confabulation is to think about the very nature of large language models: The only thing they know how to do is to pick the next best word based on statistical probability against their training set," said Simon Willison, a software developer who [often writes](https://simonwillison.net/) on the topic.


In a [2021 paper](https://arxiv.org/abs/2109.07958), a trio of researchers from the University of Oxford and OpenAI identified [two major types](https://arxiv.org/abs/2109.07958) of falsehoods that LLMs like ChatGPT might produce. The first comes from inaccurate source material in its training data set, such as common misconceptions (e.g., "eating turkey makes you drowsy"). The second arises from making inferences about specific situations that are absent from its training material (data set); this falls under the aforementioned "hallucination" label.


Whether the GPT model makes a wild guess or not is based on a property that AI researchers call "temperature," which is often characterized as a "creativity" setting. If the creativity is set high, the model will guess wildly; if it's set low, it will spit out data deterministically based on its data set.


Recently, Microsoft employee [Mikhail Parakhin](https://www.linkedin.com/in/mikhail-parakhin), who works on Bing Chat, [tweeted](https://twitter.com/MParakhin/status/1629011219041452032?s=20) about Bing Chat's tendency to hallucinate and what causes it. "This is what I tried to explain previously: hallucinations = creativity," he wrote. "It tries to produce the highest probability continuation of the string using all the data at its disposal. Very often it is correct. Sometimes people have never produced continuations like this."


Parakhin said that those wild creative leaps are what make LLMs interesting. "You can clamp down on hallucinations, and it is super-boring," he wrote. "[It] answers 'I don't know' all the time or only reads what is there in the Search results (also sometimes incorrect). What is missing is the tone of voice: it shouldn't sound so confident in those situations."


Balancing creativity and accuracy is a challenge when it comes to fine-tuning language models like ChatGPT. On the one hand, the ability to come up with creative responses is what makes ChatGPT such a powerful tool for generating new ideas or unblocking writer's block. It also makes the models sound more human. On the other hand, accuracy to the source material is crucial when it comes to producing reliable information and avoiding confabulation. Finding the right balance between the two is an ongoing challenge for the development of language models, but it's one that is essential to produce a tool that is both useful and trustworthy.


There's also the issue of compression. During the training process, GPT-3 considered petabytes of information, but the resulting neural network is only a fraction of that in size. In a [widely read New Yorker piece](https://www.newyorker.com/tech/annals-of-technology/chatgpt-is-a-blurry-jpeg-of-the-web), author Ted Chiang called this a "blurry JPEG of the web." That means a large portion of the factual training data is lost, but GPT-3 makes up for it by learning relationships between concepts that it can later use to reformulate new permutations of these facts. Like a human with a flawed memory working from a hunch of how something works, it sometimes gets things wrong. And, of course, if it doesn't know the answer, it will give its best guess.


We cannot forget the role of the prompt in confabulations. In some ways, ChatGPT is a mirror: It gives you back what you feed it. If you feed it falsehoods, it will tend to agree with you and "think" along those lines. That's why it's important to start fresh with a new prompt when changing subjects or experiencing unwanted responses. And ChatGPT is probabilistic, which means it's partially random in nature. Even with the same prompt, what it outputs can change between sessions.


All this leads to one conclusion, one that OpenAI agrees with: ChatGPT as it is currently designed, is not a reliable source of factual information and cannot be trusted as such. "ChatGPT is great for some things, such as unblocking writer's block or coming up with creative ideas," said Dr. Margaret Mitchell, researcher and chief ethics scientist at AI company Hugging Face. "It was not built to be factual and thus will not be factual. It's as simple as that."












## Tags:


### Autogenerated tags:
chatgpt gpt openai gpt-3 llms chatbots
