# More hackers adopt Sliver toolkit as a Cobalt Strike alternative
## Threat actors are dumping the Cobalt Strike penetration testing suite in favor of similar frameworks that are less known. After Brute Ratel, the open-source, cross-platform kit called Sliver is becoming an attractive alternative.
## Information:

+ Link: https://www.bleepingcomputer.com/news/security/more-hackers-adopt-sliver-toolkit-as-a-cobalt-strike-alternative/
+ Source: Bleeping Computer
+ Author: Ionut Ilascu
+ Date published: 25 August 2022, 12:28
+ Date scraped: 25 August 2022, 13:00

## Article:
![Main article image](https://www.bleepstatic.com/content/hl-images/2022/08/25/SliverC2Framework.jpg)



Threat actors are dumping the Cobalt Strike penetration testing suite in favor of similar frameworks that are less known. After Brute Ratel, the open-source, cross-platform kit called Sliver is becoming an attractive alternative.


However, malicious activity using Sliver can be detected using hunting queries drawn from analyzing the toolkit, how it works, and its components.


### Migrating away from Cobalt Strike


Over the past years, Cobalt Strike has grown in popularity as an attack tool for various threat actors, including ransomware operations, to drop on compromised networks “beacons” that allow moving laterally to high-value systems.


Since defenders have learned to detect and stop attacks relying on this toolkit, hackers are trying other options that can evade Endpoint Detection and Response (EDR) and antivirus solutions.


Facing stronger defenses against Cobalt Strike, threat actors have found alternatives. Palo Alto Networks observed them [switch to Brute Ratel](https://www.bleepingcomputer.com/news/security/ransomware-hacking-groups-move-from-cobalt-strike-to-brute-ratel/), an adversarial attack simulation tool designed to elude security products.


A report from Microsoft notes that hackers, from state-sponsored groups to cybercrime gangs, are more and more using in attacks the Go-based [Sliver](https://github.com/BishopFox/sliver) security testing tool developed by researchers at BishopFox cybersecurity company.



“Microsoft has observed the Sliver command-and-control (C2) framework now being adopted and integrated in intrusion campaigns by [nation-state threat actors](https://www.ncsc.gov.uk/files/Advisory%20Further%20TTPs%20associated%20with%20SVR%20cyber%20actors.pdf), cybercrime groups directly supporting [ransomware and extortion](https://aka.ms/ransomware-as-a-service), and other threat actors to evade detection” - [Microsoft](https://www.microsoft.com/security/blog/2022/08/24/looking-for-the-sliver-lining-hunting-for-emerging-command-and-control-frameworks/)



One group that adopted Sliver is tracked as DEV-0237 by Microsoft. Also known as FIN12, the gang has been linked to various ransomware operators.


The gang has distributed ransomware payloads from various ransomware operators in the past (Ryuk, Conti, Hive, Conti, and BlackCat) via various malware, including BazarLoader and TrickBot.



![](https://www.bleepstatic.com/images/news/u/1100723/2022/DEV-0237_FIN12_rnsmwr.png)**FIN12 gang deploying various ransomware payloads**  
*source: Microsoft*


According to a report from UK’s Government Communications Headquarters (GCHQ), state-sponsored actors in Russia, specifically APT29 (a.k.a. Cozy Bear, The Dukes, Grizzly Steppe) have also [used Sliver to maintain access to compromised environments](https://www.ncsc.gov.uk/files/Advisory%20Further%20TTPs%20associated%20with%20SVR%20cyber%20actors.pdf).


Microsoft notes that Sliver has been deployed in more recent attacks using the Bumblebee (Coldtrain) malware loader, which is [associated with the Conti syndicate](https://www.bleepingcomputer.com/news/security/new-bumblebee-malware-replaces-contis-bazarloader-in-cyberattacks/) as a replacement for BazarLoader.


### Hunting for Sliver-based activity


Despite being a novel threat, there are methods to detect malicious activity caused by the Sliver framework as well as by stealthier threats.


Microsoft provides a set of tactics, techniques, and procedures (TTPs) that defenders can use to identify Sliver and other emerging C2 frameworks.


Since the Sliver C2 network supports multiple protocols (DNS, HTTP/TLS, MTLS, TCP) and accepts implants/operator connections, and can host files to mimic a legitimate web server, threat hunters can set up listeners to identify anomalies on the network for Sliver infrastructure.


“Some common artifacts are unique HTTP header combinations and [JARM hashes](https://github.com/salesforce/jarm), the latter of which are active fingerprinting techniques for TLS servers [methodology for [Sliver](https://community.riskiq.com/article/760e65cc/description) and [Bumblebee](https://community.riskiq.com/article/0b211905) from RiskIQ]” - Microsoft


Microsoft also shared information on how to detect Sliver payloads (shellcode, executables, shared libraries/DLLs, and services) generated using the official, non-customized codebase for the C2 framework.



Detection engineers can create loader-specific detections [e.g. Bumblebee] or, if the shellcode isn’t obfuscated, rules for the shellcode payload that is embedded in the loader.



For Sliver malware payloads that don’t have much context, Microsoft recommends extracting configurations when they’re loaded into memory since the framework has to de-obfuscate and decrypt them to be able to use them.


Scanning the memory could enable researchers to extract details such as configuration data:



![](https://www.bleepstatic.com/images/news/u/1100723/2022/InMemConfigSliver.png)**Configuration extraction from Sliver test implant**  
*source: Microsoft*


Threat hunters can also look for commands used for process injection, which the default Sliver code achieves without deviating from common implementations. Among the commands used for this are:


* migrate (command) – migrate into a remote process
* spawndll (command) – load and run a reflective DLL in a remote process
* sideload (command) – load and run a shared object (shared library/DLL) in a remote process
* msf-inject (command) – inject a Metasploit Framework payload into a process
* execute-assembly (command) – load and run a .NET assembly in a child process
* getsystem (command) – spawn a new Sliver session as the *NT AUTHORITY\SYSTEM* User

Microsoft notes that the toolkit also relies on extensions and aliases (Beacon Object Files (BFOs), .NET apps, and other third-party tooling) for command injection.


The framework also uses PsExect to run commands allowing for lateral movement.


To make it easier for enterprises protected by Defender to identify Sliver activity in their environment, Microsoft has created for the aforementioned commands a set of hunting queries that can run in the Microsoft 365 Defender portal.


Microsoft underlines that the provided detection rule sets and hunting guidance are for the Sliver codebase that is currently available publicly. The use of customized variants is likely to impact detection based on Microsoft's queries.





## Tags:


### Autogenerated tags:
microsoft ransomware c2 conti malware shellcode
