# Rust devs push back as Serde project ships precompiled binaries
## Serde, a popular Rust (de)serialization project, has decided to ship its serde_derive macro as a precompiled binary. This has generated a fair amount of concern among some developers who highlight the future legal and technical issues this may pose, along with a potential for supply chain attacks.
## Information:

+ Link: https://www.bleepingcomputer.com/news/security/rust-devs-push-back-as-serde-project-ships-precompiled-binaries/
+ Source: Bleeping Computer
+ Author: Ax Sharma
+ Date published: 19 August 2023, 09:55
+ Date scraped: 19 August 2023, 14:00

## Article:
![Main article image](https://www.bleepstatic.com/content/hl-images/2021/04/03/rust-bg.jpeg)



Serde, a popular Rust (de)serialization project, has decided to ship its *serde\_derive* macro as a precompiled binary.


The move has generated a fair amount of push back among developers who worry about its future legal and technical implications, along with a potential for supply chain attacks, should the maintainer account publishing these binaries be compromised.


According to the Rust package registry, crates.io, *serde* has been downloaded [over 196 million times](https://crates.io/crates/serde) over its lifetime, whereas the *[serde\_derive](https://crates.io/crates/serde_derive)* macro has scored more than 171 million downloads, attesting to the project's widespread circulation.


## Serde macro goes precompiled: there's no way to opt-out


About three weeks ago, a Rust programmer using the Serde project in their application noticed something odd.


"I'm working on packaging serde for Fedora Linux, and I noticed that recent versions of *serde\_derive* ship a precompiled binary now," [wrote](https://github.com/serde-rs/serde/issues/2538#issue-1825383332) Fabio Valentini, a Fedora Packaging Committee member.


"This is problematic for us, since we cannot, under no circumstances (with only very few exceptions, for firmware or the like), redistribute precompiled binaries."


Serde is a commonly used *ser*ialization and *de*serialization framework for Rust data structures that, [according to its website](https://serde.rs/), is designed to conduct these operations "efficiently and generically."


"The Serde ecosystem consists of data structures that know how to serialize and deserialize themselves along with data formats that know how to serialize and deserialize other things," states the project's website. Whereas, "[derive](https://serde.rs/derive.html#using-derive)" is one of its macros.


Valentini further inquired to the project maintainers, how were these new binaries "actually produced," and if it would be possible for him to recreate the binaries, as opposed to consuming precompiled versions.


David Tolnay, who is the primary Serde maintainer, [responded](https://github.com/serde-rs/serde/issues/2538#issuecomment-1654783988) with potential workarounds at the time. But, that's not to say that everyone is pleased.


Following an influx of comments from developers as to why the decision wasn't best suited for the project, Tolnay [acknowledged the feedback](https://github.com/serde-rs/serde/issues/2538#issuecomment-1682519944), prior to closing the GitHub issue.


His justification for shipping precompiled binaries is reproduced in whole below.


"The precompiled implementation is the only supported way to use the macros that are published in *serde\_derive*.  
  

If there is implementation work needed in some build tools to accommodate it, someone should feel free to do that work (as I have done for Buck and Bazel, which are tools I use and contribute significantly to) or publish your own fork of the source code under a different name.  
  

Separately, regarding the commentary above about security, the best path forward would be for one of the people who cares about this to invest in a Cargo or crates.io RFC around first-class precompiled macros so that there is an approach that would suit your preferences; *serde\_derive* would adopt that when available."


BleepingComputer has approached Tolnay with additional questions prior to publishing.


## "First .NET's Moq and now this."


Some Rust developers request that precompiled binaries be kept *optional*and separate from the original "serde\_derive" crate, while others have likened the move to the [controversial code change](https://www.bleepingcomputer.com/news/security/popular-open-source-project-moq-criticized-for-quietly-collecting-data/) to the Moq .NET project that sparked backlash.


"Please consider moving the precompiled serde\_derive version to a different crate and default serde\_derive to building from source so that users that want the benefit of precompiled binary can opt-in to use it," [requested](https://github.com/serde-rs/serde/issues/2538#issuecomment-1661893000) one user.


"Or vice-versa. Or any other solution that allows building from source without having to patch serde\_derive."


"Having a binary shipped as part of the crate, while I understand the build time speed benefits, is for security reasons not a viable solution for some library users."


Users [pointed out](https://github.com/serde-rs/serde/issues/2538#issuecomment-1684708897) how the change could impact entities that are "legally not allowed to redistribute pre-compiled binaries, by their own licenses," specifically mentioning government-regulated environments.


"...First .NET's Moq and now this," said Jordan Singh, an Australia-based developer, in a [comment](https://archive.is/Aqxco#issuecomment-1684657021-permalink) that was later removed.


"If this is to force cargo devs to support a feature then this is terrible way around doing it. At-least give us reproducible binaries. I'm sick of devs of popular crates/libraries taking everyone hostage with absurd decisions."


Philadelphia-based Donald Stufft [cautioned against](https://twitter.com/dstufft/status/1692705666593357909) the risks of getting into the business of "shipping binaries" on social media:



![Developer cautions against the move](https://www.bleepstatic.com/images/news/u/1164866/2023/Aug/rust-serde/tweet1.jpg)**Developer cautions against the "shipping binaries" business**


Rust programmer Nathan West, who goes by *Lucretiel*, specifically [highlighted](https://twitter.com/Lucretiel/status/1692760873243160740) the supply-chain risks posed by precompiled binaries, should the maintainer account get compromised: 



![supply chain risk](https://www.bleepstatic.com/images/news/u/1164866/2023/Aug/rust-serde/tweet2.jpg)**Supply chain risks associated with shipping precompiled binaries**


"Is not this the exact way they'd go about it? Ship it silently as a semi-plausible change to how *serde* works, intransigently ignore all criticism of the decision," wrote West.


"This is \*exactly\* the reason that everyone has such a reflexive opposition to moves like this."


"Trust on the internet isn't perfect; we \*don't\* know that that's really [the maintainer] posting in GitHub. That's why we have layers and proxies of defense; sketchy sh\*t is rejected because it's not worth the risk.


Technologist Sanket Kanjalkar called the transition to ship binaries without a way of opting-out "[a step backward](https://twitter.com/sanket1729/status/1692698203572109355)."


But, a security professional who goes by Lander, has [a slightly different take](https://twitter.com/landaire/status/1692688116925305176):


"This Rust drama about *serde\_derive* shipping a precompiled binary is kind of funny," writes Lander.


"On one hand, I understand people's concern. On the other hand, who cares? nobody's reading proc macro *code/build.rs* code for every project they pull in anyways. An opt-out would be a good idea tho."


Whether you agree with the project's decision to serve its macros precompiled or not, it is a good practice to routinely inspect any source code and software binaries prior to incorporating these into your projects.


*Thanks to [Michael Kearns](https://www.linkedin.com/in/mobiuscog/) for the tip off.*





## Tags:


### Autogenerated tags:
serde_derive serde tolnay moq
