# The arrival of genAI could cover critical skills gaps, reshape IT job market
## Facing a tech talent shortage, many corporate leaders see generative AI applications such as ChatGPT as one way to fill the gap by taking on tasks normally handled by workers.
## Information:

+ Link: https://www.computerworld.com/article/3711462/four-in-10-c-level-execs-eye-genai-to-cover-critical-skills-gaps.html
+ Source: Computerworld
+ Author: Lucas Mearian
+ Date published: 04 December 2023, 03:00
+ Date scraped: 05 December 2023, 19:02

## Article:
![Main article image](https://images.idgesg.net/images/article/2023/11/shutterstock_2229125163-1-100948803-large.jpg?auto=webp&quality=85,70)


Generative artificial intelligence (genAI) is likely to play a critical role in addressing skills shortages in today’s marketplace, according to a [new study by London-based Kaspersky Research](chrome-extension://efaidnbmnnnibpcajpcglclefindmkaj/https:/media.kasperskydaily.com/wp-content/uploads/sites/86/2023/10/25123633/Report-ENG-Gen-AI-Business-Infiltration-Oct-2023-v2.2.pdf). It showed that 40% of 2,000 C-level executives surveyed plan to use genAI tools such as ChatGPT to cover critical skills shortages through the automation of tasks.

The European-based study found genAI to be firmly on the business agenda, with 95% of respondents regularly discussing ways to maximize value from the technology at the most senior level, even as 91% admitted they don’t really know how it works.

"If there's a desire to delegate critical activities and functions to genAI, it is essential that senior management first develops a deeper understanding of the data management processes, including what data can and cannot be used to train these systems,” said David Emm, Kaspersky’s principal security researcher.

GenAI offers a much lower barrier than finding new workers, which is attractive to senior bosses looking to solve critical business challenges, Kaspersky’s study revealed.

More than a quarter of those surveyed, however, called genAI a fad, comparing it to Meta’s [recently launched Threads app](https://www.npr.org/2023/07/05/1186149939/meta-launches-its-rival-app-threads-as-it-takes-aim-at-twitter) — an upstart competitor to X/Twitter. “These leaders stated that they believe Gen AI to be just another fad [that] challenges for dominance quickly and then dies off just as fast,” the Kaspersky study said.

Even so, 49% of those surveyed believe employees are already automating everyday tasks such as generating email content.

While genAI offers the promise of clear business benefits, education is key and collaboration with cybersecurity and risk experts is needed to help establish an environment where the technology can be used safely, securely, and productively, according to Emm.

Hurdles to adopting AI persist. Those issues include high costs, uncertain return on investment (ROI), the need to upskill entire staffs, and potential exposure of sensitive corporate data to unfamiliar automation technology.

Few organizations, however, have put appropriate safeguards in place to guard against some of genAI's most well-known flaws, such as hallucinations, exposure of corporate data, and data errors. Most are leaving themselves wide open to the acknowledged risks of using genAI, according to Kaspersky. For example, only 22% of C-level executives have discussed putting rules in place to regulate the use of genAI in their organizations — even as they eye it as a way of closing the skills gap.

Cisco CIO Fletcher Previn, whose team is working to embed AI in back-end systems and products, said it's critical to have the policies, security, and legal guardrails in place to be able to "safely adopt and embrace AI capabilities other vendors are rolling out into other people’s tools.

"You can imagine all the SaaS vendors…, everybody’s on this journey," Previn said in a recent interview. "But are we set up to take advantage of this journey in a way that’s compatible with our responsible AI policies?”

The Kaspersky findings indicate that, despite concerns around the use of sensitive proprietary information used to power Gen AI tools, half of the executives surveyed plan to automate mundane worker tasks, with a further 44% planning to integrate it into their own routines to expedite administrative chores.

Beyond skills, will genAI replace workers?
------------------------------------------

GenAI will influence 4.5 times more jobs than it replaces, according to Forrester Research’s 2023 Generative AI Jobs Impact Forecast. The technology will also make up nearly 30% of the jobs that arelost to automation by 2030.

“In terms of the number of jobs, we forecast that generative AI will replace 90,000 jobs in 2023, growing to 2.4 million by 2030,” the study said.

While 2.4 million jobs replaced by genAI sounds high, Forrester notes that automation and AI overall will replace just 4.9% of US jobs by 2030. And job losses over the next two years will remain modest until questions about intellectual property rights, copyright issues, plagiarism, model refresh rates, model bias, ethics, and model response reliability are resolved, the research firm said.

“We forecasted the future impacts of generative AI and found significant influence — that is, generative AI will reshape how many jobs operate and how work gets done. But job losses will be lower than many expect, and influence will far outweigh job cannibalization,” a Forrester spokesman said.

That doesn't mean workers arent paying attention.  According to Forrester, 36% of global workers employed full or part time fear losing their jobs to automation in the next 10 years.

“We’ve been tracking how AI affects jobs for nearly a decade, analyzing the impact that AI and automation have on the future of jobs. But generative AI has spurred a brand-new round of urgent conversation around this issue,” Forrester said.

The researcher cited hyped predictions by some researchers of massive job disruption from the arrival of genAI tools. Goldman Sachs, for example, [published a study earlier this year](https://www.goldmansachs.com/intelligence/pages/generative-ai-could-raise-global-gdp-by-7-percent.html) stating, “shifts in workflows triggered by [generative AI] could expose the equivalent of 300 million full-time jobs to automation.”

[![forrester jobs affected by ai graphic](https://images.idgesg.net/images/article/2023/11/forrester-jobs-affected-by-ai-graphic-100948802-large.jpg?auto=webp&quality=85,70)](https://images.idgesg.net/images/article/2023/11/forrester-jobs-affected-by-ai-graphic-100948802-orig.jpg?auto=webp&quality=85,70) 

Not surprisingly, the number of jobs postings that include “genAI” terms or skills has skyrocketed over the past year, meaning workplaces are hungry for employees with specific skills. At the beginning of 2023, just 0.003% of job postings mentioned terms related to generative AI. That grew to 0.06% by the end of October, a 20-fold increase, according to Indeed.

“We’ll have to wait to see the long-term effects of genAI, but it’s clear right now that jobs related to the field are surging. Of course, only 6 in 10,000 job postings means Generative AI jobs aren’t very common, even if they are growing rapidly,” Indeed’s report said.

![genai skills](https://images.idgesg.net/images/article/2023/11/genai-skills-100948805-large.jpg?auto=webp&quality=85,70) 

The job market can shift quickly, and has done in the past. For example, up to 60% of today’s workers are employed in occupations that didn’t exist in 1940, according to [a study by economist David Autor](http://www.computerworld.com/cms/article/360965560_The_Labor_Market_Impacts_of_Technological_Change_From_Unbridled_Enthusiasm_to_Qualified_Optimism_to_Vast_Uncertainty).

“This implies that more than 85% of employment growth over the last 80 years is explained by the technology-driven creation of new positions,” Goldman Sach said. “Added up, Goldman Sachs’ research estimates the total addressable market for generative AI software to be $150 billion, compared with $685 billion for the global software industry."

AI is already being used to help developers and engineers create all forms of software.

Cisco's Previn said one of the roles he never expected AI to touch was that of  software developer, which he equates to an art form requiring unique creative abilities. ChatGPT, however, has been adept at creating code that addresses corporate data hygiene and security and it can reuse code to build new apps.

A [study by Microsoft](https://github.blog/2022-09-07-research-quantifying-github-copilots-impact-on-developer-productivity-and-happiness/) showed that the GitHub Copilot tool, powered by ChatGPT, can help developers code up to 55% faster — and more than half of all code being checked into GitHub now was aided by AI in its development. That number is expected to jump to [80% of all code checked into GitHub](https://www.freethink.com/robots-ai/github-copilot) within the next five years, according to GitHub CEO Thomas Dohmke.

[![indeed software developer by ai](https://images.idgesg.net/images/article/2023/11/indeed-software-developer-by-ai-100948806-large.jpg?auto=webp&quality=85,70)](https://images.idgesg.net/images/article/2023/11/indeed-software-developer-by-ai-100948806-orig.jpg?auto=webp&quality=85,70) 

“That’s very interesting, because historically there was no way to compress software development timelines,” Previn said in an earlier interview. “Now, it turns out you can get a significant acceleration in velocity by helping developers with things like Copilot for code readings, code hygiene, security, commenting; it’s really good at those things.”

GenAI’s ability to develop or engineer software also changed Cisco’s internal IT system and external product strategy. Since last November, the company's IT department has developed a more “fully formed strategy” in terms of AI as a foundational infrastructure.

Internally, that means using AI to find productivity enhancements, including areas such as automated help desk functions. Externally, Cisco now thinks in terms of how to “bake AI into every product portfolio and augment the entire digital estate we’re managing in digital IT.





## Tags:


### Autogenerated tags:
genai kaspersky forrester previn github chatgpt goldman
