# Bitcoin Forensic Analysis Uncovers Money Laundering Clusters and Criminal Proceeds
## How does blockchain pseudonymity enable financial crime detection? By combining it with knowledge of licit and illicit crypto services, machine learni
## Information:

+ Link: https://thehackernews.com/2024/05/bitcoin-forensic-analysis-uncovers.html
+ Source: The Hacker News
+ Author: The Hacker News
+ Date published: 01 May 2024, 19:55
+ Date scraped: 01 May 2024, 15:09

## Article:
![Main article image](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEgWxADP1ARMwS8u094E6BhMuF0vfvJd_rCbLY9gLSSFCbJ7_CpY3f8AajraT87gINijNm-hDFZj2QmsoGRJz26OfmnR40y3O-_bddmNLQIh45SmYcR6jlt4rzqaC9Y3WjWMUOgG1zIMHrChvpNx0fqY_PnhvBveqdj_78NRzwRolWl6WZhrNa8eOFuXwZkB/s728-rw-e365/blockchain.png)


A forensic analysis of a graph dataset containing transactions on the Bitcoin blockchain has revealed clusters associated with illicit activity and money laundering, including detecting criminal proceeds sent to a crypto exchange and previously unknown wallets belonging to a Russian darknet market.


The [findings](https://www.elliptic.co/blog/our-new-research-enhancing-blockchain-analytics-through-ai) come from Elliptic in collaboration with researchers from the MIT-IBM Watson AI Lab.


The 26 GB dataset, dubbed **[Elliptic2](https://www.kaggle.com/datasets/ellipticco/elliptic2-data-set)**, is a "large graph dataset containing 122K labeled subgraphs of Bitcoin clusters within a background graph consisting of 49M node clusters and 196M edge transactions," the co-authors [said](https://arxiv.org/abs/2404.19109) in a paper shared with The Hacker News.


Elliptic2 builds on the [Elliptic Data Set](https://www.kaggle.com/datasets/ellipticco/elliptic-data-set) (aka Elliptic1), a transaction graph that was made public in July 2019 with the goal of [combating financial crime](https://arxiv.org/abs/1908.02591) using graph convolutional neural networks ([GCNs](https://distill.pub/2021/gnn-intro/)).


[![Cybersecurity](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEiuUUskkMH9dUT3LF77_Q_irGuaE4LGjp-Am2Ls_UzGJ5EBnZHfuFiSvKs4OPE5KmfedBHcuZZVHS4Bh48UJx8brpwtg6Vr2Gepbaw-lGMIm9HjUhyphenhyphen2W5DVm5-ymwPS691Ie32TrCqFIv6SxNRA-jOKCKZrOB5dV7BfL0zVAhOO0neNkP9yv-XePBU1hN_0/s728-e365/wing-d.png)](https://thehackernews.uk/third-party-risk-management-saas)
The idea, in a nutshell, is to uncover illicit activity and money laundering patterns by taking advantage of [blockchain's pseudonymity](https://www.certik.com/resources/blog/what-is-pseudonymity-and-anonymity) and combining it with knowledge about the presence of licit (e.g., exchange, wallet provider, miner, etc.) and illicit services (e.g., darknet market, malware, terrorist organizations, Ponzi scheme, etc.) on the network.


"Using machine learning at the subgraph level – i.e., the groups of transactions that make up instances of money laundering – can be effective at predicting whether crypto transactions constitute proceeds of crime," Tom Robinson, chief scientist and co-founder of Elliptic, told The Hacker News.


"This is different to conventional crypto AML solutions, which rely on tracing funds from known illicit wallets, or pattern-matching with known money laundering practices."


The study, which experimented with three different subgraph classification methods on Elliptic2, such as [GNN-Seg](https://towardsdatascience.com/graph-convolutional-networks-introduction-to-gnns-24b3f60d6c95), [Sub2Vec](https://arxiv.org/abs/1702.06921), and [GLASS](https://openreview.net/forum?id=XLxhEjKNbXj), identified subgraphs that represented crypto exchange accounts potentially engaged in illegitimate activity.


Furthermore, it has made it possible to trace back the source of funds associated with suspicious subgraphs to various entities, including a cryptocurrency mixer, a Panama-based Ponzi scheme, and an invite-only Russian dark web forum.


Robinson said just considering the "shape" – the local structures within a complex network – of the money laundering subgraphs proved to be an already effective way to flag criminal activity.


[![Cybersecurity](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEg_WRs2jRYPNRPdVnIJ52g0Zo3TY_c0FSwk8ZZN085hqm-nXig4b7WIZCpqdHexadU4EmZ402vX1EghcAxIZGa9lwLkWAPPYzPbg1gc5UZCbvTtOHQ3ozwiQAgJ1ahKFoOp8SZl-JN8_URGwiu9aTe5U2wiVHGEetM-S7kKkmgPMNdL_83d5HTJrLm7iBp6/s728-e365/cis-d.png)](https://thehackernews.uk/cis-hardened-images)
Further examination of the subgraphs predicted using the trained GLASS model has also identified known cryptocurrency laundering patterns, such as the presence of peeling chains and nested services.


"A peeling chain is where a small amount of cryptocurrency is 'peeled' to a destination address, while the remainder is sent to another address under the user's control," Robinson explained. "This happens repeatedly to form a peeling chain. The pattern can have legitimate financial privacy purposes, but it can also be indicative of money laundering, especially where the 'peeled' cryptocurrency is repeatedly sent to an exchange service."


"This is a known crypto laundering technique and has an analogy in 'smurfing' within traditional finance – so the fact that our machine learning mode independently identified it is encouraging."


As for the next steps, the research is expected to focus on increasing the accuracy and precision of these techniques, as well as extending the work to further blockchains, Robinson added.


  





## Tags:


### Autogenerated tags:
elliptic2
