# From Alert to Action: How to Speed Up Your SOC Investigations
## Alert overload is a critical challenge for SOC professionals. Learn how threat intelligence platforms can streamline investigations and bolster cybers
## Information:

+ Link: https://thehackernews.com/2024/02/from-alert-to-action-how-to-speed-up.html
+ Source: The Hacker News
+ Author: The Hacker News
+ Date published: 27 February 2024, 16:18
+ Date scraped: 27 February 2024, 12:05

## Article:
![Main article image](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEhhJM7Gec6IXUK4p3A9bTgm6ZfoIqrLR97WiJSp4KQBilm95m-JjPye4fjzaraPUN4hLfOSRFBAPsl9puDUqEPAyjaYhu87D_yFeE52oMXQ3aE16kOEijYIjWpcFQ0-a7kQU_c8khC4JAAlwfEyTrbnffSZ19QL5t5uhuQ-sduwBlRXyPtLsoYnFreUfRg/s728-rw-e365/anyrun.jpg)


Processing alerts quickly and efficiently is the cornerstone of a Security Operations Center (SOC) professional's role. Threat intelligence platforms can significantly enhance their ability to do so. Let's find out what these platforms are and how they can empower analysts.


The Challenge: Alert Overload[#](#the-challenge-alert-overload)
---------------------------------------------------------------


The modern SOC faces a relentless barrage of security alerts generated by SIEMs and EDRs. Sifting through these alerts is both time-consuming and resource-intensive. Analyzing a potential threat often requires searching across multiple sources before finding conclusive evidence to verify if it poses a real risk. This process is further hampered by the frustration of spending valuable time researching artifacts that ultimately turn out to be false positives.


As a result, a significant portion of these events remain uninvestigated. This highlights a critical challenge: finding necessary information related to different indicators quickly and accurately. Threat data platforms offer a solution. These platforms enable you to look up any suspicious URL, IP, or other indicator and receive immediate insights into its potential risk. One such platform is Threat Intelligence Lookup from ANY.RUN.


Threat Intelligence Platforms to the Rescue[#](#threat-intelligence-platforms-to-the-rescue)
--------------------------------------------------------------------------------------------


Specialized platforms for SOC investigations leverage their databases of threat data, aggregated from diverse sources. Take, for example, ANY.RUN's Threat Intelligence Lookup (TI Lookup). This platform collects Indicators of Compromise (IOCs) from millions of interactive analysis sessions (tasks) conducted within the ANY.RUN sandbox.


The platform offers an additional dimension of threat data: logs of processes, registry and network activity, command line contents, and other system information generated during sandbox analysis sessions. Users can then search for relevant details across these fields.


Threat Intelligence Platforms Benefits[#](#threat-intelligence-platforms-benefits)
----------------------------------------------------------------------------------



### Deeper Visibility into Threats[#](#deeper-visibility-into-threats)


Instead of relying on scattered data sources, such platforms offer a single point of access to search for IOCs across various data points. This includes URLs, file hashes, IP addresses, logged events, command lines, and registries, allowing for more comprehensive threat identification and investigation.


### Faster Alert Investigations[#](#faster-alert-investigations)


When a security incident occurs, time is of the essence. TI platforms help gather relevant threat intelligence data rapidly, enabling a deeper understanding of the attack's nature, affected systems, and compromise scope. This can significantly speed up and improve response efforts.


### Proactive Threat Hunting[#](#proactive-threat-hunting)


Threat intelligence platforms empower teams to actively hunt for known IOCs associated with specific malware families. This proactive approach can help uncover hidden threats before they escalate into major incidents.


They can provide access to data that might reveal potential vulnerabilities associated with known threats. This information can inform risk assessments and help organizations prioritize security efforts based on the most pressing dangers.


### Threat Analysis and Decision-Making[#](#threat-analysis-and-decisionmaking)


Armed with detailed insights into malware behavior, teams can more accurately analyze threats and make informed decisions about containment, remediation, and future preventative measures. This continuous learning cycle strengthens the overall security posture and team competency.


Threat Intelligence Platform Query Examples[#](#threat-intelligence-platform-query-examples)
--------------------------------------------------------------------------------------------



### Searching with Individual Indicators[#](#searching-with-individual-indicators)


[![Threat Intelligence](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEiBdOo_-LeFkq3zXqCi6BRdqyyVad1xaI5eri5UhVQkqetz9TRk4Upik8uiY2jreuuUBrTTRTi7ElSDWk9zcpO_3plmm4YZL81F1aiSCW3nKYID-yTRUYwyCZ2rqZA_niGGRibaZo34tggLSPhW1WPH-6I3lSNECuX5ZAhk6rsaX_2I-NBBbBudFgVklKs/s728-rw-e365/1.png)](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEiBdOo_-LeFkq3zXqCi6BRdqyyVad1xaI5eri5UhVQkqetz9TRk4Upik8uiY2jreuuUBrTTRTi7ElSDWk9zcpO_3plmm4YZL81F1aiSCW3nKYID-yTRUYwyCZ2rqZA_niGGRibaZo34tggLSPhW1WPH-6I3lSNECuX5ZAhk6rsaX_2I-NBBbBudFgVklKs/s728-rw-e365/1.png)
Imagine you suspect a compromised system within your network is downloading malicious files. You pinpoint a specific IP address as the potential source and decide to investigate further. Enter the IP address into the search bar of a threat intelligence platform. Instantly, the platform flags the address as malicious and linked to the Remcos malware, offering info on domains, ports, and even files associated with this IP.


It also provides access to analysis sessions where this IP address was involved and lists Tactics, Techniques, & Procedures (TTPs) employed by malware in these sessions.


[![Threat Intelligence](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEg-fLGF1ubqio_Q8gkkZpK4alE9dedV1UWdTmCar6r2mMouZMS68vb5C4qAvf7X3wynQzp9hoHAXOQjO_nkjf3xFBn2ynE4ljQbat3ru88ugtfsrhn4Pkd11BWal6NvP3g0j6skZxgpqDEBmmC__jTMbAubYDXzrwTvYBc6jYKCrXNk_f7HTAZQbqlAP6g/s728-rw-e365/2.png)](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEg-fLGF1ubqio_Q8gkkZpK4alE9dedV1UWdTmCar6r2mMouZMS68vb5C4qAvf7X3wynQzp9hoHAXOQjO_nkjf3xFBn2ynE4ljQbat3ru88ugtfsrhn4Pkd11BWal6NvP3g0j6skZxgpqDEBmmC__jTMbAubYDXzrwTvYBc6jYKCrXNk_f7HTAZQbqlAP6g/s728-rw-e365/2.png)
You can study every session in detail by simply clicking on it. The system will take you to the session's page in the ANY.RUN sandbox, where you will be able to explore all the processes, connections, and registry activity, as well as collect the malware's config and IOCs or download a comprehensive threat report.


### Flexible Search with Wildcards[#](#flexible-search-with-wildcards)


Another useful feature of threat intelligence platforms like TI Lookup is the ability to submit wildcards and combined queries.


[![Threat Intelligence](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEhH5yDPxzzly7meM7ap8zZBd8n6cTPxwD7foVBGoyRudfIjfmqBIjH4RRvC2_MzoantJRYQMOHduijqsMYNgP3vq6Pgfiwi04pRxa1y_qrOwQchYoPBUop_E79IDAAAkq5jQWtbWxGRfdswNER_OMrKcPxk8h79soeXM1PS7uvLTGq9lZy0laSUdTAEGkQ/s728-rw-e365/3.png)](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEhH5yDPxzzly7meM7ap8zZBd8n6cTPxwD7foVBGoyRudfIjfmqBIjH4RRvC2_MzoantJRYQMOHduijqsMYNgP3vq6Pgfiwi04pRxa1y_qrOwQchYoPBUop_E79IDAAAkq5jQWtbWxGRfdswNER_OMrKcPxk8h79soeXM1PS7uvLTGq9lZy0laSUdTAEGkQ/s728-rw-e365/3.png)
For instance, the query "binPath=\*start= auto" uses the asterisk wildcard and searches for any command line with "binPath=" followed by any characters that end with "start= auto".


The platform returns a hundred sessions where the same fragment appeared. A closer examination of the search results indicates that this specific command line artifact is characteristic of the Tofsee malware.


### Combined Search Requests[#](#combined-search-requests)


Another option for conducting an investigation is to pool together all available indicators and submit them to the threat intelligence platform to identify all instances where these criteria appear collectively.


[![Threat Intelligence](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEhnlAwKlNbR8luIVywVFVrxMMoCMFl4OHMZDkbyYmMzTAI2GeOBr21CtfwBnlrHSQtz9rJodFPHcUemFtvQynZ-GnL9qMu6K6UwDISJgRWgdxX2AozkpzJxah4AF50ug4pSEXSd-Kf7YVt5B_wfdHmX5zJabvJ6fzK1tkjgs0qvtLpz6wGVyQ2e9XsBeS0/s728-rw-e365/4.png)](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEhnlAwKlNbR8luIVywVFVrxMMoCMFl4OHMZDkbyYmMzTAI2GeOBr21CtfwBnlrHSQtz9rJodFPHcUemFtvQynZ-GnL9qMu6K6UwDISJgRWgdxX2AozkpzJxah4AF50ug4pSEXSd-Kf7YVt5B_wfdHmX5zJabvJ6fzK1tkjgs0qvtLpz6wGVyQ2e9XsBeS0/s728-rw-e365/4.png)
For example, you can construct a query that searches for all tasks (sessions) categorized as "file," run on Windows 7, with a 64-bit operating system, connecting to port 50500 and containing the string "schtasks" in the command line.


The platform then identifies numerous sessions that meet the specified criteria and additionally provides a list of IPs tagged with "RisePro," highlighting the malware responsible.


Try Threat Intelligence Lookup[#](#try-threat-intelligence-lookup)
------------------------------------------------------------------


Threat Intelligence Lookup from ANY.RUN lets you investigate threats with precision. Analyze processes, files, network activity, and more. Refine your search with 30+ fields, including IPs, domains, logged events, and MITRE techniques. Combine parameters for holistic understanding. Use wildcard queries to expand your reach.


[Request a trial](https://intelligence.any.run/plans?TI_promo&utm_source=thehackernews&utm_medium=article&utm_campaign=ti&utm_content=ti_promo&utm_term=27022024) to receive 50 free requests to explore the platform. 


  





## Tags:


### Autogenerated tags:
malware ip any.run
