# How to Automate the Hardest Parts of Employee Offboarding
## Eliminate 90% of the time and effort in finding and offboarding cloud and SaaS accounts. Say goodbye to IT offboarding headaches.
## Information:

+ Link: https://thehackernews.com/2023/11/how-to-automate-hardest-parts-of.html
+ Source: The Hacker News
+ Author: The Hacker News
+ Date published: 16 November 2023, 16:48
+ Date scraped: 16 November 2023, 12:01

## Article:
![Main article image](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEgRvu6tO1L8Grcxs6kzmHhbzYgi1WClM2WQRoNyrNSIL8nggtk0BlYUEuCJeOk9s3r-hSdKCRRKG9V2u4b0UgMaOTxaGH5mzpCJffseGzkh-q_JYMaob7ah1pW45jx6wZZ0suNEUs5gaVItQh0kMO4fSV7Rnkd_siC881DkHr3ySmvlvMgbF-dAru6qfPE/s728-rw-ft-e30/nudge.jpg)


According to recent research on [employee offboarding](https://www.nudgesecurity.com/post/employee-offboarding-by-the-numbers), 70% of IT professionals say they've experienced the negative effects of incomplete IT offboarding, whether in the form of a security incident tied to an account that wasn't deprovisioned, a surprise bill for resources that aren't in use anymore, or a missed handoff of a critical resource or account. This is despite an average of five hours spent per departing employee on activities like finding and deprovisioning SaaS accounts. As the SaaS footprint within most organizations continues to expand, it is becoming exponentially more difficult (and time-consuming) to ensure all access is deprovisioned or transferred when an employee leaves the organization. 


**How Nudge Security can help**[#](#how-nudge-security-can-help)
----------------------------------------------------------------


Nudge Security is a [SaaS management platform](https://www.nudgesecurity.com/product) for modern IT governance and security. It discovers every cloud and SaaS account ever created by anyone in your organization, including generative AI apps, giving you a single source of truth for departing users' accounts and OAuth grants that need to be deprovisioned, revoked, or transferred. 


And, a built-in playbook walks you through a comprehensive checklist for [IT offboarding](https://www.nudgesecurity.com/use-cases/employee-offboarding) in alignment with Google and Microsoft best practices. The playbook can help you save up to 90 percent of the time and effort involved in SaaS offboarding by automating time-consuming, easy-to-miss tasks like revoking OAuth grants and resetting passwords for accounts outside of single sign-on (SSO). 



‍Let's take a look at how Nudge Security helps you with each step so you can ensure complete offboarding of SaaS accounts.


### **1. Revoke access to Google Workspace or Microsoft 365**[#](#1-revoke-access-to-google-workspace-or-microsoft-365)



Once you've selected the employee you need to offboard, the first step is to verify the status of their Google or Microsoft account.


Initially, you'll want the employee's Google or Microsoft account to remain active while you complete other offboarding tasks. However, you'll want to make sure the user can no longer access the account by resetting their password and disabling any recovery methods they may have set up. Nudge Security helps you verify the status of each of these steps so you can ensure that access has been revoked.


[![](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEgmCs3Fl0vrtomkp0tpX9naK08EBTGr-9Q8QsZX6nQBaxVvIiEPBGxEpXh3WMP-z98DIX3bQIPGYCr77pmezl1YNSQ4_-9vz2eEA-O2KmpFhLeJ8323OL-4H4xjAU_tJ134FZ23h3n1rn_59IHIuXAzqtB5Tobf1rsBG-sPvgq1MDxeZwQMHi4QFcQLOi4/s728-rw-ft-e30/1.png)](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEgmCs3Fl0vrtomkp0tpX9naK08EBTGr-9Q8QsZX6nQBaxVvIiEPBGxEpXh3WMP-z98DIX3bQIPGYCr77pmezl1YNSQ4_-9vz2eEA-O2KmpFhLeJ8323OL-4H4xjAU_tJ134FZ23h3n1rn_59IHIuXAzqtB5Tobf1rsBG-sPvgq1MDxeZwQMHi4QFcQLOi4/s728-rw-ft-e30/1.png)
### **2. Transfer ownership of critical resources.** [#](#2-transfer-ownership-of-critical-resources)



Before you begin deprovisioning your departing employee's accounts, you'll want to identify and transition ownership of essential resources like AWS root user accounts, corporate domains, social media accounts and more.


Nudge Security automatically identifies critical resources owned by your departing employee and guides you through how to transfer ownership to other team members. For each resource, Nudge Security provides detailed instructions with helpful links and a summary of other app users who could take over responsibility for each resource. As you go through the list, you can confirm that you have transferred ownership or log your decision to ignore a particular resource that doesn't need to be transferred.


[![](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEhaHYI5-G2n9__mt_DtcYk-PIGp7uETirpCx-8oqzLdwCCoHfa6f7qCCVdwO5JYxIYTV8imxV6eXRR3bfU0fynekDSBib-wZNrL2uD1Z00r8lT_3mgQYfQYD9XzPsqIqRDdNsRaOCLMeIUccM82Px6Vgx_9v9YnCz3VrbbjwQLsgpfcHDs2587_FD2Dw0c/s728-rw-ft-e30/2.png)](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEhaHYI5-G2n9__mt_DtcYk-PIGp7uETirpCx-8oqzLdwCCoHfa6f7qCCVdwO5JYxIYTV8imxV6eXRR3bfU0fynekDSBib-wZNrL2uD1Z00r8lT_3mgQYfQYD9XzPsqIqRDdNsRaOCLMeIUccM82Px6Vgx_9v9YnCz3VrbbjwQLsgpfcHDs2587_FD2Dw0c/s728-rw-ft-e30/2.png)
### **3. Review and update app-to-app integrations.** [#](#3-review-and-update-apptoapp-integrations)



OAuth grants are often used to enable app-to-app integrations and automation so if a departing employee's OAuth grants are revoked without review, this could disrupt day-to-day operations.


Nudge Security shows you all app-to-app OAuth grants and scopes for the departing employee so you can assess the potential business impact of each integration and determine if it should be recreated with another account. You'll also see who the other users of that application are so you can engage them as needed. This step of the offboarding process will help ensure that automated business processes continue to work as expected after the employee leaves the organization.


[![](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEgCXlDF00jG8czCarJZcjJ_WSX_kVuNmIxz2XDG3hz13fd7TkbMEPi2UFMnhYYQrqbC38HwMMyf7c3x8w6m_Qtebfp2LhS8kq3XN0tkGHqLJgsO5n9eET8iPvkLwIRQirp61jgiLjffe8z6uNjV8cKPmKizBAdFfNAv2w76b0j4gSAFtnZaCCQ1bY15kSM/s728-rw-ft-e30/3.png)](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEgCXlDF00jG8czCarJZcjJ_WSX_kVuNmIxz2XDG3hz13fd7TkbMEPi2UFMnhYYQrqbC38HwMMyf7c3x8w6m_Qtebfp2LhS8kq3XN0tkGHqLJgsO5n9eET8iPvkLwIRQirp61jgiLjffe8z6uNjV8cKPmKizBAdFfNAv2w76b0j4gSAFtnZaCCQ1bY15kSM/s728-rw-ft-e30/3.png)
### **4. Revoke SSO-managed accounts.**[#](#4-revoke-ssomanaged-accounts)



This step is easy. With the click of a button (and without leaving the Nudge Security dashboard), you can revoke access to all of the accounts managed by your single sign-on (SSO) provider, like Azure AD or Okta. Later on, the playbook will also walk you through cleaning up the contents of those accounts.


[![](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEhPXUNCFSO-Cfff1QDYiErIZUBhV-ppHbstmaUHNOm3FeCiZl2xXfunKdcTPWQNZegZQSqH1vFar7TvB7mkwJN-LKlvJQ8tXaVuefepPFKP6foY-vvflsycBXkiG9J8F0H81GquP9IHwx9oVJe4Xedr7Xy2UNvrDCu1yWNwFPWbMP8HyKNhSZOgQrVG-QU/s728-rw-ft-e30/4.png)](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEhPXUNCFSO-Cfff1QDYiErIZUBhV-ppHbstmaUHNOm3FeCiZl2xXfunKdcTPWQNZegZQSqH1vFar7TvB7mkwJN-LKlvJQ8tXaVuefepPFKP6foY-vvflsycBXkiG9J8F0H81GquP9IHwx9oVJe4Xedr7Xy2UNvrDCu1yWNwFPWbMP8HyKNhSZOgQrVG-QU/s728-rw-ft-e30/4.png)
### **5. Revoke access to apps authenticated via OAuth.**[#](#5-revoke-access-to-apps-authenticated-via-oauth)



OAuth grants make it easy for employees to create new accounts simply by choosing the option to authenticate with Google Workspace or Microsoft 365. Nudge Security makes it just as easy for security and IT teams to identify and revoke departing users' OAuth grants directly from Nudge Security. Now that you've already reviewed and recreated any scopes related to app-to-app integrations, you can revoke the remaining app access granted via OAuth.


[![](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEj1_Zstz4gBC4sy-3Jb2_jPC3QPtIwbQp1W_XPP7E4hvhDb8CJ8HuX9z1BHVIU8eKODApfJBhJLh52qTRvyiD-daGUDxkac4Vy62j0xljnD4mYYWrNOfhjsHeQMlLqGTlzi6veGOCmmg1pIAgxEtWaBLWqOHZgXiVG4klgtWVuaiXYO_w5AulOYa3a155c/s728-rw-ft-e30/5.png)](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEj1_Zstz4gBC4sy-3Jb2_jPC3QPtIwbQp1W_XPP7E4hvhDb8CJ8HuX9z1BHVIU8eKODApfJBhJLh52qTRvyiD-daGUDxkac4Vy62j0xljnD4mYYWrNOfhjsHeQMlLqGTlzi6veGOCmmg1pIAgxEtWaBLWqOHZgXiVG4klgtWVuaiXYO_w5AulOYa3a155c/s728-rw-ft-e30/5.png)
### **6‍. Revoke access to unmanaged accounts.**[#](#6-revoke-access-to-unmanaged-accounts)



OAuth grants and SSO-managed accounts only provide a partial view of your departing employee's access. Lingering [SaaS sprawl](https://www.nudgesecurity.com/use-cases/curb-saas-sprawl) can leave doors open for illegitimate access to sensitive resources and data after an employee leaves your organization. Luckily, Nudge Security also inventories unmanaged accounts that your employee may have created with their work email outside of standard IT or procurement processes.


Not only will Nudge Security show you the list of unmanaged apps, but you can trigger automated password resets from within the platform to prevent further access by the departing employee. Without this automation, it could take hours to do this manually, if you even know the accounts exist in the first place.


[![](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEg2MyEJCHVkaLAaykiOELUH9wOSFRBJsM5ufhOSif7dYIMgCw0IlV-BY5u0qL2Ip9qfkedmhDc3IFP_bLxxPTU5NACiLGCWoBRC_TKfLMEjRzIIdLfuWuF6H4SDj0I52kH9s4H9lHaalhy3Gzq-KS0IfwigpSw22OR7WlAZzfNFbPl26gijuiENSyVlVAs/s728-rw-ft-e30/6.png)](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEg2MyEJCHVkaLAaykiOELUH9wOSFRBJsM5ufhOSif7dYIMgCw0IlV-BY5u0qL2Ip9qfkedmhDc3IFP_bLxxPTU5NACiLGCWoBRC_TKfLMEjRzIIdLfuWuF6H4SDj0I52kH9s4H9lHaalhy3Gzq-KS0IfwigpSw22OR7WlAZzfNFbPl26gijuiENSyVlVAs/s728-rw-ft-e30/6.png)
### ‍**7. Clean up revoked accounts.**[#](#7-clean-up-revoked-accounts)



Once the user's access has been revoked, it's important to clean up their accounts to avoid orphaning corporate data or continuing to pay for unused licenses.


Nudge Security enables you to send an automated "nudge" to the technical or business owner for each SaaS application with instructions to delete or move sensitive data, reallocate licenses, and reassign ownership of resources to another user.


[![](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEhg5m2fuLmC3ZIQwj6_CGuM7VnicyJsASVwoL0HVCnHiuNIFLCGCMcguSaki_Nz_bPRMeEVJAlpTyDiV2FoBt24HvjME3Q72AUfZRd59CMbuM2eMSBB4wv7mhyphenhyphenDdgR06u3t-xd91U9-b_2U5SaPHN07p_cu-zTmSTro2xd4nKYUVD-OrV-CUbfP7BKOTgQ/s728-rw-ft-e30/7.png)](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEhg5m2fuLmC3ZIQwj6_CGuM7VnicyJsASVwoL0HVCnHiuNIFLCGCMcguSaki_Nz_bPRMeEVJAlpTyDiV2FoBt24HvjME3Q72AUfZRd59CMbuM2eMSBB4wv7mhyphenhyphenDdgR06u3t-xd91U9-b_2U5SaPHN07p_cu-zTmSTro2xd4nKYUVD-OrV-CUbfP7BKOTgQ/s728-rw-ft-e30/7.png)
### ‍**8. Document offboarding activities with a built-in report.** [#](#8-document-offboarding-activities-with-a-builtin-report)



Nudge Security records all of the offboarding steps you've taken, so you can always go back and check what was completed for each employee. Once you've finished offboarding a departing employee's SaaS and cloud accounts, you can generate a .pdf report of the activities you completed and share it with internal users or auditors.


[![](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEhd3I_sMPIgf9vIxGExtqV_rTTpUk28pqAWjMQoQ93lYvsgA0b4hasJ7XZnZZlUUXtZp3aWKlbyMuvx6jN8-dCfnn6-MAff06Ia_NscmgZb3hNxJBi-xXKB4hM4J4g3PPdA1GShyphenhyphenYVDnymz9FzFT5PSsrmZLNRGohnpjX_kx0zMRP472tYNFGTZ7VoZ_R8/s728-rw-ft-e30/8.png)](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEhd3I_sMPIgf9vIxGExtqV_rTTpUk28pqAWjMQoQ93lYvsgA0b4hasJ7XZnZZlUUXtZp3aWKlbyMuvx6jN8-dCfnn6-MAff06Ia_NscmgZb3hNxJBi-xXKB4hM4J4g3PPdA1GShyphenhyphenYVDnymz9FzFT5PSsrmZLNRGohnpjX_kx0zMRP472tYNFGTZ7VoZ_R8/s728-rw-ft-e30/8.png)
**‍Transition employees seamlessly with Nudge Security**[#](#transition-employees-seamlessly-with-nudge-security)
-----------------------------------------------------------------------------------------------------------------


Nudge Security helps you offboard departing users efficiently and completely, enabling you to protect corporate resources and avoid business disruptions without wasting precious time on tedious, repetitive tasks.


[Start your free 14-day trial now.](https://www.nudgesecurity.com/getting-started)


  





## Tags:


### Autogenerated tags:
offboarding saas oauth google microsoft app-to-app deprovisioned apps accounts.#
