# U.S. Government Releases New AI Security Guidelines for Critical Infrastructure
## The U.S. government has unveiled new security guidelines to fortify critical infrastructure against AI-related risks.
## Information:

+ Link: https://thehackernews.com/2024/04/us-government-releases-new-ai-security.html
+ Source: The Hacker News
+ Author: The Hacker News
+ Date published: 30 April 2024, 16:06
+ Date scraped: 30 April 2024, 11:07

## Article:
![Main article image](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEjFg-I75TPQ8p3EkXgIz6jAlyowo-W2L1Rb-59BMGZDZHsSinyo-U9cK4YLirmjPLT2wMecWBcZE3q138xUxiuWPCpjaOjghCqD2kVZp0YO2S3DB3qeSH6HEpYJxqJqCQMs6mjiDtDKLwo1a4o73mOEPFJs0MxhN9KaagVK7nuORcNQ8ATTsK6kvF3QDZW_/s728-rw-e365/ai.png)


The U.S. government has unveiled new security guidelines aimed at bolstering critical infrastructure against artificial intelligence (AI)-related threats.


"These guidelines are informed by the whole-of-government effort to assess AI risks across all sixteen critical infrastructure sectors, and address threats both to and from, and involving AI systems," the Department of Homeland Security (DHS) [said](https://www.dhs.gov/news/2024/04/29/fact-sheet-dhs-facilitates-safe-and-responsible-deployment-and-use-artificial) Monday.


In addition, the agency said it's working to facilitate safe, responsible, and trustworthy use of the technology in a manner that does not infringe on individuals' privacy, civil rights, and civil liberties.


The new guidance concerns the use of AI to augment and scale attacks on critical infrastructure, adversarial manipulation of AI systems, and shortcomings in such tools that could result in unintended consequences, necessitating the need for transparency and secure by design practices to evaluate and mitigate AI risks.


[![Cybersecurity](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEiuUUskkMH9dUT3LF77_Q_irGuaE4LGjp-Am2Ls_UzGJ5EBnZHfuFiSvKs4OPE5KmfedBHcuZZVHS4Bh48UJx8brpwtg6Vr2Gepbaw-lGMIm9HjUhyphenhyphen2W5DVm5-ymwPS691Ie32TrCqFIv6SxNRA-jOKCKZrOB5dV7BfL0zVAhOO0neNkP9yv-XePBU1hN_0/s728-e365/wing-d.png)](https://thehackernews.uk/third-party-risk-management-saas)
Specifically, this spans four different functions such as govern, map, measure, and manage all through the AI lifecycle -


* Establish an organizational culture of AI risk management
* Understand your individual AI use context and risk profile
* Develop systems to assess, analyze, and track AI risks
* Prioritize and act upon AI risks to safety and security


"Critical infrastructure owners and operators should account for their own sector-specific and context-specific use of AI when assessing AI risks and selecting appropriate mitigations," the agency [said](https://www.dhs.gov/news/2024/04/29/dhs-publishes-guidelines-and-report-secure-critical-infrastructure-and-weapons-mass).


"Critical infrastructure owners and operators should understand where these dependencies on AI vendors exist and work to share and delineate mitigation responsibilities accordingly."


The development arrives weeks after the Five Eyes (FVEY) intelligence alliance comprising Australia, Canada, New Zealand, the U.K., and the U.S. released a cybersecurity information sheet noting the careful setup and configuration required for deploying AI systems.


"The rapid adoption, deployment, and use of AI capabilities can make them highly valuable targets for malicious cyber actors," the governments [said](https://www.nsa.gov/Press-Room/Press-Releases-Statements/Press-Release-View/Article/3741371/nsa-publishes-guidance-for-strengthening-ai-system-security/).


"Actors, who have historically used data theft of sensitive information and intellectual property to advance their interests, may seek to co-opt deployed AI systems and apply them to malicious ends."


The recommended best practices include taking steps to secure the deployment environment, review the source of AI models and supply chain security, ensure a robust deployment environment architecture, harden deployment environment configurations, validate the AI system to ensure its integrity, protect model weights, enforce strict access controls, conduct external audits, and implement robust logging.


Earlier this month, the CERT Coordination Center (CERT/CC) [detailed](https://kb.cert.org/vuls/id/253266) a shortcoming in the Keras 2 neural network library that could be exploited by an attacker to trojanize a popular AI model and redistribute it, effectively poisoning the supply chain of dependent applications.


Recent research has found AI systems to be [vulnerable](https://hiddenlayer.com/research/prompt-injection-attacks-on-llms/) to a wide range of [prompt injection attacks](https://labs.withsecure.com/publications/detecting-prompt-injection-bert-based-classifier) that induce the AI model to circumvent safety mechanisms and produce harmful outputs.


[![Cybersecurity](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEj9LS2CMV85AM5f2fKKl2aPAnQ1iZEQKbHh7hRbW3rn3MowE5BXNOrNlHsrMYRMndplTjEmzciLAj6jVsDkRJI2IdSfFXSXuSlMn6gSgmzjKktBgyRTJsC-MayMQq8Z580Hjp8oCv0WoplbNRKlOEzR3RqajPwbLY2JzbQpwEIaW6u2UDkYmcWPO_Mmzq-X/s728-e365/cis-d.png)](https://thehackernews.uk/cis-controls-guide-sme)
"Prompt injection attacks through poisoned content are a major security risk because an attacker who does this can potentially issue commands to the AI system as if they were the user," Microsoft [noted](https://www.microsoft.com/en-us/security/blog/2024/04/11/how-microsoft-discovers-and-mitigates-evolving-attacks-against-ai-guardrails/) in a recent report.


One such technique, dubbed Crescendo, has been described as a multiturn large language model (LLM) jailbreak, which, like Anthropic's [many-shot jailbreaking](https://thehackernews.com/2024/04/ai-as-service-providers-vulnerable-to.html), tricks the model into generating malicious content by "asking carefully crafted questions or prompts that gradually lead the LLM to a desired outcome, rather than asking for the goal all at once."


LLM jailbreak prompts have become [popular among cybercriminals](https://abnormalsecurity.com/blog/2023-ai-generated-email-attacks) looking to craft effective phishing lures, even as nation-state actors have begun [weaponizing generative AI](https://thehackernews.com/2024/04/microsoft-warns-north-korean-hackers.html) to orchestrate espionage and influence operations.


Even more concerningly, studies from the University of Illinois Urbana-Champaign has discovered that LLM agents can be put to use to autonomously [exploit one-day vulnerabilities](https://arxiv.org/abs/2404.08144) in real-world systems simply using their CVE descriptions and "[hack websites](https://arxiv.org/abs/2402.06664v1), performing tasks as complex as blind database schema extraction and SQL injections without human feedback."


  





## Tags:


### Autogenerated tags:
llm
