# Emerging Attacker Exploit: Microsoft Cross-Tenant Synchronization
## Attackers are misusing Microsoft's native features to achieve their goals. Dive into the details of the Cross-Tenant Synchronization attack.
## Information:

+ Link: https://thehackernews.com/2023/08/emerging-attacker-exploit-microsoft.html
+ Source: The Hacker News
+ Author: The Hacker News
+ Date published: 10 August 2023, 16:44
+ Date scraped: 10 August 2023, 12:05

## Article:
![Main article image](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEhrfSfkkl48tAhsgZGlhD_10NxuusLHEajF1vctLLOTdwqQdqfNCabxD6SImihtBbuZTsxYD9icassJHzCcxUB6swZrQ8zhW8wDwTFM3hGiu1Z1jpTmSlGIaLv9rAfJYXvP--4AxqDh5ZVegqEZjwVqdo893DvPmb_MYXUJ4GJADXubrHD6O8Zr1a6LNJE/s728-e3650/Cross-Tenant-Synchronization.jpg)


Attackers continue to target Microsoft identities to gain access to connected Microsoft applications and federated SaaS applications. Additionally, attackers continue to progress their attacks in these environments, not by exploiting vulnerabilities, but by abusing native Microsoft functionality to achieve their objective. The attacker group Nobelium, linked with the SolarWinds attacks, has been documented using native functionality like the creation of Federated Trusts [[1]](https://attack.mitre.org/techniques/T1484/002) to enable persistent access to a Microsoft tenant. 


This article demonstrates an additional native functionality that when leveraged by an attacker enables persistent access to a Microsoft cloud tenant and lateral movement capabilities to another tenant. This attack vector enables an attacker operating in a compromised tenant to abuse a misconfigured Cross-Tenant Synchronization (CTS) configuration and gain access to other connected tenants or deploy a rogue CTS configuration to maintain persistence within the tenant. Vectra AI has not observed the use of this technique in the wild but given the historical abuse of similar functionality — Vectra AI presents details for defenders to understand how the attack would present and how to monitor for its execution. In addition, the article will review how Vectra AI customers currently have coverage — and have had coverage from day one of the functionality being released for this technique through their AI-driven detections and [**Vectra Attack Signal Intelligence**](https://www.vectra.ai/products/attack-signal-intelligence)TM.


## Cross-Tenant Synchronization[#](#crosstenant-synchronization)


CTS is a new feature from Microsoft that enables organizations to synchronize users and groups from other source tenants and grant them access to resources (both Microsoft and non-Microsoft applications) in the target tenant. CTS features build on previous B2B trust configurations enabling automated and seamless collaboration between different tenants and is a feature that many organizations will look to adopt. [[2]](https://learn.microsoft.com/en-us/azure/active-directory/external-identities/cross-tenant-access-overview) [[3]](https://learn.microsoft.com/en-us/azure/active-directory/multi-tenant-organizations/cross-tenant-synchronization-overview)


CTS is a powerful and useful feature for organizations like business conglomerates with multiple tenants across affiliated companies, but also opens potential reconnaissance, lateral movement and persistence attacks by bad actors if not configured and managed correctly. Read on for the potential risks and attack paths that adversaries can leverage to exploit CTS to abuse trust relationships from a potentially compromised tenant to any other tenant configured with a CTS trust relationship.


* CTS allows users from another tenant to be synced (added) into a target tenant.
* A loosely configured CTS configuration can be exploited to move laterally from a compromised tenant to another tenant of the same or different organization.
* A rogue CTS configuration can be deployed and used as a backdoor technique to maintain access from an external adversary-controlled Microsoft tenant.


### Assumed compromise![#](#assumed-compromise)


The exploitation techniques follow Assumed Compromise philosophy. The techniques used in these exploits assume that an identity has been compromised in a Microsoft cloud environment. In a real-world setting, this could originate from a browser compromise on an Intune-managed endpoint with a Microsoft-managed identity.


### Terminologies[#](#terminologies)




|  |  |
| --- | --- |
| **Source tenant** | Tenant from where users & groups are getting synced |
| **Target tenant** | Tenant with resources where users & groups are getting synced |
| **Resources** | Microsoft applications (Teams, SharePoint, etc.) and non-Microsoft applications (ServiceNow, Adobe, etc.) |
| **CTS** | Abbreviation to reference 'Cross Tenant Synchronization' in this document |
| **CTA** | Abbreviation to reference 'Cross Tenant Access' in this document |
| **Compromised Account** | Adversaries initial point of access |

 ### The Facilitator[#](#the-facilitator)


Important things to know about CTS configuration:


1. New users get synced into a tenant via push (not pull). [[2]](https://learn.microsoft.com/en-us/azure/active-directory/multi-tenant-organizations/cross-tenant-synchronization-overview#properties)
* Source tenant pushes new users to sync into the target tenant.

3. Automatic Consent Redemption setup. [[3]](https://learn.microsoft.com/en-us/azure/active-directory/multi-tenant-organizations/cross-tenant-synchronization-overview#automatic-redemption-setting)
* Enabling this eliminates the need to consent anytime new users are synced into a target tenant.

5. Users in scope for synchronization are configured in the source tenant. [[2]](https://learn.microsoft.com/en-us/azure/active-directory/multi-tenant-organizations/cross-tenant-synchronization-overview#properties)


## The Attack[#](#the-attack)


The attack techniques described in this article require certain licenses and a privileged account compromise or privilege escalation to certain roles in the compromised tenant. A Global Admin role can perform all these actions in a tenant. [[3]](https://learn.microsoft.com/en-us/azure/active-directory/multi-tenant-organizations/cross-tenant-synchronization-configure#prerequisites)

 

|  |  |  |
| --- | --- | --- |
| **Action** | **Source Tenant** | **Target Tenant** |
| **Tenant License** | 
Azure AD Premium P1 or P2
 | 
Azure AD Premium P1 or P2
 |
| **Configure CTA** | 
Security Administrator
 | 
Security Administrator
 |
| **Configure CTS** | 
Hybrid Identity Administrator
 | 
N/A
 |
| **Assign users to CTS configuration** | 
Cloud Admin or Application Admin
 | 
N/A
 |

 ### Technique 1: Lateral Movement[#](#technique-1-lateral-movement)


An attacker operating in a compromised environment can exploit an existing CTS configuration tenant to move laterally from one tenant to another connected tenant.


![Lateral Movement Attack](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEgSzODNB1DK3RExCq8uaHTQjdDJ5bUuNa7T83Xoey2WvgvDcY3huzEkFql6LhsNdMzyIyFJfbn2yq81fuvj-BxCJ1Fc7nBd475VhGrmbT3b97a_9gWq-5isQGPCOSi25tDBoNY6dwRkKEemfIgpxiqru501hQe55X88y6-zMZugoEIT6jfIs54YDvlPJJs/s728-e3650/2.jpg)
1. The attacker accesses the compromised tenant.
2. Attacker recons the environment to identify target tenants connected via deployed Cross Tenant Access policies.
[![Microsoft Cross-Tenant Synchronization](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEiB3ZFye82Q40ss4x4kpXD4IpSso-MR6JDhK0tOFryXNkNUE0uM1cthRkNbTdd76FPcklPemn36_xpSW6zEQWuW0zLmxNORupXRhjnhNhq07II1l9BfgjPPlbJnfE9jYqrVVhIhx1Ux7Ve2oUP_HSXlOmZSGySpZh81JpsFtzFW2-4t_1NQW3ClVaidlaA/s728-e3650/3.png)](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEiB3ZFye82Q40ss4x4kpXD4IpSso-MR6JDhK0tOFryXNkNUE0uM1cthRkNbTdd76FPcklPemn36_xpSW6zEQWuW0zLmxNORupXRhjnhNhq07II1l9BfgjPPlbJnfE9jYqrVVhIhx1Ux7Ve2oUP_HSXlOmZSGySpZh81JpsFtzFW2-4t_1NQW3ClVaidlaA/s728-e365/3.png)4. Attacker reviews Cross Tenant Access policy configuration for each connected tenant to identify one with 'Outbound Sync' enabled. CTA policy with Outbound Sync enabled allows users and groups from the current tenant to be synchronized into the target tenant.
[![Microsoft Cross-Tenant Synchronization](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEhV4dezoR5A-JrgE0lD7ug-Z6Cb0pSfTKgcsIUJ4LejXAcXV9-Sd2-zRClbjgTSi_Hw0HTUivoQhrZwk88I2cqF00_V34I7H9t-57QiCh1ANKagoARzbyFFVVlT_IvKdsVgfm1tk0Ap7jyL7PjBAKH1mlKVluKnBlblw_CpvyrD1PerIVC8EzerPPc1B34/s728-e3650/4.jpg)](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEhV4dezoR5A-JrgE0lD7ug-Z6Cb0pSfTKgcsIUJ4LejXAcXV9-Sd2-zRClbjgTSi_Hw0HTUivoQhrZwk88I2cqF00_V34I7H9t-57QiCh1ANKagoARzbyFFVVlT_IvKdsVgfm1tk0Ap7jyL7PjBAKH1mlKVluKnBlblw_CpvyrD1PerIVC8EzerPPc1B34/s728-e365/4.jpg)6. From the CTA policy configuration analysis, the attacker finds a connected tenant with Outbound Sync enabled and sets the tenant as the target for lateral movement.
7. The attacker then recons the compromised tenant to find CTS sync application that runs the job of synchronizing users and groups to the target tenant.
* There is no straight forward way to find the CTS sync application linked to the target tenant. The attacker can enumerate through service principals in the tenant attempting to validate credentials with the target tenant to ultimately find the application that hosts the sync job to the target tenant. It can be done through a simple module like [this](https://github.com/vectra-ai-research/MAAD-AF/blob/7a9bfa6be64050f75c38527463b5f77d290f964f/Library/ExploitCrossTenantSynchronization.ps1#L236).

[![Microsoft Cross-Tenant Synchronization](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEiPKJmVQ6QTKFE0W1GrLBW75vNsCA5c2_LFyfbivS0rZ1kaDcmTecaAGwDWh8uHwl9F5qhSU3Cp6LRWpzDEu79p9Z1RhKcujBAXvJkd0c1qo_uGuagKKoUP3Rt0U622DUNDAA0zXfJSO_bmedIF8DB6clqLqbDBTgQC0BPXvUm_0cjBAIv6eIzTZRIV3fk/s728-e3650/5.png)](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEiPKJmVQ6QTKFE0W1GrLBW75vNsCA5c2_LFyfbivS0rZ1kaDcmTecaAGwDWh8uHwl9F5qhSU3Cp6LRWpzDEu79p9Z1RhKcujBAXvJkd0c1qo_uGuagKKoUP3Rt0U622DUNDAA0zXfJSO_bmedIF8DB6clqLqbDBTgQC0BPXvUm_0cjBAIv6eIzTZRIV3fk/s728-e365/5.png)10. After identifying the CTS sync application, the attacker can modify its configuration to add the currently compromised user account to the application sync scope. This will sync the compromised user account into the target tenant and grant attacker access to the target tenant using the same initially compromised credentials.
[![Microsoft Cross-Tenant Synchronization](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEiqGPx2vVtfQjmaF2ITyWKesbO5NN9RFpnZsl_kqsyUwjUzQTl5amzT2EfEpbbqDIZi_MSpQdzbbDMaWOpoysn_ExNHP8ke-C8vQbEk5NWgEsTFgV5PFUws7vRXZ_16QIfWGWv_Ovzt5j3-deMWOGVKEQafZiHBEnQTwl9eI06mXhbaLRtOiK7GF2-ou78/s728-e3650/6.png)](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEiqGPx2vVtfQjmaF2ITyWKesbO5NN9RFpnZsl_kqsyUwjUzQTl5amzT2EfEpbbqDIZi_MSpQdzbbDMaWOpoysn_ExNHP8ke-C8vQbEk5NWgEsTFgV5PFUws7vRXZ_16QIfWGWv_Ovzt5j3-deMWOGVKEQafZiHBEnQTwl9eI06mXhbaLRtOiK7GF2-ou78/s728-e365/6.png)12. Alternatively, the attacker can also inspect the CTS sync application configuration to identify configured sync scope and act accordingly.
[![Microsoft Cross-Tenant Synchronization](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEj2w67H4mqdk6e3iYEqreki-_JnMCOTgOYUOapIMtBR4GshNlZwm426-fG9-Luzn_scWsJFCddGXsgIP1vSqp699Zkb52aYUOyhmjYnd4F4pG-ndiXXeKoKmyK1V4Xavw1otYB6VAByBcpaIeP35hLT9cBd65uQv5EdBI6Sk6fQ4dU6BlDYk7TXbzU6UI8/s728-e3650/7.png)](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEj2w67H4mqdk6e3iYEqreki-_JnMCOTgOYUOapIMtBR4GshNlZwm426-fG9-Luzn_scWsJFCddGXsgIP1vSqp699Zkb52aYUOyhmjYnd4F4pG-ndiXXeKoKmyK1V4Xavw1otYB6VAByBcpaIeP35hLT9cBd65uQv5EdBI6Sk6fQ4dU6BlDYk7TXbzU6UI8/s728-e365/7.png)* For example, if the object in sync scope is a group, then the attacker can attempt to add the compromised user account directly or indirectly to the group which will automatically allow the compromised account to be synced into the target tenant.

[![Microsoft Cross-Tenant Synchronization](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEjmq0JlLwpx8mx2yZKpoZgq2-zg-7mE5XYY-QVkk9JKPJoMmeo_NkSWBdfcOnBjdxBd9nxgiSJMfBAsEMmbNFLDmWaaK_B3rPJ84ZsxLDtby4QgLo6rfFDIk9c0IN4-XHTNMOFviEPeFflIPVgtwXrwI7Vg1ydlTuk-Z5q4IsOqEV7kawHxxpmSRcAq5kg/s728-e3650/8.png)](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEjmq0JlLwpx8mx2yZKpoZgq2-zg-7mE5XYY-QVkk9JKPJoMmeo_NkSWBdfcOnBjdxBd9nxgiSJMfBAsEMmbNFLDmWaaK_B3rPJ84ZsxLDtby4QgLo6rfFDIk9c0IN4-XHTNMOFviEPeFflIPVgtwXrwI7Vg1ydlTuk-Z5q4IsOqEV7kawHxxpmSRcAq5kg/s728-e365/8.png)16. If there are no explicit CTA inbound conditions blocking the sync in the target tenant, the compromised account will sync into the target tenant.
17. The attacker moves laterally into the target tenant using the same initially compromised account.


### Scenario 2: Backdoor[#](#scenario-2-backdoor)


An attacker operating in a compromised tenant can deploy a rogue Cross Tenant Access configuration to maintain persistent access.


![CTS Backdoor Attack Overview](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEhNl7_p_i9r920oPJS4VQVP_LCFqEUikAZtFBsCAT_4PGl3fuRwe_HqU6v-QkjFsFTd9IiaO26t_r2lc5gB5_u0GkVZsR7vfWQqOYdrizxYtRTVb09rQrWUds3BLZUYa8jbfu1zY-yHljPhMLsgLq3ret44E7RVEJqA8EinziaJH2frYaL2FbR2RFRWhv0/s728-e3650/9.png)
1. The attacker accesses the compromised tenant.
2. The attacker attempts to deploy a new Cross Tenant Access Policy in the victim tenant with the following properties.
* Add a new CTA policy with the source tenant defined as the attacker-controlled external tenant.
[![Microsoft Cross-Tenant Synchronization](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEjClHSOpJImis8AbJRCoOy55JKg8Y-TEkJdKDS8QEOzseGpInvBAxJX_Wo0U9HYcie-2I3J52PW36izCZWsEzpp1gR55RXoGQ0pC9Z-cGm8UQ45CLqI4frsBRORTo_UhSCmb0NuLtavTWQqzwBiMdBmHmBAwsTHOIYS2WwkyJTFL3-40I8nkYLH84m5Roo/s728-e3650/10.png)](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEjClHSOpJImis8AbJRCoOy55JKg8Y-TEkJdKDS8QEOzseGpInvBAxJX_Wo0U9HYcie-2I3J52PW36izCZWsEzpp1gR55RXoGQ0pC9Z-cGm8UQ45CLqI4frsBRORTo_UhSCmb0NuLtavTWQqzwBiMdBmHmBAwsTHOIYS2WwkyJTFL3-40I8nkYLH84m5Roo/s728-e365/10.png)* Configure the new CTA policy to enable '*Inbound Sync*'.
[![Microsoft Cross-Tenant Synchronization](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEiTrFw2_xGbXemBLIANk96D5R7uRS8-xPDFDblcwyCyYBylA66ZIgBujqtjXmHNrZ6cz9PdRWLOtPVDFmgFR2_sBX02IB2Em0JDZOOHI4RhUxqZPvLZ31Pu2oxNe-UgPN0kR7IBinF_aoVx8liqDKGjFjHAc1I69MJEKAgxh_NoFA09ZMTblFfYt4v4oB8/s728-e3650/11.png)](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEiTrFw2_xGbXemBLIANk96D5R7uRS8-xPDFDblcwyCyYBylA66ZIgBujqtjXmHNrZ6cz9PdRWLOtPVDFmgFR2_sBX02IB2Em0JDZOOHI4RhUxqZPvLZ31Pu2oxNe-UgPN0kR7IBinF_aoVx8liqDKGjFjHAc1I69MJEKAgxh_NoFA09ZMTblFfYt4v4oB8/s728-e365/11.png)* Enable '*Automatic User Consent'* for inbound user sync.
[![Microsoft Cross-Tenant Synchronization](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEhib5W7MRHZ-igSRZELxaKg1C3vddpL3HdzQcCxz-Mlvsgx8h15HoxSieKUa1lEH44-0ul6DHXaq1KFNM_XYXRuMruVi5vmk8HujEmzUdrTXvmZEV5TR5K3TKUZpO5z6vOAG3Y28u7v8aE1KdidQUohMphTDCzOs9OOYENEFKYel6AUnKusum2jSyWGAhI/s728-e3650/12.png)](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEhib5W7MRHZ-igSRZELxaKg1C3vddpL3HdzQcCxz-Mlvsgx8h15HoxSieKUa1lEH44-0ul6DHXaq1KFNM_XYXRuMruVi5vmk8HujEmzUdrTXvmZEV5TR5K3TKUZpO5z6vOAG3Y28u7v8aE1KdidQUohMphTDCzOs9OOYENEFKYel6AUnKusum2jSyWGAhI/s728-e365/12.png)
4. Simultaneously, the attacker also configures CTS on its external tenant.
* The external tenant CTS setup is out of scope for this article and hence not covered here. The process of setting CTS in a source tenant is well defined by [Microsoft](https://learn.microsoft.com/en-us/azure/active-directory/multi-tenant-organizations/cross-tenant-synchronization-configure) here.

6. The attacker can now sync new users from its tenant via push to the target victim tenant anytime in future. This grants the attacker future access to resources on the target tenant using the externally controlled account.


## Defense[#](#defense)


1. The attack techniques in this document follow assumed compromise. Businesses must continue to implement and enforce security best practices to reduce the risk of account compromise.
2. CTS Target tenants must:
1. Avoid implementing a default inbound CTA configuration which permits all users/groups/applications from the source tenant to sync inbound. [[2]](https://learn.microsoft.com/en-us/azure/active-directory/external-identities/cross-tenant-access-overview#default-settings)
2. Deploy less inclusive inbound CTA configuration such as explicitly defining accounts (if possible) or groups that can get access through CTS.
3. Combine CTA policy with additional Conditional Access Policies to prevent unauthorized access.

4. CTS Source tenants must:
1. Ensure groups allowed to access other tenants via CTS (and all privileged groups in general) are properly regulated and monitored.

6. Detect and respond at scale and speed.


### Vectra Customers:[#](#vectra-customers)


Vectra's existing portfolio of alerts are capable of detecting this activity even prior to understanding this operation's implication as well as the expected actions that would occur prior to this event.


The fact that there is no actual vulnerability exploited in this technique makes it harder to prevent once an adversary is in the environment with sufficient privileges. However, Vectra's AI-driven detections have been designed to detect these types of privilege abuse scenarios without having to rely on signatures or lists of known operations.


Vectra's Azure AD Privilege Operation Anomaly monitors for the underlying value of every operation in the environment and every user. The AI continuously creates a baseline of the types of actions that should be occurring in the environment and identifies cases of cloud-based privilege abuse. By focusing on the behavior of privilege abuse, Vectra is able to identify emerging techniques like the one documented here.


![Microsoft Cross-Tenant Synchronization](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEi2t9Q1yAz6qqBsiRyK9B-3zgB5TlfcfPn5Tobcm9--suVqHYNk55ulhTCMa9o4THDHpZ1lQmIjD_0z0Rm8zcMHNBXUTmGdqLJb_LILEZTLTrwtupRV5bVstGSIqiWojLPxwGBJ54RUS2hJMOSZ1eF9xT0rWKr5t618PWjYQHALHwkjumCB40V6UjZsNLE/s728-e3650/13.png) ![Microsoft Cross-Tenant Synchronization](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEgT0_Rj2zOfmCMb1xCSKaOt5NHd_CaDv_pkSPNu2ZMNM3s_qpOzP-ZVnmbxWOu4Su9nQIYqpFlNzx3RqvWa2ZatQ2iNWMMSaqnFD4QrHqFEQp0WmT_X0BRI3yaxbN_5JgmCiZdBrbo43LC3eJLpLljJKN80pzNEDFecISW7TVCkgqzLHDgW8wAmDKH6mtU/s728-e3650/14.png) ![Microsoft Cross-Tenant Synchronization](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEhfIi8bRAzopwel_WLIT6e_N0bxY52n9phJFxG1U4RcUkSgBA8A0WzurtsHD-jGv46yw-4lMEeomWq1rfVSy7gK20oaAKI5zCURamiWN2zZVTFzkUkB1_kMpUZapZpS_MBGy1mRauuGmvPqk-pguPyrZrvZS0mf2YEx4S0fv2qOl0z9x7JdEe2loF2u2RM/s728-e3650/15.png)
Attacker actions that would occur prior to the attack such as the account access following a token theft or other forms of account compromise, would be alerted on by Vectra detections like Azure AD Unusual Scripting Engine Usage, Azure AD Suspicious Sign-on or Azure AD Suspicious OAuth Application.


## Microsoft Cloud Security Testing[#](#microsoft-cloud-security-testing)


Testing environments regularly and effectively is the best way to be confident in the ability to defend against cyberattacks. [MAAD-Attack Framework](https://github.com/vectra-ai-research/MAAD-AF) is an open-source attack emulation tool that combines the most commonly used attacker techniques and allows security teams to quickly and effectively emulate them in their environments via a simple interactive terminal. Check out [MAAD-AF on GitHub](https://github.com/vectra-ai-research/MAAD-AF) or [learn more about it here](https://www.vectra.ai/blogpost/you-should-get-maad-af-about-emulating-attacks-it-goes-a-long-way?utm_source=the-hacker-news&utm_medium=display&utm_campaign=23Q3_C_AMS_PRO_the-hacker-news-display). 


Security teams can use MAAD-AF module *"Exploit Cross Tenant Synchronization"* to emulate and test against the CTS exploitation techniques in their environment. 


Want to learn more?


Vectra AI is the leader in AI-driven threat detection and response for hybrid and multi-cloud enterprises. The Vectra AI Platform delivers the integrated signal powering XDR, SIEM, SOAR — whatever your pane of glass. This powerful platform equips SOC teams with hybrid attack surface coverage and real-time Attack Signal Intelligence, along with integrated, automated and co-managed response. Companies can choose the modules they need to achieve full coverage across identity, public cloud, SaaS and data center networks.


[**Contact Vectra AI**](https://www.vectra.ai/about/contact?utm_source=the-hacker-news&utm_medium=display&utm_campaign=23Q3_C_AMS_PRO_the-hacker-news-display) today. 


**References:**



1. https://attack.mitre.org/techniques/T1484/002
2. <https://learn.microsoft.com/en-us/azure/active-directory/external-identities/cross-tenant-access-overview>
3. <https://learn.microsoft.com/en-us/azure/active-directory/multi-tenant-organizations/cross-tenant-synchronization-overview>
4. <https://invictus-ir.medium.com/incident-response-in-azure-c3830e7783af>



  





## Tags:
***urls***: https://attack.mitre.org/techniques/T1484/002 https://learn.microsoft.com/en-us/azure/active-directory/multi-tenant-organizations/cross-tenant-synchronization-overview https://learn.microsoft.com/en-us/azure/active-directory/external-identities/cross-tenant-access-overview https://invictus-ir.medium.com/incident-response-in-azure-c3830e7783af

### Autogenerated tags:
vectra microsoft cta cloud teams ai-driven
