# Apple releases eight small AI language models aimed at on-device use
## OpenELM mirrors efforts by Microsoft to make useful small AI language models that run locally.
## Information:

+ Link: https://arstechnica.com/information-technology/2024/04/apple-releases-eight-small-ai-language-models-aimed-at-on-device-use/
+ Source: Ars Technica
+ Author: Benj Edwards
+ Date published: 25 April 2024, 20:55
+ Date scraped: 25 April 2024, 22:01

## Article:
![Main article image](https://cdn.arstechnica.net/wp-content/uploads/2024/04/apple_toss_hero_1-760x380.jpg)



In the world of AI, what might be called "small language models" have been growing in popularity recently because they can be run on a local device instead of requiring data center-grade computers in the cloud. On Wednesday, Apple [introduced](https://huggingface.co/apple/OpenELM) a set of tiny source-available AI language models called OpenELM that are small enough to run directly on a smartphone. They're mostly proof-of-concept research models for now, but they could form the basis of future on-device AI offerings from Apple.


Apple's new AI models, collectively named OpenELM for "Open-source Efficient Language Models," are currently available on the [Hugging Face](https://huggingface.co/apple/OpenELM) under an [Apple Sample Code License](https://huggingface.co/apple/OpenELM/blob/main/LICENSE). Since there are some restrictions in the license, it may not fit the [commonly accepted definition](https://opensource.org/osd) of "open source," but the source code for OpenELM is available.


On Tuesday, we covered [Microsoft's Phi-3 models](https://arstechnica.com/information-technology/2024/04/microsofts-phi-3-shows-the-surprising-power-of-small-locally-run-ai-language-models/), which aim to achieve something similar: a useful level of language understanding and processing performance in small AI models that can run locally. Phi-3-mini features 3.8 billion parameters, but some of Apple's OpenELM models are much smaller, ranging from 270 million to 3 billion parameters in eight distinct models.


In comparison, the largest model yet released in [Meta's Llama 3](https://arstechnica.com/information-technology/2024/04/meta-releases-chatgpt-like-ai-site-and-open-weights-llama-3-model/) family includes 70 billion parameters (with a 400 billion version on the way), and OpenAI's GPT-3 from 2020 shipped with 175 billion parameters. Parameter count serves as a rough measure of AI model capability and complexity, but recent research has focused on making smaller AI language models as capable as larger ones were a few years ago.


The eight OpenELM models come in two flavors: four as "pretrained" (basically a raw, next-token version of the model) and four as instruction-tuned (fine-tuned for instruction following, which is more ideal for developing AI assistants and chatbots):


* [OpenELM-270M](https://huggingface.co/apple/OpenELM-270M)
* [OpenELM-450M](https://huggingface.co/apple/OpenELM-450M)
* [OpenELM-1\_1B](https://huggingface.co/apple/OpenELM-1_1B)
* [OpenELM-3B](https://huggingface.co/apple/OpenELM-3B)
* [OpenELM-270M-Instruct](https://huggingface.co/apple/OpenELM-270M-Instruct)
* [OpenELM-450M-Instruct](https://huggingface.co/apple/OpenELM-450M-Instruct)
* [OpenELM-1\_1B-Instruct](https://huggingface.co/apple/OpenELM-1_1B-Instruct)
* [OpenELM-3B-Instruct](https://huggingface.co/apple/OpenELM-3B-Instruct)


OpenELM features a 2048-token maximum context window. The models were trained on the publicly available datasets [RefinedWeb](https://arxiv.org/abs/2306.01116), a version of [PILE](https://pile.eleuther.ai/) with duplications removed, a subset of [RedPajama](https://github.com/togethercomputer/RedPajama-Data), and a subset of [Dolma v1.6](https://huggingface.co/datasets/allenai/dolma), which Apple says totals around 1.8 trillion tokens of data. Tokens are fragmented representations of data used by AI language models for processing.


Apple says its approach with OpenELM includes a "layer-wise scaling strategy" that reportedly allocates parameters more efficiently across each layer, saving not only computational resources but also improving the model's performance while being trained on fewer tokens. According to Apple's released [white paper](https://arxiv.org/pdf/2404.14619), this strategy has enabled OpenELM to achieve a 2.36 percent improvement in accuracy over Allen AI's [OLMo 1B](https://allenai.org/olmo) (another small language model) while requiring half as many pre-training tokens.


[![An table comparing OpenELM with other small AI language models in a similar class, taken from the OpenELM research paper by Apple.](https://cdn.arstechnica.net/wp-content/uploads/2024/04/open_elm_table-640x185.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2024/04/open_elm_table.jpg) / An table comparing OpenELM with other small AI language models in a similar class, taken from the OpenELM research paper by Apple.Apple


Apple also released the code for [CoreNet](https://github.com/apple/corenet), a library it used to train OpenELM—and it also included reproducible training recipes that allow the weights (neural network files) to be replicated, which is unusual for a major tech company so far. As Apple says in its OpenELM paper abstract, transparency is a key goal for the company: "The reproducibility and transparency of large language models are crucial for advancing open research, ensuring the trustworthiness of results, and enabling investigations into data and model biases, as well as potential risks."


By releasing the source code, model weights, and training materials, Apple says it aims to "empower and enrich the open research community." However, it also cautions that since the models were trained on publicly sourced datasets, "there exists the possibility of these models producing outputs that are inaccurate, harmful, biased, or objectionable in response to user prompts."


While Apple has not yet integrated this new wave of AI language model capabilities into its consumer devices, the upcoming iOS 18 update (expected to be [revealed in June](https://arstechnica.com/gadgets/2024/03/wwdc-2024-starts-on-june-10-with-announcements-about-ios-18-and-beyond/) at WWDC) is rumored to include new AI features that [utilize on-device processing](https://arstechnica.com/apple/2024/01/apple-aims-to-run-ai-models-directly-on-iphones-other-devices/) to ensure user privacy—though the company may potentially [hire Google](https://arstechnica.com/information-technology/2024/03/apple-may-hire-google-to-power-new-iphone-ai-features-using-gemini-report/) or OpenAI to handle more complex, off-device AI processing to give Siri a long-overdue boost.





## Tags:


### Autogenerated tags:
openelm
