# SGX, Intel’s supposedly impregnable data fortress, has been breached yet again
## ÆPIC Leak spills users' most sensitive secrets in seconds from SGX enclaves.
## Information:

+ Link: https://arstechnica.com/information-technology/2022/08/architectural-bug-in-some-intel-cpus-is-more-bad-news-for-sgx-users/
+ Source: Ars Technica
+ Author: Dan Goodin
+ Date published: 09 August 2022, 17:01
+ Date scraped: 15 August 2022, 12:47

## Article:
![Main article image](https://cdn.arstechnica.net/wp-content/uploads/2022/08/intel-sgx-760x380.jpeg)







Intel’s latest generation of CPUs contains a vulnerability that allows attackers to obtain encryption keys and other confidential information protected by the company’s software guard extensions, the advanced feature that acts as a digital vault for security users’ most sensitive secrets.


Abbreviated as SGX, the protection is designed to provide a fortress of sorts for the safekeeping of encryption keys and other sensitive data, even when the operating system or a virtual machine running on top is maliciously compromised. SGX works by creating trusted execution environments that protect sensitive code and the data it works with from monitoring or tampering by anything else on the system.


## Cracks in Intel’s foundational security


SGX is a cornerstone of the security assurances many companies provide to users. Servers used to handle contact discovery for the Signal Messenger, for instance, rely on SGX to ensure the process is anonymous. Signal [says](https://signal.org/blog/private-contact-discovery/) running its advanced hashing scheme provides a “general recipe for doing private contact discovery in SGX without leaking any information to parties that have control over the machine, even if they were to attach physical hardware to the memory bus.”


The example is purely hypothetical. Signal spokesperson Jun Harada wrote in an email: “Intel alerted us to this paper... and we were able to verify that the CPUs that Signal uses are not impacted by the findings of this paper and therefore are not vulnerable to the stated attack.”


Key to the security and authenticity assurances of SGX is its creation of what are called "enclaves," or blocks of secure memory. Enclave contents are encrypted before they leave the processor and are written in RAM. They are decrypted only after they return. The job of SGX is to safeguard the enclave memory and block access to its contents by anything other than the trusted part of the CPU.


## Enter ÆPIC Leak


Since 2018, researchers have poked at least seven serious security holes in SGX, some of which completely undermined the assurances Intel makes about them. On Tuesday, a research paper publicly identified a new hole, which also completely breaks SGX guarantees in most 10th, 11th, and 12th generation Intel CPUs. The chipmaker said it released mitigations that prevent the researchers’ proof-of-concept exploit from working any longer. The researchers will [present their findings](https://blackhat.com/us-22/briefings/schedule/#architecturally-leaking-data-from-the-microarchitecture-26559) on Wednesday at the Black Hat security conference in Las Vegas.


[![A list showing which Intel CPUs are vulnerable.](https://cdn.arstechnica.net/wp-content/uploads/2022/08/vulnerable-cpus-640x205.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2022/08/vulnerable-cpus.jpg) / A list showing which Intel CPUs are vulnerable.Borrello et al.


The vulnerability resides in [APIC](https://en.wikipedia.org/wiki/Advanced_Programmable_Interrupt_Controller), short for Advanced Programmable Interrupt Controller. APIC is a mechanism built into many modern CPUs that manages and routes [interrupts](https://www.quora.com/What-is-a-CPU-interrupt-and-how-does-data-get-read-upon-an-interrupt-event), which are signals generated by hardware or software that cause the CPU to stop its current task so it can process a higher-priority event. The researchers who discovered the flaw have named the vulnerability and their proof-of-concept exploit ÆPIC Leak.


[![An overview of ÆPIC Leak.](https://cdn.arstechnica.net/wp-content/uploads/2022/08/attack-overview-640x279.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2022/08/attack-overview.jpg) / An overview of ÆPIC Leak.Borrello et al.


The bug that makes ÆPIC Leak possible is what’s known as an [uninitialized memory read](https://www.intel.com/content/www/us/en/develop/documentation/inspector-user-guide-linux/top/problem-type-reference/uninitialized-memory-access.html), which happens when memory space isn't cleared after the CPU is done processing it, causing the leak of old data that is no longer needed. Unlike previous CPU flaws with names like [Spectre, Meltdown](https://arstechnica.com/gadgets/2018/01/meltdown-and-spectre-every-modern-processor-has-unfixable-security-flaws/), [Foreshadow](https://arstechnica.com/gadgets/2018/08/intels-sgx-blown-wide-open-by-you-guessed-it-a-speculative-execution-attack/), and [RIDL/Fallout/ZombieLoad](https://arstechnica.com/gadgets/2019/05/new-speculative-execution-bug-leaks-data-from-intel-chips-internal-buffers/)—which were the result of transient execution creating [side channels](https://en.wikipedia.org/wiki/Side-channel_attack) that revealed private data—ÆPIC Leak is an architectural flaw that resides in the CPU itself.







[![](https://cdn.arstechnica.net/wp-content/uploads/2022/08/chip-vulnerability-types-640x224.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2022/08/chip-vulnerability-types.jpg)Borrello et al.


“ÆPIC Leak enables attacks against SGX enclaves on Ice Lake CPUs, forcing specific data into caches and leaking targeted secrets,” the researchers [wrote](http://aepicleak.com/). “We show attacks that allow leaking data held in memory and registers. We demonstrate how ÆPIC Leak completely breaks the guarantees provided by SGX, deterministically leaking AES secret keys, RSA private keys, and extracting the SGX sealing key for remote attestation.”


In a statement, Intel officials wrote:



> The Advanced Programmable Interrupt Controller (APIC) is an integrated CPU component responsible for accepting, prioritizing, and dispatching interrupts to logical processors (LPs). The APIC can operate in xAPIC mode, in which APIC configuration registers are exposed through a memory-mapped I/O (MMIO) page. Researchers have demonstrated attacks against Intel SGX enclaves, where stale data may be exposed by an attacker who controls the OS and can read from the legacy xAPIC. On some processors, incorrectly aligned reads from addresses in the xAPIC MMIO page could return stale data, which may correspond to data previously read by the same processor core that is reading the xAPIC page.
> 
> 
> Intel recommends that operating systems (OSes) and virtual machine monitors (VMMs) enable x2APIC mode, which disables the xAPIC MMIO page and instead exposes APIC registers through model specific registers (MSRs), which mitigates this issue in affected products. APIC virtualization is not affected; this behavior only applies to access to the physical xAPIC MMIO page.
> 
> 
> Customers can and should continue to use Intel SGX. Intel has provided a microcode update for processors with Intel Software Guard Extensions (Intel SGX) to enable support to clear buffers and mitigate potential exposure of sensitive stale data when exiting Intel SGX enclaves. Intel is also providing an updated Intel SGX Software Development Kit (SDK) for Windows and Linux that helps mitigate the possibility that enclave data that might be inferred. Intel is not aware of this issue being exploited outside of a controlled lab environment.
> 
> 


The company has also issued writeups [here](https://www.intel.com/content/www/us/en/security-center/default.html), [here](https://www.intel.com/content/www/us/en/security-center/advisory/intel-sa-00657.html), [here](https://www.intel.com/content/www/us/en/developer/articles/technical/softwaresecurity-guidance/advisory-guidance/stale-data-read-from-xapic.html), and [here](https://www.intel.com/content/www/us/en/developer/articles/technical/softwaresecurity-guidance/technical-documentation/cpuid-enumeration-and-architectural-msrs.html).


In an email, researcher Pietro Borrello of the Sapienza University of Rome wrote, “From our point of view, disabling APIC MMIO and enforcing x2APIC from the microcode would have been a more effective mitigation with no performance impact (actually, it would have had a performance improvement). However, we do not know why they chose to flush buffers and disable hyperthreading, thus [requiring] a possibly costly mitigation. It may not be possible to enforce x2APIC internally, or they may have chosen this path for compatibility reasons.”


The researchers’ proof-of-concept exploit, available [here](https://github.com/IAIK/AEPIC), is able to obtain a 128-bit AES decryption key on average in 1.35 seconds, with a success rate of 94 percent. The exploit can extract a 1024-bit RSA key on average in 81 seconds with a success rate of 74 percent. ÆPIC Leak also recovers attestation keys, a fundamental building block used in SGX, and another crucial secret known as the EPID Private Key, although the paper didn’t report the time required or the success rate.


“Extracting the EPID keys allows an attacker to forge remote attestations, breaking the whole SGX system, as enclaves can then be emulated,” the researchers explained in their paper. “Thus, SGX could not be trusted anymore on any platform until the keys are replaced.” Recovering the attestation keys, meanwhile, allows an attacker to impersonate an enclave, breaking the ground assumptions of SGX.





## One vulnerable server is all it takes


To demonstrate the risk that ÆPIC Leak poses to users of the affected CPUs, the researchers provided this hypothetical: “An attacker only needs one up-to-date system to extract secrets from an enclave (e.g., bypassing Signal private contact discovery, leaking DRM secrets or attestation keys). Thus, if not mitigated, exploiting ÆPIC Leak is a significant threat to enclave security.”


They went on to write:



> We assume either a malicious hypervisor targeting secrets in guest enclaves or a privileged attacker willing to extract secrets from local enclaves, e.g., bypassing private contact discovery on Signal Servers [51], leaking DRM secrets or even SGX attestation keys. ÆPIC Leak only requires the OS or hypervisor to access the physical Local APIC to leak secrets, with no difference between the two settings. The attacker is either running on the same physical core, on the sibling logical core, or on the same logical core, e.g., if hyperthreading is disabled.
> 
> 


Once again, Signal said the CPUs it relies on for SGX aren’t vulnerable.


[![A diagram illustrating superqueu re-encryption.](https://cdn.arstechnica.net/wp-content/uploads/2022/08/superqueu-reencryption-640x338.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2022/08/superqueu-reencryption.jpg) / A diagram illustrating superqueu re-encryption.Borrello et al.


In an email, Andreas Kogler, another author of the paper who is at the Graz University of Technology, explained the findings in more technical terms:



> We found that when reading from specific memory addresses on newer Intel CPUs, we can architecturally leak data previously sent over the interconnect between the L2 and L3 cache.
> 
> 
> The vital point here is that the attack is a simple memory read and does not require a side-channel to encode and later recover the data, as, for example, needed with the Meltdown attack.
> 
> 
> This allows for lesser "noise" and higher leakage rates.
> 
> 
> We require “root” privileges to read these specific memory addresses for this attack. Therefore, we focus on the Intel SGX platform as this threat model allows for such attacks.
> 
> 
> The idea of SGX is to provide a secure environment where data is cryptographically protected and the integrity of computations is guaranteed. E.g., you want to ensure that the "code" running on a server you rented is safeguarded and the calculations are not altered, nor that the server provider has access to your data.
> 
> 
> Our attack can break these assumptions by first leaking nearly all data of code executed inside these enclaves. Furthermore, we show that with your attack, we can extract a vital key used within the SGX platform's ecosystem.
> 
> 
> Therefore, the attack affects the cloud scenario where SGX is used (see the Signal case).
> 
> 


The vulnerability generally doesn’t pose a risk to customers who use affected CPUs for non-SGX users. Referring to the hierarchy of memory caches inside Intel CPUs, Kogler explained:



> We require “root” privileges to read from these memory locations to get “some” previously transmitted data between L2 <-> L3.
> 
> 
> The SGX threat model allows for such a strong attacker, i.e., a malicious operating system that would perform such an attack.
> 
> 
> Usually, for “normal” users, we assume the operating system to be trusted, and therefore, no attacker has “root” to mount such attacks. If an attacker already has “root” rights, the attacker could use different ways to read data from "non SGX" programs.
> 
> 


ÆPIC Leak is tracked as CVE-2022-21233. It carries a severity rating of 6.0 out of a possible 10. Intel’s mitigations are available starting Tuesday under a coordinated disclosure agreement it reached with the researchers. Users of affected CPUs can obtain the updates from their server maker. Intel is expected to fully patch the vulnerability in future generations of its microarchitecture.




## Promoted Comments


* [Nanochip](/civis/memberlist.php?mode=viewprofile&u=829316)
Smack-Fu Master, in training




 Alder Lake and Sapphire Rapids both make use of Golden Cove... Does anyone know if this vulnerability (and the need for a fix) is in part why Intel has delayed Sapphire Rapids? Also, I'm curious if the upcoming Raptor Lake / Meteor Lake are also vulnerable or whether Intel had time to implement the mitigations in the upcoming architectures.
 
 
 
 


12 posts | registered 11/19/2020












## Tags:
***CVE's***: CVE-2022-21233

### Autogenerated tags:
sgx æpic apic xapic mmio e.g root” mitigations proof-of-concept x2apic
