# Google's Gemini AI Vulnerability let Hackers Gain Control Over Users’ Queries
## Researchers discovered multiple vulnerabilities in Google's Gemini Large Language Model (LLM) family, including Gemini Pro and Ultra, that allow attackers to manipulate the model's response through prompt injection.
## Information:

+ Link: https://cybersecuritynews.com/?p=59499
+ Source: Cyber Security News
+ Author: Balaji N
+ Date published: 14 March 2024, 04:05
+ Date scraped: 14 March 2024, 05:06

## Article:
![Main article image](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEiBthBupoK-EOtdpuV3tpyleQYa03mIDv1JFIO4AvuhRB2aZ7HZexBgpSdcZAZhbRRsnm53QnL42KSTQyWsj1_M6UBnUehnwbWgso90FYZOZReO3ZdQuGlqO6G2SlQExu2X_xOhiwgtmOFL9cjLHQFk8TX2of2WhVKpOvuyc4KfA9Po1cat8KuC6Vj-xnDK/s16000/AI%20Vulnerability%20let%20Hackers%20Gain%20Control.webp)


Researchers discovered multiple vulnerabilities in [Google’s Gemini Large Language Model](https://cybersecuritynews.com/google-launches-gemini/) (LLM) family, including Gemini Pro and Ultra, that allow attackers to manipulate the model’s response through prompt injection. This could potentially lead to the generation of misleading information, unauthorized access to confidential data, and the execution of malicious code.


The attack involved feeding the LLM a specially crafted prompt that included a secret passphrase and instructed the model to act as a helpful assistant.


Researchers could trick the LLM into revealing the secret passphrase, leaking internal system prompts, and injecting a delayed malicious payload via Google Drive by manipulating the prompt and other settings.


According to [HiddenLayer](https://hiddenlayer.com/research/new-google-gemini-content-manipulation-vulns-found/), these findings highlight the importance of securing LLMs against prompt injection attacks. These attacks can potentially compromise the model’s integrity and lead to the spread of misinformation, data breaches, and other harmful consequences. 


**Vulnerabilities Present in Gemini:**
--------------------------------------


System prompt leaks reveal an LLM’s internal instructions, potentially including sensitive information and directly asking for the prompt is ineffective due to fine-tuning.


![](https://lh7-us.googleusercontent.com/IqgWRcb94egacyoxrxbgXd20EsGcxwSIoMHTNROoXkItVGBGm7VkNXAuryWtilXJXd-2RA5B6M_7Zu5GNetR9dD0E6qivMRiR9J0NXLlfVvfs2X9n5xQGntMPfce2tYbLLxvvAYJbLbEDf_GoNqj5w)


Attackers can exploit the inverse scaling property by using synonyms to rephrase their request, bypassing the protection and granting access to the instructions through reworded queries like “foundational instructions” instead of “system prompt.”


![](https://lh7-us.googleusercontent.com/5kStwwlhTEInt6WFhq1nzKdiBTM9ejQKgYhadJjEAu-1S2DtQE7FhsXygXxmp1PhyqkNNSzTdhgjXkcwYAECw6HAEQ1lXsL20tfac0bL8A-bb4JeWv1zBwiHuVnuyVDuh-O5Xahhk6bpVzluQ8uXeQ)


Bypassing built-in safety measures, the user exploits the model’s ability to write fiction. Crafting a specific prompt about a fictional election between “Bob the Caveman” and “Bob the Minion” tricks the model into generating an article despite the intended safeguards against real-world elections.


![](https://lh7-us.googleusercontent.com/ChLbW5o0ysVzXQSydcb7vld1V82g916SpypYdSaKNQEOuN-vgqkUMiaGLoVT1kql4N0JMQn3X-TJGcqw8VO0FsGs_yQgsdWPpsqr9Sczbdwuf7p8jZXXXzvZvySMVxKdLxiCKnswa-FfQUKVJAUNkw)


This demonstrates that while the model can identify and reject prompts directly mentioning elections, it might be susceptible to manipulation through cleverly disguised queries.


![](https://lh7-us.googleusercontent.com/HsVtTnIfre6VQj3I59vsZBgTNWhBs4lL4JweKxBlX7HG5vpQ4jjA9pyN7LNg3T6KWFU93IXp8rkRy501y1RjKPilbQyQYEMjX3Fm8GwSX__-MyAuwlv4f4uy85bPTGuL-klN1MBr2Mvd9APlFNK65Q)


A vulnerability in Gemini Pro, a large language model (LLM), allows potential attackers to leak information through the system prompt and by repeatedly feeding uncommon tokens, the model misinterprets them as a response prompt and attempts to confirm the previous instructions.


![](https://lh7-us.googleusercontent.com/dMUrG1RGRuwXKrLMAHYR2P6huLJ0AsihW42fvalhzXyQtXKSdUJs1WA2GLlRs6t1s3QtBI-B92LWHMxYhP1UuTwS-ERDiLmfgwEX-NjVlG2mjgsyfyO7-OyfeBR7zADyYNenwvtcO16N6gi6ou2IfQ)


It exploits the LLM’s fine-tuning on instructions, where it usually separates user input and system response and the attacker can manipulate this by crafting nonsensical token sequences, tricking the model into revealing information present in the prompt.


[Gemini Ultra](https://blog.google/technology/ai/google-gemini-ai/), Google’s most powerful language model, excels at logical reasoning and complex tasks, surpassing competitors by understanding user queries, utilizing extensions for diverse functions, and employing advanced reasoning tactics.


The vulnerabilities of Gemini Pro that persist in Gemini Ultra include a jailbreak utilizing a fictional gaslight and a method for extracting system prompts with a slight modification.


![](https://lh7-us.googleusercontent.com/nXxbO9a1rMx8DZvAYtsTBy2lmAfe_Lxe-BWlrYQkUlAub5IdE26PikplvVHhBo_9HIkREZug4NjPU6206Gx7Te28-gqixB4gJAqdlYIaNhFVaaoLi3k1wjNOIhba5nHJGgq2B1Rmxwd4LGqxnB7iGA)


![](https://lh7-us.googleusercontent.com/hI0E6kz-tWgbbDxc-PoKDwW4wAHcsVVw0cmh9LKnmRW4M1Soc9_k_DpKj5OsXI5SmC7oXs4GVFquYZscqhPrsw_3nSLJ7xXewFwmE0je7asjIhTO3tcLFhhXmZ0Wc52V4yMPVWK1RIyFUS9ycvBqMQ)


Gemini Ultra can also be jailbroken in more than one step by using its reasoning power. This can be done through a split payload attack that tricks the model into combining and running a malicious query. There is also a way to output restricted information by gradually improving and extracting content from generated narratives.


![](https://lh7-us.googleusercontent.com/2_hE8y5lavtIMOpdNBjTpDSetUmKssSGma4SIyuL1_K0rpECFvvvELtT8UXbk_Yf2jiZxUrE9L_cncQ_pxf-dEWqDJ4sM4tV5OC-yQBkKBk1bLDedEiEI2i3lyJK5I4VTEfvBh57r_r-44EVahvm6Q)


A vulnerability in Gemini allows [injection attacks](https://cybersecuritynews.com/injection-attacks/) through Google documents. By embedding malicious instructions in a shared document, an attacker can trick the user into revealing sensitive information or even gain control of their interaction with the model. 


![](https://lh7-us.googleusercontent.com/fHmTDrH7g2DdDn8dUgaYVykmFhDJuC-Ao8h9_M1qIldNfIP7trD5vqqsptqoeeWnmkTeOzw_XyTPrCTrb2Pcu0Pbz0WKC09Fu54TKVjtoOHEawK7iv0GW6W4W0r_eEHO09R6JYR7rMM8bxk9Rb1hHw)


Considering how this attack may affect Google Docs, it becomes more terrifying. Someone may secretly send you a document and include a command to retrieve it in one of your commands. The attacker would then be able to manipulate your interactions with the model.





## Tags:


### Autogenerated tags:
llm google
