# StrelaStealer’s Malware Resurgence: What Security Leaders Need to Know in 2024
## we’ll dissect a timely example of credential theft—StrelaStealer—to identify the malware’s characteristics and capabilities.
## Information:

+ Link: https://cybersecuritynews.com/?p=62329
+ Source: Cyber Security News
+ Author: Kaaviya Ragupathy
+ Date published: 15 April 2024, 12:52
+ Date scraped: 15 April 2024, 13:12

## Article:
![Main article image](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEizu3SdKwwSSQrppXap3yhJ904fXnc4VeZD8snTmXTqg67ZIDGNOd9Z7q-ixEsA65VdBuM24HCKN32iGXkcGRlZkvQSTMID-SNuQJSwMZDbprbVuvopHEQOWwYEGXMnBdT8xYPXcqm7lSV7n6UsK3PjxMo7Ex6w5JPkyc4TvITsqweQdIKKYuAgz1BqeDMP/s16000/StrelaStealer%E2%80%99s.webp)


Stolen credentials are the most common way for hackers to access an organization, according to the 2023 DBIR report. As an analyst for CyOps, **[Cynet](https://www.cynet.com/?utm_source=gbhackers&utm_medium=sponsored_article&utm_campaign=Q2-sponsored-webinars)**’s team of experts to monitor threat actor activities and protect Cynet clients, I’ve seen how cybercriminals pilfer usernames and passwords, then ruthlessly leverage those lifted logins to wreak havoc on target organizations.


The damage can be especially disastrous for small-to-medium enterprises (SMEs) that lack the big budgets and sprawling security teams to respond rapidly to a breach. Therefore, it is crucial for SME I.T. security leaders to ensure that their organizations are secure through affordable measures to reduce their exposure to compromise.


For a deeper technical dive into the mechanics and mitigations of credential stealing, plus hackers’ other favorite points of entry, **I highly encourage you to watch** “[**Securing the Top 3 SME Attack Vectors**](https://go.cynet.com/top-3-sme-attack-vectors?utm_source=gbhackers&utm_medium=sponsored_article&utm_campaign=Q2-sponsored-webinars).”


Now, in this piece, we’ll dissect a timely example of credential theft—*StrelaStealer*—to identify the malware’s characteristics and capabilities and the detections and preventions necessary to block it from affecting your organization. 


**StrelaStealer’s New Tricks**
------------------------------


A massive StrelaStealer campaign recently rocked hundreds of US- and EU-based companies. StrelaStealer, as its name suggests, is a stealer. Its goal is to swipe email login credentials from victim machines, focusing primarily on Thunderbird and Outlook email accounts.


When StrelaStealer was first observed in early November 2022, it was distributed as an ISO file that contained a .LNK file which either side-loaded the stealer’s DLL payload or, through a more sophisticated method, executed the payload as a DLL/HTML polyglot.


That distribution method has evolved. In this most recent campaign, we see StrelaStealer delivered via phishing emails in several languages, depending on what their target speaks.


Here, in this phishing email, we can see how users are lured into opening a zip file attachment purporting to enclose a PDF invoice:


![A screenshot of a computer

Description automatically generated](https://lh7-us.googleusercontent.com/Wfo-8fxGk6E9DdMcsBD8HbEFQKCR9ZiJI-O4wM0RyKjm1ji5tnIFVUGEiYZ4Yikp8iSzNOifQrs1ZywVtxu9SGVBCMFj3TKTTOUPBwGssCg3pU5n6OkHgWxkkBrtkLNM1gz_UlQ0cyX3bk7BgFossPo3z_gIJyZN)


The zip file actually contains a JavaScript file named “18262829011200.js”:


![A screenshot of a computer

Description automatically generated](https://lh7-us.googleusercontent.com/bKI7NJctNtltFs2kiKrN3nHMcPTMiObz5OtQ5O57UIznmmA4kUsYQqeyScb8Rb5ffe1w6QaEU7XRFEvY4CngWF9xt95lanrbmxBARSKeg5p_cBUy8ARL9qHsEkSL-vGoO9lTUTmIPbTp_a6vMmjRoPpRLr4Nm6IF)


Now, by performing static and dynamic analyses, we can assess that file and understand its functionality and capabilities.


**Static Analysis**
-------------------


First up, static analysis. StrelaStealer’s source code can be parsed for signs of potential security issues.


Reviewing the file in a text editor reveals several exciting commands:


1. The following commands look like an obfuscated script, replacing characters with variable names:  
![A screenshot of a computer

Description automatically generated](https://lh7-us.googleusercontent.com/LKaLk1uUyRS636EX0lX6LF1FUCz-jGQyhFptzbcMC9eXh7Fy-YezH6XvCWmvF_BRLq8BQUq0bjmuuzmjaQJdiwxspDQEcPWJi4W3WeJncBNBi_3GAQ-KNIH8AoZsmaSVxVCKzc0Vs34p984hguZWail4mfZM9Roh)


De-obfuscating the code, we can see that it contains several commands using native Windows applications to create and ultimately run a DLL file named “returnready.dll”:


![A screenshot of a computer

Description automatically generated](https://lh7-us.googleusercontent.com/d6l6WPY82QyAK2k_EfLgXtfd5zWLvKO7AcAly3NgMIZ1fcB5kA0nsCzuOdd-uadb3fXYxrE7dIInsCmeu-7ZmOeBXEPaopv5YFQajILeyRPDoCtyrvDYkLgxms0Uzq_ACa5ngc33C6fhZQMNixdaBV_HcwqtVtvS)


2. Additional strings show more obfuscated code, using the same method of setting characters as variables:  
![A screen shot of a computer screen

Description automatically generated](https://lh7-us.googleusercontent.com/2ElPvYtVxsChfB6H7eozfX_TaZAsCtPWGxiaScskyjI0CwyQOZP_6dIbBGIJTxBvJQa_o9WUhjDMu3WsWHTTTi3a9DCpqfDpj3VtQWHqFmSkCv-ZRmZPdmALQeOqmlMbY4zG6Jjcf0sahy1LtiVuV2ZRcfejkLsw)


Once decoded, we can see how wscript’s ‘shell’ method is used to execute cmd.exe and create the file “trousersperpetual.bat” in the %temp% directory:


![A screen shot of a computer code

Description automatically generated](https://lh7-us.googleusercontent.com/7MFe-kis3shO2bsICTph3KcqhF80nvH0ZRHKgdMWoQ6mbGNq-YUPd43Lt3J_uCWBONQIJuAfmGUzy6asU7vnTdw8uO_tfqR57Igfwy8oApJygHQzTD3uzCER3uSRuhMkEjhYgdk42XOG4_qffnDVu_k_wYUz21yR)


3. Finally, a very large base64 encoded string was observed in the file:  
![A green text on a white background

Description automatically generated](https://lh7-us.googleusercontent.com/5L2k6yFJHsCAWnyhZMBhT9qoBNE6AKCM0m7NAgFFNMNg1gffau2TVHDMLCZ86xQ2GgndN6WZBtWQ2c6Z1Z_iH3w9m5HzRi0JavEicrTWxnu6DyRaVm2vFupX4NxoeKZHoufrFQk2-g1yYSf3HMNG2OSeD3DtWFU8)


Decoding the string, we can see that it is a portable executable (PE) file:


![A screenshot of a computer

Description automatically generated](https://lh7-us.googleusercontent.com/f84mUSv-ZFp8OkeNIw06RkszqVl4FL8eryCiDwjupk8-3P7nrqrEibD6iXLUwNZmdDpo-81cEu_DHwF2vUjeb7PbTiKu5ftu5W8tfWdjscTmny6u9UaIHOIFCJtm1dMaN4usxx09Udl3UGIVsjYWdtm89PnuhmDv)


**Dynamic Analysis**
--------------------


Next, dynamic analysis. StrelaStealer can be run in a controlled environment to reveal its attack flow step-by-step.


Upon execution of the file “18262829011200.js” via wscript.exe, cmd.exe is used to create a copy of the .js file’s contents, which is then saved on the host as the file “C:\Users\\*\AppData\Local\Temp\**trousersperpetual.bat**”:


![A screenshot of a computer

Description automatically generated](https://lh7-us.googleusercontent.com/s1QCfxuqcBvQUy5wMjnFw0dgI-PYmcyW9D3I0McPfnJkBQ2spfcrrnTFu7mFPcy6BSEpc7wixkpPPbgcOjtZcdOaQoGJAU85sGC0pTAh9OsEw94R-JYClsDlnbEXSC01yeENwTU9pNyvjawf6Izn-kxW7zcw1_wR)


Cmd.exe continues by running “findstr” on the file “C:\Users\\*\AppData\Local\Temp\**trousersperpetual.bat**”, looking for all strings that do not contain the word “marrywise” and saving the result to the file “C:\Users\\*\AppData\Local\Temp\**magnificentdevelopment**”.


![](https://lh7-us.googleusercontent.com/TSZNtx1B5ZWWjxNH_oPVmFyTtuLMw5kCcES24qOb7wYKl-y75Xbg-lrpJS3UafNULMj4_GW0wo7Pd-uNusX_KwQ4PNxs38kRtftboMuWHDY1MalBKrXSY3YLeU0JfQ3Bv-RD3x3JN4AHZs64gfjmwsUJ9RTjV1MT)


This file ends up containing the large base64 string found in our static analysis:


![A screenshot of a computer

Description automatically generated](https://lh7-us.googleusercontent.com/6BpdMIvAR7zzAHQ-TCUshAjGd4BIYzlReWrIdfpM6-y6x9oY_CtXP5_luFfYP6Hy0C4wRpjgEPrSO-lyeQxyPYBMjhrmPk2QOSDw-6QTjktLo9jq5_R7BTeMK00Db7cMQPXXnHyBKy_Dhb1f70RDM8dgl4QXu6KM)


Then certutil.exe is invoked to decode the newly created base64 encoded file “**magnificentdevelopment**” into the file “C:\Users\\*\AppData\Local\Temp\**returnready.dll**”.



![](https://lh7-us.googleusercontent.com/6hFRd5YX4ELOhXqN8-mgUYXJI-L4p9rx4g76q4ks5ZX6OcydTncT04b6ccQGnLmakbPF4JGWet4Hcvow4lJ5oiJ_qUOHSEA-VsmzeeIVCgtFwtOl-DLZ5Fa4v2KEQ-t93mTuPQyBQhshGI_03BD2m3MWkMoCMpCb)


This is essentially StrelaStealer’s payload file:


![A screenshot of a computer

Description automatically generated](https://lh7-us.googleusercontent.com/IZ1Ch9vlJheAcfL85jrCB15Up_NeNP5rnFMYsSZjJ9LVCy4ZsJXdBv__2n1fQTlHWNXSq5rle6Jr7xF_6K_qeDoa5XlAnGSVyQIIECkYVfRQYsUqjiJYYTiEE1-mp6V7IC9zo6j6kk_PCBv1NZQsCGGqeBogpsM6)


The file “**returnready.dll**” is then executed via rundll32.exe, which proceeds to enumerate the host’s Outlook and Thunderbird email account data, before exfiltrating it to the threat actor’s command and control (C2) server. 


![A screenshot of a computer

Description automatically generated](https://lh7-us.googleusercontent.com/FitULm0CHGu-DTsd9TuBIJfcRMTnK4Fe_5Gs2Z1DJmFbmSzAbUM5i6E-Uu8nw_zD7htu3XBJSvyCEk7x9mKx2g7m5bW2R0tVgXfppkLRu-MBU41EB0xrw626ycuGgx1dUVI8ILcb3b_vPaSfUnaNHfGY8NYXnyM7)


**[MITRE ATT&CK](https://cybersecuritynews.com/mitre-engenuity-attck/) Tactics & Techniques**
---------------------------------------------------------------------------------------------




|  |  |  |  |  |  |
| --- | --- | --- | --- | --- | --- |
| **Initial Access** | **Execution** | **Defense Evasion** | **Collection** | **Command and Control** | **Exfiltration** |
| Phishing  | Command and Scripting Interpreter | Deobfuscate/Decode Files or Information | Email Collection | Application Layer Protocol | Automated Exfiltration |
|  | User Execution | Obfuscated Files or Information |  |  | Exfiltration Over C2 Channel |
|  |  | System Binary Proxy Execution |  |  |  |




**How to detect StrelaStealer**
-------------------------------


With an understanding of StrelaStealer’s characteristics and capabilities, cybersecurithttps://go.cynet.com/top-3-sme-attack-vectors?utm\_source=gbhackers&utm\_medium=sponsored\_article&utm\_campaign=Q2-sponsored-webinarsy teams can ensure their protections are able to block the stealer from compromising their organization.


Because [**Cynet**](https://go.cynet.com/top-3-sme-attack-vectors?utm_source=gbhackers&utm_medium=sponsored_article&utm_campaign=Q2-sponsored-webinars) is easily able to detect and prevent StrelaStealer, we’ll configure the all-in-one cybersecurity solution in detection mode (without prevention) to allow StrelaStealer to execute its full flow. This simulated execution lets Cynet detect and log each step of the attack, while highlighting how StrelaStealer triggers two specific Cynet detections.


### 1. **File Dumped on the Disk**


Cynet’s AV/AI engine detects that malicious files have been dumped on the disk or are attempting to run:


![A screenshot of a computer

Description automatically generated](https://lh7-us.googleusercontent.com/36PWwW7xOw90666Ws7TBKAIAH5MNXx7B57VznLqa9fdxl3hpHTCy6DEjDXDG_P_q5JwYuCVKjzNl7fWrD-Nwfmt0YBsMSO7s-NDcVQwj3433eGNXwrCi4H18XfMJ_fN0BQImDKfZ9EzDI_C206hNbbJHCE9AMXYe)  
![A screenshot of a computer

Description automatically generated](https://lh7-us.googleusercontent.com/V9rShWUgED4-vLRTiEdMPsQeb6-_rFVa1-amG5i3CjtgwoOeZW7VQWw4e-8EqHhtStEgde7epqiIHTod_deF3vZOHloujWplYPfkGkUCsedX7DeDe1WeGOmltLDZaUfmKem1er5QZz5SeU98TSwZcuC5n8QmVW4-)  
![A screenshot of a computer

Description automatically generated](https://lh7-us.googleusercontent.com/RcdZvDjT0GlZuzmpl3jU-REoYhCVbAj643teMBoCVYP1Y5piKL97f1Ohq2IhEpY3kbq8BBCMTh0ls0ZuD2W7LSu4u0pPm9PgzAn4kD6h3gs2pULodachYNRXCEdGi_8bF7FWSclvNhDd8sPnMOzlP13ArHdwDDu2)


### **Process Monitoring**


Cynet’s Process Monitoring mechanism detects the use of Certutil.exe to decode the malicious DLL file:


![A screenshot of a computer

Description automatically generated](https://lh7-us.googleusercontent.com/7AcuzzsxeM17UgSmrHFqMYovX2AXPJpg0NnDzOqPJS2jX9zQBmHIFu9LNQO5rt3hOGlh5c3vFnBMlhScySFouMgUoJ0jgQwZOPR52XLcVbrLtsz8MP6Es_8WpCXtBlwQ6WvGBTYG-2xuCl2-5dKPrgwyR0lMxhbP)





## Tags:
***urls***: cybersecurithttps://go.cynet.com/top-3-sme-attack-vectors?utm_source=gbhackers&utm_medium=sponsored_article&utm_campaign=Q2-sponsored-webinarsy

### Autogenerated tags:
strelastealer cynet dll cmd.exe base64
