# Atlassian warns of 4 new critical vulnerabilities affecting Jira, Confluence, Bitbucket
## Users must install updates to protect against remote code execution (RCE) attacks targeting users of the Australian software firm.
## Information:

+ Link: https://www.scmagazine.com/news/atlassian-warns-of-4-new-critical-vulnerabilities-affecting-jira-confluence-bitbucket
+ Source: SC Magazine
+ Author: Laura French
+ Date published: 11 December 2023, 15:34
+ Date scraped: 12 December 2023, 18:04

## Article:
![Main article image](https://files.scmagazine.com/wp-content/uploads/2023/10/1017_atlassian_confluence.jpg)

Atlassian Jira, Confluence, Bitbucket and macOS Companion app users are warned to update their software immediately due to four critical vulnerabilities allowing for remote code execution (RCE).

The Atlassian vulnerabilities [disclosed last week](https://community.atlassian.com/t5/Announcement-articles/Action-Required-RCE-Vulnerabilities-Identified-in-Multiple/ba-p/2552220) are “more likely than not” to be targeted in exploitation campaigns, [according to an Australian Cyber Security Centre alert](https://www.cyber.gov.au/about-us/view-all-content/alerts-and-advisories/serious-vulnerabilities-in-atlassian-products-including-confluence-jira-and-bitbucket), based on [previous exploitation](https://www.scmagazine.com/news/actively-exploited-atlassian-confluence-bug-elevated-to-maximum-severity-rating) of Jira and Confluence bugs. Atlassian, an Australian software company, [has more than 260,000 customers](https://www.cyber.gov.au/about-us/view-all-content/alerts-and-advisories/serious-vulnerabilities-in-atlassian-products-including-confluence-jira-and-bitbucket) in more than 190 countries, including two-thirds of Fortune 500 companies.

One of the most severe bugs, rated by Atlassian as a 9.8 using the CVSS scale, requires Jira customers to uninstall Assets Discovery agent software from all devices before installing a patch to the main Assets Discovery application.

Another vulnerability, also rated 9.8, dates back to 2022 and is now known to impact a dozen Atlassian products including multiple Jira, Confluence and Bitbucket offerings.

Critical Atlassian vulnerabilities pose malware risks
-----------------------------------------------------

Security flaws affecting Jira, Confluence, Bitbucket and the Atlassian Companion app for macOS could be used by attackers to remotely execute malicious code. Atlassian has released patches for all of these vulnerabilities, emphasizing the software updates are the only effective fix.

Ransomware exploitation of a previous Confluence bug, [tracked as CVE-2023-22518](https://nvd.nist.gov/vuln/detail/CVE-2023-22518), was reported last month. Threat actors were detected [injecting Cerber ransomware](https://www.scmagazine.com/news/actively-exploited-atlassian-confluence-bug-elevated-to-maximum-severity-rating) after using CVE-2023-22518 to bypass authentication and gain administrator access to Confluence sites.

“The recent advisories have CVSS ratings ranging from 9.0 to 9.8, which makes these bugs Critical in severity. All could allow a remote attacker to execute arbitrary code on affect systems — similar to what we saw in November,” said Dustin Childs, head of threat awareness at Trend Micro’s Zero Day Initiative, which has [tracked exploitation of CVE-2023-22518](https://www.trendmicro.com/en_us/research/23/k/cerber-ransomware-exploits-cve-2023-22518.html).

One of the newly reported vulnerabilities, [tracked as CVE-2023-22522](https://nvd.nist.gov/vuln/detail/CVE-2023-22522), enables authenticated users to add code to a Confluence template, which is executed upon loading a Confluence page with that template. [Atlassian said](https://confluence.atlassian.com/kb/faq-for-cve-2023-22522-1319248951.html) users with anonymous access can also edit templates, which could help attackers evade detection.

“CVE-2023-22522 exploitation requires an authenticated attacker, meaning a user account, but [also] some customers, have anonymous access enabled, which will allow the exploit assuming it’s internet-facing,” an Atlassian spokesperson told SC Media.

The other three vulnerabilities could be exploited by unauthenticated attackers, the spokesperson said.

Another vulnerability impacts Jira customers that use the Assets Discovery application. The app allows users to detect and collect information on hardware and software connected to a local network and import that information into Jira Service Management tools.

Atlassian said an RCE vulnerability, [tracked as CVE-2023-22523](https://nvd.nist.gov/vuln/detail/CVE-2023-22523), exists between Assets Discovery and Assets Discovery agents — software that allows offline devices to be detected by the Assets Discovery app.

All devices with an Asset Discovery agent installed need to have it manually uninstalled prior to the Asset Discovery app being updated for the vulnerability to be effectively patched, according to Atlassian. This poses a challenge for organizations with many remote devices that have Asset Discovery agents installed. [Atlassian recommends](https://confluence.atlassian.com/kb/faq-for-cve-2023-22523-1318391335.html) blocking the port used to communicate with the agents (51337 by default) as a temporary mitigation if all agents can not be immediately uninstalled.

Users of the Atlassian Companion app for Mac computers are [also warned to update](https://confluence.atlassian.com/security/cve-2023-22524-rce-vulnerability-in-atlassian-companion-app-for-macos-1319249492.html) due to a flaw in which the WebSockets protocol can be used to bypass MacOS Gatekeeper and Atlassian Companion’s blocklist to execute code on Confluence pages. The bug, tracked as CVE-2023-22524, only affects macOS users — the Windows companion app is not affected.

Java library bug rears its head 1 year later
--------------------------------------------

The Atlassian advisory also discloses that an RCE vulnerability discovered in December 2022 impacts 12 products across the Jira, Confluence and Bitbucket brands. The flaw, [tracked as CVE-2022-1471](https://nvd.nist.gov/vuln/detail/CVE-2022-1471), exists in SnakeYAML, a YAML parsing library for Java that is used in the affected products. Vulnerable versions of SnakeYAML could execute malicious code while deserializing YAML content.

[Atlassian said](https://confluence.atlassian.com/kb/faq-for-cve-2022-1471-1295810798.html) updating the SnakeYAML library is not sufficient, and the affected products must be updated to their latest versions to remediate the issue. A full list of affected products is provided in [Atlassian’s advisory](https://confluence.atlassian.com/security/cve-2022-1471-snakeyaml-library-rce-vulnerability-impacts-multiple-products-1296171009.html).  

CVE-2022-1471 [was previously found](https://www.scmagazine.com/brief/ai-server-takeovers-likely-with-critical-torchserve-vulnerabilities) to pose a major risk to AI infrastructure servers when paired with another vulnerability found in TorchServe software in October. On its own, however, the bug is “moderately difficult to weaponize,” [Rapid7 Security Research Manager Spencer McIntyre wrote](https://attackerkb.com/topics/DFsxSyi0nz/cve-2022-1471).

The company [wrote in an FAQ](https://confluence.atlassian.com/kb/faq-for-cve-2023-22523-1318391335.html) that the vulnerabilities were discovered as part of “an ongoing security review” it is conducting.

“As part of our commitment to continuous improvement, Atlassian recently enhanced its existing capabilities around third-party dependent security issues,” an Atlassian spokesperson told SC Media.

In addition to the discovery and exploitation of CVE-2023-22518 in November, Atlassian [patched two other high-severity vulnerabilities](https://www.scmagazine.com/brief/high-severity-atlassian-vulnerabilities-fixed) affecting Jira, Confluence, Bitbucket and Bamboo in September.




## Tags:
***CVE's***: CVE-2023-22524 CVE-2023-22522 CVE-2023-22518 CVE-2022-1471 CVE-2023-22523

### Autogenerated tags:
atlassian jira bitbucket macos rce cve-2023-22518 snakeyaml
