# Fortinet FortiClient EMS SQL injection flaw exploited in the wild
## A PoC exploit is available for the critical flaw, which was added to CISA’s KEV catalog Monday.
## Information:

+ Link: https://www.scmagazine.com/news/fortinet-forticlient-ems-sql-injection-flaw-exploited-in-the-wild
+ Source: SC Magazine
+ Author: Laura French
+ Date published: 26 March 2024, 00:00
+ Date scraped: 27 March 2024, 19:03

## Article:
![Main article image](https://files.scmagazine.com/wp-content/uploads/2024/03/AdobeStock_357046291.jpg)

Critical vulnerabilities in Fortinet FortiClient EMS, the Ivanti EPM Cloud Services Appliance, and the Nice Linear eMerge E-Series OS [were added to the U.S. Cybersecurity and Infrastructure Agency’s (CISA) Known Exploited Vulnerabilities (KEV) Catalog](https://www.cisa.gov/news-events/alerts/2024/03/25/cisa-adds-three-known-exploited-vulnerabilities-catalog) Monday.

A high-severity vulnerability in Microsoft SharePoint Server was also added to the KEV database Tuesday.

The Fortinet vulnerability, which was [first disclosed](https://www.fortiguard.com/psirt/FG-IR-24-007) on March 12, is a SQL injection flaw that could enable remote code execution (RCE) by an unauthenticated attacker. A proof-of-concept (PoC) exploit for the vulnerability, tracked as [CVE-2023-48788](https://nvd.nist.gov/vuln/detail/CVE-2023-48788), was [published on March 21](https://www.horizon3.ai/attack-research/attack-blogs/cve-2023-48788-fortinet-forticlientems-sql-injection-deep-dive/) by Horizon3.ai.

Fortinet also updated its advisory on March 21, indicating that the vulnerability was being exploited in the wild.

“Fortinet diligently balances our commitment to the security of our customers and our culture of transparency. We proactively communicated to customers via Fortinet’s PSIRT Advisory process, advising them to follow the guidance provided,” a Fortinet spokesperson told SC Media in an email.

CVE-2023-48788 has a CVSS score of 9.8 and affects FortiClient EMS versions 7.2.0 through 7.2.2 and 7.0.1 through 7.0.10.

SQL injection bug enables RCE through command shell
---------------------------------------------------

Horizon3.ai researchers outlined in a blog post how key components of FortiClient EMS — an enterprise endpoint management solution — communicate with one another and how an attacker can exploit this chain of connections to achieve RCE.

FmcDaemon.exe, the main component that communicates with enrolled client endpoints, listens for requests on port 8013 and forwards requests for database operations to the FCTDas.exe data access server. FCTDas.exe translates these messages into SQL queries and interacts with the Microsoft SQL Server database.

The researchers found that messages passed between FcmDaemon and FCTDas contained an FCTUID as part of the database query. By crafting a request that alters this FCTUID to include their own input, and transmitting this request through port 8013, the researchers were able to achieve SQL injection due to lack of sanitization for this element.

They further demonstrated how RCE could be achieved by crafting the injected input to execute code through the built-in command shell functionality (xp\_cmdshell) of the Microsoft SQL Server. Even when the database was not initially configured to run xp\_cmdshell commands, additional SQL injections could be used to enable this function.

The PoC exploit published by the researchers does not include the RCE function but allows users to confirm whether their instance is vulnerable to SQL injection.

Horizon3.ai Exploit Developer James Horseman told SC Media the company hasn’t tracked external activity related to CVE-2023-48788 and referred back to recommendations made in his blog post.

The blog noted users can look for connections from unrecognized clients and other potential indicators of compromise in the log files located at C:\Program Files (x86) \Fortinet\FortiClientEMS\logs. Microsoft SQL Server logs can also be examined for evidence of command execution through xp\_cmdshell.

Security organization Shadowserver [reported](https://x.com/Shadowserver/status/1771963616092193085?s=20) 130 FortiClient EMS instances vulnerable to CVE-2023-48788 were detected by its scanners on March 23, with 30 vulnerable instances in the United States.

“Note we only do a version check on the web interface, exploitation requires access to FmcDaemon on tcp/8013,” the organization [wrote on X.](https://x.com/Shadowserver/status/1771963618583589201?s=20)

GreyNoise is also tracking the vulnerability and [has so far detected](https://viz.greynoise.io/tags/fortinet-forticlientems-cve-2023-48788-sql-injection-attempt) four malicious IPs attempting to exploit the flaw, all of which are tagged as opportunistic TLS/SSL crawlers.

CISA [released a joint Secure by Design alert](https://www.cisa.gov/resources-tools/resources/secure-design-alert-eliminating-sql-injection-vulnerabilities-software) with the FBI on Monday advising software developers on preventing SQL injection vulnerabilities. The alert specifically references the [MOVEit file transfer service attack](https://www.cisa.gov/news-events/cybersecurity-advisories/aa23-158a) as an example of SQL injection exploitation.

Fortinet earlier this year patched another critical flaw in [FortiOS and FortiProxy](https://www.scmagazine.com/news/new-fortinet-rce-vulnerability-potentially-under-exploitation), tracked as [CVE-2024-21762](https://nvd.nist.gov/vuln/detail/CVE-2024-21762), which has since been added to the KEV catalog.

Another CISA [joint advisory](https://www.cisa.gov/news-events/cybersecurity-advisories/aa24-038a) last month warned that China-backed threat group [Volt Typhoon](https://www.scmagazine.com/news/volt-typhoon-fails-to-revive-botnet-after-fbi-takedown) has likely utilized Fortinet [CVE-2022-42475](https://nvd.nist.gov/vuln/detail/CVE-2022-42475), along with Ivanti, NETGEAR, Citrix and Cisco vulnerabilities, in campaigns against critical infrastructure.

Ivanti, Microsoft, Nice vulnerabilities added to KEV
----------------------------------------------------

Other severe vulnerabilities added to the KEV catalog this week include a code injection vulnerability in the Ivanti Endpoint Manager (EPM) Cloud Services Appliance (CSA) that was patched in 2021, a command injection vulnerability in Nice Linear eMerge E3 Series devices that was discovered in 2019 and patched just this year, and a Microsoft SharePoint Server code RCE vulnerability patched in May 2023.

[According to GreyNoise data](https://viz.greynoise.io/tags/ivanti-endpoint-manager-rce-attempt?days=30), 11 IPs have targeted the critical Ivanti EPM CSA bug tracked as [CVE-2021-44529](https://nvd.nist.gov/vuln/detail/CVE-2021-44529) in the last 30 days. GreyNoise researcher Ron Bowes [previously wrote](https://www.labs.greynoise.io/grimoire/2024-02-what-is-this-old-ivanti-exploit/) that the bug may be a backdoor originating from an open-source component called csrf-magic.

The Nice (formerly Nortek) bug, tracked as [CVE-2019-7256](https://nvd.nist.gov/vuln/detail/CVE-2019-7256), has a maximum CVSS score of 10 and affects the operating system used in Linear eMerge E3 Series building access control devices. The first confirmation of a patch being available came with a [CISA advisory published this month](https://www.cisa.gov/news-events/ics-advisories/icsa-24-065-01) despite [evidence of the flaw being exploited in denial-of-service (DoS) attacks](https://blog.sonicwall.com/en-us/2020/02/linear-emerge-e3-access-controller-actively-being-exploited/) as early as February 2020, [according to SecurityWeek](https://www.securityweek.com/exploited-building-access-system-vulnerability-patched-years-after-disclosure/).

The high-severity Microsoft bug tracked as [CVE-2023-24955](https://nvd.nist.gov/vuln/detail/CVE-2023-24955) requires an attacker to be authenticated as a site owner to achieve RCE. Security researcher Valentin Lobstein [previously noted](https://www.scmagazine.com/news/cisa-flags-active-exploitation-of-critical-microsoft-sharepoint-bug) that the flaw could be chained with the actively exploited privilege escalation flaw [CVE-2023-29357](https://nvd.nist.gov/vuln/detail/CVE-2023-29357).




## Tags:
***CVE's***: CVE-2021-44529 CVE-2023-48788 CVE-2023-29357 CVE-2024-21762 CVE-2019-7256 CVE-2023-24955 CVE-2022-42475

### Autogenerated tags:
sql microsoft fortinet rce forticlient ivanti kev epm cisa cve-2023-48788
