# A DNS flaw impacts a library used by millions of IoT devices
## A vulnerability in the domain name system (DNS) component of the uClibc library impacts millions of IoT products. Nozomi Networks warns of a vulnerability, tracked as CVE-2022-05-02, in the domain name system (DNS) component of the uClibc library which is used by a large number of IoT products. The flaw also affects DNS implementation of all versions of the uClibc-ng […]
## Information:

+ Link: https://securityaffairs.co/wordpress/130865/security/dns-vulnerability.html
+ Source: Security Affairs
+ Author: Pierluigi Paganini
+ Date published: 03 May 2022, 14:44
+ Date scraped: 03 May 2022, 15:00

## Article:
![Main article image](https://i0.wp.com/securityaffairs.co/wordpress/wp-content/uploads/2022/05/DNS.png?resize=300%2C300&ssl=1)


Nozomi Networks warns of a vulnerability, tracked as CVE-2022-05-02, in the domain name system (DNS) component of the [uClibc](https://www.uclibc.org/) library which is used by a large number of IoT products. The flaw also affects DNS implementation of all versions of the [uClibc-ng](https://www.uclibc-ng.org/) library, which is a fork specifically designed for OpenWRT, a common OS for routers used in various critical infrastructure sectors.


An attacker can exploit the vulnerability for DNS poisoning or DNS spoofing and redirect the victim to a malicious website instead of the legitimate one.


*“The flaw is caused by the predictability of transaction IDs included in the DNS requests generated by the library, which may allow attackers to perform DNS poisoning attacks against the target device.” reads the [advisory](https://www.nozominetworks.com/blog/nozomi-networks-discovers-unpatched-dns-bug-in-popular-c-standard-library-putting-iot-at-risk/) published by Nozomi Networks.*


The uClibc library is used by major vendors, including Linksys, Netgear, and Axis, or Linux distributions such as Embedded Gentoo. 


Security experts did not disclose the details of the flaw because the vendor has yet to address it.


The researchers from Nozomi discovered the issue by reviewing the trace of DNS requests performed by an IoT device in their test environment. They were able to determine the pattern of DNS requests performed from the output of Wireshark, the transaction ID is first incremental, then resets to the value 0x2, then is incremental again. The transaction ID of the requests was predictable, a circumstance that could allow an attacker to perform DNS poisoning under certain circumstances.


[![DNS](https://i0.wp.com/securityaffairs.co/wordpress/wp-content/uploads/2022/05/DNS.png?resize=1024%2C401&ssl=1)](https://i0.wp.com/securityaffairs.co/wordpress/wp-content/uploads/2022/05/DNS.png?ssl=1)
The researchers analyzed the executable and discovered that the problem for the creation of the DNS requests resides in the C standard library uClibc version 0.9.33.2 (`“libuClibc-0.9.33.2.so”`).


*“A source code review revealed that the uClibc library implements DNS requests by calling the internal “\_\_dns\_lookup” function, located in the source file “/libc/inet/resolv.c”.” continues the advisory. “Given that the transaction ID is now predictable, to exploit the vulnerability an attacker would need to craft a DNS response that contains the correct source port, as well as win the race against the legitimate DNS response incoming from the DNS server. Exploitability of the issue depends exactly on these factors. As the function does not apply any explicit source port randomization, it is likely that the issue can easily be exploited in a reliable way if the operating system is configured to use a fixed or predictable source port.”*


If the OS uses randomization of the source port, the only way to exploit the issue is to bruteforce the 16-bit source port value by sending multiple DNS responses, while simultaneously winning the race against the legitimate response.


*“As anticipated, as of the publication of this blog, the vulnerability is still unpatched. As stated [in a public conversation](https://mailman.openadk.org/mailman3/hyperkitty/list/devel@uclibc-ng.org/thread/S4UE7PFZOF3GY62JOYX56KYB37GCOQ2I/), the maintainer was unable to develop a fix for the vulnerability, hoping for help from the community. The vulnerability was disclosed to 200+ vendors invited to the VINCE case by CERT/CC since January 2022, and a 30-day notice was given to them before the public release.” concludes Nozomi.*



> **Please vote for Security Affairs as the best European Cybersecurity Blogger Awards 2022 – VOTE FOR YOUR WINNERS  
> Vote for me in the sections “The Underdogs – Best Personal (non-commercial) Security Blog” and “The Tech Whizz – Best Technical Blog” and others of your choice.  
> To nominate, please visit:**<https://docs.google.com/forms/d/e/1FAIpQLSfxxrxICiMZ9QM9iiPuMQIC-IoM-NpQMOsFZnJXrBQRYJGCOw/viewform>
> 
> 


Follow me on Twitter: [**@securityaffairs**](https://twitter.com/securityaffairs) and [**Facebook**](https://www.facebook.com/sec.affairs)




|  |  |
| --- | --- |
|  |  |


[**Pierluigi Paganini**](http://www.linkedin.com/pub/pierluigi-paganini/b/742/559)


**(**[**SecurityAffairs**](http://securityaffairs.co/wordpress/)**–** **hacking, domain name system)**




 
  


---


  




## Tags:
***ipv4-adresses***: 0.9.33.2
***urls***: https://docs.google.com/forms/d/e/1FAIpQLSfxxrxICiMZ9QM9iiPuMQIC-IoM-NpQMOsFZnJXrBQRYJGCOw/viewform

### Autogenerated tags:
dns nozomi uclibc
