# Threat actors exploit Apache ActiveMQ flaw to deliver the Godzilla Web Shell
## Researchers warn of a spike in attacks exploiting a now-patched flaw in Apache ActiveMQ to deliver the Godzilla web shell.
## Information:

+ Link: https://securityaffairs.com/157887/malware/apache-activemq-godzilla-web-shell.html
+ Source: Security Affairs
+ Author: Pierluigi Paganini
+ Date published: 22 January 2024, 11:19
+ Date scraped: 22 January 2024, 12:02

## Article:
![Main article image](https://securityaffairs.com/wp-content/uploads/2024/01/image-37.png)


Trustwave researchers observed a surge in attacks exploiting a now-patched flaw in Apache ActiveMQ, in many cases aimed at delivering a malicious code that borrows the code from the open-source web shell [Godzilla](https://github.com/BeichenDream/Godzilla). 


Threat actors conceal the web shell within an unknown binary format evading security and signature-based scanners. Once deployed, the ActiveMQ’s JSP engine compiles and executes the web shell.



In November 2023, researchers at Rapid7 [**reported**](https://securityaffairs.com/153454/hacking/apache-activemq-cve-2023-46604-hellokitty-ransomare.html) the suspected exploitation of the recently disclosed critical vulnerability [CVE-2023-46604](https://nvd.nist.gov/vuln/detail/CVE-2023-46604) in the Apache ActiveMQ.


[Apache ActiveMQ](https://activemq.apache.org/) is an open-source message broker software that serves as a message-oriented middleware (MOM) platform. It is developed by the Apache Software Foundation and written in Java. ActiveMQ provides messaging and communication capabilities to various applications, making it easier for them to exchange data and communicate asynchronously.


Rapid7 identified exploitation attempts of the CVE-2023-46604 flaw to deploy [HelloKitty ransomware](https://securityaffairs.com/152182/malware/hellokitty-ransomware-source-code-leaked.html) in two different customer environments.


[CVE-2023-46604](https://activemq.apache.org/security-advisories.data/CVE-2023-46604-announcement.txt) (CVSS score: 10.0) is a remote code execution vulnerability that impacts Apache ActiveMQ. A remote attacker with network access to a broker can exploit this flaw to run “arbitrary shell commands by manipulating serialized class types in the OpenWire protocol to cause the broker to instantiate any class on the classpath.”


Apache addressed the flaw with the release of new versions of ActiveMQ [on October 25, 2023](https://activemq.apache.org/components/classic/download/). The researchers pointed out that the proof-of-concept [exploit code](https://github.com/X1r0z/ActiveMQ-RCE) and [vulnerability details](https://paper.seebug.org/3058/) are both publicly available.


The vulnerability affects the following versions –


* ActiveMQ 5.18.0 before 5.18.3
* ActiveMQ 5.17.0 before 5.17.6
* ActiveMQ 5.16.0 before 5.16.7
* ActiveMQ before 5.15.16
* ActiveMQ Legacy OpenWire Module 5.18.0 before 5.18.3
* ActiveMQ Legacy OpenWire Module 5.17.0 before 5.17.6
* ActiveMQ Legacy OpenWire Module 5.16.0 before 5.16.7
* ActiveMQ Legacy OpenWire Module 5.8.0 before 5.15.16


In the attacks observed by Trustwave SpiderLabs, the malicious file was planted in the “admin” folder within the ActiveMQ installation directory. The folder contains the server scripts for the ActiveMQ administrative and web management console.


“Interestingly, the Jetty JSP engine which is the integrated web server in ActiveMQ, actually parsed, compiled and executed the embedded Java code that was encapsulated in the unknown binary.” reads the [analysis](https://www.trustwave.com/en-us/resources/blogs/spiderlabs-blog/apache-activemq-vulnerability-leads-to-stealthy-godzilla-webshell/) published by Trustwave. “Further examination of the Java code generated by Jetty showed that the web shell code was converted into Java code and therefore was executed.”


[![Apache ActiveMQ Godzilla web shell](https://i0.wp.com/securityaffairs.com/wp-content/uploads/2024/01/image-37.png?resize=902%2C546&ssl=1)](https://i0.wp.com/securityaffairs.com/wp-content/uploads/2024/01/image-37.png?ssl=1)


Once the web shell has been deployed, the threat actor can connect to it through the [Godzilla](https://github.com/BeichenDream/Godzilla) management user interface and achieve complete control over the target system.


The Godzilla Web Shell supports multiple functionalities including:


* Viewing network details
* Conducting port scans
* Executing Mimikatz commands
* Running Meterpreter commands
* Executing shell commands
* Remotely managing SQL databases
* Injecting shellcode into processes
* Handling file management tasks


The report includes Indicators of Compromise (IoCs).


Follow me on Twitter: [**@securityaffairs**](https://twitter.com/securityaffairs) and [**Facebook**](https://www.facebook.com/sec.affairs) and [**Mastodon**](https://infosec.exchange/@securityaffairs)


[**Pierluigi Paganini**](http://www.linkedin.com/pub/pierluigi-paganini/b/742/559)


**(**[**SecurityAffairs**](http://securityaffairs.co/wordpress/)**–** **hacking, ActiveMQ**)






---




---





## Tags:
***CVE's***: CVE-2023-46604

### Autogenerated tags:
activemq openwire trustwave godzilla cve-2023-46604
