# XSS flaw in WordPress WP-Members Plugin can lead to script injection
## A cross-site scripting vulnerability (XXS) in the WordPress WP-Members Membership plugin can lead to malicious script injection.
## Information:

+ Link: https://securityaffairs.com/161407/hacking/wordpress-wp-members-plugin-xss.html
+ Source: Security Affairs
+ Author: Pierluigi Paganini
+ Date published: 02 April 2024, 18:59
+ Date scraped: 02 April 2024, 20:18

## Article:
![Main article image](https://securityaffairs.com/wp-content/uploads/2024/04/image-2.png)



Researchers from Defiant’s Wordfence research team disclosed a cross-site scripting vulnerability (XXS) in the WordPress WP-Members Membership plugin that can lead to malicious script injection.


The Unauthenticated Stored Cross-Site Scripting vulnerability was reported to Wordfence by the WordPress developer [Webbernaut](https://www.wordfence.com/threat-intel/vulnerabilities/researchers/webbernaut) as part of the company [Bug Bounty Extravaganza](https://www.wordfence.com/threat-intel/bug-bounty-program/). 



Webbernaut received a $500 bounty. 


The [WP-Members Membership Plugin](https://wordpress.org/plugins/wp-members/) is currently installed on over 60,000 WordPress websites. 


*“The vulnerability allows threat actors to inject arbitrary JavaScript via the X-Forwarded-For header, used by the plugin for logging purposes.” reads the [advisory](https://www.wordfence.com/blog/2024/04/unauthenticated-stored-cross-site-scripting-vulnerability-patched-in-wp-members-membership-plugin-500-bounty-awarded/) published by Wordfence. “When viewed by an administrator, the malicious code is executed in the context of the administrator’s browser session and allows for the creation of malicious administrator users as well as changes to an affected site’s settings which could lead to a complete site takeover.”*


The flaw impacts all versions up to, and including, 3.4.9.2, the issue is due to insufficient input sanitization and output escaping. An unauthenticated attacker can trigger the flaw to inject arbitrary web scripts in pages that will execute whenever a user accesses an injected page which is the edit users page.


Wordfence states that the flaw was only partially patched in version 3.4.9.2 and fully patched in version 3.4.9.3.


In order to exploit this XSS, an attacker could intercept a registration request after filling out and submitting the registration form using a proxy. Then the attacker can modify the raw request to contain an X-Forwarded-For header set to a malicious payload enclosed in script tags.


[![WordPress WP-Members Membership plugin XSS](https://i0.wp.com/securityaffairs.com/wp-content/uploads/2024/04/image-2.png?resize=1024%2C767&ssl=1)](https://i0.wp.com/securityaffairs.com/wp-content/uploads/2024/04/image-2.png?ssl=1)


The request allows the creation of a user account with the details provided by the attacker.



The plugin stores the IP address of users who filed the registration form in their profile through the vulnerable rktgk\_get\_user\_ip function.


The rktgk\_get\_user\_ip function checks whether the request contains an HTTP\_CLIENT\_IP or HTTP\_X\_FORWARDED\_FOR header. If either header is present, the function uses that value as the user’s IP instead of the REMOTE\_ADDR variable, and then returns the provided value as the IP address. Since the input was not sanitized, an attacker can manipulate the HTTP headers supplying a malicious web script, which would then be stored as the user’s IP.


If an administrator edits or views this user account, the injected JavaScript will be present in the generated source code when the page loads.


“It is important to understand that this malicious code will be executed in the context of an administrator’s browser session and can be used to create malicious user accounts, redirect site visitors to other malicious sites and perform other malicious actions.” continues the advisory.


Follow me on Twitter: [**@securityaffairs**](https://twitter.com/securityaffairs) and [**Facebook**](https://www.facebook.com/sec.affairs) and [**Mastodon**](https://infosec.exchange/@securityaffairs)


[**Pierluigi Paganini**](http://www.linkedin.com/pub/pierluigi-paganini/b/742/559)


**(**[**SecurityAffairs**](http://securityaffairs.co/wordpress/)**–** **hacking,** **WordPress)**




---




---





## Tags:
***ipv4-adresses***: 3.4.9.2

### Autogenerated tags:
wordfence wordpress plugin ip
