# Eight Vulnerabilities Disclosed in the AI Development Supply Chain
## Details of eight vulnerabilities in the open source supply chain used to develop AI and ML models have been disclosed in a new report.
## Information:

+ Link: https://www.securityweek.com/eight-vulnerabilities-disclosed-in-the-ai-development-supply-chain/
+ Source: SecurityWeek
+ Author: Kevin Townsend
+ Date published: 16 February 2024, 12:27
+ Date scraped: 16 February 2024, 13:01

## Article:
![Main article image](https://www.securityweek.com/wp-content/uploads/2023/04/Low-Code-No-Code-Security.jpg)


**Details of eight vulnerabilities found in the open source supply chain used to develop in-house AI and ML models have been disclosed by AI cybersecurity startup [Protect AI](https://www.securityweek.com/new-offerings-from-protect-ai-venafi-tackle-software-supply-chain-security/). All have CVE numbers, one has critical severity, and seven have high severity.**


The vulnerabilities are disclosed via Protect AI’s February Vulnerability [Report](https://protectai.com/threat-research/february-vulnerability-report). They are:


* **CVE-2023-6975**: arbitrary file write in MLFLow, CVSS 9.8
* **CVE-2023-6753**: arbitrary file write on Windows in MLFlow, CVSS 9.6
* **CVE-2023-6730**: RCE in Hugging Face Transformers via RagRetriever.from\_pretrained(), CVSS 9.0
* **CVE-2023-6940**: server side template injection bypass in MLFlow, CVSS 9.0
* **CVE-2023-6976**: arbitrary file upload patch bypass in MLFlow, CVSS 8.8
* **CVE-2023-31036**: RCE via arbitrary file overwrite in Triton Inference Server, CVSS 7.5
* **CVE-2023-6909**: local file inclusion in MLFlow, CVSS 7.5
* **CVE-2024-0964**: LFI in Gradio, CVSS 7.5


The nature and vulnerability of open source code is well understood. For standard code development using OSS libraries, SBOMs are designed and used to provide some security surety. But SBOMs don’t work with open source used for AI/ML development.

**[ Learn More at the [2024 AI Risk Summit](https://www.airisksummit.com/) – June 2024, Ritz-Carlton, Half Moon Bay ]**


“Traditional SBOMs only tell you what’s happening in the code pipeline,” explained Daryan Dehghanpisheh, co-founder of Protect Ai (and former global leader for AI/ML solution architects at AWS). “When you build an AI application, you have three distinctly different pipelines where you must have full provenance. You have a code pipeline, you have a data pipeline, and more critically, you have the machine learning pipeline. That machine learning pipeline is where the AI/ML model is created. It relies on the data pipeline, and it feeds the code pipeline — but companies are blind to that middle machine learning pipeline.”

![A diagram of a data flow

Description automatically generated](https://lh7-us.googleusercontent.com/23RNMKQdjndvYrq0w_Z57rPPPR2a21mJcw1O2fbqR1AYqIp8OMH4T32EUx-CV6RTmngxmjxG8Ooexg7_NnTH5eC9O-Q2e-j61jKCiVTODn53dWE0MmgQBhCHdXx3hRr3A2FQsdytRdjC7DcxR_MX1A)


Protect AI has called for the development of an AI/ML BOM to supplement SBOMs (software) and PBOMs (product) in a separate [blog](https://protectai.com/blog/ml-bom-cyber-threats): “The AI/ML BOM specifically targets the elements of AI and machine learning systems. It addresses risks unique to AI, such as data poisoning and model bias, and requires continuous updates due to the evolving nature of AI models.”


Absent this AI/ML BOM, in-house developers are reliant on either their own expertise or that of third parties (such as Protect AI) to discover how vulnerabilities can be manipulated within the hidden machine learning pipeline to introduce flaws to the final model before deployment.

Protect AI has two basic methods for AI/ML model vulnerability detection: scanning and bounty hunters. Its [Guardian product](https://www.securityweek.com/new-offerings-from-protect-ai-venafi-tackle-software-supply-chain-security/) introduced in January 2024 can use the output of its AI/ML scanner (ModelScan) to provide a secure gateway. But it is the firm’s community of independent bounty hunters that are particularly effective at discovering new vulnerabilities.


The firm launched what it calls the world’s first AI/ML bug bounty program — which it calls huntr – in August 2023. “We now have close to 16,000 members of our community,” said Dehghanpisheh. “When we first launched in August, I think we were getting maybe three a week. Now we get north of 15 a day.”


The bounties are funded from Protect AI’s own capital (it raised [$35 million](https://www.securityweek.com/protect-ai-raises-35-million-to-protect-machine-learning-and-ai-assets/) in July 2023 just prior to launching huntr), but he believes it is money well-spent. Firstly, finding vulnerabilities highlights the complexity of a new technology that is neither well understood by the developers using the technology, nor the many traditional security companies who don’t understand the complexities of machine learning and artificial intelligence.


Secondly, the volume of vulnerabilities found and disclosed positions the firm as a leader in what he calls ‘AI/ML threat IQ’. “There are two components to this,” he continued. “The first is the Threat Reports on discovered vulnerabilities, and the second is our AI exploits tool that we give away for free.”

The third advantage is that having reached this position through the success of the huntr program, it is an effective lead generation tool. “The way I see it, paying those bounties is cheaper than paying a salesperson.”

The huntr program has proved successful in finding vulnerabilities and is likely to continue being successful. The monthly Threat Reports actively demonstrate the complexity of securing in-house developed ML/AI models by disclosing the vulnerabilities found by the hunters.

**Related**: [Don’t Expect Quick Fixes in ‘Red-Teaming’ of AI Models. Security Was an Afterthought](https://www.securityweek.com/dont-expect-quick-fixes-in-red-teaming-of-ai-models-security-was-an-afterthought/)


**Related**: [The Emerging Landscape of AI-Driven Cybersecurity Threats: A Look Ahead](https://www.securityweek.com/the-emerging-landscape-of-ai-driven-cybersecurity-threats-a-look-ahead/)


**Related**: [Addressing the State of AI’s Impact on Cyber Disinformation/Misinformation](https://www.securityweek.com/addressing-the-state-of-ais-impact-on-cyber-disinformation-misinformation/)


**Related**: [CISA Outlines AI-Related Cybersecurity Efforts](https://www.securityweek.com/cisa-outlines-ai-related-cybersecurity-efforts/)





## Tags:
***CVE's***: CVE-2023-6730 CVE-2023-6976 CVE-2023-6753 CVE-2023-31036 CVE-2023-6940 CVE-2023-6909 CVE-2024-0964 CVE-2023-6975

### Autogenerated tags:
ai/ml cvss mlflow sboms huntr in-house cybersecurity
