# Decoding the Primary Devils Behind Data Breaches
## By Reuben Koh, Director, Security Strategy - Asia Pacific &amp; Japan, Akamai Technologies  The cybersecurity landscape is rife with evolving threats,
## Information:

+ Link: https://thecyberexpress.com/protecting-against-data-breaches/
+ Source: The Cyber Express
+ Author: Ashish Khaitan
+ Date published: 26 May 2024, 17:46
+ Date scraped: 27 May 2024, 01:01

## Article:
![Main article image](https://cf276dd8.rocketcdn.me/wp-content/uploads/Data-breaches-e1716548306120.webp)


***By [Reuben Koh](https://www.linkedin.com/in/reubenkoh/?original_referer=https%3A%2F%2Fwww%2Egoogle%2Ecom%2F&originalSubdomain=sg), Director, Security Strategy – Asia Pacific & Japan, Akamai Technologies***


The cybersecurity landscape is rife with evolving threats, as highlighted by recent reports and surveys. External actors remain a predominant force, accounting for [83%](https://www.verizon.com/business/en-gb/resources/reports/dbir/?trk=article-ssr-frontend-pulse_little-text-block) of breaches, with stolen credentials being their weapon of choice in nearly half of these incidents. DNS attacks continue to plague organizations, causing app downtime of targeted entities, and web application attacks follow closely behind. Ransomware emerges as a formidable threat, dominating cybercrime with over [72%](https://www.statista.com/statistics/204457/businesses-ransomware-attack-rate/#:~:text=As%20of%202023%2C%20over%2072,far%20the%20highest%20figure%20reported.) of attacks motivated by extortion.


As cyber threats continue to escalate in sophistication and frequency, organizations must prioritize proactive security measures to safeguard their [data](https://thecyberexpress.com/what-is-data/), systems, and financial stability. Data breaches are a prevalent theme in today’s headlines — posing significant [risks](https://thecyberexpress.com/what-are-risks-in-cybersecurity/) to businesses, their customers, and partners. One of the first steps to safeguarding your organization’s sensitive data is understanding the primary causes of data breaches. Despite these risks, the adoption of robust security measures lags, with less than 1% of businesses currently employing a mature zero-trust model.


### Critical weaknesses behind Data Breaches


#### Weak and stolen credentials


Although [hacking](https://thecyberexpress.com/what-is-hacking/) attacks are frequently cited as the leading cause of data breaches, it’s often the vulnerability of compromised or weak passwords or personal data that opportunistic hackers exploit. Statistics show that four out of five breaches are partially attributed to the use of weak or stolen passwords.


To mitigate the risk of hackers executing an account takeover on sensitive accounts, businesses should consider deploying fraud protection tools. These act as proactive defenses, significantly reducing the likelihood of unauthorized access and enhancing the overall security of your accounts. Bot Managers also address challenges associated with bot traffic on websites and applications.


It’s designed to identify, manage, and mitigate both malicious and non-malicious bot traffic, ensuring a more secure and efficient online experience. To further protect your organization, it’s also advisable to implement enterprise single sign-on (SSO), establish strong password hygiene, and set up phishing-resistant [multi-factor authentication (MFA)](https://thecyberexpress.com/multi-factor-authentication-not-enough/) across computer systems — this way, you can prevent personally identifiable information from getting into the wrong person’s hands.


#### Backdoor and application vulnerabilities


Exploiting backdoor and application [vulnerabilities](https://thecyberexpress.com/what-are-vulnerabilities/) is a favored strategy among cybercriminals. When software applications are poorly written or network systems are inadequately designed, hackers will continuously probe for weaknesses to find open doors that grant them direct access to valuable data and confidential information.


Ensuring your web application firewall (WAF) is regularly updated and well-managed helps mitigate these vulnerabilities. Due to constantly shifting attack techniques, organizations should also use advanced artificial intelligence (AI) powered security solutions to [identify vulnerabilities](https://thecyberexpress.com/d-link-nas-vulnerabilities/) and protect against unauthorized access.


The WAF should be a robust security solution designed to protect web applications from a variety of cyber threats, including data breaches. It can serve as a barrier between web applications and the internet, scrutinizing and filtering HTTP traffic to identify and mitigate potential vulnerabilities and attacks.


#### Malware


The prevalence of both direct and indirect [malware](https://thecyberexpress.com/what-is-malware/) is increasing. Malware (inherently malicious software) is loaded onto a system by unsuspecting victims, providing hackers with opportunities to not only exploit the affected system but also potentially spread to other connected systems. This type of malware poses a significant security threat as it allows malicious insiders access to confidential information and provides the ability to steal data for financial gain.


Implementing an advanced malware protection solution at multiple ingress points in the network can significantly enhance your security posture, reducing the risk that employees will fall victim to malicious software. By leveraging cutting-edge data security in malware detection and prevention, organizations can fortify their data protection defenses against evolving cyber threats and [security breaches](https://thecyberexpress.com/cyberattacks-on-israel-cybersecurity/).


#### Social Engineering


Cybercriminals and hackers can shorten the effort of establishing unauthorized access by persuading individuals with legitimate data access to do it for them.  Phone calls, phishing scams, malicious links (often sent via email, text, or social media), and other forms of social engineering such as [deep fakes](https://thecyberexpress.com/tce-cyberwatch-weekly-round-up-3/) are now commonly used to manipulate individuals into unwittingly granting access or divulging sensitive information like login credentials to cybercriminals.


Such information can result in a data leak, in which hackers recycle, reuse, and trade-sensitive data like Social Security numbers or personal data for the purpose of identity theft and other illicit activities. Exercising vigilance in sharing sensitive information with external parties is quintessential. Awareness of the information being shared, and verification of legitimacy can serve as a simple yet effective defense against [social engineering tactics](https://thecyberexpress.com/social-engineering-in-the-age-of-ai/).


#### Ransomware


Ransomware is a type of malicious software designed to restrict access to a computer system or files until a sum of money, or ransom, is paid. It typically encrypts the victim’s files or locks their system, rendering it inaccessible, and then demands payment (often in cryptocurrency) in exchange for restoring access. Ensuring the safety and protection of your infrastructure against external threats is paramount. Organizations must be confident that attackers haven’t gained access to their systems and aren’t using them for [malicious activities](https://thecyberexpress.com/internet-traffic-hacking-exploit-platforms/).


Implementing a robust visibility and protection solution, such as microsegmentation will be helpful in this scenario. Microsegmentation offers a straightforward, fast, and intuitive approach to enforce Zero Trust principles within your network. This solution is designed to prevent lateral movement by visualizing activity in your IT environments, implementing precise microsegmentation policies, and swiftly detecting potential breaches.


#### Improper configuration and exposure via APIs


Misconfigured settings or parameters encompass various issues such as default passwords, open ports, or weak encryption. Such inadequacies can create vulnerabilities that hackers may exploit to gain unauthorized access to systems or data, leading to security breaches and other malicious activities. Inadequate configuration settings and vulnerabilities in APIs can expose them to a large number of security risks.


Addressing and rectifying these issues is crucial to prevent unauthorized access and potential data breaches. Consider implementing proper API security and governance from code time to runtime, including regularly auditing API security measures, which are critical steps to enhance overall protection.


To address misconfiguration and exposure via APIs, businesses must rely not just on their WAF but also on deploying an advanced [API security solution](https://thecyberexpress.com/effective-api-security-strategy/) to protect against evasive API abuses. This solution can offer comprehensive visibility, identifying vulnerabilities and detecting potential threats and abuses related to APIs.


Moreover, it assists in helping organizations establish a more proactive approach to security by lowering the overall attack surface of critical APIs from secure development to runtime protection, effectively reinforcing their overall API security posture.


#### DNS attacks


Domain Name System (DNS) attacks are malicious activities that target the DNS infrastructure to disrupt or manipulate the resolution of domain names into IP addresses. These attacks can have various objectives, including causing service disruptions using distributed denial of service (DDoS), redirecting users to malicious websites, or gaining unauthorized access to [sensitive information](https://thecyberexpress.com/alleged-luxor-data-breach/).


Organisations must deploy a strong cloud-based authoritative DNS Service ensuring 100% availability and protection against multi-vector DNS attacks like flooding and water torture attacks. Implementing best practices and deploying security countermeasures that are able to withstand the attack volume, are crucial steps to take when mitigating these attacks.


### Conclusion


Data breaches continue to pose a pervasive risk across various sectors, affecting organizations of all sizes and types — from healthcare and finance to e-commerce and retail. By proactively identifying potential vulnerabilities, organizations can reduce the likelihood of successful cyberattacks.


Investing in robust security measures that enforce a Zero Trust Security model and ensuring their applications, APIs, and DNS services are continuously protected against cyber threats, helps mitigate financial risks associated with breaches, such as regulatory fines, legal fees, and revenue loss.


By minimizing the impact of breaches, organizations can also maintain business continuity — and avoid disruptions to normal operations or damaged reputations. Overall, a comprehensive understanding of breach causes, and the implementation of appropriate security measures are vital for [protecting data](https://thecyberexpress.com/medisecure-data-breach-incident-update/), minimizing risk, and ensuring the long-term success of all organizations.


*Disclaimer: The views and opinions expressed in this guest post are solely those of the author(s) and do not necessarily reflect the official policy or position of [The Cyber Express](https://thecyberexpress.com/). Any content provided by the author is of their opinion and is not intended to malign any religion, ethnic group, club, organization, company, individual, or anyone or anything.*





## Tags:


### Autogenerated tags:
dns malware api ransomware cybercriminals microsegmentation
