# Apache Superset Vulnerability: Insecure Default Configuration Exposes Servers to RCE Attacks
## A dangerous default configuration in Apache Superset has been discovered, which (CVE-2023-27524) could allow attackers to gain remote code execution.
## Information:

+ Link: https://thehackernews.com/2023/04/apache-superset-vulnerability-insecure.html
+ Source: The Hacker News
+ Author: Ravie Lakshmanan
+ Date published: 26 April 2023, 09:29
+ Date scraped: 26 April 2023, 10:00

## Article:
![Main article image](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEgE-0pPfZHvy6Fqzcvfu7iN80u99Gq8m5ftl2LvpBlhSnolNR_VvSmBybNrvSkL7kRegpKVDoOMaRIh1VwL6IbxEIpCek3vxezuJ380FeC7F-lg3py3TgSeV9N_3LVb1x81WhvXfQW26GpCvMDM0LbU0jBJJOeOs09dnuKy6_gcuKKGnnvaxJBmTJQX/s728-e3650/apache-superset.png)


The maintainers of the [Apache Superset](https://github.com/apache/superset) open source data visualization software have released fixes to plug an insecure default configuration that could lead to remote code execution.


The vulnerability, tracked as [**CVE-2023-27524**](https://nvd.nist.gov/vuln/detail/CVE-2023-27524) (CVSS score: 8.9), impacts versions up to and including 2.0.1 and relates to the use of a default SECRET\_KEY that could be abused by attackers to authenticate and access unauthorized resources on internet-exposed installations.


Naveen Sunkavally, the chief architect at Horizon3.ai, described the issue as "a dangerous default configuration in Apache Superset that allows an unauth attacker to gain remote code execution, harvest credentials, and compromise data."


It's worth noting that the flaw does not affect Superset instances that have changed the default value for the SECRET\_KEY config to a more cryptographically secure random string.


The cybersecurity firm, which found that the SECRET\_KEY is defaulted to the value "\x02\x01thisismyscretkey\x01\x02\\e\\y\\y\\h" at install time, said that 918 out of 1,288 publicly-accessible servers were using the default configuration in October 2021.


An attacker who had knowledge of the secret key could then sign in to these servers as an administrator by forging a session cookie and seize control of the systems.


On January 11, 2022, the project maintainers [attempted](https://github.com/apache/superset/commit/412189fcb73268ddd4829d2fdb8381c5e47595ce) to rectify the problem by rotating the SECRET\_KEY value to "CHANGE\_ME\_TO\_A\_COMPLEX\_RANDOM\_SECRET" in the Python code along with [user instructions](https://github.com/apache/superset/pull/17984) to override it.


[![Apache Superset Vulnerability](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAQAAAC1HAwCAAAAC0lEQVR42mP8Xw8AAoMBgDTD2qgAAAAASUVORK5CYII=)](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEg2aqrBH4lYkMUJCWFtQtZiLuRf-tC7fCQP-KGXrjs4aUVlisnRdmWrtyS0Qhi89aAiaPylsvPQRLrZ0m-S8vlWAbkgZTslMYCWmK3APXStjojpy9e0kBw4xbYstp7V2shAFOySXN-h8oCeSwMHzPBz9a-bPfn4kQtvvRIsMe0VJ6stGPn3Gu6Cdhi3/s728-e365/apache-exploit.png)
Horizon3.ai said it further found two additional SECRET\_KEY configurations that were assigned the default values "[USE\_YOUR\_OWN\_SECURE\_RANDOM\_KEY](https://superset.apache.org/docs/installation/configuring-superset/)" and "[thisISaSECRET\_1234](https://github.com/apache/superset/blob/85da86dc81cf9f5c4791a817befd3d7961ce97ac/helm/superset/templates/_helpers.tpl)."


An expanded search conducted in February 2023 with these four keys unearthed 3,176 instances, out of which 2,124 were using one of the default keys. Some of those affected include large corporations, small companies, government agencies, and universities.


Following responsible disclosure to the Apache security team a second time, a new update ([version 2.1](https://github.com/apache/superset/releases/tag/2.1.0)) was released on April 5, 2023, to plug the security hole by preventing the server from starting up altogether if it's configured with the default SECRET\_KEY.


"This fix is not foolproof though as it's still possible to run Superset with a default SECRET\_KEY if it's installed through a docker-compose file or a helm template," Sunkavally [said](https://www.horizon3.ai/cve-2023-27524-insecure-default-configuration-in-apache-superset-leads-to-remote-code-execution/).


"The docker-compose file contains a new default SECRET\_KEY of TEST\_NON\_DEV\_SECRET that we suspect some users will unwittingly run Superset with. Some configurations also set admin/admin as the default credential for the admin user."


Horizon3.ai has also made available a [Python script](https://github.com/horizon3ai/CVE-2023-27524) that can be used to determine if Superset instances are susceptible to the flaw.


"It's commonly accepted that users don't read documentation and applications should be designed to force users along a path where they have no choice but to be secure by default," Sunkavally concluded. "The best approach is to take the choice away from users and require them to take deliberate actions to be purposefully insecure."



  





## Tags:
***CVE's***: CVE-2023-27524
***email-adresses***: chiefarchitect@horizon3.ai

### Autogenerated tags:
secret_key sunkavally horizon3.ai
