# Chinese and Russian Hackers Using SILKLOADER Malware to Evade Detection
## Threat actors from Chinese and Russian cybercriminal ecosystems have been observed using a new malware designed to load Cobalt Strike.
## Information:

+ Link: https://thehackernews.com/2023/03/chinese-and-russian-hackers-using.html
+ Source: The Hacker News
+ Author: Ravie Lakshmanan
+ Date published: 16 March 2023, 15:30
+ Date scraped: 16 March 2023, 16:00

## Article:
![Main article image](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEgvjx7jhnI64zGtr3mwvWZhKJesdDTGSZ-NT88iZ4YWw0uK-QNJ3kdcOpGhPu6y_JZOrhDUDQNHhgGhjQG8t-eSwnT_gP-Wnld6ynAak4YgDoG-oCz9M2bVku_O4ZuvOzRhDHfRKhgF7meOrLPKQQwTTXoQjmNhBLIT_0gh57RMSVumuSvUcbnK9ASl/s728-e3650/cobalt.png)


Threat activity clusters affiliated with the Chinese and Russian cybercriminal ecosystems have been observed using a new piece of malware that's designed to load Cobalt Strike onto infected machines.


Dubbed **SILKLOADER** by Finnish cybersecurity company WithSecure, the malware leverages [DLL side-loading techniques](https://attack.mitre.org/techniques/T1574/002/) to deliver commercial adversary simulation software.


The development comes as [improved detection capabilities](https://thehackernews.com/2022/11/google-identifies-34-cracked-versions.html) against Cobalt Strike, a legitimate post-exploitation tool used for red team operations, is forcing threat actors to [seek alternative options](https://thehackernews.com/2023/02/new-ex-22-tool-empowers-hackers-with.html) or concoct new ways to propagate the framework to evade detection.


"The most common of these include adding complexity to the auto-generated beacon or stager payloads via the utilization of packers, crypters, loaders, or similar techniques," WithSecure researchers [said](https://labs.withsecure.com/publications/silkloader).


SILKLOADER joins other loaders such as KoboldLoader, MagnetLoader, and LithiumLoader that have been [recently discovered](https://unit42.paloaltonetworks.com/cobalt-strike-memory-analysis/) incorporating Cobalt Strike components.


It also shares overlaps with LithiumLoader in that both employ the DLL side-loading method to hijack a legitimate application with the goal of running a separate, malicious dynamic link library ([DLL](https://learn.microsoft.com/en-us/troubleshoot/windows-client/deployment/dynamic-link-library)).


SILKLOADER achieves this via specially crafted libvlc.dll files that are dropped alongside a legitimate but renamed VLC media player binary (Charmap.exe).


WithSecure said it identified the shellcode loader following an analysis of "several human-operated intrusions" targeting various entities spanning a wide range of organizations located in Brazil, France, and Taiwan in Q4 2022.


Although these attacks were unsuccessful, the activity is suspected to be a lead-up to ransomware deployments, with the tactics and tooling "heavily overlapping" with those attributed to the [operators](https://thehackernews.com/2023/01/rackspace-confirms-play-ransomware-gang.html) of the [Play ransomware](https://infosec.exchange/@SophosXOps/109677906162017090).


In one attack aimed at an unnamed French social welfare organization, the threat actor gained a foothold into the network by exploiting a compromised Fortinet SSL VPN appliance to stage Cobalt Strike beacons.


"The threat actor maintained a foothold in this organization for several months," WithSecure said. "During this time, they performed discovery and credential stealing activities, followed by deployment of multiple Cobalt Strike beacons."


But when this attempt failed, the adversary switched to using SILKLOADER to bypass detection and deliver the beacon payload.


[![SILKLOADER Malware](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAQAAAC1HAwCAAAAC0lEQVR42mP8Xw8AAoMBgDTD2qgAAAAASUVORK5CYII=)](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEj9CdVhEX93_3HzaRwWFyW4LLbE2FahX41JrRCWseFxF22Os8ih-yTjLBTkKc_Z0PTW6WvUIJiViYnM_fIYpAI8CSMDIoV72JeySDlV_5l0hNc8GWaBH7SUoiaffjbVaDBI-UJ8zR5jJvnouOMY3rcLU8rG_R8V4Ru2gBDhHaB5eEGpXgDaCFemodcO/s728-e365/hacker.png)
That's not all. Another loader known as BAILLOADER, which is also used to distribute Cobalt Strike beacons, has been linked to attacks involving [Quantum ransomware](https://darktrace.com/blog/when-speedy-attacks-arent-enough-prolonging-quantum-ransomware), [GootLoader](https://thehackernews.com/2023/01/australian-healthcare-sector-targeted.html), and the [IcedID trojan](https://thehackernews.com/2023/01/icedid-malware-strikes-again-active.html) in recent months.


BAILLOADER, for its part, is said to exhibit similarities with a crypter codenamed [Tron](https://securityintelligence.com/posts/itg23-crypters-cooperation-between-cybercriminal-groups/#:~:text=view%20full%20table-,Tron,-Tron%20crypter%20first) that has been put to use by different adversaries to distribute Emotet, TrickBot, BazarLoader, IcedID, Conti ransomware, and Cobalt Strike.


This has given rise to the possibility that disparate threat actors share Cobalt Strike beacons, crypters, and infrastructure provided by third-party affiliates to service multiple intrusions utilizing different tactics.


In other words, SILKLOADER is likely being offered as an off-the-shelf loader through a Packer-as-a-Service program to Russian-based threat actors.


"This loader is being provided either directly to ransomware groups or possibly via groups offering Cobalt Strike/Infrastructure-as-a-Service to trusted affiliates," WithSecure said.


"Most of these affiliates appear to have been part of or have had close working relationships with the [Conti group](https://thehackernews.com/2022/07/trickbot-malware-shifted-its-focus-on.html), its members, and offspring after its [alleged shutdown](https://thehackernews.com/2022/05/conti-ransomware-gang-shut-down-after.html)."


SILKLOADER samples analyzed by the company show that early versions of the malware date back to the start of 2022, with the loader exclusively put to use in different attacks targeting victims in China and Hong Kong.


The shift from East Asian targets to other countries such as Brazil and France is believed to have occurred around July 2022, after which all SILKLOADER-related incidents have been attributed to Russian cybercriminal actors.


This has further given way to a hypothesis that "SILKLOADER was originally written by threat actors acting within the Chinese cybercriminal ecosystem" and that the "loader was used by the threat actors within this nexus at least as early as May 2022 till July 2022."


"The builder or source code was later acquired by a threat actor within the Russian cybercriminal ecosystem between July 2022 and September 2022," WithSecure said, adding, "the original Chinese author sold the loader to a Russian threat actor once they no longer had any use for it."


Both SILKLOADER and BAILLOADER are just the latest examples of threat actors refining and retooling their approaches to stay ahead of the detection curve.


"As the cybercriminal ecosystem becomes more and more modularized via [service offerings](https://www.microsoft.com/en-us/security/blog/2022/05/09/ransomware-as-a-service-understanding-the-cybercrime-gig-economy-and-how-to-protect-yourself/), it is no longer possible to attribute attacks to threat groups simply by 


linking them to specific components within their attacks," WithSecure researchers concluded.


  





## Tags:


### Autogenerated tags:
silkloader withsecure cybercriminal ransomware malware dll bailloader
