# Critical libwebp Vulnerability Under Active Exploitation - Gets Maximum CVSS Score
## Libwebp image library under attack! A new CVE-2023-5129 has emerged, scoring a maximum 10.0 on CVSS. Get the details now
## Information:

+ Link: https://thehackernews.com/2023/09/new-libwebp-vulnerability-under-active.html
+ Source: The Hacker News
+ Author: THN
+ Date published: 27 September 2023, 10:53
+ Date scraped: 27 September 2023, 06:00

## Article:
![Main article image](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEhaIkkNqC0Hj2nUAQXg12Ly7mOj1dnxzi5y6ZU_uMyyjwkn4bT5uJ7xz7hmv92p4ABcvatmeUDJtkUJCDE1jGk6qUCXMyX5NHvCsRQU3LxgwvA1vUYkZEl1SPi_CzYzjch0MwzoJRcWXqS4F6_WGqbo_yMszE_d5JLBY4hFkOwwrJWcbLIpEW-iiQ3XhNlM/s728-rw-ft-e30/webp.jpg)


Google has assigned a new CVE identifier for a critical security flaw in the libwebp image library for rendering images in the [WebP format](https://developers.google.com/speed/webp) that has come under active exploitation in the wild.


Tracked as [**CVE-2023-5129**](https://nvd.nist.gov/vuln/detail/CVE-2023-5129), the issue has been given the maximum severity score of 10.0 on the CVSS rating system. It has been described as an issue rooted in the [Huffman coding algorithm](https://en.wikipedia.org/wiki/Huffman_coding) -


*With a specially crafted WebP lossless file, libwebp may write data out of bounds to the heap. The ReadHuffmanCodes() function allocates the HuffmanCode buffer with a size that comes from an array of precomputed sizes: kTableSize. The color\_cache\_bits value defines which size to use. The kTableSize array only takes into account sizes for 8-bit first-level table lookups but not second-level table lookups. libwebp allows codes that are up to 15-bit (MAX\_ALLOWED\_CODE\_LENGTH). When BuildHuffmanTable() attempts to fill the second-level tables it may write data out-of-bounds. The OOB write to the undersized array happens in ReplicateValue.*


The development comes after [Apple](https://thehackernews.com/2023/09/apple-rushes-to-patch-zero-day-flaws.html), [Google](https://thehackernews.com/2023/09/google-rushes-to-patch-critical-chrome.html), and [Mozilla](https://thehackernews.com/2023/09/mozilla-rushes-to-patch-webp-critical.html) released fixes to contain a bug – tracked separately as CVE-2023-41064 and CVE-2023-4863 – that could cause arbitrary code execution when processing a specially crafted image. Both flaws are suspected to [address the same underlying problem](https://thehackernews.com/2023/09/apple-rushes-to-patch-3-new-zero-day.html) in the library.


[![Cybersecurity](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEjPYBKMZbU-7Y7Kg3jq6dgh_5dNBqpJMQZyBnu7A58Cl9-Hf3Zqlp6O7GKltaeaspPcedrN2-3WCGOvSx55C92iJOqEdWBLCE6RGwVakDy6TsH2P4xv2Vcu4oSW3hat-7_q1c_MTiOdDXb3niTcU9DAgkJ__W9jQIcIDRZOA7cx6KqCxchAOHDOf8wyQIda/s728-e30/bb-d.png)](https://thn.news/iEqhOvqh)
According to the Citizen Lab, CVE-2023-41064 is said to have been chained with 2023-41061 as part of a zero-click iMessage exploit chain named BLASTPASS to deploy a mercenary spyware known as Pegasus. Additional technical details are currently unknown.


But the decision to "wrongly scope" CVE-2023-4863 as a vulnerability in Google Chrome belied the fact that it also virtually affects every other application that relies on the libwebp library to process WebP images, indicating it had a broader impact than previously thought.


An analysis from Rezillion last week revealed a laundry list of widely used applications, code libraries, frameworks, and operating systems that are vulnerable to CVE-2023-4863.


"This package stands out for its efficiency, outperforming JPEG and PNG in terms of size and speed," the company [said](https://www.rezilion.com/blog/rezilion-researchers-uncover-new-details-on-severity-of-google-chrome-zero-day-vulnerability-cve-2023-4863/). "Consequently, a multitude of software, applications, and packages have adopted this library, or even adopted packages that libwebp is their dependency."


"The sheer prevalence of libwebp extends the attack surface significantly, raising serious concerns for both users and organizations."


The disclosure arrives as Google [expanded](https://chromereleases.googleblog.com/2023/09/stable-channel-update-for-chromeos.html) fixes for CVE-2023-4863 to include the Stable channel for ChromeOS and ChromeOS Flex with the release of version 15572.50.0 (browser version 117.0.5938.115).


UPCOMING WEBINAR[Fight AI with AI — Battling Cyber Threats with Next-Gen AI Tools](https://thehacker.news/ai-cyberattacks?source=inside)Ready to tackle new AI-driven cybersecurity challenges? Join our insightful webinar with Zscaler to address the growing threat of generative AI in cybersecurity.

[Claim Your Spot](https://thehacker.news/ai-cyberattacks?source=inside)
It also follows new details published by Google Project Zero regarding the in-the-wild exploitation of [CVE-2023-0266](https://nvd.nist.gov/vuln/detail/CVE-2023-0266) and [CVE-2023-26083](https://nvd.nist.gov/vuln/detail/cve-2023-26083) in December 2022 by [commercial spyware vendors](https://thehackernews.com/2023/03/spyware-vendors-caught-exploiting-zero.html) to target Android devices from Samsung in the U.A.E. and obtain kernel arbitrary read/write access.


The flaws are believed to have been put to use alongside three other flaws – [CVE-2022-4262](https://nvd.nist.gov/vuln/detail/CVE-2022-4262), [CVE-2022-3038](https://nvd.nist.gov/vuln/detail/CVE-2022-3038), [CVE-2022-22706](https://nvd.nist.gov/vuln/detail/CVE-2022-22706) – by a customer or partner of a Spanish spyware company known as Variston IT.


"It is also particularly noteworthy that this attacker created an exploit chain using multiple bugs from kernel GPU drivers," security researcher Seth Jenkins [said](https://googleprojectzero.blogspot.com/2023/09/analyzing-modern-in-wild-android-exploit.html). "These third-party Android drivers have varying degrees of code quality and regularity of maintenance, and this represents a notable opportunity for attackers."


  





## Tags:
***CVE's***: CVE-2023-5129 CVE-2023-4863 CVE-2022-22706 CVE-2022-4262 CVE-2023-41064 CVE-2023-26083 CVE-2022-3038 CVE-2023-0266

### Autogenerated tags:
libwebp google cve-2023-4863 webp spyware
