# DevOps Dilemma: How Can CISOs Regain Control in the Age of Speed?
## In the age of DevOps, CISOs must ensure security is integrated from the start. Discover strategies for effective collaboration with DevOps teams to pr
## Information:

+ Link: https://thehackernews.com/2024/05/devops-dilemma-how-can-cisos-regain.html
+ Source: The Hacker News
+ Author: The Hacker News
+ Date published: 24 May 2024, 16:05
+ Date scraped: 24 May 2024, 11:07

## Article:
![Main article image](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEij92OQITp179Lh8GyMrrxHpgOHGq-opbSJFwmj9RmB-YK_-KfdyCwvk9gmphCXTFXS17_xp9KqhfNi4tWF2A9FIQJV9ngNl-G4feZOMJPCHAnVWwaNeoK-z3Rr1hBtDcIogV-TVUklEhMtEqqwo09bjcJt9x3fGuzwnsul42HMmJI4w3Dn4mufDxtoYk0B/s728-rw-e365/main.png)


**Introduction**[#](#introduction)
----------------------------------


The infamous **[Colonial](https://www.techtarget.com/whatis/feature/Colonial-Pipeline-hack-explained-Everything-you-need-to-know)** pipeline ransomware attack (2021) and **[SolarWinds](https://www.techtarget.com/whatis/feature/SolarWinds-hack-explained-Everything-you-need-to-know)** supply chain attack (2020) were more than data leaks; they were seismic shifts in cybersecurity. These attacks exposed a critical challenge for Chief Information Security Officers (**CISOs**): holding their ground while maintaining control over cloud security in the accelerating world of DevOps. The problem was emphasized by the **[Capital One](https://www.capitalone.com/digital/facts2019/)** data breach (2019), **[Epsilon](https://www.wsj.com/articles/publicis-groupes-epsilon-to-pay-150-million-to-resolve-customer-data-case-11611792292)** data breach (2019), **[Magecart](https://www.akamai.com/blog/security-research/magecart-new-technique-404-pages-skimmer)** compromises (ongoing), and **[MongoDB](https://www.securityweek.com/mongodb-confirms-hack-says-customer-data-stolen/)** breaches (2023-), where hackers exploited a misconfigured AWS S3 bucket. Strong collaboration between CISOs and DevOps teams on proper cloud security configurations could have prevented the breaches.


More than the fight against hackers and the consequences of their attacks, several important problems stand out —the evolution of CISO's role and responsibilities and the challenge of improving cloud security, and how security operations teams collaborate with business units in the frenzy of digital transformation.


Observing SecOps vs. DevOps conflicts within organizations of different types, we'll try to navigate a complex landscape of cybersecurity leadership, particularly their dynamic relationship with the Chief Technology Officer (**CTO**). As the role of CISO becomes more important than ever, we will focus on further empowering CISOs to become influential voices in decision-making, ensuring security is taking its rightful place in DevOps practices. 


We will also suggest some ways for CISOs to communicate with IT leadership, in order to educate and increase awareness of pressing security matters. Ultimately, only strong partnerships between CISOs, DevOps teams, and IT management can improve development processes that fuel innovation without compromising security.


**The stakes for a CISO are higher than ever**[#](#the-stakes-for-a-ciso-are-higher-than-ever)
----------------------------------------------------------------------------------------------


Imagine a race car speeding down the development track. The CTO, at the wheel, pushes for breakneck innovation. But in the backseat, the CISO sweats, gripping the metaphorical handbrake of security. This is the ever-present dilemma for CISOs in the age of DevOps: *maintaining control over security* in a lightning-fast development environment.


We can agree that previously, security often came as an afterthought, bolted onto applications long after they were built. DevOps, while promoting agility, can introduce vulnerabilities if security isn't taken care of from the start. Successful development teams focused on speed might unintentionally introduce security gaps. Legacy security approaches, reliant on manual processes and limited resources, simply can't keep up with the breakneck pace of DevOps.


[![DevOps](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEimXjVhxlfa3GVWfDH0hC7ckFf0LGobjqmD8bgRV3ulFCU8iXhfX9pOl3_5jujGzgB35bwovJ0mHcjFhETCYFUzbHHifRVbH7dV7yWIkW9A7PJdlQy4vcA1vhQmt0Kuz8i2yYsuWgkplRQCiVJqg8RzJB5rlDhOa_eft4-tZXuK-oTF128NPpw2w9B74PYH/s728-rw-e365/2.jpg)](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEimXjVhxlfa3GVWfDH0hC7ckFf0LGobjqmD8bgRV3ulFCU8iXhfX9pOl3_5jujGzgB35bwovJ0mHcjFhETCYFUzbHHifRVbH7dV7yWIkW9A7PJdlQy4vcA1vhQmt0Kuz8i2yYsuWgkplRQCiVJqg8RzJB5rlDhOa_eft4-tZXuK-oTF128NPpw2w9B74PYH/s728-rw-e365/2.jpg)
One view of the modern view of IT management places the CTO at the forefront of tech-related business concerns, including moving all the infrastructure to the cloud, while the CISO focuses on security, and securing the cloud becomes one of the top priorities. The pace of change and the completely new architecture, in the case of the cloud, present new challenges for CISOs who face a constantly changing environment. It's important to adapt their communication style to effectively collaborate with CTOs who are increasingly focused on bringing innovations and driving business growth.


### **Real-world consequences for CISO**[#](#realworld-consequences-for-ciso)


The Securities and Exchange Commission (**SEC**) **[filing alleges that SolarWinds](https://www.sec.gov/news/press-release/2023-227)** failed to disclose adequate material information to investors regarding cybersecurity risks. The filing states that the company and its CISO *Timothy Brown only disclosed generic and hypothetical risks despite internal knowledge of specific deficiencies in SolarWinds' cybersecurity* practices and a heightened threat possibility.


The most infamous cases that everyone should be aware of, **[SolarWinds](https://www.techtarget.com/whatis/feature/SolarWinds-hack-explained-Everything-you-need-to-know) and [Uber](https://www.upguard.com/blog/what-caused-the-uber-data-breach) breaches**, weren't just data breaches. They were wake-up calls. Legal repercussions for security failures are a growing concern, with the SEC mandating public companies to disclose incidents within four days and requiring detailed security plans. This puts immense pressure on CISOs like Joe Sullivan (Uber's former Chief Security Officer) and Timothy G. Brown (SolarWinds' former CISO), who could face criminal charges for failing to implement adequate safeguards.


[![DevOps](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEjV4r27WNrSUjuYlYnxv04MSnxUFW-Y9dZuy1PItc_Fk-x7ij9NxXU_MiQAhQbpkjA6EySIgbR2utJTFVT0AO4q7nUpHJPvUUbkiLjg34C-q_xJ2XqKxqZ0ym98CObtMFcPTvLLfIXmP2C6D0OS1hdL5z8SUzEuStoMZNBLEetQ9Tvfip5908BW4RyCn_P7/s728-rw-e365/8.jpg)](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEjV4r27WNrSUjuYlYnxv04MSnxUFW-Y9dZuy1PItc_Fk-x7ij9NxXU_MiQAhQbpkjA6EySIgbR2utJTFVT0AO4q7nUpHJPvUUbkiLjg34C-q_xJ2XqKxqZ0ym98CObtMFcPTvLLfIXmP2C6D0OS1hdL5z8SUzEuStoMZNBLEetQ9Tvfip5908BW4RyCn_P7/s728-rw-e365/8.jpg)
These incidents underscore the delicate **balancing act that CISOs face in the age of DevOps.** DevOps methodologies prioritize **speed and agility**, which can be at odds with the need for **rigorous security practices**. Can CISOs navigate this tightrope more effectively while still ensuring innovation doesn't come at the expense of security?


### **CISO needs to bridge the gap**[#](#ciso-needs-to-bridge-the-gap)


In the early days of DevOps, CISOs often felt like passengers without seatbelts in a new, fast-paced world, where speed reigned supreme and security lagged behind. **Promoting security practices without impacting development velocity can be challenging.** The CISO's influence empowers them to collaborate effectively with DevOps teams and ensure security is not an afterthought.

 Here are the top activities that a CISO can engage in to bridge the gap:


1. **Engage external authority - like auditors:** Partnering with reputable security firms and making them your allies provides expertise and **hard evidence** to support your concerns. These independent assessments can not just identify vulnerabilities - but provide proof of potential risks and evidence that the business could be taken down.
2. **Practical tests via Red Teaming Exercises:** Red teaming exercises are like security fire drills. By giving a pentester team a card-balance to complete the mission, these exercises showcase the potential impact of a breach on the organization. Seeing sensitive financial data compromised, or all wallpapers in an organization changed via one GPO or terraform access - can be a powerful **wake-up call** for the CTO and development teams, highlighting the importance of robust security measures.
3. **Implement regular vulnerability scans and continuous external attack surface monitoring for the entire perimeter:** Professional assessments of cloud environments (AWS, Azure, etc.) uncover security misconfigurations that could leave the organization vulnerable. These assessments provide **concrete data** that can be used to influence decisions around security investments and DevSecOps practices.
4. Bring your C-suite together to **define clear roles** and responsibilities for a simulated incident response exercise, fostering a collaborative environment where everyone works together to resolve a worst-case scenario. This will not only strengthen your defenses but also earn you the loyalty of the C-suite: Tabletop exercises for breach crises are a great tool for identifying gaps in communication or awareness of emergency procedures in case of a breach. As part of the tabletop exercise, use the opportunity to review responsibilities and communications and utilize the RACI matrix as a tool to define how to improve communications across CISO/CTO/CIO and other executive functions for security matters.
5. **Legal team as your best friends:** Understand how compliance and regulation are evolving so that you can help shape a security strategy that minimizes future risk exposure. Lawyers always welcome new friends.
6. **Strengthen your security posture:** By partnering with an MDR provider, you gain a valuable ally in the fight against cyber threats. They can handle the day-to-day tasks and provide specialized knowledge when needed, allowing your in-house team to focus on high-level security strategies with peace of mind.


[![DevOps](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEjYGwVy7Tk1k419p3lN5sf0eqFvCHHBqvVgOfjbgbaT8WgNeV0NOhER6ZzXAFy3rSsNFsP16v1gHpvGIYawRMdKlB296e9hB1YnaTw0eYoS21hMKxtFHjkW_Qmo698dA-HimjFShd2QYqDKde9WM0jIpHcpd_MxfzvcMdUE3qxlRgoU7QDvwIfeaZ-U_RB3/s728-rw-e365/10.jpg)](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEjYGwVy7Tk1k419p3lN5sf0eqFvCHHBqvVgOfjbgbaT8WgNeV0NOhER6ZzXAFy3rSsNFsP16v1gHpvGIYawRMdKlB296e9hB1YnaTw0eYoS21hMKxtFHjkW_Qmo698dA-HimjFShd2QYqDKde9WM0jIpHcpd_MxfzvcMdUE3qxlRgoU7QDvwIfeaZ-U_RB3/s728-rw-e365/10.jpg)
Performed regularly, these activities will demonstrate how security can proactively reduce risk, building the credibility of the CISO and the team he engages to build a bridge between security and development. These activities drive collaboration and information sharing so that as teams work together, they will begin to share responsibility for keeping things secure. So, instead of feeling like a passenger, the CISO becomes a proactive partner, ensuring security is considered from the beginning, allowing innovation to thrive on a safe foundation within the IT department.


### **How a CISO can amplify their voice in the DevOps сonversation**[#](#how-a-ciso-can-amplify-their-voice-in-the-devops-onversation)


When CISOs can't amplify their voice, the consequences can be dire. Inadequate security practices expose the organization to legal and regulatory risks. More importantly, they leave the door open for costly breaches, as happened with SolarWinds, that stifle innovation and erode customer trust.


1. Security leadership often requires bridging the gap between technical details and broader business objectives. **Training programs focused on clear communication and negotiation** could empower him to collaborate more effectively with colleagues and secure crucial resources for the security team. Security assessments, industry reports, and real-world breach examples can quantify the potential financial impact of security failures, making the conversation about risk mitigation a compelling business discussion.
2. By demonstrating how robust security practices can enhance innovation, improve customers' trust, and ultimately drive business growth, CISOs can find common ground with CTOs who prioritize agility and efficiency. Aligning security recommendations with the CTO's existing goals, such as faster development cycles, fosters a win-win situation. Here, CISOs can leverage their understanding of the cloud environment by equipping themselves with **specialized AWS cloud training courses**. This not only strengthens their technical expertise but also allows them to speak the same language as their DevOps counterparts, facilitating smoother collaboration on secure and efficient cloud deployments.
3. Open communication and trust are the cornerstones of effective collaboration. Regularly discussing security implications throughout the development lifecycle, not just as a last-minute hurdle, allows CISOs to address concerns and prevent potential roadblocks in time. So, **speaking the CTO's language is key** in this role.
4. Managed Detection and Response (**MDR**) goes beyond just being a security tool. It acts as an **amplifier** for the CISO's voice within the DevOps conversation. The breakneck pace of DevOps can leave even the most skilled CISOs feeling like they're constantly playing catch-up. Security teams are stretched thin, struggling to monitor complex environments, detect sophisticated threats, and keep pace with the ever-evolving threat landscape. This is where **[MDR by UnderDefense](https://underdefense.com/services/managed-detection-and-response/?utm_source=hackernews.com&utm_medium=online_media&utm_campaign=article_may)** emerges as a powerful force multiplier for CISOs in the DevOps environment.


[![DevOps](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEi74yDvTiLVPBe0J3EuG7pT8Xbw582kbOVg8qQSjq793UxnXMz5NFWuot2lPQGSb0HjyxbERsieGM8z2Ln0SyFnwjEzAQH7YcXG56bZ4fjpaLdQghhKfiWJ9LMR4U3Lp6VC01GWoWyb5dx3_AcQAfIYWynRGdCcPst_APNGchXL8xvOEfO9LFy-_zG1j1Hv/s728-rw-e365/5.2.jpg)](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEi74yDvTiLVPBe0J3EuG7pT8Xbw582kbOVg8qQSjq793UxnXMz5NFWuot2lPQGSb0HjyxbERsieGM8z2Ln0SyFnwjEzAQH7YcXG56bZ4fjpaLdQghhKfiWJ9LMR4U3Lp6VC01GWoWyb5dx3_AcQAfIYWynRGdCcPst_APNGchXL8xvOEfO9LFy-_zG1j1Hv/s728-rw-e365/5.2.jpg)
Here's how MDR empowers CISOs to influence secure development:


* **24/7 Watch Compliance and Proactive Threat Detection:** MDR services provide continuous monitoring and advanced threat intelligence, allowing CISOs to **proactively address security concerns** before they become problems. This frees security teams to focus on strategic initiatives and fosters a collaborative environment where security is preventative, not reactive.
* **Early Warning System for Security Gaps:** MDR goes beyond traditional monitoring by detecting anomalies in access patterns, user behavior, and system configurations. This allows for identifying potential insider threats or misconfigurations introduced by DevOps teams. By providing **real-time alerts** of potential security risks, CISOs can work with development teams to address them before they become exploitable vulnerabilities.


Assessments, tabletop exercises, and the ability to bring in outside experts, such as an MDR team, will highlight any communication gaps within the organization. Deciding what needs to be communicated and escalated to whom is extremely important to utilize resources effectively and raise visibility to important security concerns. Identifying the key categories of concern and who needs to be informed and involved is key to successful security operations and a successful business. Reviewing and formalizing communications can save time during an emergency such as a breach.


[![DevOps](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEj51Cm3IqiV2x28nw8CPlSyinw7mTvNEPjRG-ZDK7CDRzMGQgnJrQbrH8k2wzUhMeaLChofNqoFKmm3yOxKZv7ny6281o5UcqqLE-CPIXdMsbPx7K3m21wspEvX2GhROa5KRzXH4C-9Nx4WAirBL3qzaj8ImjixwcOmyQnqaehiDeUOV3KgAgKeazpy28kV/s728-rw-e365/4.jpg)](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEj51Cm3IqiV2x28nw8CPlSyinw7mTvNEPjRG-ZDK7CDRzMGQgnJrQbrH8k2wzUhMeaLChofNqoFKmm3yOxKZv7ny6281o5UcqqLE-CPIXdMsbPx7K3m21wspEvX2GhROa5KRzXH4C-9Nx4WAirBL3qzaj8ImjixwcOmyQnqaehiDeUOV3KgAgKeazpy28kV/s728-rw-e365/4.jpg)
The **RACI matrix** is just one example, highlighting the importance of establishing clear communication models within DevOps. By implementing such models and integrating them into security policies, CISOs can gain significant leverage, ensuring security is woven into the fabric of DevOps, not bolted on as an afterthought.


Finally, the matrix emphasizes a crucial aspect of a CISO's role: **establishing strong support by the Board**. This alignment is essential for establishing security as a strategic priority and securing the resources needed for a robust security posture.


**A Strong security team is still essential**[#](#a-strong-security-team-is-still-essential)
--------------------------------------------------------------------------------------------


The fast pace of DevOps can leave even the most skilled CISOs struggling to keep pace with threats. MDR empowers CISOs to **transition from reactive firefighting to proactive threat hunting**. Instead of patching vulnerabilities after a breach, MDR helps identify and remediate them before they can be exploited. This proactive approach minimizes security risks and fosters a culture of "security by design" within the DevOps pipeline.


[![DevOps](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAQAAAC1HAwCAAAAC0lEQVR42mP8Xw8AAoMBgDTD2qgAAAAASUVORK5CYII=)](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEhs0whZBmH9lFiBPDHIRGw_dhyscuY-M9y-oMxj9gIkP61d3buwFVD-DUZrIh8uKepxrKsJLTc3y60bfxqJ5hqNHno2Ye0kJ8zBIzP5WFPXJ-Ycd0CZLa6XE51eNPOABJOdVjYNYgH5amPnlX111ROHsIMW54j2UaIN9j-X49uxYnSWYc8YwoSADIW-Tskm/s728-rw-e365/3.2.jpg)
While MDR adds significant value, it doesn't replace a strong internal security team. Security professionals remain vital for:


* **Maintaining Situational Awareness:** The security team interprets data and alerts generated by MDR, providing context and prioritizing threats.
* **Responding to Incidents:** Security personnel with deep incident response expertise are crucial for effectively containing and remediating security breaches.
* **Managing Security Requirements:** The security team ensures that security requirements are integrated into the DevSecOps pipeline, fostering a culture of "security by design."


We've also prepared the most comprehensive **[MDR Buyer's Guide by UnderDefense](https://underdefense.com/mdr-buyers-guide/?utm_source=hackernews.com&utm_medium=online_media&utm_campaign=article_may)** for your attention, which equips you to choose the perfect MDR partner, safeguarding your data and business operations. It provides vendor-agnostic expert insights to help you make informed decisions.


**The main takeaway: collaboration is a key**[#](#the-main-takeaway-collaboration-is-a-key)
-------------------------------------------------------------------------------------------


While the CISO's influence engine equips them with powerful tools, security remains a collaborative effort. Building bridges with the CTO and fostering open communication with development teams are the cornerstones of a truly secure DevOps environment. By wielding their influence effectively and collaborating across departments, CISOs can ensure security becomes an integral part of the DevOps process, enabling innovation to flourish without sacrificing safety on the security highway.


The breakneck pace of DevOps can create a security dilemma – a speed bump on the security highway. Here, the CISO plays a critical role as an architect, not an enforcer. Their expanding influence engine equips them with the tools to navigate this complex landscape. Security assessments, red teaming exercises, and collaboration with security consultants empower CISOs to advocate for robust security measures without hindering innovation.


However, the true game-changer in this scenario is MDR. It acts as a force multiplier for the CISO within the DevOps conversation. By providing 24/7 monitoring, proactive threat detection, and early warnings of security gaps, MDR empowers CISOs to shift from reactive firefighting to proactive threat hunting. This not only safeguards the organization but also fosters a culture of "**security by design**" within the DevOps pipeline.


In essence, the solution to the DevOps dilemma lies in a powerful combination: the evolving role of the CISO, wielding an expanded influence engine, and the force-multiplying capabilities of MDR. UnderDefense offers a cutting-edge **[MDR solution](https://underdefense.com/real-time-visibility/?utm_source=hackernews.com&utm_medium=online_media&utm_campaign=article_may)** that gives real-time visibility into your security posture, equipping you to proactively detect and respond to security incidents and ultimately safeguarding your organization.


By embracing collaboration and leveraging these tools, CISOs can ensure security seamlessly integrates with DevOps, enabling innovation to speed down the highway without encountering security roadblocks.


[![DevOps](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAQAAAC1HAwCAAAAC0lEQVR42mP8Xw8AAoMBgDTD2qgAAAAASUVORK5CYII=)](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEis_TRLCHvtFhaWIWrtO38hZ5ShrRwIrceOyJsWXxoeVQhmjkYY0bI_gWdKmW4Zl9_dXA-WYpxQbbNPZRxzXlufrBIqqk-aYTpbKcx46X11BIHl1iVv7ZBfxdKuOW_bNx8U8F265zappCaYweSnWg8nNwlaJLmr49XtZhhs_jbx-PdPyDxPL5KOFvG3kcoG/s728-rw-e365/dev.png)
  





## Tags:


### Autogenerated tags:
devops cisos ciso mdr teams cloud solarwinds cybersecurity aws proactively
