# Google Using Clang Sanitizers to Protect Android Against Cellular Baseband Vulnerabilities
## Google boosts Android security with Clang sanitizers! Meet IntSan and BoundSan, designed to catch vulnerabilities in the cellular baseband
## Information:

+ Link: https://thehackernews.com/2023/12/google-using-clang-sanitizers-to.html
+ Source: The Hacker News
+ Author: Newsroom
+ Date published: 13 December 2023, 18:45
+ Date scraped: 13 December 2023, 14:01

## Article:
![Main article image](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEgVPJeYgjkR-VM2qWJggAbYaHQbCK4GP7-T1fVPEHjuvElHF24Ue3yMcFcIVto4hQbzZ5tbKGvrHo7qkmGZgqFGdR6XfKe7wOiBGjWsCrHyslReJ7mmecbK38LFrqns_EvbHEWs1-tEltzUc4thdgUo_y2b4WQWfA0bJzySq7jn0owuU5Ot_V7ReXrBTYIY/s728-rw-ft-e30/android.jpg)


Google is highlighting the role played by [Clang sanitizers](https://github.com/google/sanitizers) in hardening the security of the cellular baseband in the [Android operating system](https://dl.acm.org/doi/fullHtml/10.1145/3448609) and preventing specific kinds of vulnerabilities.


This comprises Integer Overflow Sanitizer (IntSan) and BoundsSanitizer (BoundSan), both of which are part of UndefinedBehaviorSanitizer ([UBSan](https://clang.llvm.org/docs/UndefinedBehaviorSanitizer.html)), a tool designed to catch various kinds of undefined behavior during program execution.


"They are architecture agnostic, suitable for bare-metal deployment, and should be enabled in existing C/C++ code bases to mitigate unknown vulnerabilities," Ivan Lozano and Roger Piqueras Jover [said](https://security.googleblog.com/2023/12/hardening-cellular-basebands-in-android.html) in a Tuesday post.


 UPCOMING WEBINAR  [Beat AI-Powered Threats with Zero Trust - Webinar for Security Professionals](https://thehacker.news/zero-trust-attack-surface?source=inside)  Traditional security measures won't cut it in today's world. It's time for Zero Trust Security. Secure your data like never before.

 [Join Now](https://thehacker.news/zero-trust-attack-surface?source=inside) 
The development comes months after the tech giant said it's [working with ecosystem partners](https://thehackernews.com/2023/02/google-teams-up-with-ecosystem-partners.html) to increase the [security of firmware](https://source.android.com/docs/security/enhancements) that interacts with Android, thereby making it difficult for threat actors to achieve remote code execution within the Wi-Fi SoC or the cellular baseband.


IntSan and BoundSan are two of the [compiler-based sanitizers](https://source.android.com/docs/security/test/ubsan) that Google has enabled as an exploit mitigation measure to detect arithmetic overflows and perform bounds checks around array accesses, respectively.


Google acknowledged that while both BoundSan and IntSan incur a substantial performance overhead, it has enabled it in security-critical attack surfaces ahead of a full-fledged rollout over the entire codebase. This covers -


* Functions parsing messages delivered over the air in 2G, 3G, 4G, and 5G
* Libraries encoding/decoding complex formats (e.g., ASN.1, XML, DNS, etc.)
* IMS, TCP, and IP stacks, and
* Messaging functions (SMS, MMS)


"In the particular case of 2G, the best strategy is to [disable the stack altogether](https://thehackernews.com/2023/08/new-android-14-security-feature-it.html) by supporting Android's '[2G toggle](https://source.android.com/docs/setup/about/android-12-release#2g-toggle),'" the researchers said. "However, 2G is still a necessary mobile access technology in certain parts of the world and some users might need to have this legacy protocol enabled."


It's worth noting that the "tangible" benefits arising out of deploying sanitizers notwithstanding, they do not address other classes of vulnerabilities, such as those related to memory safety, necessitating a transition of the codebase to a memory-safe language like Rust.


In early October 2023, Google [announced](https://security.googleblog.com/2023/10/bare-metal-rust-in-android.html) that it had rewritten the Android Virtualization Framework's ([AVF](https://source.android.com/docs/core/virtualization)) protected VM (pVM) firmware in Rust to provide a memory-safe foundation for the pVM root of trust.


"As the high-level operating system becomes a more difficult target for attackers to successfully exploit, we expect that lower level components such as the baseband will attract more attention," the researchers concluded.


"By using modern toolchains and deploying exploit mitigation technologies, the bar for attacking the baseband can be raised as well."


  





## Tags:


### Autogenerated tags:
google android sanitizers intsan boundsan 2g
