# Hackers Can Exploit Windows Container Isolation Framework to Bypass Endpoint Security
## New research uncovers how hackers could cleverly bypass endpoint security by exploiting Windows Container Isolation
## Information:

+ Link: https://thehackernews.com/2023/08/hackers-can-exploit-windows-container.html
+ Source: The Hacker News
+ Author: THN
+ Date published: 30 August 2023, 22:34
+ Date scraped: 30 August 2023, 18:01

## Article:
![Main article image](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEjJ_QmkyxY7wxaC8T6HgA3sVQ9xZXaHPvjYbGZC1w4AZqBblmJsC6ZCyqdYI29oTBbrhFCd_AIsJc2EE5Axp-bWc27FV2uHACd1VDQIBjJ-qB9_jvcThr2Dg5Lkgt02DyQ7dNuQGiCxoiqQ6AbQS146PapjEIzogkn6gBgakx1Hd3cC4c8N9g2pdDLVWcjD/s728-e3650/windows.jpg)


New findings show that malicious actors could leverage a sneaky malware detection evasion technique and bypass endpoint security solutions by manipulating the Windows Container Isolation Framework.


The findings were presented by Deep Instinct security researcher Daniel Avinoam at the [DEF CON security conference](https://forum.defcon.org/node/245719) held earlier this month.


Microsoft's [container architecture](https://www.cyberark.com/resources/threat-research-blog/understanding-windows-containers-communication) (and by extension, [Windows Sandbox](https://research.checkpoint.com/2021/playing-in-the-windows-sandbox/)) uses what's called a [dynamically generated image](https://techcommunity.microsoft.com/t5/windows-os-platform-blog/windows-sandbox/ba-p/301849) to separate the file system from each container to the host and at the same time avoid duplication of system files.


It's nothing but an "operating system image that has clean copies of files that can change, but links to files that cannot change that are in the Windows image that already exists on the host," thereby bringing down the overall size for a full OS.


[![Cybersecurity](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEgwAoxYDskfi-J01jeLkkPEZqHZy9bLaLX8kLNuruprE8YRTIB5EBEid3uvBbzR90H6IcIJgVhjn0srTxOZLXejyJ6Jz9ZP-lexe0SPTD7GA1oU6HgxduclFP4BBnHkKiVJ_bsnI7UWFpYdpeFEkKKy1rxI2i0Y5KObLKK-rA7YfSuph4A714RQKICG252V/s728-e3650/4.png)](https://thn.news/edWGl41h)
"The result is images that contain 'ghost files,' which store no actual data but point to a different volume on the system," Avinoam [said](https://www.deepinstinct.com/blog/contain-yourself-staying-undetected-using-the-windows-container-isolation-framework) in a report shared with The Hacker News. "It was at this point that the idea struck me — what if we can use this redirection mechanism to obfuscate our file system operations and confuse security products?"


This is where the Windows Container Isolation FS (wcifs.sys) minifilter driver comes into play. The driver's main purpose is to take care of the file system separation between Windows containers and their host.


In other words, the [idea](https://github.com/deepinstinct/ContainYourself) is to have the current process running inside a fabricated container and leverage the minifilter driver to handle I/O requests such that it can create, read, write, and delete files on the file system without alerting security software.


![Windows Container Isolation Framework](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEgbtDyG8foXdeZYOrCD8hQ7bJzIV2xRN1YyJhkHaq9EdvaLr9uk9soVvNUsMg0IeJNLe9HHV2G9dRBFSIXDDAYhVp1zRBC5C557nVxJTIbMgNgRAQrXhKodYetR57NZBDrHiahQ1v-PaxinKuKQCzw2dKiZ1ZL-WDZeXzhL31Rf6neFQwMoA86EXRD3owTt/s728-e3650/ms.jpg)
It's worth pointing out at this stage that a minifilter attaches to the file system stack indirectly, by registering with the [filter manager](https://learn.microsoft.com/en-us/windows-hardware/drivers/ifs/filter-manager-concepts) for the I/O operations that it chooses to filter. Each minifilter is [allocated](https://learn.microsoft.com/en-us/windows-hardware/drivers/ifs/load-order-groups-and-altitudes-for-minifilter-drivers) a Microsoft-assigned "integer" altitude value based on filter requirements and load order group.


The wcifs driver has an [altitude range](https://learn.microsoft.com/en-us/windows-hardware/drivers/ifs/allocated-altitudes) of 180000-189999 (specifically 189900), while antivirus filters, including those from third-parties, function at an altitude range of 320000-329999. As a result, various file operations can be performed without getting their callbacks triggered.


[![Cybersecurity](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEgNmNiBV8c8Rp0Xy6N9lCX9JL2cBlrjkSeuW4JhgOVQ3mKTsYV4pPvh3nDz32D97D8XcWQ53EJ1p4n2VX0gZH_YrBZBqElUMfzFWgb50P8lv1iac_1f-p5liZzC1ISVWJygv2s1Qm36rOHwk_kPXUNNT3nbSDr144QYZ6XGq0aXRDOrFfSlUnHnc0x4Fe_F/s728-e3650/cis-d.gif)](https://thn.news/Cr7gkMdK)
"Because we can override files using the IO\_REPARSE\_TAG\_WCI\_1 reparse tag without the detection of antivirus drivers, their detection algorithm will not receive the whole picture and thus will not trigger," Avinoam explained.


That having said, pulling off the attack requires administrative permissions to communicate with the wcifs driver and it cannot be used to override files on the host system.


The disclosure comes as the cybersecurity company demonstrated a stealthy technique called [NoFilter](https://thehackernews.com/2023/08/nofilter-attack-sneaky-privilege.html) that abuses the Windows Filtering Platform (WFP) to elevate a user's privileges to that of SYSTEM and potentially execute malicious code.


The attacks allow the use of WFP to duplicate access tokens for another process, trigger an IPSec connection and leverage the Print Spooler service to insert a SYSTEM token into the table, and make it possible to obtain the token of another user logged into the compromised system for lateral movement.


  





## Tags:


### Autogenerated tags:
windows minifilter avinoam
