# How Nation-State Actors Target Your Business: New Research Exposes Major SaaS Vulnerabilities
## 2023's cyber attacks put SaaS vulnerabilities in the spotlight. Find out why SaaS is the new supply chain and how to safeguard your organization.
## Information:

+ Link: https://thehackernews.com/2024/02/how-nation-state-actors-target-your.html
+ Source: The Hacker News
+ Author: The Hacker News
+ Date published: 15 February 2024, 17:00
+ Date scraped: 15 February 2024, 12:02

## Article:
![Main article image](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEhCb3lbR5kKaNE9_BRADHrZqnNzA8MYLNnIDfJ8esB94HKtdiQsqC0exNVk5hWYeLbeUYgQyjqJoIshnKImmBKXjjSU_QWjoQnFtll_ge1xVfpf-nAl_f15ERLDetjxzj__ejnde7ebtIh3E27BN3Xm5UTrexnvX5p7oL_dT8oq25Pl5jwRT1UqeQb4VO8/s728-rw-e365/wing.jpg)


With many of the highly publicized 2023 cyber attacks revolving around one or more SaaS applications, SaaS has become a cause for genuine concern in many boardroom discussions. More so than ever, considering that GenAI applications are, in fact, SaaS applications.


Wing Security (Wing), a SaaS security company, conducted an analysis of 493 SaaS-using companies in Q4 of 2023. [**Their study reveals**](https://wing.security/resources/report/the-2024-state-of-saas-security/?utm_campaign=2024-01-State%20of%20SaaS%20Security%202024&utm_source=The%20Hacker%20News&utm_medium=Article&utm_term=Report%20THN%20Ar&utm_content=Summarizing%202024%20Report) how companies use SaaS today, and the wide variety of threats that result from that usage. This unique analysis provides rare and important insights into the breadth and depth of SaaS-related risks, but also provides practical tips to mitigate them and ensure SaaS can be widely used without compromising security posture. 


**The TL;DR Version Of SaaS Security**[#](#the-tldr-version-of-saas-security)
-----------------------------------------------------------------------------


2023 brought some now infamous examples of malicious players leveraging or directly targeting SaaS, including the North Korean group UNC4899, 0ktapus ransomware group, and Russian Midnight Blizzard APT, which targeted well-known organizations such as JumpCloud, MGM Resorts, and Microsoft (respectively), and probably many others that often go unannounced.


The first insight from this research cements the concept that SaaS is the new supply chain, providing an almost intuitive framework to the importance of securing SaaS usage. These applications are clearly an integral part of the modern organization's set of tools and vendors. That said, long gone are the days when every 3rd party with access to company data had to go through security or IT approval. Even in the most rigorous companies, when a diligent employee needs a quick and efficient solution, they'll look it up and use it to get their jobs' done faster and better. Again, think of the widespread use of GenAI, and the picture is clear.


As such, any organization concerned about the security of its supply chain must adopt SaaS security measures. According to the MITRE ATT&CK technique 'Trusted Relationships' (T1199), a supply chain attack occurs when an attacker targets a vendor to exploit it as a means to infiltrate a broader network of companies. By entrusting sensitive data to external SaaS vendors, organizations subject themselves to supply chain risks that reach beyond immediate security concerns.


**Four Common SaaS Risks**[#](#four-common-saas-risks)
------------------------------------------------------


There are various reasons and ways in which SaaS is being targeted. The good news is that most of the risks can be significantly mitigated when monitored and controlled. Basic SaaS security capabilities [**are even free**](https://wing.security/essential-sspm/?utm_campaign=2024-01-State%20of%20SaaS%20Security%202024&utm_source=The%20Hacker%20News&utm_medium=Article&utm_term=Essential%20THN%20Ar&utm_content=Summarizing%202024%20Report), suited for organizations that are just beginning to develop their SaaS security posture or need to compare it to their current solution. 


### 1) Shadow SaaS[#](#1-shadow-saas)


The first problem with SaaS usage is the fact that it often goes completely unnoticed: The number of applications used by organizations is typically 250% larger than what a basic and often-used query of the workspace reveals.


Amongst the companies analyzed:


* 41% of applications were used by only one individual, resulting in a very long tail of unsanctioned applications.
* 1 out of 5 users were utilizing applications not used by anyone else within their organization, creating security and resource strains.
* 63% of single-user applications were not even accessed within a 3-month period, begging the question - why keep them connected to company data?
* 96.7% of organizations used at least one application that had a security incident in the previous year, solidifying the continuous risk and need for proper mitigation.


### 2) MFA Bypassing[#](#2-mfa-bypassing)


Wing's research indicates a trend where users opt to use a username/password to access the services they need, bypassing the security measures in place (see image 1).


![Major SaaS Vulnerabilities](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEi3ABvHbx7sf_K1PWAKXMMACWA_wRcee9I5e2l3FZdWdabO3-OP9KsuqInojTXWDGAMbjS96QBkLafXS6I911y9NPk37HUBQvVNUlyghDhYFMdwC_ZAS_INQqGpjjM0OMrAahBykotNihFBMjkSE-EA-HD0KpVZWMrqn0PeMSasYrfDQ9scnGY1c77dq7g/s728-rw-e365/wing-1.jpg)
### 3) Forgotten tokens [#](#3-forgotten-tokens)


Users grant the applications they need tokens; this is necessary for the SaaS applications to serve their purpose. The problem is that these tokens are often forgotten about after a few or just one use. Wing's research revealed a large presence of unused tokens over a period of 3 months, creating an unnecessarily large attack surface for many customers (Image 2).

 ### 4) The new risk of Shadow AI[#](#4-the-new-risk-of-shadow-ai)


In the beginning of 2023, security teams primarily concentrated on a select few renowned services offering access to AI-based models. However, as the year progressed, thousands of conventional SaaS applications adopted AI models. The research shows that 99.7% of companies were using applications with integrated AI capabilities.


Organizations were required to agree to updated terms and conditions permitting these applications to utilize and refine their models using the organizations' most confidential data. Often, these revised terms and conditions slipped under the radar, along with the usage of AI itself.


There are different ways in which AI applications may use your data for their training models. This can come in the form of learning your data, storing your data and even having a human manually go over your data to improve the AI model. According to Wing, [**this capability is often configurable and totally avoidable**](https://wing.security/gen-ai/?utm_campaign=2024-01-State%20of%20SaaS%20Security%202024&utm_source=The%20Hacker%20News&utm_medium=Article&utm_term=AI%20THN%20Ar&utm_content=Summarizing%202024%20Report), provided it is not overlooked. 


**Solving SaaS Security Challenges In 2024**[#](#solving-saas-security-challenges-in-2024)
------------------------------------------------------------------------------------------


The report ends on a positive note, listing 8 ways in which companies can mitigate the growing threat of the SaaS supply chain. Including:


1. Ongoing [shadow IT discovery](https://wing.security/free-saas-discovery/?utm_campaign=2024-01-State%20of%20SaaS%20Security%202024&utm_source=The%20Hacker%20News&utm_medium=Article&utm_term=Freemium%20THN%20Ar&utm_content=Summarizing%202024%20Report) and management.
2. Prioritize the remediation of SaaS misconfigurations
3. Optimize anomaly detection with predefined frameworks, automate when possible.
4. Discover and monitor all AI-using SaaS applications, and constantly monitor your SaaS for updates in their T&C pertaining to AI usage.


For the full list of findings, tips on ensuring safe SaaS usage and a 2024 SaaS security forecast, [**download the full report here**](https://wing.security/resources/report/the-2024-state-of-saas-security/?utm_campaign=2024-01-State%20of%20SaaS%20Security%202024&utm_source=The%20Hacker%20News&utm_medium=Article&utm_term=Report%20THN%20Ar&utm_content=Summarizing%202024%20Report).


  





## Tags:


### Autogenerated tags:
saas
