# New R Programming Vulnerability Exposes Projects to Supply Chain Attacks
## A critical vulnerability (CVE-2024-27322) has been discovered in the R programming language. It could allow attackers to execute arbitrary code.
## Information:

+ Link: https://thehackernews.com/2024/04/new-r-programming-vulnerability-exposes.html
+ Source: The Hacker News
+ Author: The Hacker News
+ Date published: 29 April 2024, 16:20
+ Date scraped: 29 April 2024, 14:11

## Article:
![Main article image](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEgKFi4XyDlNTfpsB45dMp2OLiS151Jon16IG0pBAZo57Tt_SiuyOCRH92UF5lskx5lHMnjZfLze6RQRKOJ0oQOR_ndb7P7DiRWVmfusIlMSUhCBDRnrOT223aPM5Aek3rFJHc7X0oyZkjWaFMrIsNUavDK_iUAGag2Vp4hhgpq5Evj8icg0OnqFpG9a2py-/s728-rw-e365/r.png)


A security vulnerability has been discovered in the R programming language that could be exploited by a threat actor to create a malicious RDS (R Data Serialization) file such that it results in code execution when loaded and referenced.


The flaw, assigned the CVE identifier **CVE-2024-27322**, "involves the use of promise objects and lazy evaluation in R," AI application security company HiddenLayer said in a report[report](https://hiddenlayer.com/research/r-bitrary-code-execution/) shared with The Hacker News.


RDS, [like pickle in Python](https://thehackernews.com/2024/04/ai-as-service-providers-vulnerable-to.html), is a format used to serialize and save the state of data structures or objects in R, an open-source programming language used in statistical computing, data visualization, and machine learning.


[![Cybersecurity](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEiuUUskkMH9dUT3LF77_Q_irGuaE4LGjp-Am2Ls_UzGJ5EBnZHfuFiSvKs4OPE5KmfedBHcuZZVHS4Bh48UJx8brpwtg6Vr2Gepbaw-lGMIm9HjUhyphenhyphen2W5DVm5-ymwPS691Ie32TrCqFIv6SxNRA-jOKCKZrOB5dV7BfL0zVAhOO0neNkP9yv-XePBU1hN_0/s728-e365/wing-d.png)](https://thehackernews.uk/third-party-risk-management-saas)
This process of serialization – serialize() or saveRDS() – and deserialization – unserialize() and readRDS() – is also leveraged when saving and loading R packages.


The root cause behind CVE-2024-27322 lies in the fact that it could lead to arbitrary code execution when deserializing untrusted data, thus leaving users exposed to supply chain attacks through specially crafted R packages.


An attacker looking to weaponize the flaw could therefore take advantage of the fact that R packages leverage the RDS format to save and load data, causing automatic code execution when the package is decompressed and deserialized.



"R packages are vulnerable to this exploit and can, therefore, be used as part of a supply chain attack via package repositories," the company said. "For an attacker to take over an R package, all they need to do is overwrite the [rdx file](https://cran.r-project.org/doc/manuals/r-patched/R-ints.pdf) with the maliciously crafted file, and when the package is loaded, it will automatically execute the code."


The security defect has been addressed in [version 4.4.0](https://cran.r-project.org/doc/manuals/r-release/NEWS.html) released on April 24, 2024, following responsible disclosure.


[![Cybersecurity](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEj9LS2CMV85AM5f2fKKl2aPAnQ1iZEQKbHh7hRbW3rn3MowE5BXNOrNlHsrMYRMndplTjEmzciLAj6jVsDkRJI2IdSfFXSXuSlMn6gSgmzjKktBgyRTJsC-MayMQq8Z580Hjp8oCv0WoplbNRKlOEzR3RqajPwbLY2JzbQpwEIaW6u2UDkYmcWPO_Mmzq-X/s728-e365/cis-d.png)](https://thehackernews.uk/cis-controls-guide-sme)
"An attacker can exploit this [flaw] by crafting a file in RDS format that contains a promise instruction setting the value to unbound\_value and the expression to contain arbitrary code," HiddenLayer said. "Due to lazy evaluation, the expression will only be evaluated and run when the symbol associated with the RDS file is accessed."


"Therefore if this is simply an RDS file, when a user assigns it a symbol (variable) in order to work with it, the arbitrary code will be executed when the user references that symbol. If the object is compiled within an R package, the package can be added to an R repository such as CRAN, and the expression will be evaluated and the arbitrary code run when a user loads that package."

 
  





## Tags:
***CVE's***: CVE-2024-27322

### Autogenerated tags:
rds
