# New Silver SAML Attack Evades Golden SAML Defenses in Identity Systems
## Researchers have disclosed a new attack technique, "Silver SAML," targeting applications that use cloud identity providers such as Microsoft Entra ID.
## Information:

+ Link: https://thehackernews.com/2024/02/new-silver-saml-attack-evades-golden.html
+ Source: The Hacker News
+ Author: The Hacker News
+ Date published: 29 February 2024, 20:51
+ Date scraped: 29 February 2024, 16:01

## Article:
![Main article image](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEh3_6sv5NpzuZbAcWf78ZEfAMC5xtLD2_skoPU3hluY7oPp6fi0IqgZHMHUdLwQBE5d4E6Ib_tBfzikaR1lLkjjm7KScRsahF0S3BsjC-TI4lJ0VxdW6WSk_0PAg0dfBMz1vl1vyF5ZrShqZBmyEUdCCrmIMkJKBebQu3MibEkJzgGSrqdDCJgMGQyQGFDr/s728-rw-e365/ms.jpg)


Cybersecurity researchers have disclosed a new attack technique called **Silver SAML** that can be successful even in cases where mitigations have been applied against Golden SAML attacks.


Silver SAML "enables the exploitation of SAML to launch attacks from an identity provider like Entra ID against applications configured to use it for authentication, such as Salesforce," Semperis researchers Tomer Nahum and Eric Woodruff [said](https://www.semperis.com/blog/meet-silver-saml) in a report shared with The Hacker News.


Golden SAML (short for [Security Assertion Markup Language](https://www.cloudflare.com/learning/access-management/what-is-saml/)) was [first documented](https://www.cyberark.com/resources/threat-research-blog/golden-saml-newly-discovered-attack-technique-forges-authentication-to-cloud-apps) by CyberArk in 2017. The attack vector, in a nutshell, entails the abuse of the interoperable authentication standard to impersonate almost any identity in an organization.


It's also similar to the [Golden Ticket attack](https://www.crowdstrike.com/cybersecurity-101/golden-ticket-attack/) in that it grants attackers the ability to gain unauthorized access to any service in a federation with any privileges and to stay persistent in this environment in a stealthy manner.


"Golden SAML introduces to a federation the advantages that golden ticket offers in a Kerberos environment – from gaining any type of access to stealthily maintaining persistency," security researcher Shaked Reiner noted at the time.


Real-world attacks leveraging the method have been rare, the [first](https://www.cyberark.com/resources/threat-research-blog/golden-saml-revisited-the-solorigate-connection) [recorded use](https://www.sygnia.co/threat-reports-and-advisories/golden-saml-attack/) being the [compromise](https://www.microsoft.com/en-us/security/blog/2020/12/28/using-microsoft-365-defender-to-coordinate-protection-against-solorigate/) of [SolarWinds](https://techcommunity.microsoft.com/t5/microsoft-sentinel-blog/solarwinds-post-compromise-hunting-with-azure-sentinel/ba-p/1995095) [infrastructure](https://msrc.microsoft.com/blog/2020/12/customer-guidance-on-recent-nation-state-cyber-attacks/) to gain administrative access by forging SAML tokens using compromised SAML token signing certificates.


Golden SAML has also been weaponized by an Iranian threat actor codenamed [Peach Sandstorm](https://thehackernews.com/2023/09/iranian-nation-state-actors-employ.html) in a March 2023 intrusion to access an unnamed target's cloud resources sans requiring any password, Microsoft revealed in September 2023.


[![Silver SAML Attack](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEiEw23CuuLPQhxppcT8caizSHnHXuvyUfmqOEmBt8FOcwPbAer1BktvE5JXhSxlp7_gqtdprHfil55s2igTA9pFElJ_lDMVvhioSTkczUb6u0jY-j_qx9UeWk7vlNG3nyu4Kb5Z8_2T8LeD7-JJ3fZfN2KrcODfWSzqIWj6yhD5zRhDqTMzg6S6WQTVIg4c/s728-rw-e365/http.jpg)](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEiEw23CuuLPQhxppcT8caizSHnHXuvyUfmqOEmBt8FOcwPbAer1BktvE5JXhSxlp7_gqtdprHfil55s2igTA9pFElJ_lDMVvhioSTkczUb6u0jY-j_qx9UeWk7vlNG3nyu4Kb5Z8_2T8LeD7-JJ3fZfN2KrcODfWSzqIWj6yhD5zRhDqTMzg6S6WQTVIg4c/s728-rw-e365/http.jpg)
The latest approach is a spin on Golden SAML that works with an identity provider (IdP) like Microsoft Entra ID (formerly Azure Active Directory) and doesn't require access to the Active Directory Federation Services ([AD FS](https://learn.microsoft.com/en-us/windows-server/identity/ad-fs/ad-fs-overview)). It has been assessed as a moderate-severity threat to organizations.


"Within Entra ID, Microsoft provides a self-signed certificate for SAML response signing," the researchers said. "Alternatively, organizations can choose to use an externally generated certificate such as those from Okta. However, that option introduces a security risk."


"Any attacker that obtains the private key of an externally generated certificate can forge any SAML response they want and sign that response with the same private key that Entra ID holds. With this type of forged SAML response, the attacker can then access the application — as any user."


Following responsible disclosure to Microsoft on January 2, 2024, the company said the issue does not meet its bar for immediate servicing, but noted it will take appropriate action as needed to safeguard customers.


While there is no evidence that Silver SAML has been exploited in the wild, organizations are required to use only Entra ID self-signed certificates for SAML signing purposes. Semperis has also made available a proof-of-concept (PoC) dubbed [SilverSAMLForger](https://github.com/Semperis/SilverSamlForger) to create custom SAML responses.


"Organizations can monitor Entra ID audit logs for changes to PreferredTokenSigningKeyThumbprint under ApplicationManagement," the researchers said.


"You will need to correlate those events to Add service principal credential events that relate to the service principal. The rotation of expired certificates is a common process, so you will need to determine whether the audit events are legitimate. Implementing change control processes to document the rotation can help to minimize confusion during rotation events."


  





## Tags:


### Autogenerated tags:
saml entra microsoft
