# Non-Human Access is the Path of Least Resistance: A 2023 Recap
## With 11 high-profile attacks in 13 months and a volatile, ungoverned attack surface, non-human identities are the new perimeter, and 2023 is only the
## Information:

+ Link: https://thehackernews.com/2023/12/non-human-access-is-path-of-least.html
+ Source: The Hacker News
+ Author: The Hacker News
+ Date published: 12 December 2023, 16:55
+ Date scraped: 12 December 2023, 12:01

## Article:
![Main article image](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEgmWbS5ycnyGutc4gpBaGYeT1xivbkY4Mo5nixiiyJ9wmW3hbi4YanY9rrLPUBohXwvCloK1-gA44IwI3sRnIGjR__gX9VBXZq6JhWVWn6PjG5eQVA8aqTTfQttNcV1tRqfKTqkB1FsVjXPSuEmjsEvM8YvnI68p7S_QzwBwHgT9pdLxj6r9XuqOglTmvE/s12000/aws.jpg)


2023 has seen its fair share of cyber attacks, however there's one attack vector that proves to be more prominent than others - non-human access. With [11 high-profile attacks in 13 months](https://astrix.security/11-attacks-in-13-months-the-new-generation-of-supply-chain-attacks/) and an ever-growing ungoverned attack surface, non-human identities are the new perimeter, and 2023 is only the beginning. 


Why non-human access is a cybercriminal's paradise [#](#why-nonhuman-access-is-a-cybercriminals-paradise)
---------------------------------------------------------------------------------------------------------


People always look for the easiest way to get what they want, and this goes for cybercrime as well. Threat actors look for the path of least resistance, and it seems that in 2023 this path was non-user access credentials (API keys, tokens, service accounts and secrets).



> *"****50% of the active access tokens connecting Salesforce and third-party apps are unused. In GitHub and GCP the numbers reach 33%."***


These non-user access credentials are used to connect apps and resources to other cloud services. What makes them a true hacker's dream is that they have no security measures like user credentials do (MFA, SSO or other IAM policies), they are mostly over-permissive, ungoverned, and never-revoked. In fact, 50% of the active access tokens connecting Salesforce and third-party apps are unused. In GitHub and GCP the numbers reach 33%.\*


So how do cybercriminals exploit these non-human access credentials? To understand the attack paths, we need to first understand the types of non-human access and identities. Generally, there are two types of non-human access - external and internal.


[![Non-Human Access](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEjWzts-97lzYjNifcTyskSXLmTJ-hS8u3gXvNbQKEkVcNufG6a4NAI4PTfZHXLGQkCpVNrk_9uJaf-uCNkVpolmh3LSlG4NLHTmq3DoJdCNBz-IylxbGN13zs0-Kaszw6aFP3ONEd8blOGsTlU8rd30XDnybN_MsRI3fE_b6ddT6MwaNcjqh1zv43pQ2DI/s12000/non%20human%20access.png)](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEjWzts-97lzYjNifcTyskSXLmTJ-hS8u3gXvNbQKEkVcNufG6a4NAI4PTfZHXLGQkCpVNrk_9uJaf-uCNkVpolmh3LSlG4NLHTmq3DoJdCNBz-IylxbGN13zs0-Kaszw6aFP3ONEd8blOGsTlU8rd30XDnybN_MsRI3fE_b6ddT6MwaNcjqh1zv43pQ2DI/s1200/non%20human%20access.png)
External non-human access is created by employees connecting third-party tools and services to core business & engineering environments like Salesforce, Microsoft365, Slack, GitHub and AWS - to streamline processes and increase agility. These connections are done through API keys, service accounts, OAuth tokens and webhooks, that are owned by the third-party app or service (the non-human identity). With the growing trend of bottom-up software adoption and freemium cloud services, many of these connections are regularly made by different employees without any security governance and, even worse, from unvetted sources. Astrix research shows that 90% of the apps connected to Google Workspace environments are non-marketplace apps - meaning they were not vetted by an official app store. In Slack, the numbers reach 77%, while in Github they reach 50%.\*



> ***"74% of Personal Access Tokens in GitHub environments have no expiration."***


Internal non-human access is similar, however, it is created with [internal access credentials](https://astrix.security/not-just-code-vulnerabilities-the-overlooked-cause-of-software-supply-chain-attacks/) - also known as 'secrets'. R&D teams regularly generate secrets that connect different resources and services. These secrets are often scattered across multiple secret managers (vaults), without any visibility for the security team of where they are, if they're exposed, what they allow access to, and if they are misconfigured. In fact, 74% of Personal Access Tokens in GitHub environments have no expiration. Similarly, 59% of the webhooks in GitHub are misconfigured - meaning they are unencrypted and unassigned.\* 


[Schedule a live demo of Astrix - a leader in non-human identity security](https://astrix.security/schedule-a-live-demo/?utm_source=hackernews&utm_medium=sponsored_article&utm_campaign=hackernewsarticle)


2023's high-profile attacks exploiting non-human access[#](#2023s-highprofile-attacks-exploiting-nonhuman-access)
-----------------------------------------------------------------------------------------------------------------


This threat is anything but theoretical. 2023 has seen some big brands falling victim to non-human access exploits, with thousands of customers affected. In such attacks, attackers take advantage of exposed or stolen access credentials to penetrate organizations' most sensitive core systems, and in the case of external access - reach their customers' environments (supply chain attacks). Some of these high-profile attacks include:


* [Okta](https://astrix.security/okta-breach-leaked-service-account/) (October 2023): Attackers used a leaked service account to access Okta's support case management system. This allowed the attackers to view files uploaded by a number of Okta customers as part of recent support cases.
* [GitHub Dependabot](https://checkmarx.com/blog/surprise-when-dependabot-contributes-malicious-code/) (September 2023): Hackers stole GitHub Personal Access Tokens (PAT). These tokens were then used to make unauthorized commits as Dependabot to both public and private GitHub repositories.
* [Microsoft SAS Key](https://www.wiz.io/blog/38-terabytes-of-private-data-accidentally-exposed-by-microsoft-ai-researchers) (September 2023): A SAS token that was published by Microsoft's AI researchers actually granted full access to the entire Storage account it was created on, leading to a leak of over 38TB of extremely sensitive information. These permissions were available for attackers over the course of more than 2 years (!).
* [Slack GitHub Repositories](https://astrix.security/slacks-github-breach-6-tips-to-avoid-similar-attacks/) (January 2023): Threat actors gained access to Slack's externally hosted GitHub repositories via a "limited" number of stolen Slack employee tokens. From there, they were able to download private code repositories.
* [CircleCI](https://astrix.security/the-circleci-breach-the-results-of-a-stolen-access-token/) (January 2023): An engineering employee's computer was compromised by malware that bypassed their antivirus solution. The compromised machine allowed the threat actors to access and steal session tokens. Stolen session tokens give threat actors the same access as the account owner, even when the accounts are protected with two-factor authentication.


The impact of GenAI access[#](#the-impact-of-genai-access)
----------------------------------------------------------



> ***"32% of GenAI apps connected to Google Workspace environments have very wide access permissions (read, write, delete)."***


As one might expect, the vast adoption of GenAI tools and services exacerbates the non-human access issue. GenAI has gained enormous popularity in 2023, and it is likely to only grow. With [ChatGPT becoming the fastest growing app in history](https://www.businessinsider.com/chatgpt-may-be-fastest-growing-app-in-history-ubs-study-2023-2), and AI-powered apps being downloaded [1506% more than last year](https://techcrunch.com/2023/04/12/user-spending-goes-up-by-more-than-4000-on-ai-powered-apps/), the security risks of using and connecting often unvetted GenAI apps to business core systems is already causing sleepless nights for security leaders. The numbers from Astrix Research provide another testament to this attack surface: 32% of GenAI apps connected to Google Workspace environments have very wide access permissions (read, write, delete).\* 


The risks of GenAI access are hitting waves industry wide. In a recent report named ["Emerging Tech: Top 4 Security Risks of GenAI](https://www.gartner.com/document/4623399?ref=solrAll&refval=379579725&)", Gartner explains the risks that come with the prevalent use of GenAI tools and technologies. According to the report, "The use of generative AI (GenAI) large language models (LLMs) and chat interfaces, especially connected to third-party solutions outside the organization firewall, represent a widening of attack surfaces and security threats to enterprises."


[![Non-Human Access](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEhUyTLyqzanzOxAjpEwR8rQFCaftewoIsMQOhEQxa07lW6jCDGpFyWgNkAs6OBQoEBVPubECm1IH9Ks8KgOTrNCWgPRf-HhfbjNDEiqfpZL0KvK2vvdDG6iojEyiklv3in_McihjltYC58J3DU7ckSPk07PhYCmrsehiOtyp1eyepGw32kkrxoZBGPLBx4/s1200/AI%20Apps.png)](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEhUyTLyqzanzOxAjpEwR8rQFCaftewoIsMQOhEQxa07lW6jCDGpFyWgNkAs6OBQoEBVPubECm1IH9Ks8KgOTrNCWgPRf-HhfbjNDEiqfpZL0KvK2vvdDG6iojEyiklv3in_McihjltYC58J3DU7ckSPk07PhYCmrsehiOtyp1eyepGw32kkrxoZBGPLBx4/s1200/AI%20Apps.png)
Security has to be an enabler[#](#security-has-to-be-an-enabler)
----------------------------------------------------------------


Since non-human access is the direct result of cloud adoption and automation - both welcomed trends contributing to growth and efficiency, security must support it. With security leaders continuously striving to be enablers rather than blockers, an approach for securing non-human identities and their access credentials is no longer an option.


Improperly secured non-human access, both external and internal, massively increases the likelihood of supply chain attacks, data breaches, and compliance violations. Security policies, as well as automatic tools to enforce them, are a must for those who look to secure this volatile attack surface while allowing the business to reap the benefits of automation and hyper-connectivity.


[Schedule a live demo of Astrix - a leader in non-human identity security](https://astrix.security/schedule-a-live-demo/?utm_source=hackernews&utm_medium=sponsored_article&utm_campaign=hackernewsarticle)


*\*According to Astrix Research data, collected from enterprise environments of organizations with 1000-10,000 employees*


  





## Tags:


### Autogenerated tags:
non-human github genai apps third-party astrix high-profile salesforce cloud google
