# Third-Party ChatGPT Plugins Could Lead to Account Takeovers
## Cybersecurity experts have uncovered new vulnerabilities in #ChatGPT's third-party plugins, posing a significant risk to user data and account.
## Information:

+ Link: https://thehackernews.com/2024/03/third-party-chatgpt-plugins-could-lead.html
+ Source: The Hacker News
+ Author: The Hacker News
+ Date published: 15 March 2024, 17:04
+ Date scraped: 15 March 2024, 12:07

## Article:
![Main article image](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEj6k8kuo0Gqkw8CCM95JlOx7P4cUnDM-SnjUyN3OrZbAkzJnr1c_CPtOMYgL3-DRUQV8PSAPZwhQaD8BW-J46-7iyoRNFxzKYemHGp2IGSGFMxBg-xIFuz93lm_ZCum55AB3rNp6Y3Fc6F_vUlBcA_ZlCmkSSzRGkQE_OCkfD7uir7giw5NjrVj4NU6gbcM/s728-rw-e365/chatgpt.jpg)


Cybersecurity researchers have found that third-party plugins available for OpenAI ChatGPT could act as a new attack surface for threat actors looking to gain unauthorized access to sensitive data.


According to [new research](https://salt.security/blog/security-flaws-within-chatgpt-extensions-allowed-access-to-accounts-on-third-party-websites-and-sensitive-data) published by Salt Labs, security flaws found directly in ChatGPT and within the ecosystem could allow attackers to install malicious plugins without users' consent and hijack accounts on third-party websites like GitHub.


[ChatGPT plugins](https://openai.com/blog/chatgpt-plugins), as the name implies, are tools designed to run on top of the large language model (LLM) with the aim of accessing up-to-date information, running computations, or accessing third-party services.


OpenAI has since also introduced [GPTs](https://openai.com/blog/introducing-gpts), which are bespoke versions of ChatGPT tailored for specific use cases, while reducing third-party service dependencies. As of March 19, 2024, ChatGPT users [will no longer](https://help.openai.com/en/articles/8988022-winding-down-the-chatgpt-plugins-beta) be able to install new plugins or create new conversations with existing plugins.


One of the flaws unearthed by Salt Labs involves exploiting the [OAuth workflow](https://thehackernews.com/2023/10/critical-oauth-flaws-uncovered-in.html) to trick a user into installing an arbitrary plugin by taking advantage of the fact that ChatGPT doesn't validate that the user indeed started the plugin installation. 


This effectively could allow threat actors to intercept and exfiltrate all data shared by the victim, which may contain proprietary information.


The cybersecurity firm also unearthed issues with [PluginLab](https://www.pluginlab.ai/) that could be weaponized by threat actors to conduct zero-click account takeover attacks, allowing them to gain control of an organization's account on third-party websites like GitHub and access their source code repositories.


"'auth.pluginlab[.]ai/oauth/authorized' does not authenticate the request, which means that the attacker can insert another memberId (aka the victim) and get a code that represents the victim," security researcher Aviad Carmel explained. "With that code, he can use ChatGPT and access the GitHub of the victim."


The memberId of the victim can be obtained by querying the endpoint "auth.pluginlab[.]ai/members/requestMagicEmailCode." There is no evidence that any user data has been compromised using the flaw.


Also discovered in several plugins, including Kesem AI, is an OAuth redirection manipulation bug that could permit an attacker to steal the account credentials associated with the plugin itself by sending a specially crafted link to the victim.


The development comes weeks after Imperva [detailed](https://www.imperva.com/blog/xss-marks-the-spot-digging-up-vulnerabilities-in-chatgpt/) two cross-site scripting (XSS) vulnerabilities in ChatGPT that could be chained to seize control of any account.


In December 2023, security researcher Johann Rehberger [demonstrated](https://thehackernews.com/2024/01/italian-data-protection-watchdog.html) how malicious actors could create [custom GPTs](https://embracethered.com/blog/posts/2023/openai-custom-malware-gpt/) that can phish for user credentials and transmit the stolen data to an external server.


### New Remote Keylogging Attack on AI Assistants[#](#new-remote-keylogging-attack-on-ai-assistants)


The findings also follow [new research](https://arstechnica.com/security/2024/03/hackers-can-read-private-ai-assistant-chats-even-though-theyre-encrypted/) published this week about an LLM side-channel attack that employs token-length as a covert means to extract encrypted responses from AI Assistants over the web.



"LLMs generate and send responses as a series of tokens (akin to words), with each token transmitted from the server to the user as it is generated," a group of academics from the Ben-Gurion University and Offensive AI Research Lab said.


"While this process is encrypted, the sequential token transmission exposes a new side-channel: the token-length side-channel. Despite encryption, the size of the packets can reveal the length of the tokens, potentially allowing attackers on the network to infer sensitive and confidential information shared in private AI assistant conversations."


This is accomplished by means of a token inference attack that's designed to decipher responses in encrypted traffic by training an LLM model capable of translating token-length sequences into their natural language sentential counterparts (i.e., plaintext).


In other words, the [core idea](https://blog.cloudflare.com/ai-side-channel-attack-mitigated/) is to intercept the real-time chat responses with an LLM provider, use the network packet headers to infer the length of each token, extract and parse text segments, and leverage the custom LLM to infer the response.


[![ChatGPT Plugins](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEhJ-WTTslYYAKdKUh3fZVjvFYQ3S9ZXA7UKeYgI9v3iocszG72TiN8jW8R7-_5OsrjMYTOZlKxVP4Vh2DQ4icgIM7InxZdeZmbEsk5kbqRq6e_MJeyPA3pETtBW1zJblzqAh5QETyAVUHzvSZZkSxFvcfgzdPdrrdYFFSphjAWNgtoDarpxxIAZskWAce7c/s728-rw-e365/llm.jpg)](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEhJ-WTTslYYAKdKUh3fZVjvFYQ3S9ZXA7UKeYgI9v3iocszG72TiN8jW8R7-_5OsrjMYTOZlKxVP4Vh2DQ4icgIM7InxZdeZmbEsk5kbqRq6e_MJeyPA3pETtBW1zJblzqAh5QETyAVUHzvSZZkSxFvcfgzdPdrrdYFFSphjAWNgtoDarpxxIAZskWAce7c/s728-rw-e365/llm.jpg)
Two key prerequisites to pulling off the attack are an AI chat client running in streaming mode and an adversary who is capable of capturing network traffic between the client and the AI chatbot.


To counteract the effectiveness of the side-channel attack, it's recommended that companies that develop AI assistants apply random padding to obscure the actual length of tokens, transmit tokens in larger groups rather than individually, and send complete responses at once, instead of in a token-by-token fashion.


"Balancing security with usability and performance presents a complex challenge that requires careful consideration," the researchers concluded.


  





## Tags:
***urls***: http://auth.pluginlab.ai/oauth/authorized http://auth.pluginlab.ai/members/requestMagicEmailCode

### Autogenerated tags:
chatgpt plugins third-party llm side-channel github plugin token-length
